package span

import (
	"strings"

	"github.com/abadojack/whatlanggo"
)

// DetectLang3 returns the best guess 3-letter language code for a given text.
func DetectLang3(text string) (string, error) {
	return whatlanggo.LangToString(whatlanggo.Detect(text).Lang), nil
}

// LanguageIdentifier returns the three letter identifier from a variety of
// language name notations. Returns the empty string, if nothing matches. All
// data from http://www-01.sil.org/iso639-3/codes.asp.
func LanguageIdentifier(s string) string {
	s = strings.TrimSpace(s)
	switch len(s) {
	case 2:
		if v, ok := ISO639OneToThree[s]; ok {
			return v
		}
	case 3:
		if v, ok := ISO639BibliographicToThree[s]; ok {
			return v
		}
	default:
		if v, ok := ISO639NameToThree[s]; ok {
			return v
		}
		if v, ok := ISO639NameToThreeLower[strings.ToLower(s)]; ok {
			return v
		}
	}
	return ""
}

// ISO639OneToThree maps 639-1 identifier (two letters) (if there is one) to a
// three-letter 639-3 identifier.
var ISO639OneToThree = map[string]string{
	// awk -F $'\t' '$4 != "" { print $4, $1 }' iso-639-3_20170202.tsv
	"aa": "aar",
	"ab": "abk",
	"ae": "ave",
	"af": "afr",
	"ak": "aka",
	"am": "amh",
	"an": "arg",
	"ar": "ara",
	"as": "asm",
	"av": "ava",
	"ay": "aym",
	"az": "aze",
	"ba": "bak",
	"be": "bel",
	"bg": "bul",
	"bi": "bis",
	"bm": "bam",
	"bn": "ben",
	"bo": "bod",
	"br": "bre",
	"bs": "bos",
	"ca": "cat",
	"ce": "che",
	"ch": "cha",
	"co": "cos",
	"cr": "cre",
	"cs": "ces",
	"cu": "chu",
	"cv": "chv",
	"cy": "cym",
	"da": "dan",
	"de": "deu",
	"dv": "div",
	"dz": "dzo",
	"ee": "ewe",
	"el": "ell",
	"en": "eng",
	"eo": "epo",
	"es": "spa",
	"et": "est",
	"eu": "eus",
	"fa": "fas",
	"ff": "ful",
	"fi": "fin",
	"fj": "fij",
	"fo": "fao",
	"fr": "fra",
	"fy": "fry",
	"ga": "gle",
	"gd": "gla",
	"gl": "glg",
	"gn": "grn",
	"gu": "guj",
	"gv": "glv",
	"ha": "hau",
	"he": "heb",
	"hi": "hin",
	"ho": "hmo",
	"hr": "hrv",
	"ht": "hat",
	"hu": "hun",
	"hy": "hye",
	"hz": "her",
	"ia": "ina",
	"id": "ind",
	"ie": "ile",
	"ig": "ibo",
	"ii": "iii",
	"ik": "ipk",
	"io": "ido",
	"is": "isl",
	"it": "ita",
	"iu": "iku",
	"ja": "jpn",
	"jv": "jav",
	"ka": "kat",
	"kg": "kon",
	"ki": "kik",
	"kj": "kua",
	"kk": "kaz",
	"kl": "kal",
	"km": "khm",
	"kn": "kan",
	"ko": "kor",
	"kr": "kau",
	"ks": "kas",
	"ku": "kur",
	"kv": "kom",
	"kw": "cor",
	"ky": "kir",
	"la": "lat",
	"lb": "ltz",
	"lg": "lug",
	"li": "lim",
	"ln": "lin",
	"lo": "lao",
	"lt": "lit",
	"lu": "lub",
	"lv": "lav",
	"mg": "mlg",
	"mh": "mah",
	"mi": "mri",
	"mk": "mkd",
	"ml": "mal",
	"mn": "mon",
	"mr": "mar",
	"ms": "msa",
	"mt": "mlt",
	"my": "mya",
	"na": "nau",
	"nb": "nob",
	"nd": "nde",
	"ne": "nep",
	"ng": "ndo",
	"nl": "nld",
	"nn": "nno",
	"no": "nor",
	"nr": "nbl",
	"nv": "nav",
	"ny": "nya",
	"oc": "oci",
	"oj": "oji",
	"om": "orm",
	"or": "ori",
	"os": "oss",
	"pa": "pan",
	"pi": "pli",
	"pl": "pol",
	"ps": "pus",
	"pt": "por",
	"qu": "que",
	"rm": "roh",
	"rn": "run",
	"ro": "ron",
	"ru": "rus",
	"rw": "kin",
	"sa": "san",
	"sc": "srd",
	"sd": "snd",
	"se": "sme",
	"sg": "sag",
	"sh": "hbs",
	"si": "sin",
	"sk": "slk",
	"sl": "slv",
	"sm": "smo",
	"sn": "sna",
	"so": "som",
	"sq": "sqi",
	"sr": "srp",
	"ss": "ssw",
	"st": "sot",
	"su": "sun",
	"sv": "swe",
	"sw": "swa",
	"ta": "tam",
	"te": "tel",
	"tg": "tgk",
	"th": "tha",
	"ti": "tir",
	"tk": "tuk",
	"tl": "tgl",
	"tn": "tsn",
	"to": "ton",
	"tr": "tur",
	"ts": "tso",
	"tt": "tat",
	"tw": "twi",
	"ty": "tah",
	"ug": "uig",
	"uk": "ukr",
	"ur": "urd",
	"uz": "uzb",
	"ve": "ven",
	"vi": "vie",
	"vo": "vol",
	"wa": "wln",
	"wo": "wol",
	"xh": "xho",
	"yi": "yid",
	"yo": "yor",
	"za": "zha",
	"zh": "zho",
	"zu": "zul",
}

// ISO639BibliographicToThree maps 639-2 identifier of the bibliographic
// applications to three-letter 639-3 identifier.
var ISO639BibliographicToThree = map[string]string{
	// awk -F $'\t' '$2 != "" && $2 != $1 { print $2, $1}' iso-639-3_20170202.tsv
	"alb": "sqi",
	"arm": "hye",
	"baq": "eus",
	"bur": "mya",
	"chi": "zho",
	"cze": "ces",
	"dut": "nld",
	"fre": "fra",
	"geo": "kat",
	"ger": "deu",
	"gre": "ell",
	"ice": "isl",
	"mac": "mkd",
	"mao": "mri",
	"may": "msa",
	"per": "fas",
	"rum": "ron",
	"slo": "slk",
	"tib": "bod",
	"wel": "cym",
}

// ISO639NameToThree maps a language name to three letter identifier.
var ISO639NameToThree = map[string]string{
	// awk -F $'\t' '$1 != "" { print "\""$7"\": \""$1"\"," }' iso-639-3_20170202.tsv
	"!Xóõ":                                "nmn",
	"'Are'are":                            "alu",
	"'Auhelawa":                           "kud",
	"//Ani":                               "hnh",
	"//Gana":                              "gnk",
	"//Xegwi":                             "xeg",
	"/Gwi":                                "gwj",
	"/Xam":                                "xam",
	"=/Hua":                               "huc",
	"A-Pucikwar":                          "apq",
	"A'ou":                                "aou",
	"Aari":                                "aiw",
	"Aasáx":                               "aas",
	"Abadi":                               "kbt",
	"Abaga":                               "abg",
	"Abai Sungai":                         "abf",
	"Abanyom":                             "abm",
	"Abar":                                "mij",
	"Abau":                                "aau",
	"Abaza":                               "abq",
	"Abé":                                 "aba",
	"Abellen Ayta":                        "abp",
	"Abidji":                              "abi",
	"Abinomn":                             "bsa",
	"Abipon":                              "axb",
	"Abishira":                            "ash",
	"Abkhazian":                           "abk",
	"Abom":                                "aob",
	"Abon":                                "abo",
	"Abron":                               "abr",
	"Abu' Arapesh":                        "aah",
	"Abu":                                 "ado",
	"Abua":                                "abn",
	"Abui":                                "abz",
	"Abun":                                "kgr",
	"Abure":                               "abu",
	"Abureni":                             "mgj",
	"Acatepec Me'phaa":                    "tpx",
	"Achagua":                             "aca",
	"Achang":                              "acn",
	"Aché":                                "guq",
	"Ache":                                "yif",
	"Acheron":                             "acz",
	"Achi":                                "acr",
	"Achinese":                            "ace",
	"Achterhoeks":                         "act",
	"Achuar-Shiwiar":                      "acu",
	"Achumawi":                            "acv",
	"Acoli":                               "ach",
	"Acroá":                               "acs",
	"Adabe":                               "adb",
	"Adai":                                "xad",
	"Adamawa Fulfulde":                    "fub",
	"Adamorobe Sign Language":             "ads",
	"Adang":                               "adn",
	"Adangbe":                             "adq",
	"Adangme":                             "ada",
	"Adara":                               "kad",
	"Adasen":                              "tiu",
	"Adele":                               "ade",
	"Adhola":                              "adh",
	"Adi":                                 "adi",
	"Adilabad Gondi":                      "wsg",
	"Adioukrou":                           "adj",
	"Adithinngithigh":                     "dth",
	"Adivasi Oriya":                       "ort",
	"Adiwasi Garasia":                     "gas",
	"Adnyamathanha":                       "adt",
	"Adonara":                             "adr",
	"Aduge":                               "adu",
	"Adyghe":                              "ady",
	"Adzera":                              "adz",
	"Aeka":                                "aez",
	"Aekyom":                              "awi",
	"Aequian":                             "xae",
	"Aer":                                 "aeq",
	"Afade":                               "aal",
	"Afar":                                "aar",
	"Afghan Sign Language":                "afg",
	"Afitti":                              "aft",
	"Afrihili":                            "afh",
	"Afrikaans":                           "afr",
	"Afro-Seminole Creole":                "afs",
	"Agarabi":                             "agd",
	"Agariya":                             "agi",
	"Agatu":                               "agc",
	"Agavotaguerra":                       "avo",
	"Aghem":                               "agq",
	"Aghu-Tharnggala":                     "gtu",
	"Aghu":                                "ahh",
	"Aghul":                               "agx",
	"Aghwan":                              "xag",
	"Agi":                                 "aif",
	"Agob":                                "kit",
	"Agoi":                                "ibm",
	"Aguacateco":                          "agu",
	"Aguano":                              "aga",
	"Aguaruna":                            "agr",
	"Aguna":                               "aug",
	"Agusan Manobo":                       "msm",
	"Agutaynen":                           "agn",
	"Agwagwune":                           "yay",
	"Àhàn":                                "ahn",
	"Ahanta":                              "aha",
	"Aheri Gondi":                         "esg",
	"Aheu":                                "thm",
	"Ahirani":                             "ahr",
	"Ahom":                                "aho",
	"Ahtena":                              "aht",
	"Ahwai":                               "nfd",
	"Ai-Cham":                             "aih",
	"Aighon":                              "aix",
	"Aikanã":                              "tba",
	"Aiklep":                              "mwg",
	"Aimaq":                               "aiq",
	"Aimele":                              "ail",
	"Aimol":                               "aim",
	"Ainbai":                              "aic",
	"Ainu (China)":                        "aib",
	"Ainu (Japan)":                        "ain",
	"Aiome":                               "aki",
	"Airoran":                             "air",
	"Aiton":                               "aio",
	"Aja (Benin)":                         "ajg",
	"Aja (Sudan)":                         "aja",
	"Ajawa":                               "ajw",
	"Ajië":                                "aji",
	"Ajumbu":                              "muc",
	"Ajyíninka Apurucayali":               "cpc",
	"Ak":                                  "akq",
	"Aka-Bea":                             "abj",
	"Aka-Bo":                              "akm",
	"Aka-Cari":                            "aci",
	"Aka-Jeru":                            "akj",
	"Aka-Kede":                            "akx",
	"Aka-Kol":                             "aky",
	"Aka-Kora":                            "ack",
	"Aka":                                 "soh",
	"Akan":                                "aka",
	"Akar-Bale":                           "acl",
	"Akaselem":                            "aks",
	"Akawaio":                             "ake",
	"Ake":                                 "aik",
	"Akebu":                               "keu",
	"Akei":                                "tsr",
	"Akeu":                                "aeu",
	"Akha":                                "ahk",
	"Akhvakh":                             "akv",
	"Akkadian":                            "akk",
	"Akkala Sami":                         "sia",
	"Aklanon":                             "akl",
	"Akolet":                              "akt",
	"Akoose":                              "bss",
	"Akoye":                               "miw",
	"Akpa":                                "akf",
	"Akpes":                               "ibe",
	"Akrukay":                             "afi",
	"Akukem":                              "spm",
	"Akuku":                               "ayk",
	"Akum":                                "aku",
	"Akuntsu":                             "aqz",
	"Akurio":                              "ako",
	"Akwa":                                "akw",
	"Akyaung Ari Naga":                    "nqy",
	"Al-Sayyid Bedouin Sign Language":     "syy",
	"Alaba-K’abeena":                      "alw",
	"Alabama":                             "akz",
	"Alabat Island Agta":                  "dul",
	"Alacatlatzala Mixtec":                "mim",
	"Alago":                               "ala",
	"Alagwa":                              "wbj",
	"Alak":                                "alk",
	"Alamblak":                            "amp",
	"Alangan":                             "alj",
	"Alanic":                              "xln",
	"Alapmunte":                           "apv",
	"Alawa":                               "alh",
	"Albanian Sign Language":              "sqk",
	"Albanian":                            "sqi",
	"Alcozauca Mixtec":                    "xta",
	"Alege":                               "alf",
	"Alekano":                             "gah",
	"Aleut":                               "ale",
	"Algerian Arabic":                     "arq",
	"Algerian Saharan Arabic":             "aao",
	"Algerian Sign Language":              "asp",
	"Algonquin":                           "alq",
	"Ali":                                 "aiy",
	"Alladian":                            "ald",
	"Allar":                               "all",
	"Alngith":                             "aid",
	"Alo Phola":                           "ypo",
	"Aloápam Zapotec":                     "zaq",
	"Alor":                                "aol",
	"Alsea":                               "aes",
	"Alu Kurumba":                         "xua",
	"Alugu":                               "aub",
	"Alumu-Tesu":                          "aab",
	"Alune":                               "alp",
	"Aluo":                                "yna",
	"Alur":                                "alz",
	"Alutor":                              "alr",
	"Alviri-Vidari":                       "avd",
	"Alyawarr":                            "aly",
	"Ama (Papua New Guinea)":              "amm",
	"Ama (Sudan)":                         "nyi",
	"Amahai":                              "amq",
	"Amahuaca":                            "amc",
	"Amaimon":                             "ali",
	"Amal":                                "aad",
	"Amanab":                              "amn",
	"Amanayé":                             "ama",
	"Amara":                               "aie",
	"Amarakaeri":                          "amr",
	"Amarasi":                             "aaz",
	"Amatlán Zapotec":                     "zpo",
	"Amba (Solomon Islands)":              "utp",
	"Amba (Uganda)":                       "rwm",
	"Ambai":                               "amk",
	"Ambakich":                            "aew",
	"Ambala Ayta":                         "abc",
	"Ambelau":                             "amv",
	"Ambele":                              "ael",
	"Amblong":                             "alm",
	"Ambo-Pasco Quechua":                  "qva",
	"Ambo":                                "amb",
	"Ambonese Malay":                      "abs",
	"Ambrak":                              "aag",
	"Ambul":                               "apo",
	"Ambulas":                             "abt",
	"Amdang":                              "amj",
	"Amdo Tibetan":                        "adx",
	"Amele":                               "aey",
	"American Sign Language":              "ase",
	"Amganad Ifugao":                      "ifa",
	"Amharic":                             "amh",
	"Ami":                                 "amy",
	"Amis":                                "ami",
	"Amo":                                 "amo",
	"Amol":                                "alx",
	"Amoltepec Mixtec":                    "mbz",
	"Ampanang":                            "apg",
	"Ampari Dogon":                        "aqd",
	"Amri Karbi":                          "ajz",
	"Amto":                                "amt",
	"Amundava":                            "adw",
	"Amurdak":                             "amg",
	"Ana Tinga Dogon":                     "dti",
	"Anaang":                              "anw",
	"Anakalangu":                          "akg",
	"Anal":                                "anm",
	"Anam":                                "pda",
	"Anambé":                              "aan",
	"Anamgura":                            "imi",
	"Anasi":                               "bpo",
	"Áncá":                                "acb",
	"Ancient Greek (to 1453)":             "grc",
	"Ancient Hebrew":                      "hbo",
	"Ancient Macedonian":                  "xmk",
	"Ancient North Arabian":               "xna",
	"Ancient Zapotec":                     "xzp",
	"Andaandi":                            "dgl",
	"Andai":                               "afd",
	"Andajin":                             "ajn",
	"Andalusian Arabic":                   "xaa",
	"Andaman Creole Hindi":                "hca",
	"Andaqui":                             "ana",
	"Andarum":                             "aod",
	"Andegerebinha":                       "adg",
	"Andh":                                "anr",
	"Andi":                                "ani",
	"Andio":                               "bzb",
	"Andoa":                               "anb",
	"Andoque":                             "ano",
	"Andra-Hus":                           "anx",
	"Aneityum":                            "aty",
	"Anem":                                "anz",
	"Aneme Wake":                          "aby",
	"Anfillo":                             "myo",
	"Angaataha":                           "agm",
	"Angaité":                             "aqt",
	"Angal Enen":                          "aoe",
	"Angal Heneng":                        "akh",
	"Angal":                               "age",
	"Angami Naga":                         "njm",
	"Angguruk Yali":                       "yli",
	"Angika":                              "anp",
	"Angkamuthi":                          "avm",
	"Anglo-Norman":                        "xno",
	"Angloromani":                         "rme",
	"Angolar":                             "aoa",
	"Angor":                               "agg",
	"Angoram":                             "aog",
	"Angosturas Tunebo":                   "tnd",
	"Anguthimri":                          "awg",
	"Ani Phowa":                           "ypn",
	"Anii":                                "blo",
	"Animere":                             "anf",
	"Anindilyakwa":                        "aoi",
	"Anjam":                               "boj",
	"Ankave":                              "aak",
	"Anmatyerre":                          "amx",
	"Anong":                               "nun",
	"Anor":                                "anj",
	"Anserma":                             "ans",
	"Ansus":                               "and",
	"Antakarinya":                         "ant",
	"Antankarana Malagasy":                "xmv",
	"Antigua and Barbuda Creole English":  "aig",
	"Anu-Hkongso Chin":                    "anl",
	"Anuak":                               "anu",
	"Anufo":                               "cko",
	"Anuki":                               "aui",
	"Anus":                                "auq",
	"Anuta":                               "aud",
	"Anyin Morofo":                        "mtb",
	"Anyin":                               "any",
	"Ao Naga":                             "njo",
	"Aoheng":                              "pni",
	"Aore":                                "aor",
	"Ap Ma":                               "kbx",
	"Apalachee":                           "xap",
	"Apalaí":                              "apy",
	"Apali":                               "ena",
	"Apasco-Apoala Mixtec":                "mip",
	"Apatani":                             "apt",
	"Apiaká":                              "api",
	"Apinayé":                             "apn",
	"Apma":                                "app",
	"Aproumu Aizi":                        "ahp",
	"Apurinã":                             "apu",
	"Aputai":                              "apx",
	"Aquitanian":                          "xaq",
	"Arabana":                             "ard",
	"Arabela":                             "arl",
	"Arabic":                              "ara",
	"Aragonese":                           "arg",
	"Araki":                               "akr",
	"Arakwal":                             "rkw",
	"Aralle-Tabulahan":                    "atq",
	"Arammba":                             "stk",
	"Aranadan":                            "aaf",
	"Aranama-Tamique":                     "xrt",
	"Arandai":                             "jbj",
	"Araona":                              "aro",
	"Arapaho":                             "arp",
	"Arapaso":                             "arj",
	"Ararandewára":                        "xaj",
	"Arawak":                              "arw",
	"Araweté":                             "awt",
	"Arawum":                              "awm",
	"Arbëreshë Albanian":                  "aae",
	"Arbore":                              "arv",
	"Archi":                               "aqc",
	"Ardhamāgadhī Prākrit":                "pka",
	"Are":                                 "mwc",
	"Areba":                               "aea",
	"Arem":                                "aem",
	"Arequipa-La Unión Quechua":           "qxu",
	"Argentine Sign Language":             "aed",
	"Argobba":                             "agj",
	"Arguni":                              "agf",
	"Arhâ":                                "aqr",
	"Arhö":                                "aok",
	"Arhuaco":                             "arh",
	"Ari":                                 "aac",
	"Aribwatsa":                           "laz",
	"Aribwaung":                           "ylu",
	"Arifama-Miniafia":                    "aai",
	"Arigidi":                             "aqg",
	"Arikapú":                             "ark",
	"Arikara":                             "ari",
	"Arikem":                              "ait",
	"Arin":                                "xrn",
	"Aringa":                              "luc",
	"Arma":                                "aoh",
	"Armazic":                             "xrm",
	"Armenian Sign Language":              "aen",
	"Armenian":                            "hye",
	"Arop-Lokep":                          "apr",
	"Arop-Sissano":                        "aps",
	"Arosi":                               "aia",
	"Arpitan":                             "frp",
	"Arritinngithigh":                     "rrt",
	"Arta":                                "atz",
	"Aruá (Amazonas State)":               "aru",
	"Aruá (Rodonia State)":                "arx",
	"Aruamu":                              "msy",
	"Aruek":                               "aur",
	"Aruop":                               "lsr",
	"Arutani":                             "atx",
	"Arvanitika Albanian":                 "aat",
	"As":                                  "asz",
	"Asaro'o":                             "mtv",
	"Asas":                                "asd",
	"Asháninka":                           "cni",
	"Ashe":                                "ahs",
	"Ashéninka Pajonal":                   "cjo",
	"Ashéninka Perené":                    "prq",
	"Ashkun":                              "ask",
	"Asho Chin":                           "csh",
	"Ashtiani":                            "atn",
	"Asilulu":                             "asl",
	"Askopan":                             "eiv",
	"Asoa":                                "asv",
	"Assamese":                            "asm",
	"Assan":                               "xss",
	"Assangori":                           "sjg",
	"Assiniboine":                         "asb",
	"Assyrian Neo-Aramaic":                "aii",
	"Asturian":                            "ast",
	"Asu (Nigeria)":                       "aum",
	"Asu (Tanzania)":                      "asa",
	"Asue Awyu":                           "psa",
	"Asumboa":                             "aua",
	"Asunción Mixtepec Zapotec":           "zoo",
	"Asuri":                               "asr",
	"Ata Manobo":                          "atd",
	"Ata":                                 "atm",
	"Atakapa":                             "aqp",
	"Atampaya":                            "amz",
	"Atatláhuca Mixtec":                   "mib",
	"Atayal":                              "tay",
	"Atemble":                             "ate",
	"Athpariya":                           "aph",
	"Ati":                                 "atk",
	"Atikamekw":                           "atj",
	"Atohwaim":                            "aqm",
	"Atong (Cameroon)":                    "ato",
	"Atong (India)":                       "aot",
	"Atorada":                             "aox",
	"Atsahuaca":                           "atc",
	"Atsam":                               "cch",
	"Atsugewi":                            "atw",
	"Attapady Kurumba":                    "pkr",
	"Attié":                               "ati",
	"Atzingo Matlatzinca":                 "ocu",
	"Au":                                  "avt",
	"Aulua":                               "aul",
	"Aurá":                                "aux",
	"Aushi":                               "auh",
	"Aushiri":                             "avs",
	"Austral":                             "aut",
	"Australian Aborigines Sign Language": "asw",
	"Australian Sign Language":            "asf",
	"Austrian Sign Language":              "asq",
	"Auwe":                                "smf",
	"Auye":                                "auu",
	"Auyokawa":                            "auo",
	"Avá-Canoeiro":                        "avv",
	"Avaric":                              "ava",
	"Avatime":                             "avn",
	"Avau":                                "avb",
	"Avestan":                             "ave",
	"Avikam":                              "avi",
	"Avokaya":                             "avu",
	"Awa (China)":                         "vwa",
	"Awa (Papua New Guinea)":              "awb",
	"Awa-Cuaiquer":                        "kwi",
	"Awabakal":                            "awk",
	"Awad Bing":                           "bcu",
	"Awadhi":                              "awa",
	"Awak":                                "awo",
	"Awar":                                "aya",
	"Awara":                               "awx",
	"Awbono":                              "awh",
	"Aweer":                               "bob",
	"Awera":                               "awr",
	"Awetí":                               "awe",
	"Awing":                               "azo",
	"Awiyaana":                            "auy",
	"Awjilah":                             "auj",
	"Awngi":                               "awn",
	"Awngthim":                            "gwm",
	"Awtuw":                               "kmn",
	"Awu":                                 "yiu",
	"Awun":                                "aww",
	"Awutu":                               "afu",
	"Awyi":                                "auw",
	"Axamb":                               "ahb",
	"Axi Yi":                              "yix",
	"Ayabadhu":                            "ayd",
	"Ayacucho Quechua":                    "quy",
	"Ayautla Mazatec":                     "vmy",
	"Ayere":                               "aye",
	"Ayerrerenge":                         "axe",
	"Ayi (Papua New Guinea)":              "ayq",
	"Ayiwo":                               "nfl",
	"Ayizi":                               "yyz",
	"Ayizo Gbe":                           "ayb",
	"Aymara":                              "aym",
	"Ayoquesco Zapotec":                   "zaf",
	"Ayoreo":                              "ayo",
	"Ayu":                                 "ayu",
	"Ayutla Mixtec":                       "miy",
	"Azerbaijani":                         "aze",
	"Azha":                                "aza",
	"Azhe":                                "yiz",
	"Azoyú Me'phaa":                       "tpc",
	"Baan":                                "bvj",
	"Baangi":                              "bqx",
	"Baatonum":                            "bba",
	"Baba Malay":                          "mbf",
	"Baba":                                "bbw",
	"Babalia Creole Arabic":               "bbz",
	"Babango":                             "bbm",
	"Babanki":                             "bbk",
	"Babatana":                            "baa",
	"Babine":                              "bcr",
	"Babuza":                              "bzg",
	"Bacama":                              "bcy",
	"Bacanese Malay":                      "btj",
	"Bactrian":                            "xbc",
	"Bada (Indonesia)":                    "bhz",
	"Bada (Nigeria)":                      "bau",
	"Badaga":                              "bfq",
	"Bade":                                "bde",
	"Badeshi":                             "bdz",
	"Bädi Kanum":                          "khd",
	"Badimaya":                            "bia",
	"Badjiri":                             "jbi",
	"Badui":                               "bac",
	"Badyara":                             "pbp",
	"Baeggu":                              "bvd",
	"Baelelea":                            "bvc",
	"Baetora":                             "btr",
	"Bafanji":                             "bfj",
	"Bafaw-Balong":                        "bwt",
	"Bafia":                               "ksf",
	"Bafut":                               "bfd",
	"Baga Kaloum":                         "bqf",
	"Baga Koga":                           "bgo",
	"Baga Manduri":                        "bmd",
	"Baga Pokur":                          "bcg",
	"Baga Sitemu":                         "bsp",
	"Baga Sobané":                         "bsv",
	"Bagheli":                             "bfy",
	"Bagirmi Fulfulde":                    "fui",
	"Bagirmi":                             "bmi",
	"Bago-Kusuntu":                        "bqg",
	"Bagri":                               "bgq",
	"Bagupi":                              "bpi",
	"Bagusa":                              "bqb",
	"Bagvalal":                            "kva",
	"Baha Buyang":                         "yha",
	"Baham":                               "bdw",
	"Bahamas Creole English":              "bah",
	"Baharna Arabic":                      "abv",
	"Bahau":                               "bhv",
	"Bahinemo":                            "bjh",
	"Bahing":                              "bhj",
	"Bahnar":                              "bdq",
	"Bahonsuai":                           "bsu",
	"Bai":                                 "bdj",
	"Baibai":                              "bbf",
	"Baikeno":                             "bkx",
	"Baima":                               "bqh",
	"Baimak":                              "bmx",
	"Bainouk-Gunyaamolo":                  "bcz",
	"Bainouk-Gunyuño":                     "bab",
	"Bainouk-Samik":                       "bcb",
	"Baiso":                               "bsw",
	"Baissa Fali":                         "fah",
	"Bajan":                               "bjs",
	"Bajelani":                            "bjm",
	"Baka (Cameroon)":                     "bkc",
	"Baka (Sudan)":                        "bdh",
	"Bakairí":                             "bkq",
	"Bakaka":                              "bqz",
	"Bakhtiari":                           "bqi",
	"Baki":                                "bki",
	"Bakoko":                              "bkh",
	"Bakole":                              "kme",
	"Bakpinka":                            "bbs",
	"Bakumpai":                            "bkr",
	"Bakwé":                               "bjw",
	"Balaesang":                           "bls",
	"Balangao":                            "blw",
	"Balangingi":                          "sse",
	"Balanta-Ganja":                       "bjt",
	"Balanta-Kentohe":                     "ble",
	"Balantak":                            "blz",
	"Balau":                               "blg",
	"Baldemu":                             "bdn",
	"Bali (Democratic Republic of Congo)": "bcp",
	"Bali (Nigeria)":                      "bcn",
	"Balinese Malay":                      "mhp",
	"Balinese":                            "ban",
	"Balkan Gagauz Turkish":               "bgx",
	"Balkan Romani":                       "rmn",
	"Balo":                                "bqo",
	"Baloi":                               "biz",
	"Balti":                               "bft",
	"Baltic Romani":                       "rml",
	"Baluan-Pam":                          "blq",
	"Baluchi":                             "bal",
	"Bamako Sign Language":                "bog",
	"Bamali":                              "bbq",
	"Bambalang":                           "bmo",
	"Bambam":                              "ptu",
	"Bambara":                             "bam",
	"Bambassi":                            "myf",
	"Bambili-Bambui":                      "baw",
	"Bamenyam":                            "bce",
	"Bamu":                                "bcf",
	"Bamukumbit":                          "bqt",
	"Bamun":                               "bax",
	"Bamunka":                             "bvm",
	"Bamwe":                               "bmg",
	"Ban Khor Sign Language":              "bfk",
	"Bana":                                "bcw",
	"Banao Itneg":                         "bjx",
	"Banaro":                              "byz",
	"Banda (Indonesia)":                   "bnd",
	"Banda Malay":                         "bpq",
	"Banda-Bambari":                       "liy",
	"Banda-Banda":                         "bpd",
	"Banda-Mbrès":                         "bqk",
	"Banda-Ndélé":                         "bfl",
	"Banda-Yangere":                       "yaj",
	"Bandi":                               "bza",
	"Bandial":                             "bqj",
	"Bandjalang":                          "bdy",
	"Bangala":                             "bxg",
	"Bangandu":                            "bgf",
	"Bangba":                              "bbe",
	"Banggai":                             "bgz",
	"Banggarla":                           "bjb",
	"Bangi":                               "bni",
	"Bangime":                             "dba",
	"Bangka":                              "mfb",
	"Bangolan":                            "bgj",
	"Bangubangu":                          "bnx",
	"Bangwinji":                           "bsj",
	"Baniva":                              "bvv",
	"Baniwa":                              "bwi",
	"Banjar":                              "bjn",
	"Bankagooma":                          "bxw",
	"Bankal":                              "jjr",
	"Bankan Tey Dogon":                    "dbw",
	"Bankon":                              "abb",
	"Bannoni":                             "bcm",
	"Bantawa":                             "bap",
	"Bantayanon":                          "bfx",
	"Bantik":                              "bnq",
	"Bantoanon":                           "bno",
	"Baoulé":                              "bci",
	"Bara Malagasy":                       "bhr",
	"Baraamu":                             "brd",
	"Barababaraba":                        "rbp",
	"Barai":                               "bbb",
	"Barakai":                             "baj",
	"Baram Kayan":                         "kys",
	"Barama":                              "bbg",
	"Barambu":                             "brm",
	"Baramu":                              "bmz",
	"Barapasi":                            "brp",
	"Baras":                               "brs",
	"Barasana-Eduria":                     "bsn",
	"Barbacoas":                           "bpb",
	"Barbaram":                            "vmb",
	"Barbareño":                           "boi",
	"Barclayville Grebo":                  "gry",
	"Bardi":                               "bcj",
	"Baré":                                "bae",
	"Barein":                              "bva",
	"Bargam":                              "mlp",
	"Barí":                                "mot",
	"Bari":                                "bfa",
	"Bariai":                              "bch",
	"Bariji":                              "bjc",
	"Barikanchi":                          "bxo",
	"Barikewa":                            "jbk",
	"Barok":                               "bjk",
	"Barombi":                             "bbi",
	"Barro Negro Tunebo":                  "tbn",
	"Barrow Point":                        "bpt",
	"Baruga":                              "bjz",
	"Baruya":                              "byr",
	"Barwe":                               "bwg",
	"Barzani Jewish Neo-Aramaic":          "bjf",
	"Basa (Cameroon)":                     "bas",
	"Basa (Nigeria)":                      "bzw",
	"Basa-Gumna":                          "bsl",
	"Basa-Gurmana":                        "buj",
	"Basap":                               "bdb",
	"Basay":                               "byq",
	"Bashkardi":                           "bsg",
	"Bashkir":                             "bak",
	"Basketo":                             "bst",
	"Basque":                              "eus",
	"Bassa-Kontagora":                     "bsr",
	"Bassa":                               "bsq",
	"Bassari":                             "bsc",
	"Bassossi":                            "bsi",
	"Bata":                                "bta",
	"Batad Ifugao":                        "ifb",
	"Batak Alas-Kluet":                    "btz",
	"Batak Angkola":                       "akb",
	"Batak Dairi":                         "btd",
	"Batak Karo":                          "btx",
	"Batak Mandailing":                    "btm",
	"Batak Simalungun":                    "bts",
	"Batak Toba":                          "bbc",
	"Batak":                               "bya",
	"Batanga":                             "bnm",
	"Batek":                               "btq",
	"Bateri":                              "btv",
	"Bathari":                             "bhm",
	"Bati (Cameroon)":                     "btc",
	"Bati (Indonesia)":                    "bvt",
	"Bats":                                "bbl",
	"Batu":                                "btu",
	"Batui":                               "zbt",
	"Batuley":                             "bay",
	"Batyala":                             "xby",
	"Bau Bidayuh":                         "sne",
	"Bau":                                 "bbd",
	"Bauchi":                              "bsf",
	"Baure":                               "brg",
	"Bauria":                              "bge",
	"Bauwaki":                             "bwk",
	"Bauzi":                               "bvz",
	"Bavarian":                            "bar",
	"Bawm Chin":                           "bgr",
	"Bay Miwok":                           "mkq",
	"Bayali":                              "bjy",
	"Baybayanon":                          "bvy",
	"Baygo":                               "byg",
	"Bayono":                              "byl",
	"Bayot":                               "bda",
	"Bayungu":                             "bxj",
	"Bazigar":                             "bfr",
	"Beami":                               "beo",
	"Beaver":                              "bea",
	"Beba":                                "bfp",
	"Bebele":                              "beb",
	"Bebeli":                              "bek",
	"Bebil":                               "bxp",
	"Bedjond":                             "bjv",
	"Bedoanas":                            "bed",
	"Beeke":                               "bkf",
	"Beele":                               "bxq",
	"Beembe":                              "beq",
	"Beezen":                              "bnz",
	"Befang":                              "bby",
	"Beja":                                "bej",
	"Bekati'":                             "bei",
	"Bekwarra":                            "bkv",
	"Bekwel":                              "bkw",
	"Belait":                              "beg",
	"Belanda Bor":                         "bxb",
	"Belanda Viri":                        "bvi",
	"Belarusian":                          "bel",
	"Belhariya":                           "byw",
	"Beli (Papua New Guinea)":             "bey",
	"Beli (Sudan)":                        "blm",
	"Belize Kriol English":                "bzj",
	"Bella Coola":                         "blc",
	"Bellari":                             "brw",
	"Bemba (Zambia)":                      "bem",
	"Bembe":                               "bmb",
	"Ben Tey Dogon":                       "dbt",
	"Bena (Nigeria)":                      "yun",
	"Bena (Tanzania)":                     "bez",
	"Benabena":                            "bef",
	"Bench":                               "bcq",
	"Bende":                               "bdp",
	"Bendi":                               "bct",
	"Beng":                                "nhb",
	"Benga":                               "bng",
	"Bengali":                             "ben",
	"Benggoi":                             "bgy",
	"Bengkala Sign Language":              "bqy",
	"Bentong":                             "bnu",
	"Benyadu'":                            "byd",
	"Beothuk":                             "bue",
	"Bepour":                              "bie",
	"Bera":                                "brf",
	"Berakou":                             "bxv",
	"Berau Malay":                         "bve",
	"Berbice Creole Dutch":                "brc",
	"Berik":                               "bkl",
	"Berinomo":                            "bit",
	"Berom":                               "bom",
	"Berta":                               "wti",
	"Berti":                               "byt",
	"Besisi":                              "mhe",
	"Besme":                               "bes",
	"Besoa":                               "bep",
	"Betaf":                               "bfe",
	"Betawi":                              "bew",
	"Bete-Bendi":                          "btt",
	"Bete":                                "byf",
	"Beti (Côte d'Ivoire)":                "eot",
	"Betta Kurumba":                       "xub",
	"Bezhta":                              "kap",
	"Bhadrawahi":                          "bhd",
	"Bhalay":                              "bhx",
	"Bharia":                              "bha",
	"Bhatri":                              "bgw",
	"Bhattiyali":                          "bht",
	"Bhaya":                               "bhe",
	"Bhele":                               "bhy",
	"Bhilali":                             "bhi",
	"Bhili":                               "bhb",
	"Bhojpuri":                            "bho",
	"Bhoti Kinnauri":                      "nes",
	"Bhujel":                              "byh",
	"Bhunjia":                             "bhu",
	"Biafada":                             "bif",
	"Biage":                               "bdf",
	"Biak":                                "bhw",
	"Biali":                               "beh",
	"Bian Marind":                         "bpv",
	"Biangai":                             "big",
	"Biao Mon":                            "bmt",
	"Biao-Jiao Mien":                      "bje",
	"Biao":                                "byk",
	"Biatah Bidayuh":                      "bth",
	"Bibbulman":                           "xbp",
	"Bidhawal":                            "ihw",
	"Bidiyo":                              "bid",
	"Bidyara":                             "bym",
	"Bidyogo":                             "bjg",
	"Biem":                                "bmc",
	"Bierebo":                             "bnk",
	"Bieria":                              "brj",
	"Biete":                               "biu",
	"Big Nambas":                          "nmb",
	"Biga":                                "bhc",
	"Bigambal":                            "xbe",
	"Bih":                                 "ibh",
	"Bijori":                              "bix",
	"Bikaru":                              "bic",
	"Bikol":                               "bik",
	"Bikya":                               "byb",
	"Bila":                                "bip",
	"Bilakura":                            "bql",
	"Bilaspuri":                           "kfs",
	"Bilba":                               "bpz",
	"Bilbil":                              "brz",
	"Bile":                                "bil",
	"Bilin":                               "byn",
	"Bilma Kanuri":                        "bms",
	"Biloxi":                              "bll",
	"Bilua":                               "blb",
	"Bilur":                               "bxf",
	"Bima":                                "bhp",
	"Bimin":                               "bhl",
	"Bimoba":                              "bim",
	"Bina (Nigeria)":                      "byj",
	"Bina (Papua New Guinea)":             "bmn",
	"Binahari":                            "bxz",
	"Binandere":                           "bhg",
	"Bindal":                              "xbd",
	"Bine":                                "bon",
	"Bini":                                "bin",
	"Binji":                               "bpj",
	"Binongan Itneg":                      "itb",
	"Bintauna":                            "bne",
	"Bintulu":                             "bny",
	"Binukid":                             "bkd",
	"Binumarien":                          "bjr",
	"Bipi":                                "biq",
	"Birale":                              "bxe",
	"Birao":                               "brr",
	"Birgit":                              "btf",
	"Birhor":                              "biy",
	"Biri":                                "bzr",
	"Biritai":                             "bqq",
	"Birked":                              "brk",
	"Birri":                               "bvq",
	"Birrpayi":                            "xbj",
	"Birwa":                               "brl",
	"Biseni":                              "ije",
	"Bishnupriya":                         "bpy",
	"Bishuo":                              "bwh",
	"Bisis":                               "bnw",
	"Bislama":                             "bis",
	"Bisorio":                             "bir",
	"Bissa":                               "bib",
	"Bisu":                                "bzi",
	"Bit":                                 "bgk",
	"Bitare":                              "brt",
	"Bitur":                               "mcc",
	"Biwat":                               "bwm",
	"Biyo":                                "byo",
	"Biyom":                               "bpm",
	"Blablanga":                           "blp",
	"Blafe":                               "bfh",
	"Blagar":                              "beu",
	"Blang":                               "blr",
	"Blissymbols":                         "zbl",
	"Bo (Laos)":                           "bgl",
	"Bo (Papua New Guinea)":               "bpw",
	"Bo-Rukul":                            "mae",
	"Bo-Ung":                              "mux",
	"Boano (Maluku)":                      "bzn",
	"Boano (Sulawesi)":                    "bzl",
	"Bobongko":                            "bgb",
	"Bobot":                               "bty",
	"Bodo (Central African Republic)":     "boy",
	"Bodo (India)":                        "brx",
	"Bodo Gadaba":                         "gbj",
	"Bodo Parja":                          "bdv",
	"Bofi":                                "bff",
	"Boga":                                "bvw",
	"Bogaya":                              "boq",
	"Boghom":                              "bux",
	"Boguru":                              "bqu",
	"Bohtan Neo-Aramaic":                  "bhn",
	"Boikin":                              "bzf",
	"Bokha":                               "ybk",
	"Boko (Benin)":                        "bqc",
	"Boko (Democratic Republic of Congo)": "bkp",
	"Bokobaru":                            "bus",
	"Bokoto":                              "bdt",
	"Bokyi":                               "bky",
	"Bola":                                "bnp",
	"Bolango":                             "bld",
	"Bole":                                "bol",
	"Bolgarian":                           "xbo",
	"Bolgo":                               "bvo",
	"Bolia":                               "bli",
	"Bolinao":                             "smk",
	"Bolivian Sign Language":              "bvl",
	"Boloki":                              "bkt",
	"Bolon":                               "bof",
	"Bolondo":                             "bzm",
	"Bolongan":                            "blj",
	"Bolyu":                               "ply",
	"Bom-Kim":                             "bmf",
	"Boma":                                "boh",
	"Bomboli":                             "bml",
	"Bomboma":                             "bws",
	"Bomitaba":                            "zmx",
	"Bomu":                                "bmq",
	"Bomwali":                             "bmw",
	"Bon Gula":                            "glc",
	"Bonan":                               "peh",
	"Bondei":                              "bou",
	"Bondo":                               "bfw",
	"Bondoukou Kulango":                   "kzc",
	"Bondum Dom Dogon":                    "dbu",
	"Bonerate":                            "bna",
	"Bonerif":                             "bnv",
	"Bonggi":                              "bdg",
	"Bonggo":                              "bpg",
	"Bongili":                             "bui",
	"Bongo":                               "bot",
	"Bongu":                               "bpu",
	"Bonjo":                               "bok",
	"Bonkeng":                             "bvg",
	"Bonkiman":                            "bop",
	"Bontok":                              "bnc",
	"Bookan":                              "bnb",
	"Boon":                                "bnl",
	"Boor":                                "bvf",
	"Bora":                                "boa",
	"Borana-Arsi-Guji Oromo":              "gax",
	"Border Kuna":                         "kvn",
	"Borei":                               "gai",
	"Borgu Fulfulde":                      "fue",
	"Boro (Ethiopia)":                     "bwo",
	"Boro (Ghana)":                        "xxb",
	"Borong":                              "ksr",
	"Borôro":                              "bor",
	"Boruca":                              "brn",
	"Boselewa":                            "bwf",
	"Bosngun":                             "bqs",
	"Bosnian":                             "bos",
	"Bote-Majhi":                          "bmj",
	"Botlikh":                             "bph",
	"Botolan Sambal":                      "sbl",
	"Bouna Kulango":                       "nku",
	"Bouyei":                              "pcc",
	"Bozaba":                              "bzo",
	"Bragat":                              "aof",
	"Brahui":                              "brh",
	"Braj":                                "bra",
	"Brazilian Sign Language":             "bzs",
	"Brem":                                "buq",
	"Breri":                               "brq",
	"Breton":                              "bre",
	"Bribri":                              "bzd",
	"Brithenig":                           "bzt",
	"British Sign Language":               "bfi",
	"Brokkat":                             "bro",
	"Brokpake":                            "sgt",
	"Brokskat":                            "bkk",
	"Brooke's Point Palawano":             "plw",
	"Broome Pearling Lugger Pidgin":       "bpl",
	"Brunei Bisaya":                       "bsb",
	"Brunei":                              "kxd",
	"Bu-Nao Bunu":                         "bwx",
	"Bu":                                  "jid",
	"Bua":                                 "bub",
	"Bualkhaw Chin":                       "cbl",
	"Buamu":                               "box",
	"Bube":                                "bvb",
	"Bubi":                                "buw",
	"Bubia":                               "bbx",
	"Budeh Stieng":                        "stt",
	"Budibud":                             "btp",
	"Budong-Budong":                       "bdx",
	"Budu":                                "buu",
	"Budukh":                              "bdk",
	"Buduma":                              "bdm",
	"Budza":                               "bja",
	"Bugan":                               "bbh",
	"Bugawac":                             "buk",
	"Bughotu":                             "bgt",
	"Buginese":                            "bug",
	"Buglere":                             "sab",
	"Bugun":                               "bgg",
	"Buhi'non Bikol":                      "ubl",
	"Buhid":                               "bku",
	"Buhutu":                              "bxh",
	"Bukar-Sadung Bidayuh":                "sdo",
	"Bukat":                               "bvk",
	"Bukharic":                            "bhh",
	"Bukit Malay":                         "bvu",
	"Bukitan":                             "bkn",
	"Bukiyip":                             "ape",
	"Buksa":                               "tkb",
	"Bukusu":                              "bxk",
	"Bukwen":                              "buz",
	"Bulgarian Sign Language":             "bqn",
	"Bulgarian":                           "bul",
	"Bulgebi":                             "bmp",
	"Buli (Ghana)":                        "bwu",
	"Buli (Indonesia)":                    "bzq",
	"Bullom So":                           "buy",
	"Bulo Stieng":                         "sti",
	"Bulu (Cameroon)":                     "bum",
	"Bulu (Papua New Guinea)":             "bjl",
	"Bum":                                 "bmv",
	"Bumaji":                              "byp",
	"Bumang":                              "bvp",
	"Bumbita Arapesh":                     "aon",
	"Bumthangkha":                         "kjz",
	"Bun":                                 "buv",
	"Buna":                                "bvn",
	"Bunaba":                              "bck",
	"Bunak":                               "bfn",
	"Bunama":                              "bdd",
	"Bundeli":                             "bns",
	"Bung":                                "bqd",
	"Bungain":                             "but",
	"Bunganditj":                          "xbg",
	"Bungku":                              "bkz",
	"Bungu":                               "wun",
	"Bunoge Dogon":                        "dgb",
	"Bunun":                               "bnn",
	"Buol":                                "blf",
	"Bura-Pabir":                          "bwr",
	"Burak":                               "bys",
	"Buraka":                              "bkg",
	"Burarra":                             "bvr",
	"Burate":                              "bti",
	"Burduna":                             "bxn",
	"Bure":                                "bvh",
	"Buriat":                              "bua",
	"Burji":                               "bji",
	"Burmbar":                             "vrt",
	"Burmese":                             "mya",
	"Burmeso":                             "bzu",
	"Buru (Indonesia)":                    "mhs",
	"Buru (Nigeria)":                      "bqw",
	"Burui":                               "bry",
	"Burumakok":                           "aip",
	"Burun":                               "bdi",
	"Burunge":                             "bds",
	"Burushaski":                          "bsk",
	"Burusu":                              "bqr",
	"Buruwai":                             "asi",
	"Busa":                                "bqp",
	"Busam":                               "bxs",
	"Busami":                              "bsm",
	"Busang Kayan":                        "bfg",
	"Bushi":                               "buc",
	"Bushoong":                            "buf",
	"Buso":                                "bso",
	"Busoa":                               "bup",
	"Bussa":                               "dox",
	"Busuu":                               "bju",
	"Butbut Kalinga":                      "kyb",
	"Butmas-Tur":                          "bnr",
	"Butuanon":                            "btw",
	"Buwal":                               "bhs",
	"Buyu":                                "byi",
	"Buyuan Jinuo":                        "jiy",
	"Bwa":                                 "bww",
	"Bwaidoka":                            "bwd",
	"Bwanabwana":                          "tte",
	"Bwatoo":                              "bwa",
	"Bwe Karen":                           "bwe",
	"Bwela":                               "bwl",
	"Bwile":                               "bwc",
	"Bwisi":                               "bwz",
	"Byangsi":                             "bee",
	"Byep":                                "mkk",
	"C'Lela":                              "dri",
	"Caac":                                "msq",
	"Cabécar":                             "cjp",
	"Cabiyarí":                            "cbb",
	"Cacaloxtepec Mixtec":                 "miu",
	"Cacaopera":                           "ccr",
	"Cacgia Roglai":                       "roc",
	"Cacua":                               "cbv",
	"Caddo":                               "cad",
	"Cafundo Creole":                      "ccd",
	"Cahuarano":                           "cah",
	"Cahuilla":                            "chl",
	"Ca̱hungwa̱rya̱":                      "nat",
	"Cajamarca Quechua":                   "qvc",
	"Cajatambo North Lima Quechua":        "qvl",
	"Cajonos Zapotec":                     "zad",
	"Cajun French":                        "frc",
	"Caka":                                "ckx",
	"Cakchiquel-Quiché Mixed Language":    "ckz",
	"Cakfem-Mushere":                      "cky",
	"Calamian Tagbanwa":                   "tbk",
	"Calderón Highland Quichua":           "qud",
	"Callawalla":                          "caw",
	"Caló":                                "rmq",
	"Caluyanun":                           "clu",
	"Cameroon Mambila":                    "mcu",
	"Cameroon Pidgin":                     "wes",
	"Camling":                             "rab",
	"Campalagian":                         "cml",
	"Campidanese Sardinian":               "sro",
	"Camsá":                               "kbh",
	"Camtho":                              "cmt",
	"Camunic":                             "xcc",
	"Cañar Highland Quichua":              "qxr",
	"Candoshi-Shapra":                     "cbu",
	"Canela":                              "ram",
	"Canichana":                           "caz",
	"Cao Lan":                             "mlc",
	"Cao Miao":                            "cov",
	"Capanahua":                           "kaq",
	"Capiznon":                            "cps",
	"Cappadocian Greek":                   "cpg",
	"Caquinte":                            "cot",
	"Car Nicobarese":                      "caq",
	"Cara":                                "cfd",
	"Carabayo":                            "cby",
	"Caramanta":                           "crf",
	"Carapana":                            "cbc",
	"Carian":                              "xcr",
	"Caribbean Hindustani":                "hns",
	"Caribbean Javanese":                  "jvn",
	"Carijona":                            "cbd",
	"Carolina Algonquian":                 "crr",
	"Carolinian":                          "cal",
	"Carpathian Romani":                   "rmc",
	"Carrier":                             "crx",
	"Cashibo-Cacataibo":                   "cbr",
	"Cashinahua":                          "cbs",
	"Casiguran Dumagat Agta":              "dgc",
	"Casuarina Coast Asmat":               "asc",
	"Catalan Sign Language":               "csc",
	"Catalan":                             "cat",
	"Catawba":                             "chc",
	"Cauca":                               "cca",
	"Cavineña":                            "cav",
	"Cayubaba":                            "cyb",
	"Cayuga":                              "cay",
	"Cayuse":                              "xcy",
	"Cebaara Senoufo":                     "sef",
	"Cebuano":                             "ceb",
	"Celtiberian":                         "xce",
	"Cemuhî":                              "cam",
	"Cen":                                 "cen",
	"Central Asmat":                       "cns",
	"Central Atlas Tamazight":             "tzm",
	"Central Awyu":                        "awu",
	"Central Aymara":                      "ayr",
	"Central Bai":                         "bca",
	"Central Berawan":                     "zbc",
	"Central Bikol":                       "bcl",
	"Central Bontok":                      "lbk",
	"Central Cagayan Agta":                "agt",
	"Central Grebo":                       "grv",
	"Central Hongshuihe Zhuang":           "zch",
	"Central Huasteca Nahuatl":            "nch",
	"Central Huishui Hmong":               "hmc",
	"Central Kanuri":                      "knc",
	"Central Khmer":                       "khm",
	"Central Kurdish":                     "ckb",
	"Central Maewo":                       "mwo",
	"Central Malay":                       "pse",
	"Central Masela":                      "mxz",
	"Central Mashan Hmong":                "hmm",
	"Central Mazahua":                     "maz",
	"Central Melanau":                     "mel",
	"Central Mnong":                       "cmo",
	"Central Nahuatl":                     "nhn",
	"Central Nicobarese":                  "ncb",
	"Central Ojibwa":                      "ojc",
	"Central Okinawan":                    "ryu",
	"Central Palawano":                    "plc",
	"Central Pame":                        "pbs",
	"Central Pashto":                      "pst",
	"Central Pomo":                        "poo",
	"Central Puebla Nahuatl":              "ncx",
	"Central Sama":                        "sml",
	"Central Siberian Yupik":              "ess",
	"Central Sierra Miwok":                "csm",
	"Central Subanen":                     "syb",
	"Central Tagbanwa":                    "tgt",
	"Central Tarahumara":                  "tar",
	"Central Tunebo":                      "tuf",
	"Central Yupik":                       "esu",
	"Central-Eastern Niger Fulfulde":      "fuq",
	"Centúúm":                             "cet",
	"Cerma":                               "cme",
	"Chabu":                               "sbf",
	"Chachapoyas Quechua":                 "quk",
	"Chachi":                              "cbi",
	"Chácobo":                             "cao",
	"Chadian Arabic":                      "shu",
	"Chadian Sign Language":               "cds",
	"Chadong":                             "cdy",
	"Chagatai":                            "chg",
	"Chaima":                              "ciy",
	"Chak":                                "ckh",
	"Chakali":                             "cli",
	"Chakma":                              "ccp",
	"Chala":                               "cll",
	"Chaldean Neo-Aramaic":                "cld",
	"Chalikha":                            "tgf",
	"Chamacoco":                           "ceg",
	"Chamalal":                            "cji",
	"Chamari":                             "cdg",
	"Chambeali":                           "cdh",
	"Chambri":                             "can",
	"Chamicuro":                           "ccc",
	"Chamorro":                            "cha",
	"Chané":                               "caj",
	"Chang Naga":                          "nbc",
	"Changriwa":                           "cga",
	"Changthang":                          "cna",
	"Chantyal":                            "chx",
	"Chara":                               "cra",
	"Chaudangsi":                          "cdn",
	"Chaura":                              "crv",
	"Chavacano":                           "cbk",
	"Chayahuita":                          "cbt",
	"Chayuco Mixtec":                      "mih",
	"Chazumba Mixtec":                     "xtb",
	"Che":                                 "ruk",
	"Chechen":                             "che",
	"Cheke Holo":                          "mrn",
	"Chemakum":                            "xch",
	"Chenapian":                           "cjn",
	"Chenchu":                             "cde",
	"Chenoua":                             "cnu",
	"Chepang":                             "cdm",
	"Chepya":                              "ycp",
	"Cherepon":                            "cpn",
	"Cherokee":                            "chr",
	"Chesu":                               "ych",
	"Chetco":                              "ctc",
	"Chewong":                             "cwg",
	"Cheyenne":                            "chy",
	"Chhattisgarhi":                       "hne",
	"Chhintange":                          "ctn",
	"Chhulung":                            "cur",
	"Chiangmai Sign Language":             "csd",
	"Chiapanec":                           "cip",
	"Chibcha":                             "chb",
	"Chicahuaxtla Triqui":                 "trs",
	"Chichicapan Zapotec":                 "zpv",
	"Chichimeca-Jonaz":                    "pei",
	"Chickasaw":                           "cic",
	"Chicomuceltec":                       "cob",
	"Chiga":                               "cgg",
	"Chigmecatitlán Mixtec":               "mii",
	"Chilcotin":                           "clc",
	"Chilean Sign Language":               "csg",
	"Chilisso":                            "clh",
	"Chiltepec Chinantec":                 "csa",
	"Chimalapa Zoque":                     "zoh",
	"Chimariko":                           "cid",
	"Chimborazo Highland Quichua":         "qug",
	"Chimila":                             "cbg",
	"China Buriat":                        "bxu",
	"Chinali":                             "cih",
	"Chinbon Chin":                        "cnb",
	"Chincha Quechua":                     "qxc",
	"Chinese Pidgin English":              "cpi",
	"Chinese Sign Language":               "csl",
	"Chinese":                             "zho",
	"Chinook jargon":                      "chn",
	"Chinook":                             "chh",
	"Chipaya":                             "cap",
	"Chipewyan":                           "chp",
	"Chippewa":                            "ciw",
	"Chiquián Ancash Quechua":             "qxa",
	"Chiquihuitlán Mazatec":               "maq",
	"Chiquitano":                          "cax",
	"Chiripá":                             "nhd",
	"Chiru":                               "cdf",
	"Chitimacha":                          "ctm",
	"Chitkuli Kinnauri":                   "cik",
	"Chittagonian":                        "ctg",
	"Chitwania Tharu":                     "the",
	"Choapan Zapotec":                     "zpc",
	"Chocangacakha":                       "cgk",
	"Chochotec":                           "coz",
	"Choctaw":                             "cho",
	"Chodri":                              "cdi",
	"Chokri Naga":                         "nri",
	"Chokwe":                              "cjk",
	"Chol":                                "ctu",
	"Cholón":                              "cht",
	"Chong":                               "cog",
	"Choni":                               "cda",
	"Chonyi-Dzihana-Kauma":                "coh",
	"Chopi":                               "cce",
	"Chorasmian":                          "xco",
	"Chortí":                              "caa",
	"Chothe Naga":                         "nct",
	"Chrau":                               "crw",
	"Chru":                                "cje",
	"Chuanqiandian Cluster Miao":          "cqd",
	"Chuave":                              "cjv",
	"Chug":                                "cvg",
	"Chuj":                                "cac",
	"Chuka":                               "cuh",
	"Chukot":                              "ckt",
	"Chukwa":                              "cuw",
	"Chulym":                              "clw",
	"Chumburung":                          "ncu",
	"Chungmboko":                          "cug",
	"Churahi":                             "cdj",
	"Church Slavic":                       "chu",
	"Chut":                                "scb",
	"Chuukese":                            "chk",
	"Chuvantsy":                           "xcv",
	"Chuvash":                             "chv",
	"Chuwabu":                             "chw",
	"Ci Gbe":                              "cib",
	"Cia-Cia":                             "cia",
	"Cibak":                               "ckl",
	"Cicipu":                              "awc",
	"Cimbrian":                            "cim",
	"Cinda-Regi-Tiyal":                    "cdr",
	"Cineni":                              "cie",
	"Cinta Larga":                         "cin",
	"Cisalpine Gaulish":                   "xcg",
	"Cishingini":                          "asg",
	"Citak":                               "txt",
	"Ciwogai":                             "tgd",
	"Clallam":                             "clm",
	"Classical Armenian":                  "xcl",
	"Classical Mandaic":                   "myz",
	"Classical Mongolian":                 "cmg",
	"Classical Nahuatl":                   "nci",
	"Classical Newari":                    "nwc",
	"Classical Quechua":                   "qwc",
	"Classical Syriac":                    "syc",
	"Classical Tibetan":                   "xct",
	"Coahuilteco":                         "xcw",
	"Coast Miwok":                         "csi",
	"Coastal Konjo":                       "kjc",
	"Coatecas Altas Zapotec":              "zca",
	"Coatepec Nahuatl":                    "naz",
	"Coatlán Mixe":                        "mco",
	"Coatlán Zapotec":                     "zps",
	"Coatzospan Mixtec":                   "miz",
	"Cocama-Cocamilla":                    "cod",
	"Cochimi":                             "coj",
	"Cocopa":                              "coc",
	"Cocos Islands Malay":                 "coa",
	"Coeur d'Alene":                       "crd",
	"Cofán":                               "con",
	"Cogui":                               "kog",
	"Col":                                 "liw",
	"Colombian Sign Language":             "csn",
	"Colonia Tovar German":                "gct",
	"Colorado":                            "cof",
	"Columbia-Wenatchi":                   "col",
	"Comaltepec Chinantec":                "cco",
	"Comanche":                            "com",
	"Comecrudo":                           "xcm",
	"Como Karim":                          "cfg",
	"Comox":                               "coo",
	"Con":                                 "cno",
	"Congo Swahili":                       "swc",
	"Côông":                               "cnc",
	"Coos":                                "csz",
	"Copainalá Zoque":                     "zoc",
	"Copala Triqui":                       "trc",
	"Coptic":                              "cop",
	"Coquille":                            "coq",
	"Cori":                                "cry",
	"Cornish":                             "cor",
	"Corongo Ancash Quechua":              "qwa",
	"Corsican":                            "cos",
	"Costa Rican Sign Language":           "csr",
	"Cotabato Manobo":                     "mta",
	"Cotoname":                            "xcn",
	"Cowlitz":                             "cow",
	"Coyotepec Popoloca":                  "pbf",
	"Coyutla Totonac":                     "toc",
	"Cree":                                "cre",
	"Creek":                               "mus",
	"Crimean Tatar":                       "crh",
	"Croatia Sign Language":               "csq",
	"Croatian":                            "hrv",
	"Cross River Mbembe":                  "mfn",
	"Crow":                                "cro",
	"Cruzeño":                             "crz",
	"Cua":                                 "cua",
	"Cuba Sign Language":                  "csf",
	"Cubeo":                               "cub",
	"Cuiba":                               "cui",
	"Culina":                              "cul",
	"Cumanagoto":                          "cuo",
	"Cumbric":                             "xcb",
	"Cun":                                 "cuq",
	"Cuneiform Luwian":                    "xlu",
	"Cupeño":                              "cup",
	"Curonian":                            "xcu",
	"Curripaco":                           "kpc",
	"Cusco Quechua":                       "quz",
	"Cutchi-Swahili":                      "ccl",
	"Cuvok":                               "cuv",
	"Cuyamecalco Mixtec":                  "xtu",
	"Cuyonon":                             "cyo",
	"Cwi Bwamu":                           "bwy",
	"Cypriot Arabic":                      "acy",
	"Czech Sign Language":                 "cse",
	"Czech":                               "ces",
	"Da'a Kaili":                          "kzf",
	"Daai Chin":                           "dao",
	"Daakaka":                             "bpa",
	"Daantanai'":                          "lni",
	"Daasanach":                           "dsh",
	"Daatsʼíin":                          "dtn",
	"Daba":                                "dbq",
	"Dabarre":                             "dbr",
	"Dabe":                                "dbe",
	"Dacian":                              "xdc",
	"Dadi Dadi":                           "dda",
	"Dadibi":                              "mps",
	"Dadiya":                              "dbd",
	"Daga":                                "dgz",
	"Dagaari Dioula":                      "dgd",
	"Dagba":                               "dgk",
	"Dagbani":                             "dag",
	"Dagik":                               "dec",
	"Dagoman":                             "dgn",
	"Dahalik":                             "dlk",
	"Dahalo":                              "dal",
	"Daho-Doo":                            "das",
	"Dai Zhuang":                          "zhd",
	"Dai":                                 "dij",
	"Dair":                                "drb",
	"Dakka":                               "dkk",
	"Dakota":                              "dak",
	"Dakpakha":                            "dka",
	"Dalabon":                             "ngk",
	"Dalmatian":                           "dlm",
	"Daloa Bété":                          "bev",
	"Dama":                                "dmm",
	"Damakawa":                            "dam",
	"Damal":                               "uhn",
	"Dambi":                               "dac",
	"Dameli":                              "dml",
	"Dampelas":                            "dms",
	"Dan":                                 "dnj",
	"Danaru":                              "dnr",
	"Danau":                               "dnu",
	"Dandami Maria":                       "daq",
	"Dangaléat":                           "daa",
	"Dangaura Tharu":                      "thl",
	"Danish Sign Language":                "dsl",
	"Danish":                              "dan",
	"Dano":                                "aso",
	"Danu":                                "dnv",
	"Dao":                                 "daz",
	"Daonda":                              "dnd",
	"Dar Daju Daju":                       "djc",
	"Dar Fur Daju":                        "daj",
	"Dar Sila Daju":                       "dau",
	"Darai":                               "dry",
	"Dargwa":                              "dar",
	"Dari":                                "prs",
	"Darkinyung":                          "xda",
	"Darlong":                             "dln",
	"Darmiya":                             "drd",
	"Daro-Matu Melanau":                   "dro",
	"Dass":                                "dot",
	"Datooga":                             "tcc",
	"Daungwurrung":                        "dgw",
	"Daur":                                "dta",
	"Davawenyo":                           "daw",
	"Dâw":                                 "kwa",
	"Dawawa":                              "dww",
	"Dawera-Daweloor":                     "ddw",
	"Dawro":                               "dwr",
	"Day":                                 "dai",
	"Dayi":                                "dax",
	"Dazaga":                              "dzg",
	"Deccan":                              "dcc",
	"Dedua":                               "ded",
	"Defaka":                              "afn",
	"Defi Gbe":                            "gbh",
	"Deg":                                 "mzw",
	"Degaru":                              "dgu",
	"Degema":                              "deg",
	"Degenan":                             "dge",
	"Degexit'an":                          "ing",
	"Dehu":                                "dhv",
	"Dehwari":                             "deh",
	"Dek":                                 "dek",
	"Dela-Oenale":                         "row",
	"Delaware":                            "del",
	"Delo":                                "ntr",
	"Dem":                                 "dem",
	"Dema":                                "dmx",
	"Demisa":                              "dei",
	"Demta":                               "dmy",
	"Dendi (Benin)":                       "ddn",
	"Dendi (Central African Republic)":    "deq",
	"Dengese":                             "dez",
	"Dengka":                              "dnk",
	"Dení":                                "dny",
	"Deno":                                "dbb",
	"Denya":                               "anv",
	"Deori":                               "der",
	"Dera (Indonesia)":                    "kbv",
	"Dera (Nigeria)":                      "kna",
	"Desano":                              "des",
	"Desiya":                              "dso",
	"Dewoin":                              "dee",
	"Dezfuli":                             "def",
	"Dghwede":                             "dgh",
	"Dhaiso":                              "dhs",
	"Dhalandji":                           "dhl",
	"Dhangu-Djangu":                       "dhg",
	"Dhanki":                              "dhn",
	"Dhanwar (Nepal)":                     "dhw",
	"Dhao":                                "nfa",
	"Dhargari":                            "dhr",
	"Dharuk":                              "xdk",
	"Dharumbal":                           "xgm",
	"Dhatki":                              "mki",
	"Dhimal":                              "dhi",
	"Dhivehi":                             "div",
	"Dhodia":                              "dho",
	"Dhofari Arabic":                      "adf",
	"Dhudhuroa":                           "ddr",
	"Dhundari":                            "dhd",
	"Dhungaloo":                           "dhx",
	"Dhurga":                              "dhu",
	"Dhuwal":                              "dwu",
	"Dhuwaya":                             "dwy",
	"Dia":                                 "dia",
	"Dibabawon Manobo":                    "mbd",
	"Dibiyaso":                            "dby",
	"Dibo":                                "dio",
	"Dibole":                              "bvx",
	"Dicamay Agta":                        "duy",
	"Didinga":                             "did",
	"Dido":                                "ddo",
	"Dieri":                               "dif",
	"Digaro-Mishmi":                       "mhu",
	"Digo":                                "dig",
	"Dii":                                 "dur",
	"Dijim-Bwilim":                        "cfa",
	"Dilling":                             "dil",
	"Dima":                                "jma",
	"Dimasa":                              "dis",
	"Dimbong":                             "dii",
	"Dime":                                "dim",
	"Dimli (individual language)":         "diq",
	"Ding":                                "diz",
	"Dinka":                               "din",
	"Dirari":                              "dit",
	"Dirasha":                             "gdl",
	"Diri":                                "dwa",
	"Diriku":                              "diu",
	"Dirim":                               "dir",
	"Disa":                                "dsi",
	"Ditammari":                           "tbz",
	"Ditidaht":                            "dtd",
	"Diuwe":                               "diy",
	"Diuxi-Tilantongo Mixtec":             "xtd",
	"Dixon Reef":                          "dix",
	"Dizin":                               "mdx",
	"Djabwurrung":                         "tjw",
	"Djadjawurrung":                       "dja",
	"Djambarrpuyngu":                      "djr",
	"Djamindjung":                         "djd",
	"Djangun":                             "djf",
	"Djauan":                              "djn",
	"Djawi":                               "djw",
	"Djeebbana":                           "djj",
	"Djimini Senoufo":                     "dyi",
	"Djinang":                             "dji",
	"Djinba":                              "djb",
	"Djingili":                            "jig",
	"Djiwarli":                            "dze",
	"Dobel":                               "kvo",
	"Dobu":                                "dob",
	"Doe":                                 "doe",
	"Doga":                                "dgg",
	"Doghoro":                             "dgx",
	"Dogosé":                              "dos",
	"Dogoso":                              "dgs",
	"Dogri (individual language)":         "dgo",
	"Dogri (macrolanguage)":               "doi",
	"Dogrib":                              "dgr",
	"Dogul Dom Dogon":                     "dbg",
	"Doka":                                "dbi",
	"Doko-Uyanga":                         "uya",
	"Dolgan":                              "dlg",
	"Dolpo":                               "dre",
	"Dom":                                 "doa",
	"Domaaki":                             "dmk",
	"Domari":                              "rmt",
	"Dombe":                               "dov",
	"Dominican Sign Language":             "doq",
	"Dompo":                               "doy",
	"Domu":                                "dof",
	"Domung":                              "dev",
	"Dondo":                               "dok",
	"Dong":                                "doh",
	"Dongo":                               "doo",
	"Dongotono":                           "ddd",
	"Dongshanba Lalo":                     "yik",
	"Dongxiang":                           "sce",
	"Donno So Dogon":                      "dds",
	"Doondo":                              "dde",
	"Dori'o":                              "dor",
	"Doromu-Koki":                         "kqc",
	"Dororo":                              "drr",
	"Dorze":                               "doz",
	"Doso":                                "dol",
	"Dotyali":                             "dty",
	"Doutai":                              "tds",
	"Doyayo":                              "dow",
	"Drents":                              "drt",
	"Drung":                               "duu",
	"Duala":                               "dua",
	"Duano":                               "dup",
	"Duau":                                "dva",
	"Dubli":                               "dub",
	"Dubu":                                "dmu",
	"Dugun":                               "ndu",
	"Duguri":                              "dbm",
	"Dugwor":                              "dme",
	"Duhwa":                               "kbz",
	"Duke":                                "nke",
	"Dulbu":                               "dbo",
	"Duli-Gey":                            "duz",
	"Duma":                                "dma",
	"Dumbea":                              "duf",
	"Dumi":                                "dus",
	"Dumpas":                              "dmv",
	"Dumun":                               "dui",
	"Duna":                                "duc",
	"Dungan":                              "dng",
	"Dungmali":                            "raa",
	"Dungra Bhil":                         "duh",
	"Dungu":                               "dbv",
	"Dupaninan Agta":                      "duo",
	"Dura":                                "drq",
	"Duri":                                "mvp",
	"Duriankere":                          "dbn",
	"Duruma":                              "dug",
	"Duruwa":                              "pci",
	"Dusner":                              "dsn",
	"Dusun Deyah":                         "dun",
	"Dusun Malang":                        "duq",
	"Dusun Witu":                          "duw",
	"Dutch Sign Language":                 "dse",
	"Dutch":                               "nld",
	"Dutton World Speedwords":             "dws",
	"Duungooma":                           "dux",
	"Duupa":                               "dae",
	"Duvle":                               "duv",
	"Duwai":                               "dbp",
	"Duwet":                               "gve",
	"Dũya":                               "ldb",
	"Dwang":                               "nnu",
	"Dyaabugay":                           "dyy",
	"Dyaberdyaber":                        "dyb",
	"Dyan":                                "dya",
	"Dyangadi":                            "dyn",
	"Dyirbal":                             "dbl",
	"Dyugun":                              "dyd",
	"Dyula":                               "dyu",
	"Dza":                                 "jen",
	"Dzalakha":                            "dzl",
	"Dzando":                              "dzn",
	"Dzao Min":                            "bpn",
	"Dzodinka":                            "add",
	"Dzongkha":                            "dzo",
	"Dzùùngoo":                            "dnn",
	"E'ma Buyang":                         "yzg",
	"E'ñapa Woromaipu":                    "pbh",
	"E":                                   "eee",
	"Early Tripuri":                       "xtr",
	"East Ambae":                          "omb",
	"East Berawan":                        "zbe",
	"East Damar":                          "dmr",
	"East Futuna":                         "fud",
	"East Kewa":                           "kjs",
	"East Limba":                          "lma",
	"East Makian":                         "mky",
	"East Masela":                         "vme",
	"East Nyala":                          "nle",
	"East Tarangan":                       "tre",
	"East Yugur":                          "yuy",
	"Eastern Abnaki":                      "aaq",
	"Eastern Acipa":                       "acp",
	"Eastern Apurímac Quechua":            "qve",
	"Eastern Arrernte":                    "aer",
	"Eastern Balochi":                     "bgp",
	"Eastern Bolivian Guaraní":            "gui",
	"Eastern Bontok":                      "ebk",
	"Eastern Bru":                         "bru",
	"Eastern Canadian Inuktitut":          "ike",
	"Eastern Cham":                        "cjm",
	"Eastern Durango Nahuatl":             "azd",
	"Eastern Egyptian Bedawi Arabic":      "avl",
	"Eastern Frisian":                     "frs",
	"Eastern Gorkha Tamang":               "tge",
	"Eastern Highland Chatino":            "cly",
	"Eastern Highland Otomi":              "otm",
	"Eastern Hongshuihe Zhuang":           "zeh",
	"Eastern Huasteca Nahuatl":            "nhe",
	"Eastern Huishui Hmong":               "hme",
	"Eastern Karaboro":                    "xrb",
	"Eastern Karnic":                      "ekc",
	"Eastern Katu":                        "ktv",
	"Eastern Kayah":                       "eky",
	"Eastern Keres":                       "kee",
	"Eastern Khumi Chin":                  "cek",
	"Eastern Krahn":                       "kqo",
	"Eastern Lalu":                        "yit",
	"Eastern Lawa":                        "lwl",
	"Eastern Magar":                       "mgp",
	"Eastern Maninkakan":                  "emk",
	"Eastern Mari":                        "mhr",
	"Eastern Maroon Creole":               "djk",
	"Eastern Meohang":                     "emg",
	"Eastern Mnong":                       "mng",
	"Eastern Muria":                       "emu",
	"Eastern Ngad'a":                      "nea",
	"Eastern Nisu":                        "nos",
	"Eastern Ojibwa":                      "ojg",
	"Eastern Oromo":                       "hae",
	"Eastern Parbate Kham":                "kif",
	"Eastern Penan":                       "pez",
	"Eastern Pomo":                        "peb",
	"Eastern Qiandong Miao":               "hmq",
	"Eastern Subanen":                     "sfe",
	"Eastern Tamang":                      "taj",
	"Eastern Tawbuid":                     "bnj",
	"Eastern Xiangxi Miao":                "muq",
	"Eastern Xwla Gbe":                    "gbx",
	"Eastern Yiddish":                     "ydd",
	"Ebira":                               "igb",
	"Eblan":                               "xeb",
	"Ebrié":                               "ebr",
	"Ebughu":                              "ebg",
	"Ecuadorian Sign Language":            "ecs",
	"Ede Cabe":                            "cbj",
	"Ede Ica":                             "ica",
	"Ede Idaca":                           "idd",
	"Ede Ije":                             "ijj",
	"Edera Awyu":                          "awy",
	"Edolo":                               "etr",
	"Edomite":                             "xdm",
	"Edopi":                               "dbf",
	"Efai":                                "efa",
	"Efe":                                 "efe",
	"Efik":                                "efi",
	"Efutop":                              "ofu",
	"Ega":                                 "ega",
	"Eggon":                               "ego",
	"Egypt Sign Language":                 "esl",
	"Egyptian (Ancient)":                  "egy",
	"Egyptian Arabic":                     "arz",
	"Ehueun":                              "ehu",
	"Eipomek":                             "eip",
	"Eitiep":                              "eit",
	"Ejagham":                             "etu",
	"Ejamat":                              "eja",
	"Ekajuk":                              "eka",
	"Ekari":                               "ekg",
	"Eki":                                 "eki",
	"Ekit":                                "eke",
	"Ekpeye":                              "ekp",
	"El Alto Zapotec":                     "zpp",
	"El Hugeirat":                         "elh",
	"El Molo":                             "elo",
	"El Nayar Cora":                       "crn",
	"Elamite":                             "elx",
	"Eleme":                               "elm",
	"Elepi":                               "ele",
	"Elfdalian":                           "ovd",
	"Elip":                                "ekm",
	"Elkei":                               "elk",
	"Elotepec Zapotec":                    "zte",
	"Eloyi":                               "afo",
	"Elseng":                              "mrf",
	"Elu":                                 "elu",
	"Elymian":                             "xly",
	"Emae":                                "mmw",
	"Emai-Iuleha-Ora":                     "ema",
	"Eman":                                "emn",
	"Embaloh":                             "emb",
	"Emberá-Baudó":                        "bdc",
	"Emberá-Catío":                        "cto",
	"Emberá-Chamí":                        "cmi",
	"Emberá-Tadó":                         "tdc",
	"Embu":                                "ebu",
	"Emerillon":                           "eme",
	"Emilian":                             "egl",
	"Emplawas":                            "emw",
	"Emumu":                               "enr",
	"En":                                  "enc",
	"Enawené-Nawé":                        "unk",
	"Ende":                                "end",
	"Enga":                                "enq",
	"Engdewu":                             "ngr",
	"Engenni":                             "enn",
	"Enggano":                             "eno",
	"English":                             "eng",
	"Enlhet":                              "enl",
	"Enrekang":                            "ptt",
	"Enu":                                 "enu",
	"Enwan (Akwa Ibom State)":             "enw",
	"Enwan (Edu State)":                   "env",
	"Enxet":                               "enx",
	"Enya":                                "gey",
	"Epena":                               "sja",
	"Epi-Olmec":                           "xep",
	"Epie":                                "epi",
	"Epigraphic Mayan":                    "emy",
	"Eravallan":                           "era",
	"Erave":                               "kjy",
	"Ere":                                 "twp",
	"Eritai":                              "ert",
	"Erokwanas":                           "erw",
	"Erre":                                "err",
	"Erromintxela":                        "emx",
	"Ersu":                                "ers",
	"Eruwa":                               "erh",
	"Erzya":                               "myv",
	"Esan":                                "ish",
	"Ese Ejja":                            "ese",
	"Ese":                                 "mcq",
	"Eshtehardi":                          "esh",
	"Esimbi":                              "ags",
	"Eskayan":                             "esy",
	"Esperanto":                           "epo",
	"Esselen":                             "esq",
	"Estado de México Otomi":              "ots",
	"Estonian Sign Language":              "eso",
	"Estonian":                            "est",
	"Esuma":                               "esm",
	"Etchemin":                            "etc",
	"Etebi":                               "etb",
	"Eten":                                "etx",
	"Eteocretan":                          "ecr",
	"Eteocypriot":                         "ecy",
	"Ethiopian Sign Language":             "eth",
	"Etkywan":                             "ich",
	"Eton (Cameroon)":                     "eto",
	"Eton (Vanuatu)":                      "etn",
	"Etruscan":                            "ett",
	"Etulo":                               "utr",
	"Evant":                               "bzz",
	"Even":                                "eve",
	"Evenki":                              "evn",
	"Eviya":                               "gev",
	"Ewage-Notu":                          "nou",
	"Ewe":                                 "ewe",
	"Ewondo":                              "ewo",
	"Extremaduran":                        "ext",
	"Eyak":                                "eya",
	"Ezaa":                                "eza",
	"Fa d'Ambu":                           "fab",
	"Fagani":                              "faf",
	"Faire Atta":                          "azt",
	"Faita":                               "faj",
	"Faiwol":                              "fai",
	"Fala":                                "fax",
	"Falam Chin":                          "cfm",
	"Fali":                                "fli",
	"Faliscan":                            "xfa",
	"Fam":                                 "fam",
	"Fanagalo":                            "fng",
	"Fanamaket":                           "bjp",
	"Fanbak":                              "fnb",
	"Fang (Cameroon)":                     "fak",
	"Fang (Equatorial Guinea)":            "fan",
	"Fania":                               "fni",
	"Fanti":                               "fat",
	"Far Western Muria":                   "fmu",
	"Farefare":                            "gur",
	"Faroese":                             "fao",
	"Fas":                                 "fqs",
	"Fasu":                                "faa",
	"Fataleka":                            "far",
	"Fataluku":                            "ddg",
	"Fayu":                                "fau",
	"Fe'fe'":                              "fmp",
	"Fembe":                               "agl",
	"Fernando Po Creole English":          "fpe",
	"Feroge":                              "fer",
	"Fiji Hindi":                          "hif",
	"Fijian":                              "fij",
	"Filipino":                            "fil",
	"Filomena Mata-Coahuitlán Totonac":    "tlp",
	"Finland-Swedish Sign Language":       "fss",
	"Finnish Sign Language":               "fse",
	"Finnish":                             "fin",
	"Finongan":                            "fag",
	"Fipa":                                "fip",
	"Firan":                               "fir",
	"Fiwaga":                              "fiw",
	"Flaaitaal":                           "fly",
	"Flinders Island":                     "fln",
	"Foau":                                "flh",
	"Foi":                                 "foi",
	"Foia Foia":                           "ffi",
	"Folopa":                              "ppo",
	"Foma":                                "fom",
	"Fon":                                 "fon",
	"Fongoro":                             "fgr",
	"Foodo":                               "fod",
	"Forak":                               "frq",
	"Fordata":                             "frd",
	"Fore":                                "for",
	"Forest Enets":                        "enf",
	"Fortsenal":                           "frt",
	"Francisco León Zoque":                "zos",
	"Frankish":                            "frk",
	"French Sign Language":                "fsl",
	"French":                              "fra",
	"Friulian":                            "fur",
	"Fulah":                               "ful",
	"Fuliiru":                             "flr",
	"Fulniô":                              "fun",
	"Fum":                                 "fum",
	"Fungwa":                              "ula",
	"Fur":                                 "fvr",
	"Furu":                                "fuu",
	"Futuna-Aniwa":                        "fut",
	"Fuyug":                               "fuy",
	"Fwâi":                                "fwa",
	"Fwe":                                 "fwe",
	"Fyam":                                "pym",
	"Fyer":                                "fie",
	"Ga'anda":                             "gqa",
	"Ga'dang":                             "gdg",
	"Ga":                                  "gaa",
	"Gaa":                                 "ttb",
	"Gaam":                                "tbi",
	"Gabi-Gabi":                           "gbw",
	"Gabri":                               "gab",
	"Gabrielino-Fernandeño":               "xgf",
	"Gaɓogbo":                             "gie",
	"Gadang":                              "gdk",
	"Gaddang":                             "gad",
	"Gaddi":                               "gbk",
	"Gade Lohar":                          "gda",
	"Gade":                                "ged",
	"Gadjerawang":                         "gdh",
	"Gadsup":                              "gaj",
	"Gafat":                               "gft",
	"Gagadu":                              "gbu",
	"Gagauz":                              "gag",
	"Gagnoa Bété":                         "btg",
	"Gagu":                                "ggu",
	"Gahri":                               "bfu",
	"Gaikundi":                            "gbf",
	"Gail":                                "gic",
	"Gaina":                               "gcn",
	"Gal":                                 "gap",
	"Galambu":                             "glo",
	"Galatian":                            "xga",
	"Galela":                              "gbi",
	"Galeya":                              "gar",
	"Galibi Carib":                        "car",
	"Galice":                              "gce",
	"Galician":                            "glg",
	"Galindan":                            "xgl",
	"Gallurese Sardinian":                 "sdn",
	"Galo":                                "adl",
	"Galolen":                             "gal",
	"Gamale Kham":                         "kgj",
	"Gambera":                             "gma",
	"Gambian Wolof":                       "wof",
	"Gamilaraay":                          "kld",
	"Gamit":                               "gbl",
	"Gamkonora":                           "gak",
	"Gamo-Ningi":                          "bte",
	"Gamo":                                "gmv",
	"Gan Chinese":                         "gan",
	"Gana":                                "gnq",
	"Ganang":                              "gne",
	"Ganda":                               "lug",
	"Gāndhārī":                            "pgd",
	"Gane":                                "gzn",
	"Ganggalida":                          "gcd",
	"Ganglau":                             "ggl",
	"Gangte":                              "gnb",
	"Gangulu":                             "gnl",
	"Gants":                               "gao",
	"Ganza":                               "gza",
	"Ganzi":                               "gnz",
	"Gao":                                 "gga",
	"Gapapaiwa":                           "pwg",
	"Garhwali":                            "gbm",
	"Garifuna":                            "cab",
	"Garig-Ilgar":                         "ilg",
	"Garingbal":                           "xgi",
	"Garlali":                             "gll",
	"Garo":                                "grt",
	"Garre":                               "gex",
	"Garrwa":                              "wrk",
	"Garus":                               "gyb",
	"Garza":                               "xgr",
	"Gata'":                               "gaq",
	"Gavak":                               "dmc",
	"Gavar":                               "gou",
	"Gavião Do Jiparaná":                  "gvo",
	"Gawar-Bati":                          "gwt",
	"Gawwada":                             "gwd",
	"Gayil":                               "gyl",
	"Gayo":                                "gay",
	"Gazi":                                "gzi",
	"Gbagyi":                              "gbr",
	"Gbanu":                               "gbv",
	"Gbanziri":                            "gbg",
	"Gbari":                               "gby",
	"Gbaya (Central African Republic)":    "gba",
	"Gbaya (Sudan)":                       "krs",
	"Gbaya-Bossangoa":                     "gbp",
	"Gbaya-Bozoum":                        "gbq",
	"Gbaya-Mbodomo":                       "gmm",
	"Gbayi":                               "gyg",
	"Gbesi Gbe":                           "gbs",
	"Gbii":                                "ggb",
	"Gbin":                                "xgb",
	"Gbiri-Niragu":                        "grh",
	"Gboloo Grebo":                        "gec",
	"Ge":                                  "hmj",
	"Geba Karen":                          "kvq",
	"Gebe":                                "gei",
	"Gedaged":                             "gdd",
	"Gedeo":                               "drs",
	"Geez":                                "gez",
	"Geji":                                "gji",
	"Geko Karen":                          "ghk",
	"Gela":                                "nlg",
	"Geme":                                "geq",
	"Gen":                                 "gej",
	"Gende":                               "gaf",
	"Gengle":                              "geg",
	"Georgian":                            "kat",
	"Gepo":                                "ygp",
	"Gera":                                "gew",
	"German Sign Language":                "gsg",
	"German":                              "deu",
	"Geruma":                              "gea",
	"Geser-Gorom":                         "ges",
	"Ghadamès":                            "gha",
	"Ghanaian Pidgin English":             "gpe",
	"Ghanaian Sign Language":              "gse",
	"Ghandruk Sign Language":              "gds",
	"Ghanongga":                           "ghn",
	"Ghari":                               "gri",
	"Ghayavi":                             "bmk",
	"Gheg Albanian":                       "aln",
	"Ghera":                               "ghr",
	"Ghodoberi":                           "gdo",
	"Ghomálá'":                            "bbj",
	"Ghomara":                             "gho",
	"Ghotuo":                              "aaa",
	"Ghulfan":                             "ghl",
	"Giangan":                             "bgi",
	"Gibanawa":                            "gib",
	"Gidar":                               "gid",
	"Giiwo":                               "kks",
	"Gikyode":                             "acd",
	"Gilaki":                              "glk",
	"Gilbertese":                          "gil",
	"Gilima":                              "gix",
	"Gilyak":                              "niv",
	"Gimi (Eastern Highlands)":            "gim",
	"Gimi (West New Britain)":             "gip",
	"Gimme":                               "kmp",
	"Gimnime":                             "gmn",
	"Ginuman":                             "gnm",
	"Ginyanga":                            "ayg",
	"Girawa":                              "bbr",
	"Giryama":                             "nyf",
	"Githabul":                            "gih",
	"Gitonga":                             "toh",
	"Gitua":                               "ggt",
	"Gitxsan":                             "git",
	"Giyug":                               "giy",
	"Gizrra":                              "tof",
	"Glaro-Twabo":                         "glr",
	"Glavda":                              "glw",
	"Glio-Oubi":                           "oub",
	"Gnau":                                "gnu",
	"Goan Konkani":                        "gom",
	"Goaria":                              "gig",
	"Gobasi":                              "goi",
	"Gobu":                                "gox",
	"Godié":                               "god",
	"Godwari":                             "gdx",
	"Goemai":                              "ank",
	"Gofa":                                "gof",
	"Gogo":                                "gog",
	"Gogodala":                            "ggw",
	"Gokana":                              "gkn",
	"Gola":                                "gol",
	"Golin":                               "gvf",
	"Golpa":                               "lja",
	"Gondi":                               "gon",
	"Gone Dau":                            "goo",
	"Gongduk":                             "goe",
	"Gonja":                               "gjn",
	"Gooniyandi":                          "gni",
	"Gor":                                 "gqr",
	"Gorakor":                             "goc",
	"Gorap":                               "goq",
	"Goreng":                              "xgg",
	"Gorontalo":                           "gor",
	"Gorovu":                              "grq",
	"Gorowa":                              "gow",
	"Gothic":                              "got",
	"Goundo":                              "goy",
	"Gourmanchéma":                        "gux",
	"Gowlan":                              "goj",
	"Gowli":                               "gok",
	"Gowro":                               "gwf",
	"Gozarkhani":                          "goz",
	"Grangali":                            "nli",
	"Grass Koiari":                        "kbk",
	"Grebo":                               "grb",
	"Greek Sign Language":                 "gss",
	"Green Gelao":                         "giq",
	"Grenadian Creole English":            "gcl",
	"Gresi":                               "grs",
	"Groma":                               "gro",
	"Gronings":                            "gos",
	"Gros Ventre":                         "ats",
	"Gua":                                 "gwx",
	"Guadeloupean Creole French":          "gcf",
	"Guahibo":                             "guh",
	"Guajá":                               "gvj",
	"Guajajára":                           "gub",
	"Guambiano":                           "gum",
	"Guana (Brazil)":                      "gqn",
	"Guana (Paraguay)":                    "gva",
	"Guanano":                             "gvc",
	"Guanche":                             "gnc",
	"Guanyinqiao":                         "jiq",
	"Guarani":                             "grn",
	"Guarayu":                             "gyr",
	"Guarequena":                          "gae",
	"Guatemalan Sign Language":            "gsm",
	"Guató":                               "gta",
	"Guayabero":                           "guo",
	"Gudang":                              "xgd",
	"Gudanji":                             "nji",
	"Gude":                                "gde",
	"Gudu":                                "gdu",
	"Guduf-Gava":                          "gdf",
	"Guerrero Amuzgo":                     "amu",
	"Guerrero Nahuatl":                    "ngu",
	"Guevea De Humboldt Zapotec":          "zpg",
	"Gugadj":                              "ggd",
	"Gugu Badhun":                         "gdc",
	"Gugu Warra":                          "wrw",
	"Gugubera":                            "kkp",
	"Guguyimidjir":                        "kky",
	"Guhu-Samane":                         "ghs",
	"Guianese Creole French":              "gcr",
	"Guibei Zhuang":                       "zgb",
	"Guiberoua Béte":                      "bet",
	"Guibian Zhuang":                      "zgn",
	"Güilá Zapotec":                       "ztu",
	"Guinea Kpelle":                       "gkp",
	"Guinean Sign Language":               "gus",
	"Guiqiong":                            "gqi",
	"Gujarati":                            "guj",
	"Gujari":                              "gju",
	"Gula (Central African Republic)":     "kcm",
	"Gula (Chad)":                         "glu",
	"Gula Iro":                            "glj",
	"Gula'alaa":                           "gmb",
	"Gulay":                               "gvl",
	"Gule":                                "gly",
	"Gulf Arabic":                         "afb",
	"Guliguli":                            "gli",
	"Gumalu":                              "gmu",
	"Gumatj":                              "gnn",
	"Gumawana":                            "gvs",
	"Gumuz":                               "guk",
	"Gun":                                 "guw",
	"Gundi":                               "gdi",
	"Gunditjmara":                         "gjm",
	"Gundungurra":                         "xrd",
	"Gungabula":                           "gyf",
	"Gungu":                               "rub",
	"Guntai":                              "gnt",
	"Gunwinggu":                           "gup",
	"Gunya":                               "gyy",
	"Gupa-Abawa":                          "gpa",
	"Gupapuyngu":                          "guf",
	"Guragone":                            "gge",
	"Guramalum":                           "grz",
	"Gurani":                              "hac",
	"Gurdjar":                             "gdj",
	"Gureng Gureng":                       "gnr",
	"Gurgula":                             "ggg",
	"Guriaso":                             "grx",
	"Gurindji Kriol":                      "gjr",
	"Gurinji":                             "gue",
	"Gurmana":                             "gvm",
	"Guro":                                "goa",
	"Gurung":                              "gvr",
	"Guruntum-Mbaaru":                     "grd",
	"Gusii":                               "guz",
	"Gusilay":                             "gsl",
	"Guwa":                                "xgw",
	"Guwamu":                              "gwu",
	"Guya":                                "gka",
	"Guyanese Creole English":             "gyn",
	"Guyani":                              "gvy",
	"Gvoko":                               "ngs",
	"Gwa":                                 "gwb",
	"Gwahatike":                           "dah",
	"Gwak":                                "jgk",
	"Gwamhi-Wuri":                         "bga",
	"Gwandara":                            "gwn",
	"Gweda":                               "grw",
	"Gweno":                               "gwe",
	"Gwere":                               "gwr",
	"Gwichʼin":                            "gwi",
	"Gyele":                               "gyi",
	"Gyem":                                "gye",
	"Ha":                                  "haq",
	"Habu":                                "hbu",
	"Hadiyya":                             "hdy",
	"Hadothi":                             "hoj",
	"Hadrami Arabic":                      "ayh",
	"Hadrami":                             "xhd",
	"Hadza":                               "hts",
	"Haeke":                               "aek",
	"Hahon":                               "hah",
	"Hai//om":                             "hgm",
	"Haida":                               "hai",
	"Haigwai":                             "hgw",
	"Haiphong Sign Language":              "haf",
	"Haisla":                              "has",
	"Haitian Vodoun Culture Language":     "hvc",
	"Haitian":                             "hat",
	"Haji":                                "hji",
	"Hajong":                              "haj",
	"Hakha Chin":                          "cnh",
	"Hakka Chinese":                       "hak",
	"Hakö":                                "hao",
	"Halang Doan":                         "hld",
	"Halang":                              "hal",
	"Halbi":                               "hlb",
	"Halh Mongolian":                      "khk",
	"Halia":                               "hla",
	"Halkomelem":                          "hur",
	"Hamap":                               "hmu",
	"Hamba":                               "hba",
	"Hamer-Banna":                         "amf",
	"Hamtai":                              "hmt",
	"Han":                                 "haa",
	"Hanga Hundi":                         "wos",
	"Hanga":                               "hag",
	"Hangaza":                             "han",
	"Hani":                                "hni",
	"Hano":                                "lml",
	"Hanoi Sign Language":                 "hab",
	"Hanunoo":                             "hnn",
	"Harami":                              "xha",
	"Harari":                              "har",
	"Harijan Kinnauri":                    "kjo",
	"Haroi":                               "hro",
	"Harsusi":                             "hss",
	"Haruai":                              "tmd",
	"Haruku":                              "hrk",
	"Haryanvi":                            "bgc",
	"Harzani":                             "hrz",
	"Hasha":                               "ybj",
	"Hassaniyya":                          "mey",
	"Hatam":                               "had",
	"Hattic":                              "xht",
	"Hausa Sign Language":                 "hsl",
	"Hausa":                               "hau",
	"Havasupai-Walapai-Yavapai":           "yuf",
	"Haveke":                              "hvk",
	"Havu":                                "hav",
	"Hawai'i Creole English":              "hwc",
	"Hawai'i Sign Language (HSL)":         "hps",
	"Hawaiian":                            "haw",
	"Haya":                                "hay",
	"Hazaragi":                            "haz",
	"Hdi":                                 "xed",
	"Hebrew":                              "heb",
	"Hehe":                                "heh",
	"Heiban":                              "hbn",
	"Heiltsuk":                            "hei",
	"Helambu Sherpa":                      "scp",
	"Helong":                              "heg",
	"Hema":                                "nix",
	"Hemba":                               "hem",
	"Herdé":                               "hed",
	"Herero":                              "her",
	"Hermit":                              "llf",
	"Hernican":                            "xhr",
	"Hértevin":                            "hrt",
	"Hewa":                                "ham",
	"Heyo":                                "auk",
	"Hiberno-Scottish Gaelic":             "ghc",
	"Hibito":                              "hib",
	"Hidatsa":                             "hid",
	"Hieroglyphic Luwian":                 "hlu",
	"Higaonon":                            "mba",
	"Highland Konjo":                      "kjk",
	"Highland Oaxaca Chontal":             "chd",
	"Highland Popoluca":                   "poi",
	"Highland Puebla Nahuatl":             "azz",
	"Highland Totonac":                    "tos",
	"Hijazi Arabic":                       "acw",
	"Hijuk":                               "hij",
	"Hiligaynon":                          "hil",
	"Himarimã":                            "hir",
	"Hindi":                               "hin",
	"Hinduri":                             "hii",
	"Hinukh":                              "gin",
	"Hiri Motu":                           "hmo",
	"Hittite":                             "hit",
	"Hitu":                                "htu",
	"Hiw":                                 "hiw",
	"Hixkaryána":                          "hix",
	"Hlai":                                "lic",
	"Hlepho Phowa":                        "yhl",
	"Hlersu":                              "hle",
	"Hmar":                                "hmr",
	"Hmong Daw":                           "mww",
	"Hmong Dô":                            "hmv",
	"Hmong Don":                           "hmf",
	"Hmong Njua":                          "hnj",
	"Hmong Shua":                          "hmz",
	"Hmong":                               "hmn",
	"Hmwaveke":                            "mrk",
	"Ho Chi Minh City Sign Language":      "hos",
	"Ho-Chunk":                            "win",
	"Ho":                                  "hoc",
	"Hoava":                               "hoa",
	"Hobyót":                              "hoh",
	"Hoia Hoia":                           "hhi",
	"Holikachuk":                          "hoi",
	"Holiya":                              "hoy",
	"Holma":                               "hod",
	"Holoholo":                            "hoo",
	"Holu":                                "hol",
	"Homa":                                "hom",
	"Honduras Sign Language":              "hds",
	"Hõne":                                "juh",
	"Hong Kong Sign Language":             "hks",
	"Honi":                                "how",
	"Hopi":                                "hop",
	"Horned Miao":                         "hrm",
	"Horo":                                "hor",
	"Horom":                               "hoe",
	"Horpa":                               "ero",
	"Hote":                                "hot",
	"Hoti":                                "hti",
	"Hovongan":                            "hov",
	"Hoyahoya":                            "hhy",
	"Hozo":                                "hoz",
	"Hpon":                                "hpo",
	"Hrangkhol":                           "hra",
	"Hre":                                 "hre",
	"Hruso":                               "hru",
	"Hu":                                  "huo",
	"Huachipaeri":                         "hug",
	"Huallaga Huánuco Quechua":            "qub",
	"Huamalíes-Dos de Mayo Huánuco Quechua": "qvh",
	"Huambisa":                  "hub",
	"Huarijio":                  "var",
	"Huastec":                   "hus",
	"Huaulu":                    "hud",
	"Huautla Mazatec":           "mau",
	"Huaxcaleca Nahuatl":        "nhq",
	"Huaylas Ancash Quechua":    "qwh",
	"Huaylla Wanca Quechua":     "qvw",
	"Huba":                      "hbb",
	"Huehuetla Tepehua":         "tee",
	"Huichol":                   "hch",
	"Huilliche":                 "huh",
	"Huitepec Mixtec":           "mxs",
	"Huizhou Chinese":           "czh",
	"Hukumina":                  "huw",
	"Hula":                      "hul",
	"Hulaulá":                   "huy",
	"Huli":                      "hui",
	"Hulung":                    "huk",
	"Humburi Senni Songhay":     "hmb",
	"Humene":                    "huf",
	"Humla":                     "hut",
	"Hun-Saare":                 "dud",
	"Hunde":                     "hke",
	"Hung":                      "hnu",
	"Hungana":                   "hum",
	"Hungarian Sign Language":   "hsh",
	"Hungarian":                 "hun",
	"Hunjara-Kaina Ke":          "hkk",
	"Hunnic":                    "xhc",
	"Hunsrik":                   "hrx",
	"Hunzib":                    "huz",
	"Hupa":                      "hup",
	"Hupdë":                     "jup",
	"Hupla":                     "hap",
	"Hurrian":                   "xhu",
	"Hutterite German":          "geh",
	"Hwana":                     "hwo",
	"Hya":                       "hya",
	"Hyam":                      "jab",
	"I-Wak":                     "iwk",
	"Iaai":                      "iai",
	"Iamalele":                  "yml",
	"Iatmul":                    "ian",
	"Iau":                       "tmu",
	"Ibali Teke":                "tek",
	"Ibaloi":                    "ibl",
	"Iban":                      "iba",
	"Ibanag":                    "ibg",
	"Ibani":                     "iby",
	"Ibatan":                    "ivb",
	"Iberian":                   "xib",
	"Ibibio":                    "ibb",
	"Ibino":                     "ibn",
	"Ibu":                       "ibu",
	"Ibuoro":                    "ibr",
	"Icelandic Sign Language":   "icl",
	"Icelandic":                 "isl",
	"Iceve-Maci":                "bec",
	"Ida'an":                    "dbj",
	"Idakho-Isukha-Tiriki":      "ida",
	"Idaté":                     "idt",
	"Idere":                     "ide",
	"Idesa":                     "ids",
	"Idi":                       "idi",
	"Ido":                       "ido",
	"Idoma":                     "idu",
	"Idon":                      "idc",
	"Idu-Mishmi":                "clk",
	"Iduna":                     "viv",
	"Ifè":                       "ife",
	"Ifo":                       "iff",
	"Igala":                     "igl",
	"Igana":                     "igg",
	"Igbo":                      "ibo",
	"Igede":                     "ige",
	"Ignaciano":                 "ign",
	"Igo":                       "ahl",
	"Iguta":                     "nar",
	"Igwe":                      "igw",
	"Iha Based Pidgin":          "ihb",
	"Iha":                       "ihp",
	"Ihievbe":                   "ihi",
	"Ija-Zuba":                  "vki",
	"Ik":                        "ikx",
	"Ika":                       "ikk",
	"Ikaranggal":                "ikr",
	"Ikizu":                     "ikz",
	"Iko":                       "iki",
	"Ikobi":                     "meb",
	"Ikoma-Nata-Isenye":         "ntk",
	"Ikpeng":                    "txi",
	"Ikpeshi":                   "ikp",
	"Ikposo":                    "kpo",
	"Iku-Gora-Ankwa":            "ikv",
	"Ikulu":                     "ikl",
	"Ikwere":                    "ikw",
	"Ikwo":                      "iqw",
	"Ila":                       "ilb",
	"Ile Ape":                   "ila",
	"Ili Turki":                 "ili",
	"Ili'uun":                   "ilu",
	"Ilianen Manobo":            "mbi",
	"Illyrian":                  "xil",
	"Iloko":                     "ilo",
	"Ilongot":                   "ilk",
	"Ilue":                      "ilv",
	"Ilwana":                    "mlk",
	"Imbabura Highland Quichua": "qvi",
	"Imbongu":                   "imo",
	"Imonda":                    "imn",
	"Imroing":                   "imr",
	"Inabaknon":                 "abx",
	"Inapang":                   "mzu",
	"Iñapari":                   "inp",
	"Inari Sami":                "smn",
	"Indian Sign Language":      "ins",
	"Indo-Portuguese":           "idb",
	"Indonesian Bajau":          "bdl",
	"Indonesian Sign Language":  "inl",
	"Indonesian":                "ind",
	"Indri":                     "idr",
	"Indus Kohistani":           "mvy",
	"Indus Valley Language":     "xiv",
	"Inebu One":                 "oin",
	"Ineseño":                   "inz",
	"Inga":                      "inb",
	"Ingrian":                   "izh",
	"Ingush":                    "inh",
	"Inlaod Itneg":              "iti",
	"Inoke-Yate":                "ino",
	"Inonhan":                   "loc",
	"Inor":                      "ior",
	"Inpui Naga":                "nkf",
	"Interglossa":               "igs",
	"Interlingua (International Auxiliary Language Association)": "ina",
	"Interlingue":                    "ile",
	"International Sign":             "ils",
	"Intha":                          "int",
	"Inuinnaqtun":                    "ikt",
	"Inuit Sign Language":            "iks",
	"Inuktitut":                      "iku",
	"Inupiaq":                        "ipk",
	"Iowa-Oto":                       "iow",
	"Ipalapa Amuzgo":                 "azm",
	"Ipiko":                          "ipo",
	"Ipili":                          "ipi",
	"Ipulo":                          "ass",
	"Iquito":                         "iqu",
	"Ir":                             "irr",
	"Iranian Persian":                "pes",
	"Irántxe":                        "irn",
	"Iranun (Malaysia)":              "ilm",
	"Iranun (Philippines)":           "ilp",
	"Iraqw":                          "irk",
	"Irarutu":                        "irh",
	"Iraya":                          "iry",
	"Iresim":                         "ire",
	"Irigwe":                         "iri",
	"Irish Sign Language":            "isg",
	"Irish":                          "gle",
	"Irula":                          "iru",
	"Isabi":                          "isa",
	"Isanzu":                         "isn",
	"Isarog Agta":                    "agk",
	"Isconahua":                      "isc",
	"Isebe":                          "igo",
	"Isekiri":                        "its",
	"Ishkashimi":                     "isk",
	"Isinai":                         "inn",
	"Isirawa":                        "srl",
	"Island Carib":                   "crb",
	"Islander Creole English":        "icr",
	"Isnag":                          "isd",
	"Isoko":                          "iso",
	"Israeli Sign Language":          "isr",
	"Isthmus Mixe":                   "mir",
	"Isthmus Zapotec":                "zai",
	"Isthmus-Cosoleacaque Nahuatl":   "nhk",
	"Isthmus-Mecayapan Nahuatl":      "nhx",
	"Isthmus-Pajapan Nahuatl":        "nhp",
	"Istriot":                        "ist",
	"Istro Romanian":                 "ruo",
	"Isu (Fako Division)":            "szv",
	"Isu (Menchum Division)":         "isu",
	"Italian Sign Language":          "ise",
	"Italian":                        "ita",
	"Itawit":                         "itv",
	"Itelmen":                        "itl",
	"Itene":                          "ite",
	"Iteri":                          "itr",
	"Itik":                           "itx",
	"Ito":                            "itw",
	"Itonama":                        "ito",
	"Itu Mbon Uzo":                   "itm",
	"Itundujia Mixtec":               "mce",
	"Itzá":                           "itz",
	"Iu Mien":                        "ium",
	"Ivatan":                         "ivv",
	"Ivbie North-Okpela-Arhe":        "atg",
	"Iwaidja":                        "ibd",
	"Iwal":                           "kbm",
	"Iwam":                           "iwm",
	"Iwur":                           "iwo",
	"Ixcatec":                        "ixc",
	"Ixcatlán Mazatec":               "mzi",
	"Ixil":                           "ixl",
	"Ixtayutla Mixtec":               "vmj",
	"Ixtenco Otomi":                  "otz",
	"Iyayu":                          "iya",
	"Iyive":                          "uiv",
	"Iyo'wujwa Chorote":              "crq",
	"Iyo":                            "nca",
	"Iyojwa'ja Chorote":              "crt",
	"Izere":                          "izr",
	"Izii":                           "izz",
	"Izon":                           "ijc",
	"Izora":                          "cbo",
	"Jabutí":                         "jbt",
	"Jad":                            "jda",
	"Jadgali":                        "jdg",
	"Jah Hut":                        "jah",
	"Jahanka":                        "jad",
	"Jair Awyu":                      "awv",
	"Jaitmatang":                     "xjt",
	"Jakati":                         "jat",
	"Jakun":                          "jak",
	"Jalapa De Díaz Mazatec":         "maj",
	"Jalkunan":                       "bxl",
	"Jamaican Country Sign Language": "jcs",
	"Jamaican Creole English":        "jam",
	"Jamaican Sign Language":         "jls",
	"Jamamadí":                       "jaa",
	"Jambi Malay":                    "jax",
	"Jamiltepec Mixtec":              "mxt",
	"Jamsay Dogon":                   "djm",
	"Jandai":                         "jan",
	"Jandavra":                       "jnd",
	"Jangkang":                       "djo",
	"Jangshung":                      "jna",
	"Janji":                          "jni",
	"Japanese Sign Language":         "jsl",
	"Japanese":                       "jpn",
	"Japrería":                       "jru",
	"Jaqaru":                         "jqr",
	"Jara":                           "jaf",
	"Jarai":                          "jra",
	"Jarawa (India)":                 "anq",
	"Jaru":                           "ddj",
	"Jauja Wanca Quechua":            "qxw",
	"Jaunsari":                       "jns",
	"Javanese":                       "jav",
	"Javindo":                        "jvd",
	"Jawe":                           "jaz",
	"Jaya":                           "jyy",
	"Jebero":                         "jeb",
	"Jeh":                            "jeh",
	"Jehai":                          "jhi",
	"Jejueo":                         "jje",
	"Jemez":                          "tow",
	"Jenaama Bozo":                   "bze",
	"Jennu Kurumba":                  "xuj",
	"Jere":                           "jer",
	"Jeri Kuo":                       "jek",
	"Jèrriais":                       "nrf",
	"Jerung":                         "jee",
	"Jewish Babylonian Aramaic (ca. 200-1200 CE)": "tmr",
	"Jewish Palestinian Aramaic":                  "jpa",
	"Jhankot Sign Language":                       "jhs",
	"Jiamao":                                      "jio",
	"Jiarong":                                     "jya",
	"Jiba":                                        "juo",
	"Jibu":                                        "jib",
	"Jicarilla Apache":                            "apj",
	"Jiiddu":                                      "jii",
	"Jilbe":                                       "jie",
	"Jilim":                                       "jil",
	"Jimi (Cameroon)":                             "jim",
	"Jimi (Nigeria)":                              "jmi",
	"Jina":                                        "jia",
	"Jinyu Chinese":                               "cjy",
	"Jiongnai Bunu":                               "pnu",
	"Jirel":                                       "jul",
	"Jiru":                                        "jrr",
	"Jita":                                        "jit",
	"Jju":                                         "kaj",
	"Joba":                                        "job",
	"Jofotek-Bromnya":                             "jbr",
	"Jogi":                                        "jog",
	"Jola-Fonyi":                                  "dyo",
	"Jola-Kasa":                                   "csk",
	"Jonkor Bourmataguil":                         "jeu",
	"Jorá":                                        "jor",
	"Jordanian Sign Language":                     "jos",
	"Jorto":                                       "jrt",
	"Jowulu":                                      "jow",
	"Ju":                                          "juu",
	"Ju/'hoan":                                    "ktz",
	"Juang":                                       "jun",
	"Judeo-Arabic":                                "jrb",
	"Judeo-Berber":                                "jbe",
	"Judeo-Georgian":                              "jge",
	"Judeo-Iraqi Arabic":                          "yhd",
	"Judeo-Italian":                               "itk",
	"Judeo-Moroccan Arabic":                       "aju",
	"Judeo-Persian":                               "jpr",
	"Judeo-Tat":                                   "jdt",
	"Judeo-Tripolitanian Arabic":                  "yud",
	"Judeo-Tunisian Arabic":                       "ajt",
	"Judeo-Yemeni Arabic":                         "jye",
	"Jukun Takum":                                 "jbu",
	"Júma":                                        "jua",
	"Jumjum":                                      "jum",
	"Jumla Sign Language":                         "jus",
	"Jumli":                                       "jml",
	"Jungle Inga":                                 "inj",
	"Juquila Mixe":                                "mxq",
	"Jur Modo":                                    "bex",
	"Juray":                                       "juy",
	"Jurchen":                                     "juc",
	"Jurúna":                                      "jur",
	"Jutish":                                      "jut",
	"Juwal":                                       "mwb",
	"Juxtlahuaca Mixtec":                          "vmc",
	"Jwira-Pepesa":                                "jwi",
	"K'iche'":                                     "quc",
	"Kaamba":                                      "xku",
	"Kaan":                                        "ldl",
	"Kaang Chin":                                  "ckn",
	"Kaansa":                                      "gna",
	"Kaba":                                        "ksp",
	"Kabalai":                                     "kvf",
	"Kabardian":                                   "kbd",
	"Kabatei":                                     "xkp",
	"Kabiyè":                                      "kbp",
	"Kabola":                                      "klz",
	"Kabore One":                                  "onk",
	"Kabras":                                      "lkb",
	"Kaburi":                                      "uka",
	"Kabutra":                                     "kbu",
	"Kabuverdianu":                                "kea",
	"Kabwa":                                       "cwa",
	"Kabwari":                                     "kcw",
	"Kabyle":                                      "kab",
	"Kachama-Ganjule":                             "kcx",
	"Kachari":                                     "xac",
	"Kachhi":                                      "kfr",
	"Kachi Koli":                                  "gjk",
	"Kachin":                                      "kac",
	"Kacipo-Balesi":                               "koe",
	"Kaco'":                                       "xkk",
	"Kadai":                                       "kzd",
	"Kadar":                                       "kej",
	"Kadaru":                                      "kdu",
	"Kadazan Dusun":                               "dtp",
	"Kadiwéu":                                     "kbc",
	"Kadu":                                        "zkd",
	"Kaduo":                                       "ktp",
	"Kaera":                                       "jka",
	"Kafa":                                        "kbr",
	"Kafoa":                                       "kpu",
	"Kagan Kalagan":                               "kll",
	"Kagate":                                      "syw",
	"Kagayanen":                                   "cgc",
	"Kagoma":                                      "kdm",
	"Kagoro":                                      "xkg",
	"Kagulu":                                      "kki",
	"Kahe":                                        "hka",
	"Kahua":                                       "agw",
	"Kaian":                                       "kct",
	"Kaibobo":                                     "kzb",
	"Kaidipang":                                   "kzp",
	"Kaiep":                                       "kbw",
	"Kaikadi":                                     "kep",
	"Kaikavian Literary Language":                 "kjv",
	"Kaike":                                       "kzq",
	"Kaiku":                                       "kkq",
	"Kaimbé":                                      "xai",
	"Kaimbulawa":                                  "zka",
	"Kaingang":                                    "kgp",
	"Kairak":                                      "ckr",
	"Kairiru":                                     "kxa",
	"Kairui-Midiki":                               "krd",
	"Kais":                                        "kzm",
	"Kaivi":                                       "kce",
	"Kaiwá":                                       "kgk",
	"Kaiy":                                        "tcq",
	"Kajakse":                                     "ckq",
	"Kajali":                                      "xkj",
	"Kajaman":                                     "kag",
	"Kakabai":                                     "kqf",
	"Kakabe":                                      "kke",
	"Kakanda":                                     "kka",
	"Kaki Ae":                                     "tbd",
	"Kako":                                        "kkj",
	"Kakwa":                                       "keo",
	"Kala Lagaw Ya":                               "mwp",
	"Kalaallisut":                                 "kal",
	"Kalaamaya":                                   "lkm",
	"Kalabakan":                                   "kve",
	"Kalabari":                                    "ijn",
	"Kalabra":                                     "kzz",
	"Kalagan":                                     "kqe",
	"Kalaktang Monpa":                             "kkf",
	"Kalam":                                       "kmh",
	"Kalami":                                      "gwc",
	"Kalamsé":                                     "knz",
	"Kalanadi":                                    "wkl",
	"Kalanga":                                     "kck",
	"Kalanguya":                                   "kak",
	"Kalao":                                       "kly",
	"Kalapuya":                                    "kyl",
	"Kalarko":                                     "kba",
	"Kalasha":                                     "kls",
	"Kalenjin":                                    "kln",
	"Kalispel-Pend d'Oreille":                     "fla",
	"Kalkoti":                                     "xka",
	"Kalkutung":                                   "ktg",
	"Kalmyk":                                      "xal",
	"Kalo Finnish Romani":                         "rmf",
	"Kalou":                                       "ywa",
	"Kaluli":                                      "bco",
	"Kalumpang":                                   "kli",
	"Kam":                                         "kdx",
	"Kamakan":                                     "vkm",
	"Kamang":                                      "woi",
	"Kamano":                                      "kbq",
	"Kamantan":                                    "kci",
	"Kamar":                                       "keq",
	"Kamara":                                      "jmr",
	"Kamarian":                                    "kzx",
	"Kamaru":                                      "kgx",
	"Kamas":                                       "xas",
	"Kamasa":                                      "klp",
	"Kamasau":                                     "kms",
	"Kamayo":                                      "kyk",
	"Kamayurá":                                    "kay",
	"Kamba (Kenya)":                               "kam",
	"Kambaata":                                    "ktb",
	"Kambaira":                                    "kyy",
	"Kambera":                                     "xbr",
	"Kamberau":                                    "irx",
	"Kambiwá":                                     "xbw",
	"Kami (Nigeria)":                              "kmi",
	"Kami (Tanzania)":                             "kcu",
	"Kamo":                                        "kcq",
	"Kamoro":                                      "kgq",
	"Kamu":                                        "xmu",
	"Kamula":                                      "xla",
	"Kamviri":                                     "xvi",
	"Kamwe":                                       "hig",
	"Kanakanabu":                                  "xnb",
	"Kanamarí":                                    "knm",
	"Kanan":                                       "zkn",
	"Kanashi":                                     "xns",
	"Kanasi":                                      "soq",
	"Kanauji":                                     "bjj",
	"Kandas":                                      "kqw",
	"Kandawo":                                     "gam",
	"Kande":                                       "kbs",
	"Kanembu":                                     "kbl",
	"Kang":                                        "kyp",
	"Kanga":                                       "kcp",
	"Kangean":                                     "kkv",
	"Kanggape":                                    "igm",
	"Kangjia":                                     "kxs",
	"Kango (Bas-Uélé District)":                   "kty",
	"Kango (Tshopo District)":                     "kzy",
	"Kangri":                                      "xnr",
	"Kaniet":                                      "ktk",
	"Kanikkaran":                                  "kev",
	"Kaningdon-Nindem":                            "kdp",
	"Kaningi":                                     "kzo",
	"Kaningra":                                    "knr",
	"Kaninuwa":                                    "wat",
	"Kanite":                                      "kmu",
	"Kanjari":                                     "kft",
	"Kanju":                                       "kbe",
	"Kankanaey":                                   "kne",
	"Kannada Kurumba":                             "kfi",
	"Kannada":                                     "kan",
	"Kanoé":                                       "kxo",
	"Kanowit-Tanjong Melanau":                     "kxn",
	"Kansa":                                       "ksk",
	"Kantosi":                                     "xkt",
	"Kanu":                                        "khx",
	"Kanufi":                                      "kni",
	"Kanuri":                                      "kau",
	"Kanyok":                                      "kny",
	"Kao":                                         "kax",
	"Kaonde":                                      "kqn",
	"Kap":                                         "ykm",
	"Kapin":                                       "tbx",
	"Kapinawá":                                    "xpn",
	"Kapingamarangi":                              "kpg",
	"Kapori":                                      "khp",
	"Kapriman":                                    "dju",
	"Kaptiau":                                     "kbi",
	"Kapya":                                       "klo",
	"Kaqchikel":                                   "cak",
	"Kara (Central African Republic)":             "kah",
	"Kara (Korea)":                                "zra",
	"Kara (Papua New Guinea)":                     "leu",
	"Kara (Tanzania)":                             "reg",
	"Kara-Kalpak":                                 "kaa",
	"Karachay-Balkar":                             "krc",
	"Karadjeri":                                   "gbd",
	"Karagas":                                     "kim",
	"Karaim":                                      "kdr",
	"Karajá":                                      "kpj",
	"Karakhanid":                                  "xqa",
	"Karami":                                      "xar",
	"Karamojong":                                  "kdj",
	"Karang":                                      "kzr",
	"Karanga":                                     "kth",
	"Karankawa":                                   "zkk",
	"Karao":                                       "kyj",
	"Karas":                                       "kgv",
	"Karata":                                      "kpt",
	"Karawa":                                      "xrw",
	"Karbi":                                       "mjw",
	"Kare (Central African Republic)":             "kbn",
	"Kare (Papua New Guinea)":                     "kmf",
	"Karekare":                                    "kai",
	"Karelian":                                    "krl",
	"Karenggapa":                                  "eaa",
	"Karey":                                       "kyd",
	"Kari":                                        "kbj",
	"Karingani":                                   "kgn",
	"Karipúna Creole French":                      "kmv",
	"Karipuna":                                    "kuq",
	"Karipúna":                                    "kgm",
	"Karirí-Xocó":                                 "kzw",
	"Karitiâna":                                   "ktn",
	"Kariya":                                      "kil",
	"Kariyarra":                                   "vka",
	"Karkar-Yuri":                                 "yuj",
	"Karkin":                                      "krb",
	"Karko":                                       "kko",
	"Karnai":                                      "bbv",
	"Karo (Brazil)":                               "arr",
	"Karo (Ethiopia)":                             "kxh",
	"Karok":                                       "kyh",
	"Karon Dori":                                  "kgw",
	"Karon":                                       "krx",
	"Karore":                                      "xkx",
	"Karranga":                                    "xrq",
	"Karuwali":                                    "rxw",
	"Kasanga":                                     "ccj",
	"Kasem":                                       "xsm",
	"Kashaya":                                     "kju",
	"Kashmiri":                                    "kas",
	"Kashubian":                                   "csb",
	"Kasiguranin":                                 "ksn",
	"Kaska":                                       "kkz",
	"Kaskean":                                     "zsk",
	"Kasua":                                       "khs",
	"Katabaga":                                    "ktq",
	"Katawixi":                                    "xat",
	"Katbol":                                      "tmb",
	"Katcha-Kadugli-Miri":                         "xtc",
	"Kâte":                                        "kmg",
	"Kathoriya Tharu":                             "tkt",
	"Kathu":                                       "ykt",
	"Kati":                                        "bsh",
	"Katkari":                                     "kfu",
	"Katla":                                       "kcr",
	"Kato":                                        "ktw",
	"Katso":                                       "kaf",
	"Katua":                                       "kta",
	"Katukína":                                    "kav",
	"Kaulong":                                     "pss",
	"Kaur":                                        "vkk",
	"Kaure":                                       "bpp",
	"Kaurna":                                      "zku",
	"Kauwera":                                     "xau",
	"Kavalan":                                     "ckv",
	"Kavet":                                       "krv",
	"Kawacha":                                     "kcb",
	"Kawaiisu":                                    "xaw",
	"Kawe":                                        "kgb",
	"Kawi":                                        "kaw",
	"Kaxararí":                                    "ktx",
	"Kaxuiâna":                                    "kbb",
	"Kayabí":                                      "kyz",
	"Kayagar":                                     "kyt",
	"Kayan Mahakam":                               "xay",
	"Kayan River Kayan":                           "xkn",
	"Kayan":                                       "pdu",
	"Kayapó":                                      "txu",
	"Kayardild":                                   "gyd",
	"Kayaw":                                       "kvl",
	"Kayeli":                                      "kzl",
	"Kayong":                                      "kxy",
	"Kayort":                                      "kyv",
	"Kaytetye":                                    "gbb",
	"Kayupulau":                                   "kzu",
	"Kazakh":                                      "kaz",
	"Kazukuru":                                    "kzk",
	"Ke'o":                                        "xxk",
	"Keak":                                        "keh",
	"Keapara":                                     "khz",
	"Kedah Malay":                                 "meo",
	"Kedang":                                      "ksx",
	"Keder":                                       "kdy",
	"Kehu":                                        "khh",
	"Kei":                                         "kei",
	"Keiga":                                       "kec",
	"Kein":                                        "bmh",
	"Keiyo":                                       "eyo",
	"Kekchí":                                      "kek",
	"Kela (Democratic Republic of Congo)":         "kel",
	"Kela (Papua New Guinea)":                     "kcl",
	"Kelabit":                                     "kzi",
	"Kele (Democratic Republic of Congo)":         "khy",
	"Kele (Papua New Guinea)":                     "sbc",
	"Kélé":                                        "keb",
	"Keley-I Kallahan":                            "ify",
	"Keliko":                                      "kbo",
	"Kelo":                                        "xel",
	"Kelon":                                       "kyo",
	"Kemak":                                       "kem",
	"Kembayan":                                    "xem",
	"Kemberano":                                   "bzp",
	"Kembra":                                      "xkw",
	"Kemedzung":                                   "dmo",
	"Kemi Sami":                                   "sjk",
	"Kemiehua":                                    "kfj",
	"Kemtuik":                                     "kmt",
	"Kenaboi":                                     "xbn",
	"Kenati":                                      "gat",
	"Kendayan":                                    "knx",
	"Kendeje":                                     "klf",
	"Kendem":                                      "kvm",
	"Kenga":                                       "kyq",
	"Keningau Murut":                              "kxi",
	"Keninjal":                                    "knl",
	"Kensiu":                                      "kns",
	"Kenswei Nsei":                                "ndb",
	"Kenyan Sign Language":                        "xki",
	"Kenyang":                                     "ken",
	"Kenyi":                                       "lke",
	"Kenzi":                                       "xnz",
	"Keoru-Ahia":                                  "xeu",
	"Kepkiriwát":                                  "kpn",
	"Kepo'":                                       "kuk",
	"Kera":                                        "ker",
	"Kerak":                                       "hhr",
	"Kereho":                                      "xke",
	"Kerek":                                       "krk",
	"Kerewe":                                      "ked",
	"Kerewo":                                      "kxz",
	"Kerinci":                                     "kvr",
	"Kesawai":                                     "xes",
	"Ket":                                         "ket",
	"Ketangalan":                                  "kae",
	"Kete":                                        "kcv",
	"Ketengban":                                   "xte",
	"Ketum":                                       "ktt",
	"Keyagana":                                    "kyg",
	"Kɛlɛngaxo Bozo":                              "bzx",
	"Kgalagadi":                                   "xkv",
	"Khakas":                                      "kjh",
	"Khalaj":                                      "kjf",
	"Khaling":                                     "klr",
	"Khamba":                                      "kbg",
	"Khams Tibetan":                               "khg",
	"Khamti":                                      "kht",
	"Khamyang":                                    "ksu",
	"Khana":                                       "ogo",
	"Khandesi":                                    "khn",
	"Kháng":                                       "kjm",
	"Khanty":                                      "kca",
	"Khao":                                        "xao",
	"Kharam Naga":                                 "kfw",
	"Kharia Thar":                                 "ksy",
	"Kharia":                                      "khr",
	"Khasi":                                       "kha",
	"Khayo":                                       "lko",
	"Khazar":                                      "zkz",
	"Khe":                                         "kqg",
	"Khehek":                                      "tlx",
	"Khengkha":                                    "xkf",
	"Khetrani":                                    "xhe",
	"Khezha Naga":                                 "nkh",
	"Khiamniungan Naga":                           "kix",
	"Khinalugh":                                   "kjj",
	"Khirwar":                                     "kwx",
	"Khisa":                                       "kqm",
	"Khlor":                                       "llo",
	"Khlula":                                      "ykl",
	"Khmu":                                        "kjg",
	"Kho'ini":                                     "xkc",
	"Khoekhoe":                                    "naq",
	"Khoibu Naga":                                 "nkb",
	"Kholok":                                      "ktc",
	"Khorasani Turkish":                           "kmz",
	"Khorezmian":                                  "zkh",
	"Khotanese":                                   "kho",
	"Khowar":                                      "khw",
	"Khua":                                        "xhv",
	"Khuen":                                       "khf",
	"Khumi Chin":                                  "cnk",
	"Khün":                                        "kkh",
	"Khunsari":                                    "kfm",
	"Khvarshi":                                    "khv",
	"Kibala":                                      "blv",
	"Kibet":                                       "kie",
	"Kibiri":                                      "prm",
	"Kickapoo":                                    "kic",
	"Kikai":                                       "kzg",
	"Kikuyu":                                      "kik",
	"Kildin Sami":                                 "sjd",
	"Kilivila":                                    "kij",
	"Kiliwa":                                      "klb",
	"Kilmeri":                                     "kih",
	"Kim Mun":                                     "mji",
	"Kim":                                         "kia",
	"Kimaama":                                     "kig",
	"Kimaragang":                                  "kqr",
	"Kimbu":                                       "kiv",
	"Kimbundu":                                    "kmb",
	"Kimki":                                       "sbt",
	"Kimré":                                       "kqp",
	"Kinabalian":                                  "cbw",
	"Kinalakna":                                   "kco",
	"Kinamiging Manobo":                           "mkx",
	"Kinaray-A":                                   "krj",
	"Kinga":                                       "zga",
	"Kinnauri":                                    "kfk",
	"Kintaq":                                      "knq",
	"Kinuku":                                      "kkd",
	"Kinyarwanda":                                 "kin",
	"Kioko":                                       "ues",
	"Kiong":                                       "kkm",
	"Kiorr":                                       "xko",
	"Kiowa Apache":                                "apk",
	"Kiowa":                                       "kio",
	"Kipsigis":                                    "sgc",
	"Kiput":                                       "kyi",
	"Kir-Balar":                                   "kkr",
	"Kire":                                        "geb",
	"Kirghiz":                                     "kir",
	"Kirike":                                      "okr",
	"Kirikiri":                                    "kiy",
	"Kirmanjki (individual language)":             "kiu",
	"Kirya-Konzəl":                                "fkk",
	"Kis":                                         "kis",
	"Kisa":                                        "lks",
	"Kisan":                                       "xis",
	"Kisankasa":                                   "kqh",
	"Kisar":                                       "kje",
	"Kisi":                                        "kiz",
	"Kistane":                                     "gru",
	"Kita Maninkakan":                             "mwk",
	"Kitan":                                       "zkt",
	"Kitja":                                       "gia",
	"Kitsai":                                      "kii",
	"Kituba (Congo)":                              "mkw",
	"Kituba (Democratic Republic of Congo)":       "ktu",
	"Kiunum":                                      "wei",
	"Kla-Dan":                                     "lda",
	"Klamath-Modoc":                               "kla",
	"Klao":                                        "klu",
	"Klias River Kadazan":                         "kqt",
	"Klingon":                                     "tlh",
	"Knaanic":                                     "czk",
	"Ko":                                          "fuj",
	"Koalib":                                      "kib",
	"Koasati":                                     "cku",
	"Koba":                                        "kpd",
	"Kobiana":                                     "kcj",
	"Kobol":                                       "kgu",
	"Kobon":                                       "kpw",
	"Koch":                                        "kdq",
	"Kochila Tharu":                               "thq",
	"Koda":                                        "cdz",
	"Kodaku":                                      "ksz",
	"Kodava":                                      "kfa",
	"Kodeoha":                                     "vko",
	"Kodi":                                        "kod",
	"Kodia":                                       "kwp",
	"Koenoem":                                     "kcs",
	"Kofa":                                        "kso",
	"Kofei":                                       "kpi",
	"Kofyar":                                      "kwl",
	"Koguryo":                                     "zkg",
	"Kohin":                                       "kkx",
	"Kohistani Shina":                             "plk",
	"Koho":                                        "kpm",
	"Kohumono":                                    "bcs",
	"Koi":                                         "kkt",
	"Koibal":                                      "zkb",
	"Koireng":                                     "nkd",
	"Koitabu":                                     "kqi",
	"Koiwat":                                      "kxt",
	"Kok Borok":                                   "trp",
	"Kok-Nar":                                     "gko",
	"Kokata":                                      "ktd",
	"Koke":                                        "kou",
	"Koki Naga":                                   "nxk",
	"Koko Babangk":                                "okg",
	"Kokoda":                                      "xod",
	"Kokola":                                      "kzn",
	"Kokota":                                      "kkk",
	"Kol (Bangladesh)":                            "ekl",
	"Kol (Cameroon)":                              "biw",
	"Kol (Papua New Guinea)":                      "kol",
	"Kola":                                        "kvv",
	"Kolbila":                                     "klc",
	"Kolibugan Subanon":                           "skn",
	"Kölsch":                                      "ksh",
	"Koluwawa":                                    "klx",
	"Kom (Cameroon)":                              "bkm",
	"Kom (India)":                                 "kmm",
	"Koma":                                        "kmy",
	"Komba":                                       "kpf",
	"Kombai":                                      "tyn",
	"Kombio":                                      "xbi",
	"Komering":                                    "kge",
	"Komi-Permyak":                                "koi",
	"Komi-Zyrian":                                 "kpv",
	"Komi":                                        "kom",
	"Kominimung":                                  "xoi",
	"Komo (Democratic Republic of Congo)":         "kmw",
	"Komo (Sudan)":                                "xom",
	"Komodo":                                      "kvh",
	"Kompane":                                     "kvp",
	"Komyandaret":                                 "kzv",
	"Kon Keu":                                     "kkn",
	"Konai":                                       "kxw",
	"Konda-Dora":                                  "kfc",
	"Konda":                                       "knd",
	"Koneraw":                                     "kdw",
	"Kongo":                                       "kon",
	"Konkani (individual language)":               "knn",
	"Konkani (macrolanguage)":                     "kok",
	"Konkomba":                                    "xon",
	"Konni":                                       "kma",
	"Kono (Guinea)":                               "knu",
	"Kono (Nigeria)":                              "klk",
	"Kono (Sierra Leone)":                         "kno",
	"Konomala":                                    "koa",
	"Konongo":                                     "kcz",
	"Konso":                                       "kxc",
	"Konyak Naga":                                 "nbe",
	"Konyanka Maninka":                            "mku",
	"Konzo":                                       "koo",
	"Koongo":                                      "kng",
	"Koonzime":                                    "ozm",
	"Koorete":                                     "kqy",
	"Kopar":                                       "xop",
	"Kopkaka":                                     "opk",
	"Korafe-Yegha":                                "kpr",
	"Korak":                                       "koz",
	"Korana":                                      "kqz",
	"Korandje":                                    "kcy",
	"Korean Sign Language":                        "kvk",
	"Korean":                                      "kor",
	"Koreguaje":                                   "coe",
	"Koresh-e Rostam":                             "okh",
	"Korku":                                       "kfq",
	"Korlai Creole Portuguese":                    "vkp",
	"Koro (Côte d'Ivoire)":                        "kfo",
	"Koro (India)":                                "jkr",
	"Koro (Papua New Guinea)":                     "kxr",
	"Koro (Vanuatu)":                              "krf",
	"Koro Wachi":                                  "bqv",
	"Koromfé":                                     "kfz",
	"Koromira":                                    "kqj",
	"Koronadal Blaan":                             "bpr",
	"Koroni":                                      "xkq",
	"Korop":                                       "krp",
	"Koropó":                                      "xxr",
	"Koroshi":                                     "ktl",
	"Korowai":                                     "khe",
	"Korra Koraga":                                "kfd",
	"Korubo":                                      "xor",
	"Korupun-Sela":                                "kpq",
	"Korwa":                                       "kfp",
	"Koryak":                                      "kpy",
	"Kosadle":                                     "kiq",
	"Kosarek Yale":                                "kkl",
	"Kosena":                                      "kze",
	"Koshin":                                      "kid",
	"Kosraean":                                    "kos",
	"Kota (Gabon)":                                "koq",
	"Kota (India)":                                "kfe",
	"Kota Bangun Kutai Malay":                     "mqg",
	"Kota Marudu Talantang":                       "grm",
	"Kotafon Gbe":                                 "kqk",
	"Kotava":                                      "avk",
	"Koti":                                        "eko",
	"Kott":                                        "zko",
	"Kouya":                                       "kyf",
	"Kovai":                                       "kqb",
	"Kove":                                        "kvc",
	"Kowaki":                                      "xow",
	"Kowiai":                                      "kwh",
	"Koy Sanjaq Surat":                            "kqd",
	"Koya":                                        "kff",
	"Koyaga":                                      "kga",
	"Koyo":                                        "koh",
	"Koyra Chiini Songhay":                        "khq",
	"Koyraboro Senni Songhai":                     "ses",
	"Koyukon":                                     "koy",
	"Kpagua":                                      "kuw",
	"Kpala":                                       "kpl",
	"Kpan":                                        "kpk",
	"Kpasam":                                      "pbn",
	"Kpati":                                       "koc",
	"Kpatili":                                     "kym",
	"Kpeego":                                      "cpo",
	"Kpelle":                                      "kpe",
	"Kpessi":                                      "kef",
	"Kplang":                                      "kph",
	"Krache":                                      "kye",
	"Krahô":                                       "xra",
	"Kraol":                                       "rka",
	"Krenak":                                      "kqq",
	"Krevinian":                                   "zkv",
	"Kreye":                                       "xre",
	"Kriang":                                      "ngt",
	"Krikati-Timbira":                             "xri",
	"Krio":                                        "kri",
	"Kriol":                                       "rop",
	"Krisa":                                       "ksi",
	"Krobu":                                       "kxb",
	"Krongo":                                      "kgo",
	"Krung":                                       "krr",
	"Krymchak":                                    "jct",
	"Kryts":                                       "kry",
	"Kua-nsi":                                     "ykn",
	"Kua":                                         "tyu",
	"Kuamasi":                                     "yku",
	"Kuan":                                        "uan",
	"Kuanhua":                                     "xnh",
	"Kuanua":                                      "ksd",
	"Kuanyama":                                    "kua",
	"Kube":                                        "kgf",
	"Kubi":                                        "kof",
	"Kubo":                                        "jko",
	"Kubu":                                        "kvb",
	"Kucong":                                      "lkc",
	"Kudiya":                                      "kfg",
	"Kudmali":                                     "kyw",
	"Kudu-Camo":                                   "kov",
	"Kugama":                                      "kow",
	"Kugbo":                                       "kes",
	"Kui (India)":                                 "kxu",
	"Kui (Indonesia)":                             "kvd",
	"Kuijau":                                      "dkr",
	"Kuikúro-Kalapálo":                            "kui",
	"Kujarge":                                     "vkj",
	"Kuk":                                         "kfn",
	"Kukatja":                                     "kux",
	"Kuke":                                        "ght",
	"Kukele":                                      "kez",
	"Kukna":                                       "kex",
	"Kuku-Mangk":                                  "xmq",
	"Kuku-Mu'inh":                                 "xmp",
	"Kuku-Muminh":                                 "xmh",
	"Kuku-Ugbanh":                                 "ugb",
	"Kuku-Uwanh":                                  "uwa",
	"Kuku-Yalanji":                                "gvn",
	"Kula":                                        "tpg",
	"Kulere":                                      "kul",
	"Kulfa":                                       "kxj",
	"Kulina Pano":                                 "xpk",
	"Kulisusu":                                    "vkl",
	"Kullu Pahari":                                "kfx",
	"Kulon-Pazeh":                                 "uun",
	"Kulung (Nepal)":                              "kle",
	"Kulung (Nigeria)":                            "bbu",
	"Kumalu":                                      "ksl",
	"Kumam":                                       "kdi",
	"Kuman (Papua New Guinea)":                    "kue",
	"Kuman (Russia)":                              "qwm",
	"Kumaoni":                                     "kfy",
	"Kumarbhag Paharia":                           "kmj",
	"Kumba":                                       "ksm",
	"Kumbainggar":                                 "kgs",
	"Kumbaran":                                    "wkb",
	"Kumbewaha":                                   "xks",
	"Kumhali":                                     "kra",
	"Kumiai":                                      "dih",
	"Kumukio":                                     "kuo",
	"Kumyk":                                       "kum",
	"Kumzari":                                     "zum",
	"Kunama":                                      "kun",
	"Kunbarlang":                                  "wlg",
	"Kunda":                                       "kdn",
	"Kundal Shahi":                                "shd",
	"Kunduvadi":                                   "wku",
	"Kung-Ekoka":                                  "knw",
	"Kung":                                        "kfl",
	"Kungarakany":                                 "ggk",
	"Kungardutyi":                                 "gdt",
	"Kunggari":                                    "kgl",
	"Kungkari":                                    "lku",
	"Kuni-Boazi":                                  "kvg",
	"Kuni":                                        "kse",
	"Kunigami":                                    "xug",
	"Kunimaipa":                                   "kup",
	"Kunja":                                       "pep",
	"Kunjen":                                      "kjn",
	"Kunyi":                                       "njx",
	"Kunza":                                       "kuz",
	"Kuo":                                         "xuo",
	"Kuot":                                        "kto",
	"Kupa":                                        "kug",
	"Kupang Malay":                                "mkn",
	"Kupia":                                       "key",
	"Kupsabiny":                                   "kpz",
	"Kur":                                         "kuv",
	"Kura Ede Nago":                               "nqk",
	"Kurama":                                      "krh",
	"Kuranko":                                     "knk",
	"Kurdish":                                     "kur",
	"Kuri":                                        "nbn",
	"Kuria":                                       "kuj",
	"Kurichiya":                                   "kfh",
	"Kurmukar":                                    "kfv",
	"Kurnai":                                      "unn",
	"Kurrama":                                     "vku",
	"Kurti":                                       "ktm",
	"Kurtokha":                                    "xkz",
	"Kuruáya":                                     "kyr",
	"Kurudu":                                      "kjr",
	"Kurukh":                                      "kru",
	"Kusaal":                                      "kus",
	"Kusaghe":                                     "ksg",
	"Kushi":                                       "kuh",
	"Kusu":                                        "ksv",
	"Kusunda":                                     "kgg",
	"Kutenai":                                     "kut",
	"Kutep":                                       "kub",
	"Kuthant":                                     "xut",
	"Kutong":                                      "skm",
	"Kutto":                                       "kpa",
	"Kutu":                                        "kdc",
	"Kuturmi":                                     "khj",
	"Kuuk-Yak":                                    "uky",
	"Kuuku-Ya'u":                                  "kuy",
	"Kuvale":                                      "olu",
	"Kuvi":                                        "kxv",
	"Kuwaa":                                       "blh",
	"Kuwaataay":                                   "cwt",
	"Kuy":                                         "kdt",
	"Kven Finnish":                                "fkv",
	"Kw'adza":                                     "wka",
	"Kwa'":                                        "bko",
	"Kwa":                                         "kwb",
	"Kwaami":                                      "ksq",
	"Kwadi":                                       "kwz",
	"Kwaio":                                       "kwd",
	"Kwaja":                                       "kdz",
	"Kwakiutl":                                    "kwk",
	"Kwakum":                                      "kwu",
	"Kwalhioqua-Tlatskanai":                       "qwt",
	"Kwama":                                       "kmq",
	"Kwambi":                                      "kwm",
	"Kwamera":                                     "tnk",
	"Kwami":                                       "ktf",
	"Kwamtim One":                                 "okk",
	"Kwandu":                                      "xdo",
	"Kwang":                                       "kvi",
	"Kwanga":                                      "kwj",
	"Kwangali":                                    "kwn",
	"Kwanja":                                      "knp",
	"Kwara'ae":                                    "kwf",
	"Kwasio":                                      "nmg",
	"Kwaya":                                       "kya",
	"Kwaza":                                       "xwa",
	"Kwegu":                                       "xwg",
	"Kwer":                                        "kwr",
	"Kwerba Mamberamo":                            "xwr",
	"Kwerba":                                      "kwe",
	"Kwere":                                       "cwe",
	"Kwerisa":                                     "kkb",
	"Kwese":                                       "kws",
	"Kwesten":                                     "kwt",
	"Kwini":                                       "gww",
	"Kwinsu":                                      "kuc",
	"Kwinti":                                      "kww",
	"Kwoma":                                       "kmo",
	"Kwomtari":                                    "kwo",
	"Kxoe":                                        "xuu",
	"Kyak":                                        "bka",
	"Kyaka":                                       "kyc",
	"Kyan-Karyaw Naga":                            "nqq",
	"Kyanga":                                      "tye",
	"Kyenele":                                     "kql",
	"Kyerung":                                     "kgy",
	"La'bi":                                       "lbi",
	"Láá Láá Bwamu":                               "bwj",
	"Láadan":                                      "ldn",
	"Laal":                                        "gdm",
	"Laari":                                       "ldi",
	"Laba":                                        "lau",
	"Label":                                       "lbb",
	"Labir":                                       "jku",
	"Labo Phowa":                                  "ypb",
	"Labo":                                        "mwi",
	"Labu":                                        "lbu",
	"Labuk-Kinabatangan Kadazan":                  "dtb",
	"Lacandon":                                    "lac",
	"Lachi":                                       "lbt",
	"Lachiguiri Zapotec":                          "zpa",
	"Lachixío Zapotec":                            "zpl",
	"Ladakhi":                                     "lbj",
	"Ladin":                                       "lld",
	"Ladino":                                      "lad",
	"Ladji Ladji":                                 "llj",
	"Laeko-Libuat":                                "lkl",
	"Lafofa":                                      "laf",
	"Laghu":                                       "lgb",
	"Laghuu":                                      "lgh",
	"Lagwan":                                      "kot",
	"Laha (Indonesia)":                            "lhh",
	"Laha (Viet Nam)":                             "lha",
	"Lahanan":                                     "lhn",
	"Lahnda":                                      "lah",
	"Lahta Karen":                                 "kvt",
	"Lahu Shi":                                    "lhi",
	"Lahu":                                        "lhu",
	"Lahul Lohar":                                 "lhl",
	"Laimbue":                                     "lmx",
	"Laitu Chin":                                  "clj",
	"Laiyolo":                                     "lji",
	"Lak":                                         "lbe",
	"Laka (Chad)":                                 "lap",
	"Laka (Nigeria)":                              "lak",
	"Lakalei":                                     "lka",
	"Lake Miwok":                                  "lmw",
	"Lakha":                                       "lkh",
	"Laki":                                        "lki",
	"Lakkia":                                      "lbc",
	"Lakon":                                       "lkn",
	"Lakondê":                                     "lkd",
	"Lakota Dida":                                 "dic",
	"Lakota":                                      "lkt",
	"Lala-Bisa":                                   "leb",
	"Lala-Roba":                                   "lla",
	"Lala":                                        "nrz",
	"Lalana Chinantec":                            "cnl",
	"Lalia":                                       "lal",
	"Lama (Togo)":                                 "las",
	"Lama Bai":                                    "lay",
	"Lamaholot":                                   "slp",
	"Lamalera":                                    "lmr",
	"Lamang":                                      "hia",
	"Lamatuka":                                    "lmq",
	"Lamba":                                       "lam",
	"Lambadi":                                     "lmn",
	"Lambayeque Quechua":                          "quf",
	"Lambichhong":                                 "lmh",
	"Lamboya":                                     "lmy",
	"Lambya":                                      "lai",
	"Lame":                                        "bma",
	"Lamenu":                                      "lmu",
	"Lamet":                                       "lbn",
	"Lamja-Dengsa-Tola":                           "ldh",
	"Lamkang":                                     "lmk",
	"Lamma":                                       "lev",
	"Lamnso'":                                     "lns",
	"Lamogai":                                     "lmg",
	"Lampung Api":                                 "ljp",
	"Lampung Nyo":                                 "abl",
	"Lamu-Lamu":                                   "lby",
	"Lamu":                                        "llh",
	"Lanas Lobu":                                  "ruu",
	"Landoma":                                     "ldm",
	"Lang'e":                                      "yne",
	"Langam":                                      "lnm",
	"Langbashe":                                   "lna",
	"Langi":                                       "lag",
	"Langnian Buyang":                             "yln",
	"Lango (Sudan)":                               "lno",
	"Lango (Uganda)":                              "laj",
	"Langobardic":                                 "lng",
	"Langue des signes de Belgique Francophone": "sfb",
	"Lanima":                                "lnw",
	"Lanoh":                                 "lnh",
	"Lao Naga":                              "nlq",
	"Lao":                                   "lao",
	"Laomian":                               "lwm",
	"Laopang":                               "lbg",
	"Laos Sign Language":                    "lso",
	"Lapaguía-Guivini Zapotec":              "ztl",
	"Laragia":                               "lrg",
	"Larantuka Malay":                       "lrt",
	"Lardil":                                "lbz",
	"Larevat":                               "lrv",
	"Large Flowery Miao":                    "hmd",
	"Lari":                                  "lrl",
	"Larike-Wakasihu":                       "alo",
	"Laro":                                  "lro",
	"Larteh":                                "lar",
	"Laru":                                  "lan",
	"Lasalimu":                              "llm",
	"Lasgerdi":                              "lsa",
	"Lashi":                                 "lsi",
	"Lasi":                                  "lss",
	"Late Middle Chinese":                   "ltc",
	"Latgalian":                             "ltg",
	"Latin":                                 "lat",
	"Latu":                                  "ltu",
	"Latundê":                               "ltn",
	"Latvian Sign Language":                 "lsl",
	"Latvian":                               "lav",
	"Lau":                                   "llu",
	"Laua":                                  "luf",
	"Lauan":                                 "llx",
	"Lauje":                                 "law",
	"Laura":                                 "lur",
	"Laurentian":                            "lre",
	"Lautu Chin":                            "clt",
	"Lavatbura-Lamusong":                    "lbv",
	"Lave":                                  "brb",
	"Laven":                                 "lbo",
	"Lavukaleve":                            "lvk",
	"Lawangan":                              "lbx",
	"Lawu":                                  "lwu",
	"Lawunuia":                              "tgi",
	"Layakha":                               "lya",
	"Laz":                                   "lzz",
	"Lealao Chinantec":                      "cle",
	"Leco":                                  "lec",
	"Ledo Kaili":                            "lew",
	"Leelau":                                "ldk",
	"Lefa":                                  "lfa",
	"Lega-Mwenga":                           "lgm",
	"Lega-Shabunda":                         "lea",
	"Legbo":                                 "agb",
	"Legenyem":                              "lcc",
	"Lehali":                                "tql",
	"Lehalurup":                             "urr",
	"Lehar":                                 "cae",
	"Leinong Naga":                          "lzn",
	"Leipon":                                "lek",
	"Lelak":                                 "llk",
	"Lele (Chad)":                           "lln",
	"Lele (Democratic Republic of Congo)":   "lel",
	"Lele (Guinea)":                         "llc",
	"Lele (Papua New Guinea)":               "lle",
	"Lelemi":                                "lef",
	"Lelepa":                                "lpa",
	"Lembena":                               "leq",
	"Lemerig":                               "lrz",
	"Lemio":                                 "lei",
	"Lemnian":                               "xle",
	"Lemolang":                              "ley",
	"Lemoro":                                "ldj",
	"Lenakel":                               "tnl",
	"Lenca":                                 "len",
	"Lendu":                                 "led",
	"Lengilu":                               "lgi",
	"Lengo":                                 "lgr",
	"Lengola":                               "lej",
	"Leningitij":                            "lnj",
	"Lenje":                                 "leh",
	"Lenkau":                                "ler",
	"Lenyima":                               "ldg",
	"Lepcha":                                "lep",
	"Lepki":                                 "lpe",
	"Lepontic":                              "xlp",
	"Lere":                                  "gnh",
	"Lese":                                  "les",
	"Lesing-Gelimi":                         "let",
	"Letemboi":                              "nms",
	"Leti (Cameroon)":                       "leo",
	"Leti (Indonesia)":                      "lti",
	"Levuka":                                "lvu",
	"Lewo Eleng":                            "lwe",
	"Lewo":                                  "lww",
	"Lewotobi":                              "lwt",
	"Leyigha":                               "ayi",
	"Lezghian":                              "lez",
	"Lhokpu":                                "lhp",
	"Lhomi":                                 "lhm",
	"Li'o":                                  "ljl",
	"Liabuku":                               "lix",
	"Liana-Seti":                            "ste",
	"Liangmai Naga":                         "njn",
	"Lianshan Zhuang":                       "zln",
	"Liberia Kpelle":                        "xpe",
	"Liberian English":                      "lir",
	"Libido":                                "liq",
	"Libinza":                               "liz",
	"Libon Bikol":                           "lbl",
	"Liburnian":                             "xli",
	"Libyan Arabic":                         "ayl",
	"Libyan Sign Language":                  "lbs",
	"Ligbi":                                 "lig",
	"Ligenza":                               "lgz",
	"Ligurian (Ancient)":                    "xlg",
	"Ligurian":                              "lij",
	"Lihir":                                 "lih",
	"Lijili":                                "mgi",
	"Lika":                                  "lik",
	"Liki":                                  "lio",
	"Likila":                                "lie",
	"Likuba":                                "kxx",
	"Likum":                                 "lib",
	"Likwala":                               "kwc",
	"Lilau":                                 "lll",
	"Lillooet":                              "lil",
	"Limassa":                               "bme",
	"Limbu":                                 "lif",
	"Limbum":                                "lmp",
	"Limburgan":                             "lim",
	"Limi":                                  "ylm",
	"Limilngan":                             "lmc",
	"Limos Kalinga":                         "kmk",
	"Linear A":                              "lab",
	"Lingala":                               "lin",
	"Lingao":                                "onb",
	"Lingarak":                              "lgk",
	"Lingua Franca Nova":                    "lfn",
	"Lingua Franca":                         "pml",
	"Lipan Apache":                          "apl",
	"Lipo":                                  "lpo",
	"Lisabata-Nuniali":                      "lcs",
	"Lisela":                                "lcl",
	"Lish":                                  "lsh",
	"Lishán Didán":                          "trg",
	"Lishana Deni":                          "lsd",
	"Lishanid Noshan":                       "aij",
	"Lisu":                                  "lis",
	"Literary Chinese":                      "lzh",
	"Lithuanian Sign Language":              "lls",
	"Lithuanian":                            "lit",
	"Litzlitz":                              "lzl",
	"Liujiang Zhuang":                       "zlj",
	"Liuqian Zhuang":                        "zlq",
	"Liv":                                   "liv",
	"Livvi":                                 "olo",
	"Lo-Toga":                               "lht",
	"Loarki":                                "lrk",
	"Lobala":                                "loq",
	"Lobi":                                  "lob",
	"Lodhi":                                 "lbm",
	"Logba":                                 "lgq",
	"Logo":                                  "log",
	"Logol":                                 "lof",
	"Logooli":                               "rag",
	"Logorik":                               "liu",
	"Logudorese Sardinian":                  "src",
	"Lohorung":                              "lbr",
	"Loja Highland Quichua":                 "qvj",
	"Lojban":                                "jbo",
	"Lokaa":                                 "yaz",
	"Loke":                                  "loy",
	"Loko":                                  "lok",
	"Lokoya":                                "lky",
	"Lola":                                  "lcd",
	"Lolak":                                 "llq",
	"Lole":                                  "llg",
	"Lolo":                                  "llb",
	"Loloda":                                "loa",
	"Lolopo":                                "ycl",
	"Loma (Côte d'Ivoire)":                  "loi",
	"Loma (Liberia)":                        "lom",
	"Lomaiviti":                             "lmv",
	"Lomavren":                              "rmi",
	"Lombard":                               "lmo",
	"Lombi":                                 "lmi",
	"Lombo":                                 "loo",
	"Lomwe":                                 "ngl",
	"Loncong":                               "lce",
	"Long Phuri Naga":                       "lpn",
	"Long Wat":                              "ttw",
	"Longgu":                                "lgu",
	"Longto":                                "wok",
	"Longuda":                               "lnu",
	"Loniu":                                 "los",
	"Lonwolwol":                             "crc",
	"Lonzo":                                 "lnz",
	"Loo":                                   "ldo",
	"Lopa":                                  "lop",
	"Lopi":                                  "lov",
	"Lopit":                                 "lpx",
	"Lorang":                                "lrn",
	"Lorediakarkar":                         "lnn",
	"Loreto-Ucayali Spanish":                "spq",
	"Lote":                                  "uvl",
	"Lotha Naga":                            "njh",
	"Lotud":                                 "dtr",
	"Lou":                                   "loj",
	"Louisiana Creole":                      "lou",
	"Loun":                                  "lox",
	"Loup A":                                "xlo",
	"Loup B":                                "xlb",
	"Low German":                            "nds",
	"Lower Burdekin":                        "xbb",
	"Lower Chehalis":                        "cea",
	"Lower Grand Valley Dani":               "dni",
	"Lower Silesian":                        "sli",
	"Lower Sorbian":                         "dsb",
	"Lower Southern Aranda":                 "axl",
	"Lower Ta'oih":                          "tto",
	"Lower Tanana":                          "taa",
	"Lowland Oaxaca Chontal":                "clo",
	"Lowland Tarahumara":                    "tac",
	"Loxicha Zapotec":                       "ztp",
	"Lozi":                                  "loz",
	"Lü":                                    "khb",
	"Luang":                                 "lex",
	"Luba-Katanga":                          "lub",
	"Luba-Lulua":                            "lua",
	"Lubila":                                "kcc",
	"Lubu":                                  "lcf",
	"Lubuagan Kalinga":                      "knb",
	"Luchazi":                               "lch",
	"Lucumi":                                "luq",
	"Ludian":                                "lud",
	"Lufu":                                  "ldq",
	"Lugbara":                               "lgg",
	"Luguru":                                "ruf",
	"Luhu":                                  "lcq",
	"Lui":                                   "lba",
	"Luimbi":                                "lum",
	"Luiseno":                               "lui",
	"Lukpa":                                 "dop",
	"Lule Sami":                             "smj",
	"Lule":                                  "ule",
	"Lumba-Yakkha":                          "luu",
	"Lumbee":                                "lmz",
	"Lumbu":                                 "lup",
	"Lumun":                                 "lmd",
	"Luna":                                  "luj",
	"Lunanakha":                             "luk",
	"Lunda":                                 "lun",
	"Lundayeh":                              "lnd",
	"Lungalunga":                            "vmg",
	"Lungga":                                "lga",
	"Luo (Cameroon)":                        "luw",
	"Luo (Kenya and Tanzania)":              "luo",
	"Luopohe Hmong":                         "hml",
	"Luri":                                  "ldd",
	"Lusengo":                               "lse",
	"Lushai":                                "lus",
	"Lushootseed":                           "lut",
	"Lusi":                                  "khl",
	"Lusitanian":                            "xls",
	"Lutos":                                 "ndy",
	"Luvale":                                "lue",
	"Luwati":                                "luv",
	"Luwo":                                  "lwo",
	"Luxembourgish":                         "ltz",
	"Luyana":                                "lyn",
	"Luyia":                                 "luy",
	"Lwalu":                                 "lwa",
	"Lycian":                                "xlc",
	"Lydian":                                "xld",
	"Lyélé":                                 "lee",
	"Lyngngam":                              "lyg",
	"Lyons Sign Language":                   "lsg",
	"Ma (Democratic Republic of Congo)":     "msj",
	"Ma (Papua New Guinea)":                 "mjn",
	"Ma Manda":                              "skc",
	"Ma'anyan":                              "mhy",
	"Ma'di":                                 "mhi",
	"Ma'ya":                                 "slz",
	"Maa":                                   "cma",
	"Maaka":                                 "mew",
	"Maasina Fulfulde":                      "ffm",
	"Maay":                                  "ymm",
	"Maba (Chad)":                           "mde",
	"Maba (Indonesia)":                      "mqa",
	"Mabaale":                               "mmz",
	"Mabaan":                                "mfz",
	"Mabaka Valley Kalinga":                 "kkg",
	"Mabire":                                "muj",
	"Maca":                                  "mca",
	"Macaguaje":                             "mcl",
	"Macaguán":                              "mbn",
	"Macanese":                              "mzs",
	"Macedo-Romanian":                       "rup",
	"Macedonian":                            "mkd",
	"Machame":                               "jmc",
	"Machiguenga":                           "mcb",
	"Machinere":                             "mpd",
	"Machinga":                              "mvw",
	"Maco":                                  "wpc",
	"Macuna":                                "myy",
	"Macushi":                               "mbc",
	"Mada (Cameroon)":                       "mxu",
	"Mada (Nigeria)":                        "mda",
	"Madagascar Sign Language":              "mzc",
	"Madak":                                 "mmx",
	"Maden":                                 "xmx",
	"Madhi Madhi":                           "dmd",
	"Madi":                                  "grg",
	"Madngele":                              "zml",
	"Madurese":                              "mad",
	"Mae":                                   "mme",
	"Maek":                                  "hmk",
	"Maeng Itneg":                           "itt",
	"Mafa":                                  "maf",
	"Mafea":                                 "mkv",
	"Mag-antsi Ayta":                        "sgb",
	"Mag-Indi Ayta":                         "blx",
	"Magahi":                                "mag",
	"Magbukun Ayta":                         "ayt",
	"Magdalena Peñasco Mixtec":              "xtm",
	"Mághdì":                                "gmd",
	"Magɨyi":                                "gmg",
	"Magoma":                                "gmx",
	"Magori":                                "zgr",
	"Maguindanaon":                          "mdh",
	"Mahali":                                "mjx",
	"Māhārāṣṭri Prākrit":                    "pmh",
	"Mahasu Pahari":                         "bfz",
	"Mahican":                               "mjy",
	"Mahongwe":                              "mhb",
	"Mahou":                                 "mxx",
	"Mai Brat":                              "ayz",
	"Maia":                                  "sks",
	"Maiadomu":                              "mzz",
	"Maiani":                                "tnh",
	"Maii":                                  "mmm",
	"Mailu":                                 "mgu",
	"Maindo":                                "cwb",
	"Mainfränkisch":                         "vmf",
	"Mainstream Kenyah":                     "xkl",
	"Mairasi":                               "zrs",
	"Maisin":                                "mbq",
	"Maithili":                              "mai",
	"Maiwa (Indonesia)":                     "wmm",
	"Maiwa (Papua New Guinea)":              "mti",
	"Maiwala":                               "mum",
	"Majang":                                "mpe",
	"Majera":                                "xmj",
	"Majhi":                                 "mjz",
	"Majhwar":                               "mmj",
	"Majukayang Kalinga":                    "kmd",
	"Mak (China)":                           "mkg",
	"Mak (Nigeria)":                         "pbl",
	"Makaa":                                 "mcp",
	"Makah":                                 "myh",
	"Makalero":                              "mjb",
	"Makasae":                               "mkz",
	"Makasar":                               "mak",
	"Makassar Malay":                        "mfp",
	"Makayam":                               "aup",
	"Makhuwa-Marrevone":                     "xmc",
	"Makhuwa-Meetto":                        "mgh",
	"Makhuwa-Moniga":                        "mhm",
	"Makhuwa-Saka":                          "xsq",
	"Makhuwa-Shirima":                       "vmk",
	"Makhuwa":                               "vmw",
	"Maklew":                                "mgf",
	"Makolkol":                              "zmh",
	"Makonde":                               "kde",
	"Maku'a":                                "lva",
	"Máku":                                  "xak",
	"Makuráp":                               "mpu",
	"Makuri Naga":                           "jmn",
	"Makwe":                                 "ymk",
	"Makyan Naga":                           "umn",
	"Mal Paharia":                           "mkb",
	"Mal":                                   "mlf",
	"Mala (Nigeria)":                        "ruy",
	"Mala (Papua New Guinea)":               "ped",
	"Mala Malasar":                          "ima",
	"Malaccan Creole Malay":                 "ccm",
	"Malaccan Creole Portuguese":            "mcm",
	"Malagasy":                              "mlg",
	"Malalamai":                             "mmt",
	"Malango":                               "mln",
	"Malankuravan":                          "mjo",
	"Malapandaram":                          "mjp",
	"Malaryan":                              "mjq",
	"Malas":                                 "mkr",
	"Malasar":                               "ymr",
	"Malavedan":                             "mjr",
	"Malawi Lomwe":                          "lon",
	"Malawi Sena":                           "swk",
	"Malay (individual language)":           "zlm",
	"Malay (macrolanguage)":                 "msa",
	"Malayalam":                             "mal",
	"Malayic Dayak":                         "xdy",
	"Malaynon":                              "mlz",
	"Malayo":                                "mbp",
	"Malaysian Sign Language":               "xml",
	"Malba Birifor":                         "bfo",
	"Male (Ethiopia)":                       "mdy",
	"Male (Papua New Guinea)":               "mdc",
	"Malecite-Passamaquoddy":                "pqm",
	"Maléku Jaíka":                          "gut",
	"Maleng":                                "pkt",
	"Maleu-Kilenge":                         "mgl",
	"Malfaxal":                              "mlx",
	"Malgana":                               "vml",
	"Malgbe":                                "mxf",
	"Mali":                                  "gcc",
	"Malila":                                "mgq",
	"Malimba":                               "mzd",
	"Malimpung":                             "mli",
	"Malinaltepec Me'phaa":                  "tcf",
	"Malo":                                  "mla",
	"Malol":                                 "mbk",
	"Maltese Sign Language":                 "mdl",
	"Maltese":                               "mlt",
	"Malua Bay":                             "mll",
	"Malvi":                                 "mup",
	"Malyangapa":                            "yga",
	"Mam":                                   "mam",
	"Mama":                                  "mma",
	"Mamaa":                                 "mhf",
	"Mamaindé":                              "wmd",
	"Mamanwa":                               "mmn",
	"Mamara Senoufo":                        "myk",
	"Mamasa":                                "mqj",
	"Mambae":                                "mgm",
	"Mambai":                                "mcs",
	"Mamboru":                               "mvd",
	"Mambwe-Lungu":                          "mgr",
	"Mampruli":                              "maw",
	"Mamuju":                                "mqx",
	"Mamulique":                             "emm",
	"Mamusi":                                "kdf",
	"Mamvu":                                 "mdi",
	"Man Met":                               "mml",
	"Manado Malay":                          "xmm",
	"Manam":                                 "mva",
	"Manambu":                               "mle",
	"Manangba":                              "nmm",
	"Manangkari":                            "znk",
	"Manchu":                                "mnc",
	"Manda (Australia)":                     "zma",
	"Manda (India)":                         "mha",
	"Manda (Tanzania)":                      "mgs",
	"Mandahuaca":                            "mht",
	"Mandaic":                               "mid",
	"Mandan":                                "mhq",
	"Mandandanyi":                           "zmk",
	"Mandar":                                "mdr",
	"Mandara":                               "tbf",
	"Mandari":                               "mqu",
	"Mandarin Chinese":                      "cmn",
	"Mandaya":                               "mry",
	"Mandeali":                              "mjl",
	"Mander":                                "mqr",
	"Mandingo":                              "man",
	"Mandinka":                              "mnk",
	"Mandjak":                               "mfv",
	"Mandobo Atas":                          "aax",
	"Mandobo Bawah":                         "bwp",
	"Manem":                                 "jet",
	"Mang":                                  "zng",
	"Manga Kanuri":                          "kby",
	"Mangala":                               "mem",
	"Mangarayi":                             "mpc",
	"Mangareva":                             "mrv",
	"Mangas":                                "zns",
	"Mangayat":                              "myj",
	"Mangbetu":                              "mdj",
	"Mangbutu":                              "mdk",
	"Mangerr":                               "zme",
	"Mangga Buang":                          "mmo",
	"Manggarai":                             "mqy",
	"Mango":                                 "mge",
	"Mangole":                               "mqc",
	"Mangseng":                              "mbh",
	"Mangue":                                "mom",
	"Manichaean Middle Persian":             "xmn",
	"Manide":                                "abd",
	"Manikion":                              "mnx",
	"Manipa":                                "mqp",
	"Manipuri":                              "mni",
	"Mankanya":                              "knf",
	"Manna-Dora":                            "mju",
	"Mannan":                                "mjv",
	"Mano":                                  "mev",
	"Manombai":                              "woo",
	"Mansaka":                               "msk",
	"Mansi":                                 "mns",
	"Mansoanka":                             "msw",
	"Manta":                                 "myg",
	"Mantsi":                                "nty",
	"Manumanaw Karen":                       "kxf",
	"Manx":                                  "glv",
	"Manya":                                 "mzj",
	"Manyawa":                               "mny",
	"Manyika":                               "mxc",
	"Manza":                                 "mzv",
	"Mao Naga":                              "nbi",
	"Maonan":                                "mmd",
	"Maore Comorian":                        "swb",
	"Maori":                                 "mri",
	"Mape":                                  "mlh",
	"Mapena":                                "mnm",
	"Mapia":                                 "mpy",
	"Mapidian":                              "mpw",
	"Mapos Buang":                           "bzh",
	"Mapoyo":                                "mcg",
	"Mapudungun":                            "arn",
	"Mapun":                                 "sjm",
	"Maquiritari":                           "mch",
	"Mara Chin":                             "mrh",
	"Mara":                                  "mec",
	"Marachi":                               "lri",
	"Maraghei":                              "vmh",
	"Maragus":                               "mrs",
	"Maram Naga":                            "nma",
	"Marama":                                "lrm",
	"Maramba":                               "myd",
	"Maranao":                               "mrw",
	"Maranunggu":                            "zmr",
	"Mararit":                               "mgb",
	"Marathi":                               "mar",
	"Marau":                                 "mvr",
	"Marba":                                 "mpg",
	"Maremgi":                               "mrx",
	"Marenje":                               "vmr",
	"Marfa":                                 "mvu",
	"Margany":                               "zmc",
	"Marghi Central":                        "mrt",
	"Marghi South":                          "mfm",
	"Margos-Yarowilca-Lauricocha Quechua":   "qvm",
	"Margu":                                 "mhg",
	"Mari (East Sepik Province)":            "mbx",
	"Mari (Madang Province)":                "hob",
	"Mari (Russia)":                         "chm",
	"Maria (India)":                         "mrr",
	"Maria (Papua New Guinea)":              "mds",
	"Maricopa":                              "mrc",
	"Maridan":                               "zmd",
	"Maridjabin":                            "zmj",
	"Marik":                                 "dad",
	"Marimanindji":                          "zmm",
	"Marind":                                "mrz",
	"Maring Naga":                           "nng",
	"Maring":                                "mbw",
	"Maringarr":                             "zmt",
	"Marino":                                "mrb",
	"Mariri":                                "mqi",
	"Marithiel":                             "mfr",
	"Maritime Sign Language":                "nsr",
	"Maritsauá":                             "msp",
	"Mariyedi":                              "zmy",
	"Marka":                                 "rkm",
	"Markweeta":                             "enb",
	"Marma":                                 "rmz",
	"Marovo":                                "mvo",
	"Marriammu":                             "xru",
	"Marrucinian":                           "umc",
	"Marshallese":                           "mah",
	"Marsian":                               "ims",
	"Martha's Vineyard Sign Language":       "mre",
	"Marti Ke":                              "zmg",
	"Martu Wangka":                          "mpj",
	"Martuyhunira":                          "vma",
	"Maru":                                  "mhx",
	"Marúbo":                                "mzr",
	"Marwari (India)":                       "rwr",
	"Marwari (Pakistan)":                    "mve",
	"Marwari":                               "mwr",
	"Masaaba":                               "myx",
	"Masadiit Itneg":                        "tis",
	"Masai":                                 "mas",
	"Masalit":                               "mls",
	"Masana":                                "mcn",
	"Masbatenyo":                            "msb",
	"Mashco Piro":                           "cuj",
	"Mashi (Nigeria)":                       "jms",
	"Mashi (Zambia)":                        "mho",
	"Masikoro Malagasy":                     "msh",
	"Masimasi":                              "ism",
	"Masiwang":                              "bnf",
	"Maskelynes":                            "klv",
	"Maslam":                                "msv",
	"Masmaje":                               "mes",
	"Massalat":                              "mdg",
	"Massep":                                "mvs",
	"Matagalpa":                             "mtn",
	"Matal":                                 "mfh",
	"Matbat":                                "xmt",
	"Matengo":                               "mgv",
	"Matepi":                                "mqe",
	"Matigsalug Manobo":                     "mbt",
	"Matipuhy":                              "mzo",
	"Matís":                                 "mpq",
	"Mato Grosso Arára":                     "axg",
	"Mato":                                  "met",
	"Mator":                                 "mtm",
	"Matsés":                                "mcf",
	"Mattole":                               "mvb",
	"Matu Chin":                             "hlt",
	"Matukar":                               "mjk",
	"Matumbi":                               "mgw",
	"Matya Samo":                            "stj",
	"Maung":                                 "mph",
	"Mauritian Sign Language":               "lsy",
	"Mauwake":                               "mhl",
	"Mawa (Chad)":                           "mcw",
	"Mawa (Nigeria)":                        "wma",
	"Mawak":                                 "mjj",
	"Mawan":                                 "mcz",
	"Mawayana":                              "mzx",
	"Mawchi":                                "mke",
	"Mawes":                                 "mgk",
	"Maxakalí":                              "mbl",
	"Maxi Gbe":                              "mxl",
	"Maya Samo":                             "sym",
	"Mayaguduna":                            "xmy",
	"Mayangna":                              "yan",
	"Mayawali":                              "yxa",
	"Mayeka":                                "myc",
	"Mayi-Kulan":                            "xyk",
	"Mayi-Thakurti":                         "xyt",
	"Mayi-Yapi":                             "xyj",
	"Mayo":                                  "mfy",
	"Mayogo":                                "mdm",
	"Mayoyao Ifugao":                        "ifu",
	"Mazagway":                              "dkx",
	"Mazaltepec Zapotec":                    "zpy",
	"Mazanderani":                           "mzn",
	"Mazatlán Mazatec":                      "vmz",
	"Mazatlán Mixe":                         "mzl",
	"Mba":                                   "mfc",
	"Mbala":                                 "mdp",
	"Mbalanhu":                              "lnb",
	"Mbandja":                               "zmz",
	"Mbangala":                              "mxg",
	"Mbangi":                                "mgn",
	"Mbangwe":                               "zmn",
	"Mbara (Australia)":                     "mvl",
	"Mbara (Chad)":                          "mpk",
	"Mbariman-Gudhinma":                     "zmv",
	"Mbati":                                 "mdn",
	"Mbato":                                 "gwa",
	"Mbay":                                  "myb",
	"Mbe'":                                  "mtk",
	"Mbe":                                   "mfo",
	"Mbelime":                               "mql",
	"Mbere":                                 "mdt",
	"Mbesa":                                 "zms",
	"Mbo (Cameroon)":                        "mbo",
	"Mbo (Democratic Republic of Congo)":    "zmw",
	"Mboi":                                  "moi",
	"Mboko":                                 "mdu",
	"Mbole":                                 "mdq",
	"Mbonga":                                "xmb",
	"Mbongno":                               "bgu",
	"Mbosi":                                 "mdw",
	"Mbowe":                                 "mxo",
	"Mbre":                                  "mka",
	"Mbudum":                                "xmd",
	"Mbugu":                                 "mhd",
	"Mbugwe":                                "mgz",
	"Mbuko":                                 "mqb",
	"Mbukushu":                              "mhw",
	"Mbula-Bwazza":                          "mbu",
	"Mbula":                                 "mna",
	"Mbule":                                 "mlb",
	"Mbulungish":                            "mbv",
	"Mbum":                                  "mdd",
	"Mbunda":                                "mck",
	"Mbunga":                                "mgy",
	"Mburku":                                "bbt",
	"Mbwela":                                "mfu",
	"Mbyá Guaraní":                          "gun",
	"Me'en":                                 "mym",
	"Medebur":                               "mjm",
	"Media Lengua":                          "mue",
	"Mediak":                                "mwx",
	"Median":                                "xme",
	"Mednyj Aleut":                          "mud",
	"Medumba":                               "byv",
	"Mefele":                                "mfj",
	"Megam":                                 "mef",
	"Megleno Romanian":                      "ruq",
	"Mehek":                                 "nux",
	"Mehináku":                              "mmh",
	"Mehri":                                 "gdq",
	"Mekeo":                                 "mek",
	"Mekmek":                                "mvk",
	"Mekwei":                                "msf",
	"Mele-Fila":                             "mxe",
	"Melo":                                  "mfx",
	"Melpa":                                 "med",
	"Memoni":                                "mby",
	"Mendalam Kayan":                        "xkd",
	"Mendankwe-Nkwen":                       "mfd",
	"Mende (Papua New Guinea)":              "sim",
	"Mende (Sierra Leone)":                  "men",
	"Mengaka":                               "xmg",
	"Mengen":                                "mee",
	"Mengisa":                               "mct",
	"Ménik":                                 "tnr",
	"Menka":                                 "mea",
	"Menominee":                             "mez",
	"Mentawai":                              "mwv",
	"Menya":                                 "mcr",
	"Meoswar":                               "mvx",
	"Mer":                                   "mnu",
	"Meramera":                              "mxm",
	"Merei":                                 "lmb",
	"Merey":                                 "meq",
	"Meriam":                                "ulk",
	"Merlav":                                "mrm",
	"Meroitic":                              "xmr",
	"Meru":                                  "mer",
	"Merwari":                               "wry",
	"Mesaka":                                "iyo",
	"Mescalero-Chiricahua Apache":           "apm",
	"Mese":                                  "mci",
	"Meskwaki":                              "sac",
	"Mesme":                                 "zim",
	"Mesmes":                                "mys",
	"Mesopotamian Arabic":                   "acm",
	"Mesqan":                                "mvz",
	"Messapic":                              "cms",
	"Meta'":                                 "mgo",
	"Metlatónoc Mixtec":                     "mxv",
	"Mewari":                                "mtr",
	"Mewati":                                "wtm",
	"Mexican Sign Language":                 "mfs",
	"Meyah":                                 "mej",
	"Mezontla Popoloca":                     "pbe",
	"Mezquital Otomi":                       "ote",
	"Mfinu":                                 "zmf",
	"Mfumte":                                "nfu",
	"Mgbolizhia":                            "gmz",
	"Mi'kmaq":                               "mic",
	"Miahuatlán Zapotec":                    "zam",
	"Miami":                                 "mia",
	"Mian":                                  "mpt",
	"Miani":                                 "pla",
	"Michif":                                "crg",
	"Michigamea":                            "cmm",
	"Michoacán Mazahua":                     "mmc",
	"Michoacán Nahuatl":                     "ncl",
	"Mid Grand Valley Dani":                 "dnt",
	"Mid-Southern Banda":                    "bjo",
	"Middle Armenian":                       "axm",
	"Middle Breton":                         "xbm",
	"Middle Cornish":                        "cnx",
	"Middle Dutch (ca. 1050-1350)":          "dum",
	"Middle English (1100-1500)":            "enm",
	"Middle French (ca. 1400-1600)":         "frm",
	"Middle High German (ca. 1050-1500)":    "gmh",
	"Middle Hittite":                        "htx",
	"Middle Irish (900-1200)":               "mga",
	"Middle Korean (10th-16th cent.)":       "okm",
	"Middle Low German":                     "gml",
	"Middle Mongolian":                      "xng",
	"Middle Newar":                          "nwx",
	"Middle Watut":                          "mpl",
	"Middle Welsh":                          "wlm",
	"Midob":                                 "mei",
	"Migaama":                               "mmy",
	"Migabac":                               "mpp",
	"Migum":                                 "klm",
	"Miju-Mishmi":                           "mxj",
	"Mikasuki":                              "mik",
	"Mili":                                  "ymh",
	"Miltu":                                 "mlj",
	"Miluk":                                 "iml",
	"Milyan":                                "imy",
	"Min Bei Chinese":                       "mnp",
	"Min Dong Chinese":                      "cdo",
	"Min Nan Chinese":                       "nan",
	"Min Zhong Chinese":                     "czo",
	"Mina (Cameroon)":                       "hna",
	"Mina (India)":                          "myi",
	"Minaean":                               "inm",
	"Minang":                                "xrg",
	"Minangkabau":                           "min",
	"Minanibai":                             "mcv",
	"Minaveha":                              "mvn",
	"Minderico":                             "drc",
	"Mindiri":                               "mpn",
	"Mingang Doso":                          "mko",
	"Mingrelian":                            "xmf",
	"Minica Huitoto":                        "hto",
	"Minidien":                              "wii",
	"Minjungbal":                            "xjb",
	"Minkin":                                "xxm",
	"Minoan":                                "omn",
	"Minokok":                               "mqq",
	"Minriq":                                "mnq",
	"Mintil":                                "mzt",
	"Minz Zhuang":                           "zgm",
	"Miqie":                                 "yiq",
	"Mirandese":                             "mwl",
	"Miraya Bikol":                          "rbl",
	"Mirgan":                                "zrg",
	"Miriti":                                "mmv",
	"Miriwoong Sign Language":               "rsm",
	"Miriwung":                              "mep",
	"Miship":                                "mjs",
	"Misima-Panaeati":                       "mpx",
	"Mising":                                "mrg",
	"Mískito":                               "miq",
	"Mitla Zapotec":                         "zaw",
	"Mitlatongo Mixtec":                     "vmm",
	"Mittu":                                 "mwu",
	"Mituku":                                "zmq",
	"Miu":                                   "mpo",
	"Miwa":                                  "vmi",
	"Mixed Great Andamanese":                "gac",
	"Mixtepec Mixtec":                       "mix",
	"Mixtepec Zapotec":                      "zpm",
	"Miya":                                  "mkf",
	"Miyako":                                "mvi",
	"Miyobe":                                "soy",
	"Mlabri":                                "mra",
	"Mlahsö":                                "lhs",
	"Mlap":                                  "kja",
	"Mlomp":                                 "mlo",
	"Mmaala":                                "mmu",
	"Mmen":                                  "bfm",
	"Mo'da":                                 "gbn",
	"Moabite":                               "obm",
	"Moba":                                  "mfq",
	"Mobilian":                              "mod",
	"Mobumrin Aizi":                         "ahm",
	"Mobwa Karen":                           "jkm",
	"Mócheno":                               "mhn",
	"Mochi":                                 "old",
	"Mochica":                               "omc",
	"Mocho":                                 "mhc",
	"Mocoví":                                "moc",
	"Modang":                                "mxd",
	"Modern Greek (1453-)":                  "ell",
	"Modole":                                "mqo",
	"Moere":                                 "mvq",
	"Mofu-Gudur":                            "mif",
	"Mogholi":                               "mhj",
	"Mogofin":                               "mfg",
	"Mogum":                                 "mou",
	"Mohave":                                "mov",
	"Mohawk":                                "moh",
	"Mohegan-Pequot":                        "xpq",
	"Moi (Congo)":                           "mow",
	"Moi (Indonesia)":                       "mxn",
	"Moikodi":                               "mkp",
	"Moingi":                                "mwz",
	"Moji":                                  "ymi",
	"Mok":                                   "mqt",
	"Moken":                                 "mwt",
	"Mokerang":                              "mft",
	"Mokilese":                              "mkj",
	"Moklen":                                "mkm",
	"Mokole":                                "mkl",
	"Mokpwe":                                "bri",
	"Moksela":                               "vms",
	"Moksha":                                "mdf",
	"Molale":                                "mbe",
	"Molbog":                                "pwm",
	"Moldova Sign Language":                 "vsi",
	"Molengue":                              "bxc",
	"Molima":                                "mox",
	"Molmo One":                             "aun",
	"Molo":                                  "zmo",
	"Molof":                                 "msl",
	"Moloko":                                "mlw",
	"Mom Jango":                             "ver",
	"Moma":                                  "myl",
	"Momare":                                "msz",
	"Mombo Dogon":                           "dmb",
	"Mombum":                                "mso",
	"Momina":                                "mmb",
	"Momuna":                                "mqf",
	"Mon":                                   "mnw",
	"Monastic Sign Language":                "mzg",
	"Mondé":                                 "mnd",
	"Mondropolon":                           "npn",
	"Mongo":                                 "lol",
	"Mongol":                                "mgt",
	"Mongolia Buriat":                       "bxm",
	"Mongolian Sign Language":               "msr",
	"Mongolian":                             "mon",
	"Mongondow":                             "mog",
	"Moni":                                  "mnz",
	"Mono (Cameroon)":                       "mru",
	"Mono (Democratic Republic of Congo)":   "mnh",
	"Mono (Solomon Islands)":                "mte",
	"Mono (USA)":                            "mnr",
	"Monom":                                 "moo",
	"Monsang Naga":                          "nmh",
	"Montagnais":                            "moe",
	"Montol":                                "mtl",
	"Monumbo":                               "mxk",
	"Monzombo":                              "moj",
	"Moo":                                   "gwg",
	"Moose Cree":                            "crm",
	"Mopán Maya":                            "mop",
	"Mor (Bomberai Peninsula)":              "moq",
	"Mor (Mor Islands)":                     "mhz",
	"Moraid":                                "msg",
	"Morawa":                                "mze",
	"Morelos Nahuatl":                       "nhm",
	"Morerebi":                              "xmo",
	"Moresada":                              "msx",
	"Mori Atas":                             "mzq",
	"Mori Bawah":                            "xmz",
	"Morigi":                                "mdb",
	"Morisyen":                              "mfe",
	"Moro":                                  "mor",
	"Moroccan Arabic":                       "ary",
	"Moroccan Sign Language":                "xms",
	"Morokodo":                              "mgc",
	"Morom":                                 "bdo",
	"Moronene":                              "mqn",
	"Morori":                                "mok",
	"Morouas":                               "mrp",
	"Mortlockese":                           "mrl",
	"Moru":                                  "mgd",
	"Mosimo":                                "mqv",
	"Mosiro":                                "mwy",
	"Moskona":                               "mtj",
	"Mossi":                                 "mos",
	"Mota":                                  "mtt",
	"Motlav":                                "mlv",
	"Motu":                                  "meu",
	"Mouk-Aria":                             "mwh",
	"Mountain Koiali":                       "kpx",
	"Mouwase":                               "jmw",
	"Movima":                                "mzp",
	"Moyadan Itneg":                         "ity",
	"Moyon Naga":                            "nmo",
	"Mozambican Sign Language":              "mzy",
	"Mozarabic":                             "mxi",
	"Mpade":                                 "mpi",
	"Mpalitjanh":                            "xpj",
	"Mpi":                                   "mpz",
	"Mpiemo":                                "mcx",
	"Mpoto":                                 "mpa",
	"Mpotovoro":                             "mvt",
	"Mpumpong":                              "mgg",
	"Mpuono":                                "zmp",
	"Mpur":                                  "akc",
	"Mro-Khimi Chin":                        "cmr",
	"Mru":                                   "mro",
	"Mser":                                  "kqx",
	"Mt. Iraya Agta":                        "atl",
	"Mt. Iriga Agta":                        "agz",
	"Muak Sa-aak":                           "ukk",
	"Mualang":                               "mtd",
	"Mubami":                                "tsx",
	"Mubi":                                  "mub",
	"Muda":                                  "ymd",
	"Mudburra":                              "dmw",
	"Mudhili Gadaba":                        "gau",
	"Mudu Koraga":                           "vmd",
	"Muduga":                                "udg",
	"Mufian":                                "aoj",
	"Mugom":                                 "muk",
	"Muinane":                               "bmr",
	"Mukha-Dora":                            "mmk",
	"Mukulu":                                "moz",
	"Mulaha":                                "mfw",
	"Mulam":                                 "mlm",
	"Mulao":                                 "giu",
	"Mulgi":                                 "mvh",
	"Mullu Kurumba":                         "kpb",
	"Mullukmulluk":                          "mpb",
	"Multiple languages":                    "mul",
	"Muluridyi":                             "vmu",
	"Mum":                                   "kqa",
	"Mumuye":                                "mzm",
	"Mün Chin":                              "mwq",
	"Muna":                                  "mnb",
	"Munda":                                 "unx",
	"Mundabli":                              "boe",
	"Mundang":                               "mua",
	"Mundani":                               "mnf",
	"Mundari":                               "unr",
	"Mundat":                                "mmf",
	"Mündü":                                 "muh",
	"Mundurukú":                             "myu",
	"Mungaka":                               "mhk",
	"Munggui":                               "mth",
	"Mungkip":                               "mpv",
	"Muniche":                               "myr",
	"Munit":                                 "mtc",
	"Munji":                                 "mnj",
	"Munsee":                                "umu",
	"Muong":                                 "mtq",
	"Mur Pano":                              "tkv",
	"Muratayak":                             "asx",
	"Murik (Malaysia)":                      "mxr",
	"Murik (Papua New Guinea)":              "mtf",
	"Murkim":                                "rmh",
	"Murle":                                 "mur",
	"Murrinh-Patha":                         "mwf",
	"Mursi":                                 "muz",
	"Murui Huitoto":                         "huu",
	"Murupi":                                "mqw",
	"Muruwari":                              "zmu",
	"Musak":                                 "mmq",
	"Musar":                                 "mmi",
	"Musasa":                                "smm",
	"Musey":                                 "mse",
	"Musgu":                                 "mug",
	"Mushungulu":                            "xma",
	"Musi":                                  "mui",
	"Muskum":                                "mje",
	"Muslim Tat":                            "ttt",
	"Musom":                                 "msu",
	"Mussau-Emira":                          "emi",
	"Muthuvan":                              "muv",
	"Mutu":                                  "tuc",
	"Muya":                                  "mvm",
	"Muyang":                                "muy",
	"Muyuw":                                 "myw",
	"Muzi":                                  "ymz",
	"Mvanip":                                "mcj",
	"Mvuba":                                 "mxh",
	"Mwaghavul":                             "sur",
	"Mwali Comorian":                        "wlc",
	"Mwan":                                  "moa",
	"Mwani":                                 "wmw",
	"Mwatebu":                               "mwa",
	"Mwera (Chimwera)":                      "mwe",
	"Mwera (Nyasa)":                         "mjh",
	"Mwimbi-Muthambi":                       "mws",
	"Mycenaean Greek":                       "gmy",
	"Myene":                                 "mye",
	"Mysian":                                "yms",
	"Mzieme Naga":                           "nme",
	"N'Ko":                                  "nqo",
	"N/u":                                   "ngh",
	"Ná-Meo":                                "neo",
	"Na":                                    "nbt",
	"Naaba":                                 "nao",
	"Naami":                                 "bzv",
	"Naasioi":                               "nas",
	"Naba":                                  "mne",
	"Nabak":                                 "naf",
	"Nabi":                                  "mty",
	"Nachering":                             "ncd",
	"Nadëb":                                 "mbj",
	"Nadruvian":                             "ndf",
	"Nafaanra":                              "nfr",
	"Nafi":                                  "srf",
	"Nafri":                                 "nxx",
	"Nafusi":                                "jbn",
	"Naga Pidgin":                           "nag",
	"Nagarchal":                             "nbg",
	"Nage":                                  "nxe",
	"Nagumi":                                "ngv",
	"Nahali":                                "nlx",
	"Nahari":                                "nhh",
	"Nai":                                   "bio",
	"Najdi Arabic":                          "ars",
	"Naka'ela":                              "nae",
	"Nakai":                                 "nkj",
	"Nakame":                                "nib",
	"Nakanai":                               "nak",
	"Nakara":                                "nck",
	"Nake":                                  "nbk",
	"Naki":                                  "mff",
	"Nakwi":                                 "nax",
	"Nalca":                                 "nlc",
	"Nali":                                  "nss",
	"Nalik":                                 "nal",
	"Nalögo":                                "nlz",
	"Nalu":                                  "naj",
	"Naluo Yi":                              "ylo",
	"Nama (Papua New Guinea)":               "nmx",
	"Namakura":                              "nmk",
	"Namat":                                 "nkm",
	"Nambo":                                 "ncm",
	"Nambya":                                "nmq",
	"Namia":                                 "nnm",
	"Namiae":                                "nvm",
	"Namibian Sign Language":                "nbs",
	"Namla":                                 "naa",
	"Namo":                                  "mxw",
	"Namonuito":                             "nmt",
	"Namosi-Naitasiri-Serua":                "bwb",
	"Namuyi":                                "nmy",
	"Nanai":                                 "gld",
	"Nancere":                               "nnc",
	"Nande":                                 "nnb",
	"Nandi":                                 "niq",
	"Nanerigé Sénoufo":                      "sen",
	"Nanga Dama Dogon":                      "nzz",
	"Nankina":                               "nnk",
	"Nanti":                                 "cox",
	"Nanticoke":                             "nnt",
	"Nanubae":                               "afk",
	"Napo Lowland Quechua":                  "qvo",
	"Napu":                                  "npy",
	"Nar Phu":                               "npa",
	"Nara":                                  "nrb",
	"Narak":                                 "nac",
	"Narango":                               "nrg",
	"Narau":                                 "nxu",
	"Nari Nari":                             "rnr",
	"Narim":                                 "loh",
	"Naro":                                  "nhr",
	"Narom":                                 "nrm",
	"Narragansett":                          "xnt",
	"Narrinyeri":                            "nay",
	"Narua":                                 "nru",
	"Narungga":                              "nnr",
	"Nasal":                                 "nsy",
	"Nasarian":                              "nvh",
	"Naskapi":                               "nsk",
	"Natanzi":                               "ntz",
	"Nataoran Amis":                         "ais",
	"Natchez":                               "ncz",
	"Nateni":                                "ntm",
	"Nathembo":                              "nte",
	"Natioro":                               "nti",
	"Natügu":                                "ntu",
	"Nauete":                                "nxa",
	"Naukan Yupik":                          "ynk",
	"Nauna":                                 "ncn",
	"Nauo":                                  "nwo",
	"Nauru":                                 "nau",
	"Navajo":                                "nav",
	"Navut":                                 "nsw",
	"Nawaru":                                "nwr",
	"Nawathinehena":                         "nwa",
	"Nawdm":                                 "nmz",
	"Nawuri":                                "naw",
	"Naxi":                                  "nxq",
	"Nayi":                                  "noz",
	"Nayini":                                "nyq",
	"Ncane":                                 "ncr",
	"Nchumbulu":                             "nlu",
	"Nda'nda'":                              "nnz",
	"Ndai":                                  "gke",
	"Ndaka":                                 "ndk",
	"Ndaktup":                               "ncp",
	"Ndali":                                 "ndh",
	"Ndam":                                  "ndm",
	"Ndamba":                                "ndj",
	"Ndambomo":                              "nxo",
	"Ndasa":                                 "nda",
	"Ndau":                                  "ndc",
	"Nde-Gbite":                             "ned",
	"Nde-Nsele-Nta":                         "ndd",
	"Ndemli":                                "nml",
	"Ndendeule":                             "dne",
	"Ndengereko":                            "ndg",
	"Nding":                                 "eli",
	"Ndo":                                   "ndp",
	"Ndobo":                                 "ndw",
	"Ndoe":                                  "nbb",
	"Ndogo":                                 "ndz",
	"Ndolo":                                 "ndl",
	"Ndom":                                  "nqm",
	"Ndombe":                                "ndq",
	"Ndonde Hamba":                          "njd",
	"Ndonga":                                "ndo",
	"Ndoola":                                "ndr",
	"Ndra'ngith":                            "dgt",
	"Nduga":                                 "ndx",
	"Ndumu":                                 "nmd",
	"Ndunda":                                "nuh",
	"Ndunga":                                "ndt",
	"Ndut":                                  "ndv",
	"Ndyuka-Trio Pidgin":                    "njt",
	"Ndzwani Comorian":                      "wni",
	"Neapolitan":                            "nap",
	"Nedebang":                              "nec",
	"Nefamese":                              "nef",
	"Negerhollands":                         "dcr",
	"Negeri Sembilan Malay":                 "zmi",
	"Negidal":                               "neg",
	"Nehan":                                 "nsn",
	"Nek":                                   "nif",
	"Nekgini":                               "nkg",
	"Neko":                                  "nej",
	"Neku":                                  "nek",
	"Nêlêmwa-Nixumwak":                      "nee",
	"Nema":                                  "gsn",
	"Neme":                                  "nex",
	"Nemi":                                  "nem",
	"Nen":                                   "nqn",
	"Nend":                                  "anh",
	"Nenets":                                "yrk",
	"Nengone":                               "nen",
	"Neo-Hittite":                           "nei",
	"Neo":                                   "neu",
	"Nepalese Sign Language":                "nsp",
	"Nepali (individual language)":          "npi",
	"Nepali (macrolanguage)":                "nep",
	"Nepali Kurux":                          "kxl",
	"Nete":                                  "net",
	"New Caledonian Javanese":               "jas",
	"New Zealand Sign Language":             "nzs",
	"Newari":                                "new",
	"Neyo":                                  "ney",
	"Nez Perce":                             "nez",
	"Ngaanyatjarra":                         "ntj",
	"Ngäbere":                               "gym",
	"Ngad'a":                                "nxg",
	"Ngadjunmaya":                           "nju",
	"Ngadjuri":                              "jui",
	"Ngaing":                                "nnf",
	"Ngaju":                                 "nij",
	"Ngala":                                 "nud",
	"Ngalakan":                              "nig",
	"Ngalum":                                "szb",
	"Ngam":                                  "nmc",
	"Ngamambo":                              "nbv",
	"Ngambay":                               "sba",
	"Ngamini":                               "nmv",
	"Ngamo":                                 "nbh",
	"Ngan'gityemerri":                       "nam",
	"Nganakarti":                            "xnk",
	"Nganasan":                              "nio",
	"Ngandi":                                "nid",
	"Ngando (Central African Republic)":     "ngd",
	"Ngando (Democratic Republic of Congo)": "nxd",
	"Ngandyera":                             "nne",
	"Ngangam":                               "gng",
	"Ngantangarra":                          "ntg",
	"Nganyaywana":                           "nyx",
	"Ngardi":                                "rxd",
	"Ngarigu":                               "xni",
	"Ngarinman":                             "nbj",
	"Ngarinyin":                             "ung",
	"Ngarla":                                "nrk",
	"Ngarluma":                              "nrl",
	"Ngas":                                  "anc",
	"Ngasa":                                 "nsg",
	"Ngatik Men's Creole":                   "ngm",
	"Ngawn Chin":                            "cnw",
	"Ngawun":                                "nxn",
	"Ngayawung":                             "nwg",
	"Ngazidja Comorian":                     "zdj",
	"Ngbaka Ma'bo":                          "nbm",
	"Ngbaka Manza":                          "ngg",
	"Ngbaka":                                "nga",
	"Ngbee":                                 "jgb",
	"Ngbinda":                               "nbd",
	"Ngbundu":                               "nuu",
	"Ngelima":                               "agh",
	"Ngemba":                                "nge",
	"Ngendelengo":                           "nql",
	"Ngete":                                 "nnn",
	"Nggem":                                 "nbq",
	"Nggwahyi":                              "ngx",
	"Ngie":                                  "ngj",
	"Ngiemboon":                             "nnh",
	"Ngile":                                 "jle",
	"Ngindo":                                "nnq",
	"Ngiti":                                 "niy",
	"Ngizim":                                "ngi",
	"Ngkâlmpw Kanum":                        "kcd",
	"Ngom":                                  "nra",
	"Ngomba":                                "jgo",
	"Ngombale":                              "nla",
	"Ngombe (Central African Republic)":     "nmj",
	"Ngombe (Democratic Republic of Congo)": "ngc",
	"Ngongo":                                "noq",
	"Ngoni":                                 "ngo",
	"Ngoshie":                               "nsh",
	"Ngul":                                  "nlo",
	"Ngulu":                                 "ngp",
	"Nguluwan":                              "nuw",
	"Ngumbi":                                "nui",
	"Ngunawal":                              "xul",
	"Ngundi":                                "ndn",
	"Ngundu":                                "nue",
	"Ngungwel":                              "ngz",
	"Nguôn":                                 "nuo",
	"Ngurimi":                               "ngq",
	"Ngurmbur":                              "nrx",
	"Ngwaba":                                "ngw",
	"Ngwe":                                  "nwe",
	"Ngwo":                                  "ngn",
	"Nhanda":                                "nha",
	"Nhengatu":                              "yrl",
	"Nhirrpi":                               "hrp",
	"Nhuwala":                               "nhf",
	"Nias":                                  "nia",
	"Nicaragua Creole English":              "bzk",
	"Nicaraguan Sign Language":              "ncs",
	"Niellim":                               "nie",
	"Nigeria Mambila":                       "mzk",
	"Nigerian Fulfulde":                     "fuv",
	"Nigerian Pidgin":                       "pcm",
	"Nigerian Sign Language":                "nsi",
	"Nihali":                                "nll",
	"Nii":                                   "nii",
	"Niksek":                                "gbe",
	"Nila":                                  "nil",
	"Nilamba":                               "nim",
	"Nimadi":                                "noe",
	"Nimanbur":                              "nmp",
	"Nimbari":                               "nmr",
	"Nimboran":                              "nir",
	"Nimi":                                  "nis",
	"Nimo":                                  "niw",
	"Nimoa":                                 "nmw",
	"Ninam":                                 "shb",
	"Nindi":                                 "nxi",
	"Ningera":                               "nby",
	"Ninggerum":                             "nxr",
	"Ningil":                                "niz",
	"Ningye":                                "nns",
	"Ninia Yali":                            "nlk",
	"Ninzo":                                 "nin",
	"Nipsan":                                "nps",
	"Nisa":                                  "njs",
	"Nisenan":                               "nsz",
	"Nisga'a":                               "ncg",
	"Nisi (China)":                          "yso",
	"Niuafo'ou":                             "num",
	"Niuatoputapu":                          "nkp",
	"Niuean":                                "niu",
	"Nivaclé":                               "cag",
	"Niwer Mil":                             "hrc",
	"Njalgulgule":                           "njl",
	"Njebi":                                 "nzb",
	"Njen":                                  "njj",
	"Njerep":                                "njr",
	"Njyem":                                 "njy",
	"Nkami":                                 "nkq",
	"Nkangala":                              "nkn",
	"Nkari":                                 "nkz",
	"Nkem-Nkum":                             "isi",
	"Nkhumbi":                               "khu",
	"Nkongho":                               "nkc",
	"Nkonya":                                "nko",
	"Nkoroo":                                "nkx",
	"Nkoya":                                 "nka",
	"Nkukoli":                               "nbo",
	"Nkutu":                                 "nkw",
	"Nnam":                                  "nbp",
	"No linguistic content":                 "zxx",
	"Nobiin":                                "fia",
	"Nobonob":                               "gaw",
	"Nocamán":                               "nom",
	"Nocte Naga":                            "njb",
	"Nogai":                                 "nog",
	"Noipx":                                 "npx",
	"Noiri":                                 "noi",
	"Nokuku":                                "nkk",
	"Nomaande":                              "lem",
	"Nomane":                                "nof",
	"Nomatsiguenga":                         "not",
	"Nomlaki":                               "nol",
	"Nomu":                                  "noh",
	"Nong Zhuang":                           "zhn",
	"Nonuya":                                "noj",
	"Nooksack":                              "nok",
	"Noon":                                  "snf",
	"Noone":                                 "nhu",
	"Nopala Chatino":                        "cya",
	"Noric":                                 "nrc",
	"Norn":                                  "nrn",
	"Norra":                                 "nrr",
	"North Alaskan Inupiatun":               "esi",
	"North Ambrym":                          "mmg",
	"North Asmat":                           "nks",
	"North Awyu":                            "yir",
	"North Azerbaijani":                     "azj",
	"North Babar":                           "bcd",
	"North Bolivian Quechua":                "qul",
	"North Central Mixe":                    "neq",
	"North Efate":                           "llp",
	"North Fali":                            "fll",
	"North Giziga":                          "gis",
	"North Junín Quechua":                   "qvn",
	"North Levantine Arabic":                "apc",
	"North Marquesan":                       "mrq",
	"North Mesopotamian Arabic":             "ayp",
	"North Mofu":                            "mfk",
	"North Moluccan Malay":                  "max",
	"North Muyu":                            "kti",
	"North Ndebele":                         "nde",
	"North Nuaulu":                          "nni",
	"North Picene":                          "nrp",
	"North Slavey":                          "scs",
	"North Tairora":                         "tbg",
	"North Tanna":                           "tnn",
	"North Wahgi":                           "whg",
	"North Watut":                           "una",
	"Northeast Kiwai":                       "kiw",
	"Northeast Maidu":                       "nmu",
	"Northeast Pashai":                      "aee",
	"Northeastern Dinka":                    "dip",
	"Northeastern Pomo":                     "pef",
	"Northeastern Thai":                     "tts",
	"Northern Alta":                         "aqn",
	"Northern Altai":                        "atv",
	"Northern Amami-Oshima":                 "ryn",
	"Northern Betsimisaraka Malagasy":       "bmm",
	"Northern Binukidnon":                   "kyn",
	"Northern Bobo Madaré":                  "bbo",
	"Northern Bontok":                       "rbk",
	"Northern Catanduanes Bikol":            "cts",
	"Northern Conchucos Ancash Quechua":     "qxn",
	"Northern Dagara":                       "dgi",
	"Northern Dong":                         "doc",
	"Northern East Cree":                    "crl",
	"Northern Emberá":                       "emp",
	"Northern Frisian":                      "frr",
	"Northern Ghale":                        "ghh",
	"Northern Gondi":                        "gno",
	"Northern Grebo":                        "gbo",
	"Northern Guiyang Hmong":                "huj",
	"Northern Haida":                        "hdn",
	"Northern Hindko":                       "hno",
	"Northern Huishui Hmong":                "hmi",
	"Northern Kalapuya":                     "nrt",
	"Northern Kankanay":                     "xnn",
	"Northern Katang":                       "ncq",
	"Northern Khmer":                        "kxm",
	"Northern Kissi":                        "kqs",
	"Northern Kurdish":                      "kmr",
	"Northern Luri":                         "lrc",
	"Northern Mashan Hmong":                 "hmp",
	"Northern Muji":                         "ymx",
	"Northern Nago":                         "xkb",
	"Northern Ngbandi":                      "ngb",
	"Northern Nisu":                         "yiv",
	"Northern Nuni":                         "nuv",
	"Northern Oaxaca Nahuatl":               "nhy",
	"Northern Ohlone":                       "cst",
	"Northern One":                          "onr",
	"Northern Paiute":                       "pao",
	"Northern Pame":                         "pmq",
	"Northern Pashto":                       "pbu",
	"Northern Pastaza Quichua":              "qvz",
	"Northern Pomo":                         "pej",
	"Northern Puebla Nahuatl":               "ncj",
	"Northern Pumi":                         "pmi",
	"Northern Qiandong Miao":                "hea",
	"Northern Qiang":                        "cng",
	"Northern Rengma Naga":                  "nnl",
	"Northern Roglai":                       "rog",
	"Northern Sami":                         "sme",
	"Northern Sierra Miwok":                 "nsq",
	"Northern Sorsoganon":                   "bks",
	"Northern Subanen":                      "stb",
	"Northern Tarahumara":                   "thh",
	"Northern Tepehuan":                     "ntp",
	"Northern Thai":                         "nod",
	"Northern Tidung":                       "ntd",
	"Northern Tiwa":                         "twf",
	"Northern Tlaxiaco Mixtec":              "xtn",
	"Northern Toussian":                     "tsp",
	"Northern Tujia":                        "tji",
	"Northern Tutchone":                     "ttm",
	"Northern Uzbek":                        "uzn",
	"Northern Yukaghir":                     "ykg",
	"Northwest Alaska Inupiatun":            "esk",
	"Northwest Gbaya":                       "gya",
	"Northwest Maidu":                       "mjd",
	"Northwest Oaxaca Mixtec":               "mxa",
	"Northwest Pashai":                      "glh",
	"Northwestern Dinka":                    "diw",
	"Northwestern Fars":                     "faz",
	"Northwestern Kolami":                   "kfb",
	"Northwestern Nisu":                     "nsf",
	"Northwestern Ojibwa":                   "ojb",
	"Northwestern Tamang":                   "tmk",
	"Norwegian Bokmål":                      "nob",
	"Norwegian Nynorsk":                     "nno",
	"Norwegian Sign Language":               "nsl",
	"Norwegian":                             "nor",
	"Notre":                                 "bly",
	"Notsi":                                 "ncf",
	"Nottoway-Meherrin":                     "nwy",
	"Nottoway":                              "ntw",
	"Novial":                                "nov",
	"Noy":                                   "noy",
	"Nsenga":                                "nse",
	"Nshi":                                  "nsc",
	"Nsongo":                                "nsx",
	"Ntcham":                                "bud",
	"Ntomba":                                "nto",
	"Nubaca":                                "baf",
	"Nubi":                                  "kcn",
	"Nubri":                                 "kte",
	"Nuer":                                  "nus",
	"Nugunu (Australia)":                    "nnv",
	"Nugunu (Cameroon)":                     "yas",
	"Nuk":                                   "noc",
	"Nukak Makú":                            "mbr",
	"Nukna":                                 "klt",
	"Nukuini":                               "nuc",
	"Nukumanu":                              "nuq",
	"Nukunul":                               "xnu",
	"Nukuoro":                               "nkr",
	"Nukuria":                               "nur",
	"Numana-Nunku-Gbantu-Numbu":             "nbr",
	"Numanggang":                            "nop",
	"Numbami":                               "sij",
	"Nume":                                  "tgs",
	"Numèè":                                 "kdk",
	"Numidian":                              "nxm",
	"Nung (Viet Nam)":                       "nut",
	"Nungali":                               "nug",
	"Nunggubuyu":                            "nuy",
	"Nungu":                                 "rin",
	"Nupbikha":                              "npb",
	"Nupe-Nupe-Tako":                        "nup",
	"Nüpode Huitoto":                        "hux",
	"Nusa Laut":                             "nul",
	"Nusu":                                  "nuf",
	"Nuu-chah-nulth":                        "nuk",
	"Nyabwa":                                "nwb",
	"Nyaheun":                               "nev",
	"Nyahkur":                               "cbn",
	"Nyakyusa-Ngonde":                       "nyy",
	"Nyâlayu":                               "yly",
	"Nyali":                                 "nlj",
	"Nyam":                                  "nmi",
	"Nyamal":                                "nly",
	"Nyambo":                                "now",
	"Nyamusa-Molo":                          "nwm",
	"Nyamwanga":                             "mwn",
	"Nyamwezi":                              "nym",
	"Nyaneka":                               "nyk",
	"Nyang'i":                               "nyp",
	"Nyanga-li":                             "nyc",
	"Nyanga":                                "nyj",
	"Nyangatom":                             "nnj",
	"Nyangbo":                               "nyb",
	"Nyangga":                               "nny",
	"Nyangumarta":                           "nna",
	"Nyanja":                                "nya",
	"Nyankole":                              "nyn",
	"Nyankpa":                               "yes",
	"Nyarafolo Senoufo":                     "sev",
	"Nyaturu":                               "rim",
	"Nyaw":                                  "nyw",
	"Nyawaygi":                              "nyt",
	"Nyemba":                                "nba",
	"Nyengo":                                "nye",
	"Nyenkha":                               "neh",
	"Nyeu":                                  "nyl",
	"Nyigina":                               "nyh",
	"Nyiha (Malawi)":                        "nyr",
	"Nyiha (Tanzania)":                      "nih",
	"Nyika (Malawi and Zambia)":             "nkv",
	"Nyika (Tanzania)":                      "nkt",
	"Nyindrou":                              "lid",
	"Nyindu":                                "nyg",
	"Nyishi":                                "njz",
	"Nyiyaparli":                            "xny",
	"Nyokon":                                "nvo",
	"Nyole":                                 "nuj",
	"Nyong":                                 "muo",
	"Nyore":                                 "nyd",
	"Nyoro":                                 "nyo",
	"Nyulnyul":                              "nyv",
	"Nyunga":                                "nys",
	"Nyungwe":                               "nyu",
	"Nzakambay":                             "nzy",
	"Nzakara":                               "nzk",
	"Nzanyi":                                "nja",
	"Nzima":                                 "nzi",
	"O'chi'chi'":                            "xoc",
	"O'du":                                  "tyh",
	"Obanliku":                              "bzy",
	"Obispeño":                              "obi",
	"Oblo":                                  "obl",
	"Obo Manobo":                            "obo",
	"Obokuitai":                             "afz",
	"Obolo":                                 "ann",
	"Obulom":                                "obu",
	"Ocaina":                                "oca",
	"Occitan (post 1500)":                   "oci",
	"Ocotepec Mixtec":                       "mie",
	"Ocotlán Zapotec":                       "zac",
	"Od":                                    "odk",
	"Odia":                                  "ory",
	"Odiai":                                 "bhf",
	"Odoodee":                               "kkc",
	"Odual":                                 "odu",
	"Odut":                                  "oda",
	"Ofayé":                                 "opy",
	"Official Aramaic (700-300 BCE)":        "arc",
	"Ofo":                                   "ofo",
	"Ogbah":                                 "ogc",
	"Ogbia":                                 "ogb",
	"Ogbogolo":                              "ogg",
	"Ogbronuagum":                           "ogu",
	"Ogea":                                  "eri",
	"Oirata":                                "oia",
	"Ojibwa":                                "oji",
	"Ojitlán Chinantec":                     "chj",
	"Okanagan":                              "oka",
	"Oki-No-Erabu":                          "okn",
	"Okiek":                                 "oki",
	"Oko-Eni-Osayen":                        "oks",
	"Oko-Juwoi":                             "okj",
	"Okobo":                                 "okb",
	"Okodia":                                "okd",
	"Okolod":                                "kqv",
	"Okpamheri":                             "opa",
	"Okpe (Northwestern Edo)":               "okx",
	"Okpe (Southwestern Edo)":               "oke",
	"Oksapmin":                              "opm",
	"Oku":                                   "oku",
	"Old Aramaic (up to 700 BCE)":           "oar",
	"Old Avar":                              "oav",
	"Old Breton":                            "obt",
	"Old Burmese":                           "obr",
	"Old Chinese":                           "och",
	"Old Cornish":                           "oco",
	"Old Dutch":                             "odt",
	"Old English (ca. 450-1100)":            "ang",
	"Old French (842-ca. 1400)":             "fro",
	"Old Frisian":                           "ofs",
	"Old Georgian":                          "oge",
	"Old High German (ca. 750-1050)":        "goh",
	"Old Hittite":                           "oht",
	"Old Hungarian":                         "ohu",
	"Old Irish (to 900)":                    "sga",
	"Old Japanese":                          "ojp",
	"Old Kentish Sign Language":             "okl",
	"Old Korean (3rd-9th cent.)":            "oko",
	"Old Lithuanian":                        "olt",
	"Old Manipuri":                          "omp",
	"Old Marathi":                           "omr",
	"Old Mon":                               "omx",
	"Old Norse":                             "non",
	"Old Nubian":                            "onw",
	"Old Ossetic":                           "oos",
	"Old Persian (ca. 600-400 B.C.)":        "peo",
	"Old Provençal (to 1500)":               "pro",
	"Old Russian":                           "orv",
	"Old Saxon":                             "osx",
	"Old Spanish":                           "osp",
	"Old Tamil":                             "oty",
	"Old Tibetan":                           "otb",
	"Old Turkish":                           "otk",
	"Old Uighur":                            "oui",
	"Old Welsh":                             "owl",
	"Olekha":                                "ole",
	"Olkol":                                 "olk",
	"Olo":                                   "ong",
	"Oloma":                                 "olm",
	"Olrat":                                 "olr",
	"Olu'bo":                                "lul",
	"Olulumo-Ikom":                          "iko",
	"Oluta Popoluca":                        "plo",
	"Omagua":                                "omg",
	"Omaha-Ponca":                           "oma",
	"Omani Arabic":                          "acx",
	"Ombamba":                               "mbm",
	"Ombo":                                  "oml",
	"Ometepec Nahuatl":                      "nht",
	"Omi":                                   "omi",
	"Ömie":                                  "aom",
	"Omok":                                  "omk",
	"Omotik":                                "omt",
	"Omurano":                               "omu",
	"Ona":                                   "ona",
	"Oneida":                                "one",
	"Ong":                                   "oog",
	"Önge":                                  "oon",
	"Onin Based Pidgin":                     "onx",
	"Onin":                                  "oni",
	"Onjob":                                 "onj",
	"Ono":                                   "ons",
	"Onobasulu":                             "onn",
	"Onondaga":                              "ono",
	"Ontenu":                                "ont",
	"Ontong Java":                           "ojv",
	"Oorlams":                               "oor",
	"Opao":                                  "opo",
	"Opata":                                 "opt",
	"Orang Kanaq":                           "orn",
	"Orang Seletar":                         "ors",
	"Oraon Sadri":                           "sdr",
	"Orejón":                                "ore",
	"Oring":                                 "org",
	"Oriya (macrolanguage)":                 "ori",
	"Orizaba Nahuatl":                       "nlv",
	"Orma":                                  "orc",
	"Ormu":                                  "orz",
	"Ormuri":                                "oru",
	"Oro Win":                               "orw",
	"Oro":                                   "orx",
	"Oroch":                                 "oac",
	"Oroha":                                 "ora",
	"Orok":                                  "oaa",
	"Orokaiva":                              "okv",
	"Oroko":                                 "bdu",
	"Orokolo":                               "oro",
	"Oromo":                                 "orm",
	"Oroqen":                                "orh",
	"Orowe":                                 "bpk",
	"Oruma":                                 "orr",
	"Orya":                                  "ury",
	"Osage":                                 "osa",
	"Osatu":                                 "ost",
	"Oscan":                                 "osc",
	"Osing":                                 "osi",
	"Ososo":                                 "oso",
	"Ossetian":                              "oss",
	"Ot Danum":                              "otd",
	"Otank":                                 "uta",
	"Oti":                                   "oti",
	"Otoro":                                 "otr",
	"Ottawa":                                "otw",
	"Ottoman Turkish (1500-1928)":           "ota",
	"Otuho":                                 "lot",
	"Otuke":                                 "otu",
	"Ouma":                                  "oum",
	"Oune":                                  "oue",
	"Owa":                                   "stn",
	"Owenia":                                "wsr",
	"Owiniga":                               "owi",
	"Oy":                                    "oyb",
	"Oya'oya":                               "oyy",
	"Oyda":                                  "oyd",
	"Ozolotepec Zapotec":                    "zao",
	"Ozumacín Chinantec":                    "chz",
	"Pa Di":                                 "pdi",
	"Pa-Hng":                                "pha",
	"Pa'a":                                  "pqa",
	"Pa'o Karen":                            "blk",
	"Pááfang":                               "pfa",
	"Paakantyi":                             "drl",
	"Paama":                                 "pma",
	"Paasaal":                               "sig",
	"Pacahuara":                             "pcp",
	"Pacaraos Quechua":                      "qvp",
	"Pacific Gulf Yupik":                    "ems",
	"Pacoh":                                 "pac",
	"Padoe":                                 "pdo",
	"Paekche":                               "pkc",
	"Paelignian":                            "pgn",
	"Páez":                                  "pbb",
	"Pagi":                                  "pgi",
	"Pagibete":                              "pae",
	"Pagu":                                  "pgu",
	"Pahanan Agta":                          "apf",
	"Pahari-Potwari":                        "phr",
	"Pahi":                                  "lgt",
	"Pahlavani":                             "phv",
	"Pahlavi":                               "pal",
	"Pai Tavytera":                          "pta",
	"Paicî":                                 "pri",
	"Paipai":                                "ppi",
	"Paite Chin":                            "pck",
	"Paiwan":                                "pwn",
	"Pak-Tong":                              "pkg",
	"Pakaásnovos":                           "pav",
	"Pakanha":                               "pkn",
	"Pakistan Sign Language":                "pks",
	"Paku Karen":                            "jkp",
	"Paku":                                  "pku",
	"Pal":                                   "abw",
	"Palaic":                                "plq",
	"Palaka Senoufo":                        "plr",
	"Palantla Chinantec":                    "cpa",
	"Palauan":                               "pau",
	"Paleni":                                "pnl",
	"Palenquero":                            "pln",
	"Pali":                                  "pli",
	"Palikúr":                               "plu",
	"Paliyan":                               "pcf",
	"Pallanganmiddang":                      "pmd",
	"Palor":                                 "fap",
	"Palpa":                                 "plp",
	"Palu'e":                                "ple",
	"Paluan":                                "plz",
	"Palya Bareli":                          "bpx",
	"Pam":                                   "pmn",
	"Pambia":                                "pmb",
	"Pamlico":                               "pmk",
	"Pamona":                                "pmf",
	"Pamosu":                                "hih",
	"Pampanga":                              "pam",
	"Pamplona Atta":                         "att",
	"Pana (Burkina Faso)":                   "pnq",
	"Pana (Central African Republic)":       "pnz",
	"Panamanian Sign Language":              "lsp",
	"Panamint":                              "par",
	"Panao Huánuco Quechua":                 "qxh",
	"Panará":                                "kre",
	"Panasuan":                              "psn",
	"Panawa":                                "pwb",
	"Pancana":                               "pnp",
	"Panchpargania":                         "tdb",
	"Pande":                                 "bkj",
	"Pangasinan":                            "pag",
	"Pangseng":                              "pgs",
	"Pangutaran Sama":                       "slm",
	"Pangwa":                                "pbr",
	"Pangwali":                              "pgg",
	"Panim":                                 "pnr",
	"Paniya":                                "pcg",
	"Panjabi":                               "pan",
	"Pankararé":                             "pax",
	"Pankararú":                             "paz",
	"Pankhu":                                "pkh",
	"Pannei":                                "pnc",
	"Pano":                                  "mqz",
	"Panoan Katukína":                       "knt",
	"Panobo":                                "pno",
	"Panyi Bai":                             "bfc",
	"Panytyima":                             "pnw",
	"Papantla Totonac":                      "top",
	"Papapana":                              "ppn",
	"Papar":                                 "dpp",
	"Papasena":                              "pas",
	"Papel":                                 "pbo",
	"Papi":                                  "ppe",
	"Papiamento":                            "pap",
	"Papitalai":                             "pat",
	"Papora":                                "ppu",
	"Papua New Guinean Sign Language":       "pgz",
	"Papuan Malay":                          "pmy",
	"Papuma":                                "ppm",
	"Pará Arára":                            "aap",
	"Pará Gavião":                           "gvp",
	"Para Naga":                             "pzn",
	"Parachi":                               "prc",
	"Paraguayan Guaraní":                    "gug",
	"Paraguayan Sign Language":              "pys",
	"Parakanã":                              "pak",
	"Paranan":                               "prf",
	"Paranawát":                             "paf",
	"Paraujano":                             "pbg",
	"Parauk":                                "prk",
	"Parawen":                               "prw",
	"Pardhan":                               "pch",
	"Pardhi":                                "pcl",
	"Pare":                                  "ppt",
	"Parecís":                               "pab",
	"Parenga":                               "pcj",
	"Päri":                                  "lkr",
	"Parkari Koli":                          "kvx",
	"Parkwa":                                "pbi",
	"Parsi-Dari":                            "prd",
	"Parsi":                                 "prp",
	"Parthian":                              "xpr",
	"Parya":                                 "paq",
	"Pasi":                                  "psq",
	"Pass Valley Yali":                      "yac",
	"Patamona":                              "pbc",
	"Patani":                                "ptn",
	"Pataxó Hã-Ha-Hãe":                      "pth",
	"Patep":                                 "ptp",
	"Pathiya":                               "pty",
	"Patpatar":                              "gfk",
	"Pattani Malay":                         "mfa",
	"Pattani":                               "lae",
	"Pattapu":                               "ptq",
	"Patwin":                                "pwi",
	"Paulohi":                               "plh",
	"Paumarí":                               "pad",
	"Paunaka":                               "pnk",
	"Pauri Bareli":                          "bfb",
	"Pauserna":                              "psm",
	"Pawaia":                                "pwa",
	"Pawnee":                                "paw",
	"Paynamar":                              "pmr",
	"Pe":                                    "pai",
	"Pear":                                  "pcb",
	"Pech":                                  "pay",
	"Pecheneg":                              "xpc",
	"Pedi":                                  "nso",
	"Peere":                                 "pfe",
	"Pei":                                   "ppq",
	"Pekal":                                 "pel",
	"Pela":                                  "bxd",
	"Pele-Ata":                              "ata",
	"Pelende":                               "ppp",
	"Pemon":                                 "aoc",
	"Pémono":                                "pev",
	"Penang Sign Language":                  "psg",
	"Penchal":                               "pek",
	"Pendau":                                "ums",
	"Pengo":                                 "peg",
	"Pennsylvania German":                   "pdc",
	"Peñoles Mixtec":                        "mil",
	"Penrhyn":                               "pnh",
	"Pentlatch":                             "ptw",
	"Perai":                                 "wet",
	"Peranakan Indonesian":                  "pea",
	"Peripheral Mongolian":                  "mvf",
	"Pero":                                  "pip",
	"Persian Sign Language":                 "psc",
	"Persian":                               "fas",
	"Peruvian Sign Language":                "prl",
	"Petapa Zapotec":                        "zpe",
	"Petats":                                "pex",
	"Petjo":                                 "pey",
	"Pévé":                                  "lme",
	"Pfaelzisch":                            "pfl",
	"Phai":                                  "prt",
	"Phake":                                 "phk",
	"Phala":                                 "ypa",
	"Phalura":                               "phl",
	"Phana'":                                "phq",
	"Phangduwali":                           "phw",
	"Phende":                                "pem",
	"Philippine Sign Language":              "psp",
	"Phimbi":                                "phm",
	"Phoenician":                            "phn",
	"Phola":                                 "ypg",
	"Pholo":                                 "yip",
	"Phom Naga":                             "nph",
	"Phong-Kniang":                          "pnx",
	"Phrae Pwo Karen":                       "kjt",
	"Phrygian":                              "xpg",
	"Phu Thai":                              "pht",
	"Phuan":                                 "phu",
	"Phudagi":                               "phd",
	"Phuie":                                 "pug",
	"Phukha":                                "phh",
	"Phuma":                                 "ypm",
	"Phunoi":                                "pho",
	"Phuong":                                "phg",
	"Phupa":                                 "ypp",
	"Phupha":                                "yph",
	"Phuza":                                 "ypz",
	"Piamatsina":                            "ptr",
	"Piame":                                 "pin",
	"Piapoco":                               "pio",
	"Piaroa":                                "pid",
	"Picard":                                "pcd",
	"Pichis Ashéninka":                      "cpu",
	"Pictish":                               "xpi",
	"Pidgin Delaware":                       "dep",
	"Piemontese":                            "pms",
	"Pijao":                                 "pij",
	"Pije":                                  "piz",
	"Pijin":                                 "pis",
	"Pilagá":                                "plg",
	"Pileni":                                "piv",
	"Pima Bajo":                             "pia",
	"Pimbwe":                                "piw",
	"Pinai-Hagahai":                         "pnn",
	"Pingelapese":                           "pif",
	"Pini":                                  "pii",
	"Pinigura":                              "pnv",
	"Pinjarup":                              "pnj",
	"Pinji":                                 "pic",
	"Pinotepa Nacional Mixtec":              "mio",
	"Pintiini":                              "pti",
	"Pintupi-Luritja":                       "piu",
	"Pinyin":                                "pny",
	"Pipil":                                 "ppl",
	"Pirahã":                                "myp",
	"Piratapuyo":                            "pir",
	"Pirlatapa":                             "bxi",
	"Piro":                                  "pie",
	"Pirriya":                               "xpa",
	"Pisabo":                                "pig",
	"Pisaflores Tepehua":                    "tpp",
	"Piscataway":                            "psy",
	"Pisidian":                              "xps",
	"Pitcairn-Norfolk":                      "pih",
	"Pite Sami":                             "sje",
	"Piti":                                  "pcn",
	"Pitjantjatjara":                        "pjt",
	"Pitta Pitta":                           "pit",
	"Piu":                                   "pix",
	"Piya-Kwonci":                           "piy",
	"Plains Cree":                           "crk",
	"Plains Indian Sign Language":           "psd",
	"Plains Miwok":                          "pmw",
	"Plapo Krumen":                          "ktj",
	"Plateau Malagasy":                      "plt",
	"Plautdietsch":                          "pdt",
	"Playero":                               "gob",
	"Pnar":                                  "pbv",
	"Pochuri Naga":                          "npo",
	"Pochutec":                              "xpo",
	"Podena":                                "pdn",
	"Pogolo":                                "poy",
	"Pohnpeian":                             "pon",
	"Pokangá":                               "pok",
	"Poke":                                  "pof",
	"Pokomo":                                "pkb",
	"Pökoot":                                "pko",
	"Polabian":                              "pox",
	"Polari":                                "pld",
	"Polci":                                 "plj",
	"Polish Sign Language":                  "pso",
	"Polish":                                "pol",
	"Polonombauk":                           "plb",
	"Pom":                                   "pmo",
	"Pomo":                                  "pmm",
	"Ponam":                                 "ncc",
	"Pongu":                                 "png",
	"Ponosakan":                             "pns",
	"Pontic":                                "pnt",
	"Ponyo-Gongwang Naga":                   "npg",
	"Popti'":                                "jac",
	"Poqomam":                               "poc",
	"Poqomchi'":                             "poh",
	"Porohanon":                             "prh",
	"Port Sandwich":                         "psw",
	"Port Vato":                             "ptv",
	"Portuguese Sign Language":              "psr",
	"Portuguese":                            "por",
	"Potawatomi":                            "pot",
	"Potiguára":                             "pog",
	"Pottangi Ollar Gadaba":                 "gdb",
	"Poumei Naga":                           "pmx",
	"Pouye":                                 "bye",
	"Powari":                                "pwr",
	"Powhatan":                              "pim",
	"Poyanáwa":                              "pyn",
	"Prasuni":                               "prn",
	"Primitive Irish":                       "pgl",
	"Principense":                           "pre",
	"Providencia Sign Language":             "prz",
	"Prussian":                              "prg",
	"Psikye":                                "kvj",
	"Pu-Xian Chinese":                       "cpx",
	"Puare":                                 "pux",
	"Pudtol Atta":                           "atp",
	"Puelche":                               "pue",
	"Puerto Rican Sign Language":            "psl",
	"Puimei Naga":                           "npu",
	"Puinave":                               "pui",
	"Pukapuka":                              "pkp",
	"Pulaar":                                "fuc",
	"Pulabu":                                "pup",
	"Pular":                                 "fuf",
	"Puluwatese":                            "puw",
	"Puma":                                  "pum",
	"Pumé":                                  "yae",
	"Pumpokol":                              "xpm",
	"Punan Aput":                            "pud",
	"Punan Bah-Biau":                        "pna",
	"Punan Batu 1":                          "pnm",
	"Punan Merah":                           "puf",
	"Punan Merap":                           "puc",
	"Punan Tubu":                            "puj",
	"Punic":                                 "xpu",
	"Puno Quechua":                          "qxp",
	"Punthamara":                            "xpt",
	"Punu":                                  "puu",
	"Puoc":                                  "puo",
	"Puquina":                               "puq",
	"Puragi":                                "pru",
	"Purari":                                "iar",
	"Purepecha":                             "tsz",
	"Puri":                                  "prr",
	"Purik":                                 "prx",
	"Purisimeño":                            "puy",
	"Puroik":                                "suv",
	"Puruborá":                              "pur",
	"Purum":                                 "pub",
	"Pushto":                                "pus",
	"Putai":                                 "mfl",
	"Putoh":                                 "put",
	"Putukwam":                              "afe",
	"Puyo-Paekche":                          "xpp",
	"Puyo":                                  "xpy",
	"Puyuma":                                "pyu",
	"Pwaamei":                               "pme",
	"Pwapwâ":                                "pop",
	"Pwo Eastern Karen":                     "kjp",
	"Pwo Northern Karen":                    "pww",
	"Pwo Western Karen":                     "pwo",
	"Pyapun":                                "pcw",
	"Pye Krumen":                            "pye",
	"Pyen":                                  "pyy",
	"Pyu (Myanmar)":                         "pyx",
	"Pyu (Papua New Guinea)":                "pby",
	"Q'anjob'al":                            "kjb",
	"Qabiao":                                "laq",
	"Qaqet":                                 "byx",
	"Qashqa'i":                              "qxq",
	"Qatabanian":                            "xqt",
	"Qau":                                   "gqu",
	"Qawasqar":                              "alc",
	"Qila Muji":                             "ymq",
	"Qimant":                                "ahg",
	"Qiubei Zhuang":                         "zqe",
	"Quapaw":                                "qua",
	"Quebec Sign Language":                  "fcs",
	"Quechan":                               "yum",
	"Quechua":                               "que",
	"Quenya":                                "qya",
	"Querétaro Otomi":                       "otq",
	"Quetzaltepec Mixe":                     "pxm",
	"Queyu":                                 "qvy",
	"Quiavicuzas Zapotec":                   "zpj",
	"Quileute":                              "qui",
	"Quinault":                              "qun",
	"Quinqui":                               "quq",
	"Quioquitani-Quierí Zapotec":            "ztq",
	"Quiotepec Chinantec":                   "chq",
	"Quiripi":                               "qyp",
	"Rabha":                                 "rah",
	"Rade":                                  "rad",
	"Raetic":                                "xrr",
	"Rahambuu":                              "raz",
	"Rajah Kabunsuwan Manobo":               "mqk",
	"Rajasthani":                            "raj",
	"Rajbanshi":                             "rjs",
	"Raji":                                  "rji",
	"Rajong":                                "rjg",
	"Rajput Garasia":                        "gra",
	"Rakahanga-Manihiki":                    "rkh",
	"Rakhine":                               "rki",
	"Ralte":                                 "ral",
	"Rama":                                  "rma",
	"Ramoaaina":                             "rai",
	"Ramopa":                                "kjx",
	"Rampi":                                 "lje",
	"Rana Tharu":                            "thr",
	"Rang":                                  "rax",
	"Rangkas":                               "rgk",
	"Ranglong":                              "rnl",
	"Rangpuri":                              "rkt",
	"Rao":                                   "rao",
	"Rapa":                                  "ray",
	"Rapanui":                               "rap",
	"Rapoisi":                               "kyx",
	"Rapting":                               "rpt",
	"Rara Bakati'":                          "lra",
	"Rarotongan":                            "rar",
	"Rasawa":                                "rac",
	"Ratagnon":                              "btn",
	"Ratahan":                               "rth",
	"Rathawi":                               "rtw",
	"Rathwi Bareli":                         "bgd",
	"Raute":                                 "rau",
	"Ravula":                                "yea",
	"Rawa":                                  "rwo",
	"Rawang":                                "raw",
	"Rawat":                                 "jnl",
	"Rawngtu Chin":                          "weu",
	"Rawo":                                  "rwa",
	"Rayón Zoque":                           "zor",
	"Razajerdi":                             "rat",
	"Rāziḥī":                                "rzh",
	"Red Gelao":                             "gir",
	"Reel":                                  "atu",
	"Rejang Kayan":                          "ree",
	"Rejang":                                "rej",
	"Reli":                                  "rei",
	"Rema":                                  "bow",
	"Rembarunga":                            "rmb",
	"Rembong":                               "reb",
	"Remo":                                  "rem",
	"Remontado Dumagat":                     "agv",
	"Rempi":                                 "rmp",
	"Remun":                                 "lkj",
	"Rendille":                              "rel",
	"Rengao":                                "ren",
	"Rennell-Bellona":                       "mnv",
	"Repanbitip":                            "rpn",
	"Rer Bare":                              "rer",
	"Rerau":                                 "rea",
	"Rerep":                                 "pgk",
	"Reshe":                                 "res",
	"Resígaro":                              "rgr",
	"Retta":                                 "ret",
	"Réunion Creole French":                 "rcf",
	"Reyesano":                              "rey",
	"Riang (India)":                         "ria",
	"Riang (Myanmar)":                       "ril",
	"Riantana":                              "ran",
	"Ribun":                                 "rir",
	"Rikbaktsa":                             "rkb",
	"Rincón Zapotec":                        "zar",
	"Rinconada Bikol":                       "bto",
	"Ringgou":                               "rgu",
	"Ririo":                                 "rri",
	"Ritarungo":                             "rit",
	"Riung":                                 "riu",
	"Riverain Sango":                        "snj",
	"Rogo":                                  "rod",
	"Rohingya":                              "rhg",
	"Roma":                                  "rmm",
	"Romagnol":                              "rgn",
	"Romam":                                 "rmx",
	"Romanian Sign Language":                "rms",
	"Romanian":                              "ron",
	"Romano-Greek":                          "rge",
	"Romano-Serbian":                        "rsb",
	"Romanova":                              "rmv",
	"Romansh":                               "roh",
	"Romany":                                "rom",
	"Romblomanon":                           "rol",
	"Rombo":                                 "rof",
	"Romkun":                                "rmk",
	"Ron":                                   "cla",
	"Ronga":                                 "rng",
	"Rongga":                                "ror",
	"Rongmei Naga":                          "nbu",
	"Rongpo":                                "rnp",
	"Ronji":                                 "roe",
	"Roon":                                  "rnn",
	"Roria":                                 "rga",
	"Rotokas":                               "roo",
	"Rotuman":                               "rtm",
	"Roviana":                               "rug",
	"Ruching Palaung":                       "pce",
	"Rudbari":                               "rdb",
	"Rufiji":                                "rui",
	"Ruga":                                  "ruh",
	"Rukai":                                 "dru",
	"Ruma":                                  "ruz",
	"Rumai Palaung":                         "rbb",
	"Rumu":                                  "klq",
	"Rundi":                                 "run",
	"Runga":                                 "rou",
	"Rungtu Chin":                           "rtc",
	"Rungus":                                "drg",
	"Rungwa":                                "rnw",
	"Russia Buriat":                         "bxr",
	"Russian Sign Language":                 "rsl",
	"Russian":                               "rus",
	"Rusyn":                                 "rue",
	"Rutul":                                 "rut",
	"Ruuli":                                 "ruc",
	"Ruund":                                 "rnd",
	"Rwa":                                   "rwk",
	"S'gaw Karen":                           "ksw",
	"Sa'a":                                  "apb",
	"Sa'ban":                                "snv",
	"Sa'och":                                "scq",
	"Sa":                                    "sax",
	"Saafi-Saafi":                           "sav",
	"Saam":                                  "raq",
	"Saamia":                                "lsm",
	"Saaroa":                                "sxr",
	"Saba":                                  "saa",
	"Sabaean":                               "xsa",
	"Sabah Bisaya":                          "bsy",
	"Sabah Malay":                           "msi",
	"Sabanê":                                "sae",
	"Sabaot":                                "spy",
	"Sabine":                                "sbv",
	"Sabu":                                  "hvn",
	"Sabüm":                                 "sbo",
	"Sacapulteco":                           "quv",
	"Sadri":                                 "sck",
	"Saek":                                  "skb",
	"Saep":                                  "spd",
	"Safaliba":                              "saf",
	"Safeyoka":                              "apz",
	"Safwa":                                 "sbk",
	"Sagala":                                "sbm",
	"Sagalla":                               "tga",
	"Saho":                                  "ssy",
	"Sahu":                                  "saj",
	"Saidi Arabic":                          "aec",
	"Saint Lucian Creole French":            "acf",
	"Saisiyat":                              "xsy",
	"Sajalong":                              "sjl",
	"Sajau Basap":                           "sjb",
	"Sakachep":                              "sch",
	"Sakalava Malagasy":                     "skg",
	"Sakao":                                 "sku",
	"Sakata":                                "skt",
	"Sake":                                  "sak",
	"Sakirabiá":                             "skf",
	"Sala":                                  "shq",
	"Salampasu":                             "slx",
	"Salar":                                 "slr",
	"Salas":                                 "sgu",
	"Salasaca Highland Quichua":             "qxl",
	"Salchuq":                               "slq",
	"Saleman":                               "sau",
	"Saliba":                                "sbe",
	"Sáliba":                                "slc",
	"Salinan":                               "sln",
	"Sallands":                              "sdz",
	"Salt-Yui":                              "sll",
	"Saluan":                                "loe",
	"Salumá":                                "slj",
	"Salvadoran Sign Language":              "esn",
	"Sam":                                   "snx",
	"Sama":                                  "smd",
	"Samaritan Aramaic":                     "sam",
	"Samaritan":                             "smp",
	"Samarokena":                            "tmj",
	"Samatao":                               "ysd",
	"Samay":                                 "syx",
	"Samba Daka":                            "ccg",
	"Samba Leko":                            "ndi",
	"Samba":                                 "smx",
	"Sambal":                                "xsb",
	"Sambalpuri":                            "spv",
	"Sambe":                                 "xab",
	"Samberigi":                             "ssx",
	"Samburu":                               "saq",
	"Samei":                                 "smh",
	"Samo":                                  "smq",
	"Samoan":                                "smo",
	"Samogitian":                            "sgs",
	"Samosa":                                "swm",
	"Sampang":                               "rav",
	"Samre":                                 "sxm",
	"Samtao":                                "stu",
	"Samvedi":                               "smv",
	"San Agustín Mixtepec Zapotec":          "ztm",
	"San Baltazar Loxicha Zapotec":          "zpx",
	"San Blas Kuna":                         "cuk",
	"San Dionisio Del Mar Huave":            "hve",
	"San Felipe Otlaltepec Popoloca":        "pow",
	"San Francisco Del Mar Huave":           "hue",
	"San Francisco Matlatzinca":             "mat",
	"San Jerónimo Tecóatl Mazatec":          "maa",
	"San Juan Atzingo Popoloca":             "poe",
	"San Juan Colorado Mixtec":              "mjc",
	"San Juan Teita Mixtec":                 "xtj",
	"San Luís Temalacayuca Popoloca":        "pps",
	"San Marcos Tlacoyalco Popoloca":        "pls",
	"San Martín Itunyoso Triqui":            "trq",
	"San Martín Quechua":                    "qvs",
	"San Mateo Del Mar Huave":               "huv",
	"San Miguel Creole French":              "scf",
	"San Miguel El Grande Mixtec":           "mig",
	"San Miguel Piedras Mixtec":             "xtp",
	"San Pedro Amuzgos Amuzgo":              "azg",
	"San Pedro Quiatoni Zapotec":            "zpf",
	"San Salvador Kongo":                    "kwy",
	"San Vicente Coatlán Zapotec":           "zpt",
	"Sanaani Arabic":                        "ayn",
	"Sanapaná":                              "spn",
	"Sandawe":                               "sad",
	"Sanga (Democratic Republic of Congo)":  "sng",
	"Sanga (Nigeria)":                       "xsn",
	"Sanggau":                               "scg",
	"Sangil":                                "snl",
	"Sangir":                                "sxn",
	"Sangisari":                             "sgr",
	"Sangkong":                              "sgk",
	"Sanglechi":                             "sgy",
	"Sango":                                 "sag",
	"Sangtam Naga":                          "nsa",
	"Sangu (Gabon)":                         "snq",
	"Sangu (Tanzania)":                      "sbp",
	"Sani":                                  "ysn",
	"Sanie":                                 "ysy",
	"Saniyo-Hiyewe":                         "sny",
	"Sankaran Maninka":                      "msc",
	"Sansi":                                 "ssi",
	"Sanskrit":                              "san",
	"Santa Ana de Tusi Pasco Quechua":       "qxt",
	"Santa Catarina Albarradas Zapotec":     "ztn",
	"Santa Inés Ahuatempan Popoloca":        "pca",
	"Santa Inés Yatzechi Zapotec":           "zpn",
	"Santa Lucía Monteverde Mixtec":         "mdv",
	"Santa María Del Mar Huave":             "hvv",
	"Santa María La Alta Nahuatl":           "nhz",
	"Santa María Quiegolani Zapotec":        "zpi",
	"Santa María Zacatepec Mixtec":          "mza",
	"Santa Teresa Cora":                     "cok",
	"Santali":                               "sat",
	"Santiago del Estero Quichua":           "qus",
	"Santiago Xanica Zapotec":               "zpr",
	"Santo Domingo Albarradas Zapotec":      "zas",
	"Sanumá":                                "xsu",
	"São Paulo Kaingáng":                    "zkp",
	"Sãotomense":                            "cri",
	"Saparua":                               "spr",
	"Sapé":                                  "spc",
	"Sapo":                                  "krn",
	"Saponi":                                "spi",
	"Saposa":                                "sps",
	"Sapuan":                                "spu",
	"Sar":                                   "mwm",
	"Sara Kaba Deme":                        "kwg",
	"Sara Kaba Náà":                         "kwv",
	"Sara Kaba":                             "sbz",
	"Sara":                                  "sre",
	"Saraiki":                               "skr",
	"Saramaccan":                            "srm",
	"Sarangani Blaan":                       "bps",
	"Sarangani Manobo":                      "mbs",
	"Sarasira":                              "zsa",
	"Saraveca":                              "sar",
	"Sardinian":                             "srd",
	"Sari":                                  "asj",
	"Sarikoli":                              "srh",
	"Sarli":                                 "sdf",
	"Sarsi":                                 "srs",
	"Sartang":                               "onp",
	"Sarua":                                 "swy",
	"Sarudu":                                "sdu",
	"Saruga":                                "sra",
	"Sasak":                                 "sas",
	"Sasaru":                                "sxs",
	"Sassarese Sardinian":                   "sdc",
	"Satawalese":                            "stw",
	"Sateré-Mawé":                           "mav",
	"Saterfriesisch":                        "stq",
	"Saudi Arabian Sign Language":           "sdl",
	"Sauraseni Prākrit":                     "psu",
	"Saurashtra":                            "saz",
	"Sauri":                                 "srt",
	"Sauria Paharia":                        "mjt",
	"Sause":                                 "sao",
	"Sausi":                                 "ssj",
	"Savi":                                  "sdg",
	"Savosavo":                              "svs",
	"Sawai":                                 "szw",
	"Saweru":                                "swr",
	"Sawi":                                  "saw",
	"Sawila":                                "swt",
	"Sawknah":                               "swn",
	"Saxwe Gbe":                             "sxw",
	"Saya":                                  "say",
	"Sayula Popoluca":                       "pos",
	"Scots":                                 "sco",
	"Scottish Gaelic":                       "gla",
	"Scythian":                              "xsc",
	"Sea Island Creole English":             "gul",
	"Seba":                                  "kdg",
	"Sebat Bet Gurage":                      "sgw",
	"Seberuang":                             "sbx",
	"Sebop":                                 "sib",
	"Sebuyau":                               "snb",
	"Sechelt":                               "sec",
	"Secoya":                                "sey",
	"Sedang":                                "sed",
	"Sedoa":                                 "tvw",
	"Seeku":                                 "sos",
	"Segai":                                 "sge",
	"Segeju":                                "seg",
	"Seget":                                 "sbg",
	"Sehwi":                                 "sfw",
	"Seimat":                                "ssg",
	"Seit-Kaitetu":                          "hik",
	"Sekani":                                "sek",
	"Sekapan":                               "skp",
	"Sekar":                                 "skz",
	"Seke (Nepal)":                          "skj",
	"Seke (Vanuatu)":                        "ske",
	"Sekele":                                "vaj",
	"Seki":                                  "syi",
	"Seko Padang":                           "skx",
	"Seko Tengah":                           "sko",
	"Sekpele":                               "lip",
	"Selangor Sign Language":                "kgi",
	"Selaru":                                "slu",
	"Selayar":                               "sly",
	"Selee":                                 "snw",
	"Selepet":                               "spl",
	"Selian":                                "sxl",
	"Selkup":                                "sel",
	"Selungai Murut":                        "slg",
	"Seluwasan":                             "sws",
	"Semai":                                 "sea",
	"Semandang":                             "sdm",
	"Semaq Beri":                            "szc",
	"Sembakung Murut":                       "sbr",
	"Semelai":                               "sza",
	"Semimi":                                "etz",
	"Semnam":                                "ssm",
	"Semnani":                               "smy",
	"Sempan":                                "xse",
	"Sena":                                  "seh",
	"Senara Sénoufo":                        "seq",
	"Senaya":                                "syn",
	"Sene":                                  "sej",
	"Seneca":                                "see",
	"Sened":                                 "sds",
	"Sengele":                               "szg",
	"Senggi":                                "snu",
	"Sengo":                                 "spk",
	"Sengseng":                              "ssz",
	"Senhaja De Srair":                      "sjs",
	"Sensi":                                 "sni",
	"Sentani":                               "set",
	"Senthang Chin":                         "sez",
	"Sentinel":                              "std",
	"Sepa (Indonesia)":                      "spb",
	"Sepa (Papua New Guinea)":               "spe",
	"Sepik Iwam":                            "iws",
	"Sera":                                  "sry",
	"Serbian":                               "srp",
	"Serbo-Croatian":                        "hbs",
	"Sere":                                  "swf",
	"Serer":                                 "srr",
	"Seri":                                  "sei",
	"Serili":                                "sve",
	"Seroa":                                 "kqu",
	"Serrano":                               "ser",
	"Seru":                                  "szd",
	"Serua":                                 "srw",
	"Serudung Murut":                        "srk",
	"Serui-Laut":                            "seu",
	"Seselwa Creole French":                 "crs",
	"Seta":                                  "stf",
	"Setaman":                               "stm",
	"Seti":                                  "sbi",
	"Settla":                                "sta",
	"Severn Ojibwa":                         "ojs",
	"Sewa Bay":                              "sew",
	"Seze":                                  "sze",
	"Sha":                                   "scw",
	"Shabak":                                "sdb",
	"Shahmirzadi":                           "srz",
	"Shahrudi":                              "shm",
	"Shall-Zwall":                           "sha",
	"Shama-Sambuga":                         "sqa",
	"Shamang":                               "xsh",
	"Shambala":                              "ksb",
	"Shan":                                  "shn",
	"Shanenawa":                             "swo",
	"Shanga":                                "sho",
	"Sharanahua":                            "mcd",
	"Shark Bay":                             "ssv",
	"Sharwa":                                "swq",
	"Shasta":                                "sht",
	"Shatt":                                 "shj",
	"Shau":                                  "sqh",
	"Shawnee":                               "sjw",
	"She":                                   "shx",
	"Shehri":                                "shv",
	"Shekhawati":                            "swv",
	"Shekkacho":                             "moy",
	"Sheko":                                 "she",
	"Shelta":                                "sth",
	"Shempire Senoufo":                      "seb",
	"Shendu":                                "shl",
	"Sheni":                                 "scv",
	"Sherbro":                               "bun",
	"Sherdukpen":                            "sdp",
	"Sherpa":                                "xsr",
	"Sheshi Kham":                           "kip",
	"Shi":                                   "shr",
	"Shihhi Arabic":                         "ssh",
	"Shiki":                                 "gua",
	"Shilluk":                               "shk",
	"Shina":                                 "scl",
	"Shipibo-Conibo":                        "shp",
	"Shixing":                               "sxg",
	"Sholaga":                               "sle",
	"Shom Peng":                             "sii",
	"Shona":                                 "sna",
	"Shoo-Minda-Nye":                        "bcv",
	"Shor":                                  "cjs",
	"Shoshoni":                              "shh",
	"Shua":                                  "shg",
	"Shuadit":                               "sdt",
	"Shuar":                                 "jiv",
	"Shubi":                                 "suj",
	"Shughni":                               "sgh",
	"Shumashti":                             "sts",
	"Shumcho":                               "scu",
	"Shuswap":                               "shs",
	"Shuwa-Zamani":                          "ksa",
	"Shwai":                                 "shw",
	"Shwe Palaung":                          "pll",
	"Sialum":                                "slw",
	"Siamou":                                "sif",
	"Sian":                                  "spg",
	"Siane":                                 "snp",
	"Siang":                                 "sya",
	"Siar-Lak":                              "sjr",
	"Siawi":                                 "mmp",
	"Sibe":                                  "nco",
	"Siberian Tatar":                        "sty",
	"Sibu Melanau":                          "sdx",
	"Sicanian":                              "sxc",
	"Sicel":                                 "scx",
	"Sichuan Yi":                            "iii",
	"Sicilian":                              "scn",
	"Sìcìté Sénoufo":                        "sep",
	"Siculo Arabic":                         "sqr",
	"Sidamo":                                "sid",
	"Sidetic":                               "xsd",
	"Sie":                                   "erg",
	"Sierra de Juárez Zapotec":              "zaa",
	"Sierra Leone Sign Language":            "sgx",
	"Sierra Negra Nahuatl":                  "nsu",
	"Sighu":                                 "sxe",
	"Sihan":                                 "snr",
	"Sihuas Ancash Quechua":                 "qws",
	"Sika":                                  "ski",
	"Sikaiana":                              "sky",
	"Sikaritai":                             "tty",
	"Sikiana":                               "sik",
	"Sikkimese":                             "sip",
	"Siksika":                               "bla",
	"Sikule":                                "skh",
	"Sila":                                  "slt",
	"Silacayoapan Mixtec":                   "mks",
	"Sileibi":                               "sbq",
	"Silesian":                              "szl",
	"Silimo":                                "wul",
	"Siliput":                               "mkc",
	"Silopi":                                "xsp",
	"Silt'e":                                "stv",
	"Simaa":                                 "sie",
	"Simba":                                 "sbw",
	"Simbali":                               "smg",
	"Simbari":                               "smb",
	"Simbo":                                 "sbb",
	"Simeku":                                "smz",
	"Simeulue":                              "smr",
	"Simte":                                 "smt",
	"Sinagen":                               "siu",
	"Sinasina":                              "sst",
	"Sinaugoro":                             "snc",
	"Sindarin":                              "sjn",
	"Sindhi Bhil":                           "sbn",
	"Sindhi":                                "snd",
	"Sindihui Mixtec":                       "xts",
	"Singa":                                 "sgm",
	"Singapore Sign Language":               "sls",
	"Singpho":                               "sgp",
	"Sinhala":                               "sin",
	"Sinicahua Mixtec":                      "xti",
	"Sininkere":                             "skq",
	"Sinsauru":                              "snz",
	"Sinte Romani":                          "rmo",
	"Sinyar":                                "sys",
	"Sio":                                   "xsi",
	"Siona":                                 "snn",
	"Sipacapense":                           "qum",
	"Sira":                                  "swj",
	"Siraya":                                "fos",
	"Sirenik Yupik":                         "ysr",
	"Siri":                                  "sir",
	"Siriano":                               "sri",
	"Sirionó":                               "srq",
	"Sirmauri":                              "srx",
	"Siroi":                                 "ssd",
	"Sissala":                               "sld",
	"Sissano":                               "sso",
	"Siuslaw":                               "sis",
	"Sivandi":                               "siy",
	"Siwai":                                 "siw",
	"Siwi":                                  "siz",
	"Siwu":                                  "akp",
	"Siyin Chin":                            "csy",
	"Skagit":                                "ska",
	"Skalvian":                              "svx",
	"Skepi Creole Dutch":                    "skw",
	"Skolt Sami":                            "sms",
	"Skou":                                  "skv",
	"Slave (Athapascan)":                    "den",
	"Slavomolisano":                         "svm",
	"Slovak":                                "slk",
	"Slovakian Sign Language":               "svk",
	"Slovenian":                             "slv",
	"Small Flowery Miao":                    "sfm",
	"Smärky Kanum":                          "kxq",
	"Snohomish":                             "sno",
	"So (Democratic Republic of Congo)":     "soc",
	"So'a":                                  "ssq",
	"Sô":                                    "sss",
	"Sobei":                                 "sob",
	"Sochiapam Chinantec":                   "cso",
	"Soga":                                  "xog",
	"Sogdian":                               "sog",
	"Soi":                                   "soj",
	"Sokoro":                                "sok",
	"Solano":                                "xso",
	"Soli":                                  "sby",
	"Solomon Islands Sign Language":         "szs",
	"Solong":                                "aaw",
	"Solos":                                 "sol",
	"Som":                                   "smc",
	"Somali":                                "som",
	"Somba-Siawari":                         "bmu",
	"Somrai":                                "sor",
	"Somray":                                "smu",
	"Somyev":                                "kgt",
	"Sonaga":                                "ysg",
	"Sonde":                                 "shc",
	"Songe":                                 "sop",
	"Songlai Chin":                          "csj",
	"Songo":                                 "soo",
	"Songomeno":                             "soe",
	"Songoora":                              "sod",
	"Sonha":                                 "soi",
	"Sonia":                                 "siq",
	"Soninke":                               "snk",
	"Sonsorol":                              "sov",
	"Soo":                                   "teu",
	"Sop":                                   "urw",
	"Soqotri":                               "sqt",
	"Sora":                                  "srb",
	"Sori-Harengan":                         "sbh",
	"Sorkhei":                               "sqo",
	"Sorothaptic":                           "sxo",
	"Sorsogon Ayta":                         "ays",
	"Sos Kundi":                             "sdk",
	"Sota Kanum":                            "krz",
	"Sou Nama":                              "tlt",
	"Sou Upaa":                              "wha",
	"Sou":                                   "sqq",
	"South African Sign Language":           "sfs",
	"South Awyu":                            "aws",
	"South Azerbaijani":                     "azb",
	"South Bolivian Quechua":                "quh",
	"South Central Banda":                   "lnl",
	"South Central Dinka":                   "dib",
	"South Efate":                           "erk",
	"South Fali":                            "fal",
	"South Giziga":                          "giz",
	"South Lembata":                         "lmf",
	"South Levantine Arabic":                "ajp",
	"South Marquesan":                       "mqm",
	"South Muyu":                            "kts",
	"South Ndebele":                         "nbl",
	"South Nuaulu":                          "nxl",
	"South Picene":                          "spx",
	"South Slavey":                          "xsl",
	"South Tairora":                         "omw",
	"South Ucayali Ashéninka":               "cpy",
	"South Watut":                           "mcy",
	"South West Bay":                        "sns",
	"Southeast Ambrym":                      "tvk",
	"Southeast Babar":                       "vbb",
	"Southeast Ijo":                         "ijs",
	"Southeast Pashai":                      "psi",
	"Southeastern Dinka":                    "dks",
	"Southeastern Ixtlán Zapotec":           "zpd",
	"Southeastern Kolami":                   "nit",
	"Southeastern Nochixtlán Mixtec":        "mxy",
	"Southeastern Pomo":                     "pom",
	"Southeastern Puebla Nahuatl":           "npl",
	"Southeastern Tarahumara":               "tcu",
	"Southeastern Tepehuan":                 "stp",
	"Southern Alta":                         "agy",
	"Southern Altai":                        "alt",
	"Southern Amami-Oshima":                 "ams",
	"Southern Aymara":                       "ayc",
	"Southern Bai":                          "bfs",
	"Southern Balochi":                      "bcc",
	"Southern Betsimisaraka Malagasy":       "bzc",
	"Southern Binukidnon":                   "mtw",
	"Southern Birifor":                      "biv",
	"Southern Bobo Madaré":                  "bwq",
	"Southern Bontok":                       "obk",
	"Southern Carrier":                      "caf",
	"Southern Catanduanes Bikol":            "bln",
	"Southern Conchucos Ancash Quechua":     "qxo",
	"Southern Dagaare":                      "dga",
	"Southern Dong":                         "kmc",
	"Southern East Cree":                    "crj",
	"Southern Ghale":                        "ghe",
	"Southern Grebo":                        "grj",
	"Southern Guiyang Hmong":                "hmy",
	"Southern Haida":                        "hax",
	"Southern Hindko":                       "hnd",
	"Southern Kalapuya":                     "sxk",
	"Southern Kalinga":                      "ksc",
	"Southern Katang":                       "sct",
	"Southern Kisi":                         "kss",
	"Southern Kiwai":                        "kjd",
	"Southern Kurdish":                      "sdh",
	"Southern Lolopo":                       "ysp",
	"Southern Luri":                         "luz",
	"Southern Ma'di":                        "snm",
	"Southern Mashan Hmong":                 "hma",
	"Southern Mnong":                        "mnn",
	"Southern Muji":                         "ymc",
	"Southern Nago":                         "nqg",
	"Southern Nambikuára":                   "nab",
	"Southern Ngbandi":                      "nbw",
	"Southern Nicobarese":                   "nik",
	"Southern Nisu":                         "nsd",
	"Southern Nuni":                         "nnw",
	"Southern Ohlone":                       "css",
	"Southern One":                          "osu",
	"Southern Pame":                         "pmz",
	"Southern Pashto":                       "pbt",
	"Southern Pastaza Quechua":              "qup",
	"Southern Pomo":                         "peq",
	"Southern Puebla Mixtec":                "mit",
	"Southern Puget Sound Salish":           "slh",
	"Southern Pumi":                         "pmj",
	"Southern Qiandong Miao":                "hms",
	"Southern Qiang":                        "qxs",
	"Southern Rengma Naga":                  "nre",
	"Southern Rincon Zapotec":               "zsr",
	"Southern Roglai":                       "rgs",
	"Southern Sama":                         "ssb",
	"Southern Sami":                         "sma",
	"Southern Samo":                         "sbd",
	"Southern Sierra Miwok":                 "skd",
	"Southern Sorsoganon":                   "srv",
	"Southern Sotho":                        "sot",
	"Southern Subanen":                      "laa",
	"Southern Thai":                         "sou",
	"Southern Tidung":                       "itd",
	"Southern Tiwa":                         "tix",
	"Southern Toussian":                     "wib",
	"Southern Tujia":                        "tjs",
	"Southern Tutchone":                     "tce",
	"Southern Uzbek":                        "uzs",
	"Southern Yamphu":                       "lrr",
	"Southern Yukaghir":                     "yux",
	"Southwest Gbaya":                       "gso",
	"Southwest Palawano":                    "plv",
	"Southwest Pashai":                      "psh",
	"Southwest Tanna":                       "nwi",
	"Southwestern Bontok":                   "vbk",
	"Southwestern Dinka":                    "dik",
	"Southwestern Fars":                     "fay",
	"Southwestern Guiyang Hmong":            "hmg",
	"Southwestern Huishui Hmong":            "hmh",
	"Southwestern Nisu":                     "nsv",
	"Southwestern Tarahumara":               "twr",
	"Southwestern Tepehuan":                 "tla",
	"Southwestern Tlaxiaco Mixtec":          "meh",
	"Sowa":                                  "sww",
	"Sowanda":                               "sow",
	"Soyaltepec Mazatec":                    "vmp",
	"Soyaltepec Mixtec":                     "vmq",
	"Spanish Sign Language":                 "ssp",
	"Spanish":                               "spa",
	"Spiti Bhoti":                           "spt",
	"Spokane":                               "spo",
	"Squamish":                              "squ",
	"Sranan Tongo":                          "srn",
	"Sri Lankan Creole Malay":               "sci",
	"Sri Lankan Sign Language":              "sqs",
	"Standard Arabic":                       "arb",
	"Standard Estonian":                     "ekk",
	"Standard Latvian":                      "lvs",
	"Standard Malay":                        "zsm",
	"Standard Moroccan Tamazight":           "zgh",
	"Stellingwerfs":                         "stl",
	"Stod Bhoti":                            "sbu",
	"sTodsde":                               "jih",
	"Stoney":                                "sto",
	"Straits Salish":                        "str",
	"Suabo":                                 "szp",
	"Suarmin":                               "seo",
	"Suau":                                  "swp",
	"Suba-Simbiti":                          "ssc",
	"Suba":                                  "sxb",
	"Subiya":                                "sbs",
	"Subtiaba":                              "sut",
	"Sudanese Arabic":                       "apd",
	"Sudanese Creole Arabic":                "pga",
	"Sudest":                                "tgo",
	"Sudovian":                              "xsv",
	"Suena":                                 "sue",
	"Suga":                                  "sgi",
	"Suganga":                               "sug",
	"Sugut Dusun":                           "kzs",
	"Sui":                                   "swi",
	"Suki":                                  "sui",
	"Suku":                                  "sub",
	"Sukuma":                                "suk",
	"Sukur":                                 "syk",
	"Sukurum":                               "zsu",
	"Sula":                                  "szn",
	"Sulka":                                 "sua",
	"Sulod":                                 "srg",
	"Suma":                                  "sqm",
	"Sumariup":                              "siv",
	"Sumau":                                 "six",
	"Sumbawa":                               "smw",
	"Sumbwa":                                "suw",
	"Sumerian":                              "sux",
	"Sumi Naga":                             "nsm",
	"Sumtu Chin":                            "csv",
	"Sunam":                                 "ssk",
	"Sundanese":                             "sun",
	"Sunwar":                                "suz",
	"Suoy":                                  "syo",
	"Supyire Senoufo":                       "spp",
	"Sur":                                   "tdl",
	"Surbakhal":                             "sbj",
	"Surgujia":                              "sgj",
	"Suri":                                  "suq",
	"Surigaonon":                            "sgd",
	"Surjapuri":                             "sjp",
	"Sursurunga":                            "sgz",
	"Suruahá":                               "swx",
	"Surubu":                                "sde",
	"Suruí Do Pará":                         "mdz",
	"Suruí":                                 "sru",
	"Susquehannock":                         "sqn",
	"Susu":                                  "sus",
	"Susuami":                               "ssu",
	"Suundi":                                "sdj",
	"Suwawa":                                "swu",
	"Suyá":                                  "suy",
	"Svan":                                  "sva",
	"Swabian":                               "swg",
	"Swahili (individual language)":         "swh",
	"Swahili (macrolanguage)":               "swa",
	"Swampy Cree":                           "csw",
	"Swati":                                 "ssw",
	"Swedish Sign Language":                 "swl",
	"Swedish":                               "swe",
	"Swiss German":                          "gsw",
	"Swiss-French Sign Language":            "ssr",
	"Swiss-German Sign Language":            "sgg",
	"Swiss-Italian Sign Language":           "slf",
	"Swo":                                   "sox",
	"Syenara Senoufo":                       "shz",
	"Sylheti":                               "syl",
	"Syriac":                                "syr",
	"T'apo":                                 "lgn",
	"T'en":                                  "tct",
	"Ta'izzi-Adeni Arabic":                  "acq",
	"Taabwa":                                "tap",
	"Tabaa Zapotec":                         "zat",
	"Tabaru":                                "tby",
	"Tabasco Chontal":                       "chf",
	"Tabasco Nahuatl":                       "nhc",
	"Tabasco Zoque":                         "zoq",
	"Tabassaran":                            "tab",
	"Tabla":                                 "tnm",
	"Tabo":                                  "knv",
	"Tabriak":                               "tzx",
	"Tacahua Mixtec":                        "xtt",
	"Tacana":                                "tna",
	"Tachawit":                              "shy",
	"Tachelhit":                             "shi",
	"Tachoni":                               "lts",
	"Tadaksahak":                            "dsq",
	"Tado":                                  "klw",
	"Tadyawan":                              "tdy",
	"Tae'":                                  "rob",
	"Tafi":                                  "tcd",
	"Tagabawa":                              "bgs",
	"Tagakaulo":                             "klg",
	"Tagal Murut":                           "mvv",
	"Tagalaka":                              "tgz",
	"Tagalog":                               "tgl",
	"Tagargrent":                            "oua",
	"Tagbanwa":                              "tbw",
	"Tagbu":                                 "tbm",
	"Tagdal":                                "tda",
	"Tagin":                                 "tgj",
	"Tagish":                                "tgx",
	"Tagoi":                                 "tag",
	"Tagwana Senoufo":                       "tgw",
	"Tahaggart Tamahaq":                     "thv",
	"Tahitian":                              "tah",
	"Tahltan":                               "tht",
	"Tai Daeng":                             "tyr",
	"Tai Dam":                               "blt",
	"Tai Do":                                "tyj",
	"Tai Dón":                               "twh",
	"Tai Hongjin":                           "tiz",
	"Tai Laing":                             "tjl",
	"Tai Loi":                               "tlq",
	"Tai Long":                              "thi",
	"Tai Nüa":                               "tdd",
	"Tai Pao":                               "tpo",
	"Tai Thanh":                             "tmm",
	"Tai Ya":                                "cuu",
	"Tai":                                   "taw",
	"Taiap":                                 "gpn",
	"Taikat":                                "aos",
	"Tainae":                                "ago",
	"Taino":                                 "tnq",
	"Tairaha":                               "bxa",
	"Tairuma":                               "uar",
	"Taita":                                 "dav",
	"Taiwan Sign Language":                  "tss",
	"Taje":                                  "pee",
	"Tajik":                                 "tgk",
	"Tajiki Arabic":                         "abh",
	"Tajio":                                 "tdj",
	"Tajuasohn":                             "tja",
	"Takelma":                               "tkm",
	"Takestani":                             "tks",
	"Takia":                                 "tbc",
	"Takua":                                 "tkz",
	"Takuu":                                 "nho",
	"Takwane":                               "tke",
	"Tal":                                   "tal",
	"Tala":                                  "tak",
	"Talaud":                                "tld",
	"Taliabu":                               "tlv",
	"Talieng":                               "tdf",
	"Talinga-Bwisi":                         "tlj",
	"Talise":                                "tlr",
	"Talodi":                                "tlo",
	"Taloki":                                "tlk",
	"Talondo'":                              "tln",
	"Talossan":                              "tzl",
	"Talu":                                  "yta",
	"Talysh":                                "tly",
	"Tama (Chad)":                           "tma",
	"Tama (Colombia)":                       "ten",
	"Tamagario":                             "tcg",
	"Taman (Indonesia)":                     "tmn",
	"Taman (Myanmar)":                       "tcl",
	"Tamanaku":                              "tmz",
	"Tamashek":                              "tmh",
	"Tamasheq":                              "taq",
	"Tamazola Mixtec":                       "vmx",
	"Tambas":                                "tdk",
	"Tambora":                               "xxt",
	"Tambotalo":                             "tls",
	"Tami":                                  "tmy",
	"Tamil":                                 "tam",
	"Tamki":                                 "tax",
	"Tamnim Citak":                          "tml",
	"Tampias Lobu":                          "low",
	"Tampuan":                               "tpu",
	"Tampulma":                              "tpm",
	"Tanacross":                             "tcb",
	"Tanahmerah":                            "tcm",
	"Tanaina":                               "tfn",
	"Tanapag":                               "tpv",
	"Tandaganon":                            "tgn",
	"Tandia":                                "tni",
	"Tandroy-Mahafaly Malagasy":             "tdx",
	"Tanema":                                "tnx",
	"Tangale":                               "tan",
	"Tangchangya":                           "tnv",
	"Tanggu":                                "tgu",
	"Tangkhul Naga (India)":                 "nmf",
	"Tangkhul Naga (Myanmar)":               "ntx",
	"Tangko":                                "tkx",
	"Tanglang":                              "ytl",
	"Tangoa":                                "tgp",
	"Tanguat":                               "tbs",
	"Tangut":                                "txg",
	"Tanimbili":                             "tbe",
	"Tanimuca-Retuarã":                      "tnc",
	"Tanjijili":                             "uji",
	"Tanosy Malagasy":                       "txy",
	"Tanudan Kalinga":                       "kml",
	"Tanzanian Sign Language":               "tza",
	"Tapeba":                                "tbb",
	"Tapei":                                 "afp",
	"Tapieté":                               "tpj",
	"Tapirapé":                              "taf",
	"Tarao Naga":                            "tro",
	"Tareng":                                "tgr",
	"Tariana":                               "tae",
	"Tarifit":                               "rif",
	"Tarjumo":                               "txj",
	"Tarok":                                 "yer",
	"Taroko":                                "trv",
	"Tarpia":                                "tpf",
	"Tartessian":                            "txr",
	"Taruma":                                "tdm",
	"Tasawaq":                               "twq",
	"Tase Naga":                             "nst",
	"Tasmanian":                             "xtz",
	"Tasmate":                               "tmt",
	"Tataltepec Chatino":                    "cta",
	"Tatana":                                "txx",
	"Tatar":                                 "tat",
	"Tatuyo":                                "tav",
	"Tauade":                                "ttd",
	"Taulil":                                "tuh",
	"Taungyo":                               "tco",
	"Taupota":                               "tpa",
	"Tause":                                 "tad",
	"Taushiro":                              "trr",
	"Tausug":                                "tsg",
	"Tauya":                                 "tya",
	"Taveta":                                "tvs",
	"Tavoyan":                               "tvn",
	"Tavringer Romani":                      "rmu",
	"Tawala":                                "tbo",
	"Tawallammat Tamajaq":                   "ttq",
	"Tawandê":                               "xtw",
	"Tawang Monpa":                          "twm",
	"Tawara":                                "twl",
	"Taworta":                               "tbp",
	"Tawoyan":                               "twy",
	"Tawr Chin":                             "tcp",
	"Tay Boi":                               "tas",
	"Tay Khang":                             "tnu",
	"Tày Sa Pa":                             "tys",
	"Tày Tac":                               "tyt",
	"Tày":                                   "tyz",
	"Tayabas Ayta":                          "ayy",
	"Tayart Tamajeq":                        "thz",
	"Tayo":                                  "cks",
	"Taznatit":                              "grr",
	"Tboli":                                 "tbl",
	"Tchitchege":                            "tck",
	"Tchumbuli":                             "bqa",
	"Te'un":                                 "tve",
	"Teanu":                                 "tkw",
	"Tebul Sign Language":                   "tsy",
	"Tebul Ure Dogon":                       "dtu",
	"Tecpatlán Totonac":                     "tcw",
	"Tedaga":                                "tuq",
	"Tedim Chin":                            "ctd",
	"Tee":                                   "tkq",
	"Téén":                                  "lor",
	"Tefaro":                                "tfo",
	"Tegali":                                "ras",
	"Tehit":                                 "kps",
	"Tehuelche":                             "teh",
	"Tejalapan Zapotec":                     "ztt",
	"Teke-Ebo":                              "ebo",
	"Teke-Fuumu":                            "ifm",
	"Teke-Kukuya":                           "kkw",
	"Teke-Laali":                            "lli",
	"Teke-Nzikou":                           "nzu",
	"Teke-Tege":                             "teg",
	"Teke-Tsaayi":                           "tyi",
	"Teke-Tyee":                             "tyx",
	"Tektiteko":                             "ttc",
	"Tela-Masbuar":                          "tvm",
	"Telefol":                               "tlf",
	"Telugu":                                "tel",
	"Tem":                                   "kdh",
	"Temacine Tamazight":                    "tjo",
	"Temascaltepec Nahuatl":                 "nhv",
	"Tembé":                                 "tqb",
	"Tembo (Kitembo)":                       "tbt",
	"Tembo (Motembo)":                       "tmv",
	"Teme":                                  "tdo",
	"Temein":                                "teq",
	"Temi":                                  "soz",
	"Temiar":                                "tea",
	"Temoaya Otomi":                         "ott",
	"Temoq":                                 "tmo",
	"Temuan":                                "tmw",
	"Ten'edn":                               "tnz",
	"Tena Lowland Quichua":                  "quw",
	"Tenango Otomi":                         "otn",
	"Tene Kan Dogon":                        "dtk",
	"Tenggarong Kutai Malay":                "vkt",
	"Tengger":                               "tes",
	"Tenharim":                              "pah",
	"Tenino":                                "tqn",
	"Tenis":                                 "tns",
	"Tennet":                                "tex",
	"Teop":                                  "tio",
	"Teor":                                  "tev",
	"Tepecano":                              "tep",
	"Tepetotutla Chinantec":                 "cnt",
	"Tepeuxila Cuicatec":                    "cux",
	"Tepinapa Chinantec":                    "cte",
	"Tepo Krumen":                           "ted",
	"Ter Sami":                              "sjt",
	"Tera":                                  "ttr",
	"Terebu":                                "trb",
	"Terei":                                 "buo",
	"Tereno":                                "ter",
	"Teressa":                               "tef",
	"Tereweng":                              "twg",
	"Teribe":                                "tfr",
	"Terik":                                 "tec",
	"Termanu":                               "twu",
	"Ternate":                               "tft",
	"Ternateño":                             "tmg",
	"Tesaka Malagasy":                       "tkg",
	"Tese":                                  "keg",
	"Teshenawa":                             "twc",
	"Teso":                                  "teo",
	"Tetela":                                "tll",
	"Tetelcingo Nahuatl":                    "nhg",
	"Tetete":                                "teb",
	"Tetum":                                 "tet",
	"Tetun Dili":                            "tdt",
	"Teutila Cuicatec":                      "cut",
	"Tewa (Indonesia)":                      "twe",
	"Tewa (USA)":                            "tew",
	"Tewe":                                  "twx",
	"Texcatepec Otomi":                      "otx",
	"Texistepec Popoluca":                   "poq",
	"Texmelucan Zapotec":                    "zpz",
	"Tezoatlán Mixtec":                      "mxb",
	"Tha":                                   "thy",
	"Thachanadan":                           "thn",
	"Thado Chin":                            "tcz",
	"Thai Sign Language":                    "tsq",
	"Thai Song":                             "soa",
	"Thai":                                  "tha",
	"Thaiphum Chin":                         "cth",
	"Thakali":                               "ths",
	"Thangal Naga":                          "nki",
	"Thangmi":                               "thf",
	"Thao":                                  "ssf",
	"Tharaka":                               "thk",
	"Thawa":                                 "xtv",
	"Thayore":                               "thd",
	"Thaypan":                               "typ",
	"Thiin":                                 "iin",
	"Tho":                                   "tou",
	"Thompson":                              "thp",
	"Thopho":                                "ytp",
	"Thracian":                              "txh",
	"Thu Lao":                               "tyl",
	"Thudam":                                "thw",
	"Thulung":                               "tdh",
	"Thur":                                  "lth",
	"Thurawal":                              "tbh",
	"Thuri":                                 "thu",
	"Tiagbamrin Aizi":                       "ahi",
	"Tiale":                                 "mnl",
	"Tiang":                                 "tbj",
	"Tibea":                                 "ngy",
	"Tibetan":                               "bod",
	"Tichurong":                             "tcn",
	"Ticuna":                                "tca",
	"Tidaá Mixtec":                          "mtx",
	"Tidikelt Tamazight":                    "tia",
	"Tidore":                                "tvo",
	"Tiéfo":                                 "tiq",
	"Tiemacèwè Bozo":                        "boo",
	"Tiene":                                 "tii",
	"Tiéyaxo Bozo":                          "boz",
	"Tifal":                                 "tif",
	"Tigak":                                 "tgc",
	"Tigon Mbembe":                          "nza",
	"Tigre":                                 "tig",
	"Tigrinya":                              "tir",
	"Tii":                                   "txq",
	"Tijaltepec Mixtec":                     "xtl",
	"Tikar":                                 "tik",
	"Tikopia":                               "tkp",
	"Tilapa Otomi":                          "otl",
	"Tillamook":                             "til",
	"Tilquiapan Zapotec":                    "zts",
	"Tilung":                                "tij",
	"Tima":                                  "tms",
	"Timbe":                                 "tim",
	"Timne":                                 "tem",
	"Timor Pidgin":                          "tvy",
	"Timucua":                               "tjm",
	"Timugon Murut":                         "tih",
	"Tinani":                                "lbf",
	"Tindi":                                 "tin",
	"Tingui-Boto":                           "tgv",
	"Tinigua":                               "tit",
	"Tinputz":                               "tpz",
	"Tippera":                               "tpe",
	"Tira":                                  "tic",
	"Tirahi":                                "tra",
	"Tiranige Diga Dogon":                   "tde",
	"Tiri":                                  "cir",
	"Tiruray":                               "tiy",
	"Tita":                                  "tdq",
	"Titan":                                 "ttv",
	"Tiv":                                   "tiv",
	"Tiwa":                                  "lax",
	"Tiwi":                                  "tiw",
	"Tjurruru":                              "tju",
	"Tlachichilco Tepehua":                  "tpt",
	"Tlacoapa Me'phaa":                      "tpl",
	"Tlacoatzintepec Chinantec":             "ctl",
	"Tlacolulita Zapotec":                   "zpk",
	"Tlahuitoltepec Mixe":                   "mxp",
	"Tlamacazapa Nahuatl":                   "nuz",
	"Tlazoyaltepec Mixtec":                  "mqh",
	"Tlingit":                               "tli",
	"To'abaita":                             "mlu",
	"To":                                    "toz",
	"Toaripi":                               "tqo",
	"Toba-Maskoy":                           "tmf",
	"Toba":                                  "tob",
	"Tobagonian Creole English":             "tgh",
	"Tobanga":                               "tng",
	"Tobati":                                "tti",
	"Tobelo":                                "tlb",
	"Tobian":                                "tox",
	"Tobilung":                              "tgb",
	"Tobo":                                  "tbv",
	"Tocantins Asurini":                     "asu",
	"Tocho":                                 "taz",
	"Toda":                                  "tcx",
	"Todrah":                                "tdr",
	"Tofanma":                               "tlg",
	"Tofin Gbe":                             "tfi",
	"Togbo-Vara Banda":                      "tor",
	"Togoyo":                                "tgy",
	"Tohono O'odham":                        "ood",
	"Tojolabal":                             "toj",
	"Tok Pisin":                             "tpi",
	"Tokano":                                "zuh",
	"Tokelau":                               "tkl",
	"Tokharian A":                           "xto",
	"Tokharian B":                           "txb",
	"Toku-No-Shima":                         "tkn",
	"Tol":                                   "jic",
	"Tolaki":                                "lbw",
	"Tolomako":                              "tlm",
	"Tolowa":                                "tol",
	"Toma":                                  "tod",
	"Tomadino":                              "tdi",
	"Tombelala":                             "ttp",
	"Tombonuo":                              "txa",
	"Tombulu":                               "tom",
	"Tomini":                                "txm",
	"Tommo So Dogon":                        "dto",
	"Tomo Kan Dogon":                        "dtm",
	"Tomoip":                                "tqp",
	"Tondano":                               "tdn",
	"Tondi Songway Kiini":                   "tst",
	"Tonga (Nyasa)":                         "tog",
	"Tonga (Tonga Islands)":                 "ton",
	"Tonga (Zambia)":                        "toi",
	"Tongwe":                                "tny",
	"Tonjon":                                "tjn",
	"Tonkawa":                               "tqw",
	"Tonsawang":                             "tnw",
	"Tonsea":                                "txs",
	"Tontemboan":                            "tnt",
	"Tooro":                                 "ttj",
	"Topoiyo":                               "toy",
	"Toposa":                                "toq",
	"Torá":                                  "trz",
	"Toraja-Sa'dan":                         "sda",
	"Toram":                                 "trj",
	"Torau":                                 "ttu",
	"Tornedalen Finnish":                    "fit",
	"Toro So Dogon":                         "dts",
	"Toro Tegu Dogon":                       "dtt",
	"Toro":                                  "tdv",
	"Toromono":                              "tno",
	"Torona":                                "tqr",
	"Torres Strait Creole":                  "tcs",
	"Torricelli":                            "tei",
	"Torwali":                               "trw",
	"Tosk Albanian":                         "als",
	"Totela":                                "ttl",
	"Toto":                                  "txo",
	"Totoli":                                "txe",
	"Totomachapan Zapotec":                  "zph",
	"Totontepec Mixe":                       "mto",
	"Totoro":                                "ttk",
	"Touo":                                  "tqu",
	"Toura (Côte d'Ivoire)":                 "neb",
	"Toura (Papua New Guinea)":              "don",
	"Towei":                                 "ttn",
	"Transalpine Gaulish":                   "xtg",
	"Traveller Danish":                      "rmd",
	"Traveller Norwegian":                   "rmg",
	"Traveller Scottish":                    "trl",
	"Tregami":                               "trm",
	"Tremembé":                              "tme",
	"Trieng":                                "stg",
	"Trimuris":                              "tip",
	"Tring":                                 "tgq",
	"Tringgus-Sembaan Bidayuh":              "trx",
	"Trinidad and Tobago Sign Language":     "lst",
	"Trinidadian Creole English":            "trf",
	"Trinitario":                            "trn",
	"Trió":                                  "tri",
	"Truká":                                 "tka",
	"Trumai":                                "tpy",
	"Ts'ün-Lao":                             "tsl",
	"Tsaangi":                               "tsa",
	"Tsakhur":                               "tkr",
	"Tsakonian":                             "tsd",
	"Tsakwambo":                             "kvz",
	"Tsamai":                                "tsb",
	"Tsat":                                  "huq",
	"Tseku":                                 "tsk",
	"Tsetsaut":                              "txc",
	"Tshangla":                              "tsj",
	"Tsikimba":                              "kdl",
	"Tsimané":                               "cas",
	"Tsimihety Malagasy":                    "xmw",
	"Tsimshian":                             "tsi",
	"Tsishingini":                           "tsw",
	"Tso":                                   "ldp",
	"Tsoa":                                  "hio",
	"Tsogo":                                 "tsv",
	"Tsonga":                                "tso",
	"Tsotso":                                "lto",
	"Tsou":                                  "tsu",
	"Tsucuba":                               "cbq",
	"Tsum":                                  "ttz",
	"Tsuvadi":                               "tvd",
	"Tsuvan":                                "tsh",
	"Tswa":                                  "tsc",
	"Tswana":                                "tsn",
	"Tswapong":                              "two",
	"Tu":                                    "mjg",
	"Tuamotuan":                             "pmt",
	"Tubar":                                 "tbu",
	"Tübatulabal":                           "tub",
	"Tucano":                                "tuo",
	"Tugen":                                 "tuy",
	"Tugun":                                 "tzn",
	"Tugutil":                               "tuj",
	"Tukang Besi North":                     "khc",
	"Tukang Besi South":                     "bhq",
	"Tuki":                                  "bag",
	"Tukpa":                                 "tpq",
	"Tukudede":                              "tkd",
	"Tukumanféd":                            "tkf",
	"Tula":                                  "tul",
	"Tulehu":                                "tlu",
	"Tulishi":                               "tey",
	"Tulu-Bohuai":                           "rak",
	"Tulu":                                  "tcy",
	"Tuma-Irumu":                            "iou",
	"Tumak":                                 "tmc",
	"Tumari Kanuri":                         "krt",
	"Tumbuka":                               "tum",
	"Tumi":                                  "kku",
	"Tumleo":                                "tmq",
	"Tumshuqese":                            "xtq",
	"Tumtum":                                "tbr",
	"Tumulung Sisaala":                      "sil",
	"Tumzabt":                               "mzb",
	"Tundra Enets":                          "enh",
	"Tunen":                                 "tvu",
	"Tungag":                                "lcm",
	"Tunggare":                              "trt",
	"Tunia":                                 "tug",
	"Tunica":                                "tun",
	"Tunisian Arabic":                       "aeb",
	"Tunisian Sign Language":                "tse",
	"Tunjung":                               "tjg",
	"Tunni":                                 "tqq",
	"Tunzu":                                 "dza",
	"Tuotomb":                               "ttf",
	"Tuparí":                                "tpr",
	"Tupí":                                  "tpw",
	"Tupinambá":                             "tpn",
	"Tupinikin":                             "tpk",
	"Tupuri":                                "tui",
	"Turaka":                                "trh",
	"Turi":                                  "trd",
	"Turiwára":                              "twt",
	"Turka":                                 "tuz",
	"Turkana":                               "tuv",
	"Turkic Khalaj":                         "klj",
	"Turkish Sign Language":                 "tsm",
	"Turkish":                               "tur",
	"Turkmen":                               "tuk",
	"Turks And Caicos Creole English":       "tch",
	"Turoyo":                                "tru",
	"Turumsa":                               "tqm",
	"Turung":                                "try",
	"Tuscarora":                             "tus",
	"Tutelo":                                "tta",
	"Tutong":                                "ttg",
	"Tutsa Naga":                            "tvt",
	"Tutuba":                                "tmi",
	"Tututepec Mixtec":                      "mtu",
	"Tututni":                               "tuu",
	"Tuvalu":                                "tvl",
	"Tuvinian":                              "tyv",
	"Tuwali Ifugao":                         "ifk",
	"Tuwari":                                "tww",
	"Tuwuli":                                "bov",
	"Tuxá":                                  "tud",
	"Tuxináwa":                              "tux",
	"Tuyuca":                                "tue",
	"Twana":                                 "twa",
	"Twendi":                                "twn",
	"Twents":                                "twd",
	"Twi":                                   "twi",
	"Tyap":                                  "kcg",
	"Tyaraity":                              "woa",
	"Tz'utujil":                             "tzj",
	"Tzeltal":                               "tzh",
	"Tzotzil":                               "tzo",
	"U":                                     "uuu",
	"Uab Meto":                              "aoz",
	"Uamué":                                 "uam",
	"Uare":                                  "ksj",
	"Ubaghara":                              "byc",
	"Ubang":                                 "uba",
	"Ubi":                                   "ubi",
	"Ubir":                                  "ubr",
	"Ubykh":                                 "uby",
	"Ucayali-Yurúa Ashéninka":               "cpb",
	"Uda":                                   "uda",
	"Udi":                                   "udi",
	"Udihe":                                 "ude",
	"Udmurt":                                "udm",
	"Uduk":                                  "udu",
	"Ufim":                                  "ufi",
	"Ugandan Sign Language":                 "ugn",
	"Ugaritic":                              "uga",
	"Ughele":                                "uge",
	"Ugong":                                 "ugo",
	"Uhami":                                 "uha",
	"Uighur":                                "uig",
	"Uisai":                                 "uis",
	"Ujir":                                  "udj",
	"Ukaan":                                 "kcf",
	"Ukhwejo":                               "ukh",
	"Ukit":                                  "umi",
	"Ukpe-Bayobiri":                         "ukp",
	"Ukpet-Ehom":                            "akd",
	"Ukrainian Sign Language":               "ukl",
	"Ukrainian":                             "ukr",
	"Ukue":                                  "uku",
	"Ukuriguma":                             "ukg",
	"Ukwa":                                  "ukq",
	"Ukwuani-Aboh-Ndoni":                    "ukw",
	"Ulau-Suain":                            "svb",
	"Ulch":                                  "ulc",
	"Ulithian":                              "uli",
	"Ullatan":                               "ull",
	"Ulukwumi":                              "ulb",
	"Ulumanda'":                             "ulm",
	"Ulwa":                                  "ulw",
	"Uma' Lasan":                            "xky",
	"Uma' Lung":                             "ulu",
	"Uma":                                   "ppk",
	"Umanakaina":                            "gdn",
	"Umatilla":                              "uma",
	"Umbindhamu":                            "umd",
	"Umbrian":                               "xum",
	"Umbu-Ungu":                             "ubu",
	"Umbugarla":                             "umr",
	"Umbundu":                               "umb",
	"Umbuygamu":                             "umg",
	"Ume Sami":                              "sju",
	"Umeda":                                 "upi",
	"Umiida":                                "xud",
	"Umiray Dumaget Agta":                   "due",
	"Umon":                                  "umm",
	"Umotína":                               "umo",
	"Umpila":                                "ump",
	"Una":                                   "mtg",
	"Unami":                                 "unm",
	"Uncoded languages":                     "mis",
	"Unde Kaili":                            "unz",
	"Undetermined":                          "und",
	"Uneapa":                                "bbn",
	"Uneme":                                 "une",
	"Unggaranggu":                           "xun",
	"Unggumi":                               "xgu",
	"Unserdeutsch":                          "uln",
	"Unua":                                  "onu",
	"Unubahe":                               "unu",
	"Upper Chehalis":                        "cjh",
	"Upper Grand Valley Dani":               "dna",
	"Upper Guinea Crioulo":                  "pov",
	"Upper Kinabatangan":                    "dmg",
	"Upper Kuskokwim":                       "kuu",
	"Upper Necaxa Totonac":                  "tku",
	"Upper Saxon":                           "sxu",
	"Upper Sorbian":                         "hsb",
	"Upper Ta'oih":                          "tth",
	"Upper Tanana":                          "tau",
	"Upper Taromi":                          "tov",
	"Upper Umpqua":                          "xup",
	"Ura (Papua New Guinea)":                "uro",
	"Ura (Vanuatu)":                         "uur",
	"Uradhi":                                "urf",
	"Urak Lawoi'":                           "urk",
	"Urali":                                 "url",
	"Urapmin":                               "urm",
	"Urarina":                               "ura",
	"Urartian":                              "xur",
	"Urat":                                  "urt",
	"Urdu":                                  "urd",
	"Urhobo":                                "urh",
	"Uri":                                   "uvh",
	"Urigina":                               "urg",
	"Urim":                                  "uri",
	"Urimo":                                 "urx",
	"Uripiv-Wala-Rano-Atchin":               "upv",
	"Urningangg":                            "urc",
	"Uru-Eu-Wau-Wau":                        "urz",
	"Uru-Pa-In":                             "urp",
	"Uru":                                   "ure",
	"Uruangnirin":                           "urn",
	"Uruava":                                "urv",
	"Urubú-Kaapor Sign Language":            "uks",
	"Urubú-Kaapor":                          "urb",
	"Uruguayan Sign Language":               "ugy",
	"Urum":                                  "uum",
	"Urumi":                                 "uru",
	"Usaghade":                              "usk",
	"Usan":                                  "wnu",
	"Usarufa":                               "usa",
	"Ushojo":                                "ush",
	"Usila Chinantec":                       "cuc",
	"Usku":                                  "ulf",
	"Uspanteco":                             "usp",
	"Usui":                                  "usi",
	"ut-Ma'in":                              "gel",
	"Utarmbung":                             "omo",
	"Ute-Southern Paiute":                   "ute",
	"Utu":                                   "utu",
	"Uvbie":                                 "evh",
	"Uya":                                   "usu",
	"Uyajitaya":                             "duk",
	"Uzbek":                                 "uzb",
	"Uzbeki Arabic":                         "auz",
	"Uzekwe":                                "eze",
	"Vaagri Booli":                          "vaa",
	"Vafsi":                                 "vaf",
	"Vaghat-Ya-Bijim-Legeri":                "bij",
	"Vaghri":                                "vgr",
	"Vaghua":                                "tva",
	"Vagla":                                 "vag",
	"Vai":                                   "vai",
	"Vaiphei":                               "vap",
	"Vale":                                  "vae",
	"Valencian Sign Language":               "vsv",
	"Valle Nacional Chinantec":              "cvn",
	"Valley Maidu":                          "vmv",
	"Valman":                                "van",
	"Valpei":                                "vlp",
	"Vamale":                                "mkt",
	"Vame":                                  "mlr",
	"Vandalic":                              "xvn",
	"Vangunu":                               "mpr",
	"Vanimo":                                "vam",
	"Vano":                                  "vnk",
	"Vanuma":                                "vau",
	"Vao":                                   "vao",
	"Varhadi-Nagpuri":                       "vah",
	"Varisi":                                "vrs",
	"Varli":                                 "vav",
	"Vasavi":                                "vas",
	"Veddah":                                "ved",
	"Vehes":                                 "val",
	"Veluws":                                "vel",
	"Vemgo-Mabas":                           "vem",
	"Venda":                                 "ven",
	"Venetian":                              "vec",
	"Venetic":                               "xve",
	"Venezuelan Sign Language":              "vsl",
	"Vengo":                                 "bav",
	"Ventureño":                             "veo",
	"Veps":                                  "vep",
	"Vera'a":                                "vra",
	"Vestinian":                             "xvs",
	"Vidunda":                               "vid",
	"Viemo":                                 "vig",
	"Vietnamese":                            "vie",
	"Vilela":                                "vil",
	"Vili":                                  "vif",
	"Villa Viciosa Agta":                    "dyg",
	"Vincentian Creole English":             "svc",
	"Vinmavis":                              "vnm",
	"Vinza":                                 "vin",
	"Virgin Islands Creole English":         "vic",
	"Vishavan":                              "vis",
	"Viti":                                  "vit",
	"Vitou":                                 "vto",
	"Vitu":                                  "wiv",
	"Vlaams":                                "vls",
	"Vlaamse Gebarentaal":                   "vgt",
	"Vlax Romani":                           "rmy",
	"Volapük":                               "vol",
	"Volscian":                              "xvo",
	"Vono":                                  "kch",
	"Voro":                                  "vor",
	"Võro":                                  "vro",
	"Votic":                                 "vot",
	"Vumbu":                                 "vum",
	"Vunapu":                                "vnp",
	"Vunjo":                                 "vun",
	"Vurës":                                 "msn",
	"Vute":                                  "vut",
	"Vwanji":                                "wbi",
	"Wa'ema":                                "wag",
	"Wa":                                    "wbm",
	"Waama":                                 "wwa",
	"Waamwang":                              "wmn",
	"Waata":                                 "ssn",
	"Wab":                                   "wab",
	"Wabo":                                  "wbb",
	"Waboda":                                "kmx",
	"Waci Gbe":                              "wci",
	"Wadaginam":                             "wdg",
	"Waddar":                                "wbq",
	"Wadi Wadi":                             "xwd",
	"Wadikali":                              "wdk",
	"Wadiyara Koli":                         "kxp",
	"Wadjabangayi":                          "wdy",
	"Wadjiginy":                             "wdj",
	"Wadjigu":                               "wdu",
	"Wae Rana":                              "wrx",
	"Waffa":                                 "waj",
	"Wagawaga":                              "wgb",
	"Wagaya":                                "wga",
	"Wagdi":                                 "wbr",
	"Wageman":                               "waq",
	"Wagi":                                  "fad",
	"Wahau Kayan":                           "whu",
	"Wahau Kenyah":                          "whk",
	"Wahgi":                                 "wgi",
	"Waigali":                               "wbk",
	"Waigeo":                                "wgo",
	"Wailaki":                               "wlk",
	"Wailapa":                               "wlr",
	"Waima'a":                               "wmh",
	"Waima":                                 "rro",
	"Waimaha":                               "bao",
	"Waimiri-Atroari":                       "atr",
	"Waioli":                                "wli",
	"Waiwai":                                "waw",
	"Waja":                                  "wja",
	"Wajarri":                               "wbv",
	"Wajuk":                                 "xwj",
	"Waka":                                  "wav",
	"Wakabunga":                             "wwb",
	"Wakawaka":                              "wkw",
	"Wakde":                                 "wkd",
	"Wakhi":                                 "wbl",
	"Wakoná":                                "waf",
	"Wala":                                  "lgl",
	"Walak":                                 "wlw",
	"Walangama":                             "nlw",
	"Wali (Ghana)":                          "wlx",
	"Wali (Sudan)":                          "wll",
	"Waling":                                "wly",
	"Walio":                                 "wla",
	"Walla Walla":                           "waa",
	"Wallisian":                             "wls",
	"Walloon":                               "wln",
	"Walmajarri":                            "wmt",
	"Walser":                                "wae",
	"Walungge":                              "ola",
	"Wamas":                                 "wmc",
	"Wambaya":                               "wmb",
	"Wambon":                                "wms",
	"Wambule":                               "wme",
	"Wamey":                                 "cou",
	"Wamin":                                 "wmi",
	"Wampanoag":                             "wam",
	"Wampar":                                "lbq",
	"Wampur":                                "waz",
	"Wan":                                   "wan",
	"Wanambre":                              "wnb",
	"Wanap":                                 "wnp",
	"Wancho Naga":                           "nnp",
	"Wanda":                                 "wbh",
	"Wandala":                               "mfi",
	"Wandamen":                              "wad",
	"Wandarang":                             "wnd",
	"Wandji":                                "wdd",
	"Wané":                                  "hwa",
	"Waneci":                                "wne",
	"Wanga":                                 "lwg",
	"Wangaaybuwan-Ngiyambaa":                "wyb",
	"Wanggamala":                            "wnm",
	"Wangganguru":                           "wgg",
	"Wanggom":                               "wng",
	"Wangkayutyuru":                         "wky",
	"Wangkumara":                            "xwk",
	"Wanman":                                "wbt",
	"Wannu":                                 "jub",
	"Wano":                                  "wno",
	"Wantoat":                               "wnc",
	"Wanukaka":                              "wnk",
	"Wanyi":                                 "wny",
	"Waorani":                               "auc",
	"Wapan":                                 "juk",
	"Wãpha":                                 "juw",
	"Wapishana":                             "wap",
	"Wappo":                                 "wao",
	"War-Jaintia":                           "aml",
	"Wara":                                  "wbf",
	"Wára":                                  "tci",
	"Warao":                                 "wba",
	"Warapu":                                "wra",
	"Waray (Australia)":                     "wrz",
	"Waray (Philippines)":                   "war",
	"Wardaman":                              "wrr",
	"Wardandi":                              "wxw",
	"Warduji":                               "wrd",
	"Warembori":                             "wsa",
	"Wares":                                 "wai",
	"Waris":                                 "wrs",
	"Waritai":                               "wbe",
	"Wariyangga":                            "wri",
	"Warji":                                 "wji",
	"Warkay-Bipim":                          "bgv",
	"Warlmanpa":                             "wrl",
	"Warlpiri":                              "wbp",
	"Warluwara":                             "wrb",
	"Warnang":                               "wrn",
	"Waropen":                               "wrp",
	"Warrgamay":                             "wgy",
	"Warrwa":                                "wwr",
	"Waru":                                  "wru",
	"Warumungu":                             "wrm",
	"Waruna":                                "wrv",
	"Warungu":                               "wrg",
	"Warwar Feni":                           "hrw",
	"Wasa":                                  "wss",
	"Wasco-Wishram":                         "wac",
	"Wasembo":                               "gsp",
	"Washo":                                 "was",
	"Waskia":                                "wsk",
	"Wasu":                                  "wsu",
	"Watakataui":                            "wtk",
	"Watam":                                 "wax",
	"Wathawurrung":                          "wth",
	"Watiwa":                                "wtf",
	"Watubela":                              "wah",
	"Waube":                                 "kop",
	"Waurá":                                 "wau",
	"Wauyai":                                "wuy",
	"Wawa":                                  "www",
	"Wawonii":                               "wow",
	"Waxianghua":                            "wxa",
	"Wayampi":                               "oym",
	"Wayana":                                "way",
	"Wayanad Chetti":                        "ctt",
	"Wayoró":                                "wyr",
	"Wayu":                                  "vay",
	"Wayuu":                                 "guc",
	"Wè Northern":                           "wob",
	"Wè Southern":                           "gxx",
	"Wè Western":                            "wec",
	"Wedau":                                 "wed",
	"Weh":                                   "weh",
	"Wejewa":                                "wew",
	"Weliki":                                "klh",
	"Welsh Romani":                          "rmw",
	"Welsh":                                 "cym",
	"Wemale":                                "weo",
	"Wemba Wemba":                           "xww",
	"Weme Gbe":                              "wem",
	"Wergaia":                               "weg",
	"Weri":                                  "wer",
	"Wersing":                               "kvw",
	"West Albay Bikol":                      "fbl",
	"West Ambae":                            "nnd",
	"West Bengal Sign Language":             "wbs",
	"West Berawan":                          "zbw",
	"West Central Banda":                    "bbp",
	"West Central Oromo":                    "gaz",
	"West Coast Bajau":                      "bdr",
	"West Damar":                            "drn",
	"West Goodenough":                       "ddi",
	"West Kewa":                             "kew",
	"West Lembata":                          "lmj",
	"West Makian":                           "mqs",
	"West Masela":                           "mss",
	"West Tarangan":                         "txn",
	"West Uvean":                            "uve",
	"West Yugur":                            "ybe",
	"West-Central Limba":                    "lia",
	"Western Abnaki":                        "abe",
	"Western Apache":                        "apw",
	"Western Arrarnta":                      "are",
	"Western Balochi":                       "bgn",
	"Western Bolivian Guaraní":              "gnw",
	"Western Bru":                           "brv",
	"Western Bukidnon Manobo":               "mbb",
	"Western Cham":                          "cja",
	"Western Dani":                          "dnw",
	"Western Durango Nahuatl":               "azn",
	"Western Fijian":                        "wyy",
	"Western Frisian":                       "fry",
	"Western Highland Chatino":              "ctp",
	"Western Highland Purepecha":            "pua",
	"Western Huasteca Nahuatl":              "nhw",
	"Western Juxtlahuaca Mixtec":            "jmx",
	"Western Kanjobal":                      "knj",
	"Western Karaboro":                      "kza",
	"Western Katu":                          "kuf",
	"Western Kayah":                         "kyu",
	"Western Keres":                         "kjq",
	"Western Krahn":                         "krw",
	"Western Lalu":                          "ywl",
	"Western Lawa":                          "lcp",
	"Western Magar":                         "mrd",
	"Western Maninkakan":                    "mlq",
	"Western Mari":                          "mrj",
	"Western Mashan Hmong":                  "hmw",
	"Western Meohang":                       "raf",
	"Western Muria":                         "mut",
	"Western Neo-Aramaic":                   "amw",
	"Western Niger Fulfulde":                "fuh",
	"Western Ojibwa":                        "ojw",
	"Western Panjabi":                       "pnb",
	"Western Parbate Kham":                  "kjl",
	"Western Penan":                         "pne",
	"Western Sisaala":                       "ssl",
	"Western Subanon":                       "suc",
	"Western Tamang":                        "tdg",
	"Western Tawbuid":                       "twb",
	"Western Tlacolula Valley Zapotec":      "zab",
	"Western Totonac":                       "tqt",
	"Western Tunebo":                        "tnb",
	"Western Xiangxi Miao":                  "mmr",
	"Western Xwla Gbe":                      "xwl",
	"Western Yiddish":                       "yih",
	"Westphalien":                           "wep",
	"Wetamut":                               "wwo",
	"Wewaw":                                 "wea",
	"Weyto":                                 "woy",
	"White Gelao":                           "giw",
	"White Lachi":                           "lwh",
	"Whitesands":                            "tnp",
	"Wiarumus":                              "tua",
	"Wichí Lhamtés Güisnay":                 "mzh",
	"Wichí Lhamtés Nocten":                  "mtp",
	"Wichí Lhamtés Vejoz":                   "wlv",
	"Wichita":                               "wic",
	"Wik-Epa":                               "wie",
	"Wik-Iiyanh":                            "wij",
	"Wik-Keyangan":                          "wif",
	"Wik-Me'anha":                           "wih",
	"Wik-Mungkan":                           "wim",
	"Wik-Ngathana":                          "wig",
	"Wikalkan":                              "wik",
	"Wikngenchera":                          "wua",
	"Wilawila":                              "wil",
	"Wintu":                                 "wnw",
	"Winyé":                                 "kst",
	"Wipi":                                  "gdr",
	"Wiradhuri":                             "wrh",
	"Wiraféd":                               "wir",
	"Wirangu":                               "wgu",
	"Wiru":                                  "wiu",
	"Wiyot":                                 "wiy",
	"Woccon":                                "xwc",
	"Wogamusin":                             "wog",
	"Wogeo":                                 "woc",
	"Woi":                                   "wbw",
	"Woiwurrung":                            "wyi",
	"Wojenaka":                              "jod",
	"Wolane":                                "wle",
	"Wolani":                                "wod",
	"Wolaytta":                              "wal",
	"Woleaian":                              "woe",
	"Wolio":                                 "wlo",
	"Wolof":                                 "wol",
	"Wom (Nigeria)":                         "wom",
	"Wom (Papua New Guinea)":                "wmo",
	"Womo":                                  "wmx",
	"Wongo":                                 "won",
	"Woods Cree":                            "cwd",
	"Woria":                                 "wor",
	"Worimi":                                "kda",
	"Worodougou":                            "jud",
	"Worrorra":                              "wro",
	"Wotapuri-Katarqalai":                   "wsv",
	"Wotjobaluk":                            "xwt",
	"Wotu":                                  "wtw",
	"Woun Meu":                              "noa",
	"Written Oirat":                         "xwo",
	"Wu Chinese":                            "wuu",
	"Wuding-Luquan Yi":                      "ywq",
	"Wudu":                                  "wud",
	"Wuliwuli":                              "wlu",
	"Wulna":                                 "wux",
	"Wumboko":                               "bqm",
	"Wumbvu":                                "wum",
	"Wumeng Nasu":                           "ywu",
	"Wunai Bunu":                            "bwn",
	"Wunambal":                              "wub",
	"Wunumara":                              "wnn",
	"Wurrugu":                               "wur",
	"Wusa Nasu":                             "yig",
	"Wushi":                                 "bse",
	"Wusi":                                  "wsi",
	"Wutung":                                "wut",
	"Wutunhua":                              "wuh",
	"Wuvulu-Aua":                            "wuv",
	"Wuzlam":                                "udl",
	"Wyandot":                               "wya",
	"Wymysorys":                             "wym",
	"Xaasongaxango":                         "kao",
	"Xadani Zapotec":                        "zax",
	"Xakriabá":                              "xkr",
	"Xamtanga":                              "xan",
	"Xanaguía Zapotec":                      "ztg",
	"Xârâcùù":                               "ane",
	"Xârâgurè":                              "axx",
	"Xavánte":                               "xav",
	"Xerénte":                               "xer",
	"Xetá":                                  "xet",
	"Xhosa":                                 "xho",
	"Xiang Chinese":                         "hsn",
	"Xibe":                                  "sjo",
	"Xicotepec De Juárez Totonac":           "too",
	"Xinca":                                 "xin",
	"Xingú Asuriní":                         "asn",
	"Xipaya":                                "xiy",
	"Xiri":                                  "xii",
	"Xiriâna":                               "xir",
	"Xishanba Lalo":                         "ywt",
	"Xokleng":                               "xok",
	"Xukurú":                                "xoo",
	"Xwela Gbe":                             "xwe",
	"Yaaku":                                 "muu",
	"Yabaâna":                               "ybn",
	"Yabarana":                              "yar",
	"Yabem":                                 "jae",
	"Yaben":                                 "ybm",
	"Yabong":                                "ybo",
	"Yabula Yabula":                         "yxy",
	"Yace":                                  "ekr",
	"Yaeyama":                               "rys",
	"Yafi":                                  "wfg",
	"Yagara":                                "yxg",
	"Yagaria":                               "ygr",
	"Yagnobi":                               "yai",
	"Yagomi":                                "ygm",
	"Yagua":                                 "yad",
	"Yagwoia":                               "ygw",
	"Yahadian":                              "ner",
	"Yahang":                                "rhp",
	"Yahuna":                                "ynu",
	"Yaka (Central African Republic)":       "axk",
	"Yaka (Congo)":                          "iyx",
	"Yaka (Democratic Republic of Congo)":   "yaf",
	"Yakaikeke":                             "ykk",
	"Yakama":                                "yak",
	"Yakan":                                 "yka",
	"Yakha":                                 "ybh",
	"Yakoma":                                "yky",
	"Yakut":                                 "sah",
	"Yala":                                  "yba",
	"Yalahatan":                             "jal",
	"Yalakalore":                            "xyl",
	"Yalálag Zapotec":                       "zpu",
	"Yalarnnga":                             "ylr",
	"Yale":                                  "nce",
	"Yaleba":                                "ylb",
	"Yalunka":                               "yal",
	"Yámana":                                "yag",
	"Yamap":                                 "ymp",
	"Yamba":                                 "yam",
	"Yambes":                                "ymb",
	"Yambeta":                               "yat",
	"Yamdena":                               "jmd",
	"Yameo":                                 "yme",
	"Yami":                                  "tao",
	"Yaminahua":                             "yaa",
	"Yamna":                                 "ymn",
	"Yamongeri":                             "ymg",
	"Yamphu":                                "ybi",
	"Yan-nhangu":                            "jay",
	"Yan-nhaŋu Sign Language":               "yhs",
	"Yana":                                  "ynn",
	"Yanahuanca Pasco Quechua":              "qur",
	"Yanda Dom Dogon":                       "dym",
	"Yanda":                                 "yda",
	"Yandjibara":                            "xyb",
	"Yandruwandha":                          "ynd",
	"Yanesha'":                              "ame",
	"Yang Zhuang":                           "zyg",
	"Yangben":                               "yav",
	"Yangkam":                               "bsx",
	"Yangman":                               "jng",
	"Yango":                                 "yng",
	"Yangulam":                              "ynl",
	"Yangum Dey":                            "yde",
	"Yangum Gel":                            "ygl",
	"Yangum Mon":                            "ymo",
	"Yankunytjatjara":                       "kdd",
	"Yanomámi":                              "wca",
	"Yanomamö":                              "guu",
	"Yansi":                                 "yns",
	"Yanyuwa":                               "jao",
	"Yao":                                   "yao",
	"Yaosakor Asmat":                        "asy",
	"Yaouré":                                "yre",
	"Yapese":                                "yap",
	"Yapunda":                               "yev",
	"Yaqay":                                 "jaq",
	"Yaqui":                                 "yaq",
	"Yarawata":                              "yrw",
	"Yardliyawarra":                         "yxl",
	"Yareba":                                "yrb",
	"Yareni Zapotec":                        "zae",
	"Yarluyandi":                            "yry",
	"Yaroamë":                               "yro",
	"Yarsun":                                "yrs",
	"Yasa":                                  "yko",
	"Yassic":                                "ysc",
	"Yatay":                                 "yty",
	"Yatee Zapotec":                         "zty",
	"Yatzachi Zapotec":                      "zav",
	"Yau (Morobe Province)":                 "yuw",
	"Yau (Sandaun Province)":                "yyu",
	"Yaul":                                  "yla",
	"Yauma":                                 "yax",
	"Yaur":                                  "jau",
	"Yautepec Zapotec":                      "zpb",
	"Yauyos Quechua":                        "qux",
	"Yavitero":                              "yvt",
	"Yawa":                                  "yva",
	"Yawalapití":                            "yaw",
	"Yawanawa":                              "ywn",
	"Yawarawarga":                           "yww",
	"Yaweyuha":                              "yby",
	"Yawijibaya":                            "jbw",
	"Yawiyo":                                "ybx",
	"Yawuru":                                "ywr",
	"Yaygir":                                "xya",
	"Yazgulyam":                             "yah",
	"Yecuatla Totonac":                      "tlc",
	"Yei":                                   "jei",
	"Yekhee":                                "ets",
	"Yekora":                                "ykr",
	"Yela":                                  "yel",
	"Yele":                                  "yle",
	"Yelmek":                                "jel",
	"Yelogu":                                "ylg",
	"Yemba":                                 "ybb",
	"Yemsa":                                 "jnj",
	"Yendang":                               "ynq",
	"Yeni":                                  "yei",
	"Yeniche":                               "yec",
	"Yerakai":                               "yra",
	"Yeretuar":                              "gop",
	"Yerong":                                "yrn",
	"Yerukula":                              "yeu",
	"Yessan-Mayo":                           "yss",
	"Yetfa":                                 "yet",
	"Yevanic":                               "yej",
	"Yeyi":                                  "yey",
	"Yiddish":                               "yid",
	"Yidgha":                                "ydg",
	"Yidiny":                                "yii",
	"Yil":                                   "yll",
	"Yimas":                                 "yee",
	"Yimchungru Naga":                       "yim",
	"Yinbaw Karen":                          "kvu",
	"Yinchia":                               "yin",
	"Yindjibarndi":                          "yij",
	"Yindjilandji":                          "yil",
	"Yine":                                  "pib",
	"Yinggarda":                             "yia",
	"Yinhawangka":                           "ywg",
	"Yiningayi":                             "ygi",
	"Yintale Karen":                         "kvy",
	"Yinwum":                                "yxm",
	"Yir Yoront":                            "yyr",
	"Yirandali":                             "ljw",
	"Yirrk-Mel":                             "yrm",
	"Yis":                                   "yis",
	"Yitha Yitha":                           "xth",
	"Yoba":                                  "yob",
	"Yocoboué Dida":                         "gud",
	"Yogad":                                 "yog",
	"Yoidik":                                "ydk",
	"Yoke":                                  "yki",
	"Yokuts":                                "yok",
	"Yola":                                  "yol",
	"Yolŋu Sign Language":                   "ygs",
	"Yoloxochitl Mixtec":                    "xty",
	"Yom":                                   "pil",
	"Yombe":                                 "yom",
	"Yonaguni":                              "yoi",
	"Yong":                                  "yno",
	"Yongbei Zhuang":                        "zyb",
	"Yongkom":                               "yon",
	"Yongnan Zhuang":                        "zyn",
	"Yopno":                                 "yut",
	"Yora":                                  "mts",
	"Yoron":                                 "yox",
	"Yorta Yorta":                           "xyy",
	"Yoruba":                                "yor",
	"Yosondúa Mixtec":                       "mpm",
	"Yotti":                                 "yot",
	"Youjiang Zhuang":                       "zyj",
	"Youle Jinuo":                           "jiu",
	"Younuo Bunu":                           "buh",
	"Yout Wam":                              "ytw",
	"Yoy":                                   "yoy",
	"Yuanga":                                "nua",
	"Yucatec Maya Sign Language":            "msd",
	"Yucateco":                              "yua",
	"Yuchi":                                 "yuc",
	"Yucuañe Mixtec":                        "mvg",
	"Yucuna":                                "ycn",
	"Yue Chinese":                           "yue",
	"Yug":                                   "yug",
	"Yugambal":                              "yub",
	"Yugoslavian Sign Language":             "ysl",
	"Yugul":                                 "ygu",
	"Yuhup":                                 "yab",
	"Yuki":                                  "yuk",
	"Yukpa":                                 "yup",
	"Yukuben":                               "ybl",
	"Yulu":                                  "yul",
	"Yuqui":                                 "yuq",
	"Yuracare":                              "yuz",
	"Yurats":                                "rts",
	"Yurok":                                 "yur",
	"Yuru":                                  "ljx",
	"Yurutí":                                "yui",
	"Yutanduchi Mixtec":                     "mab",
	"Yuwana":                                "yau",
	"Yuyu":                                  "yxu",
	"Ywom":                                  "gek",
	"Zaachila Zapotec":                      "ztx",
	"Zabana":                                "kji",
	"Zacatepec Chatino":                     "ctz",
	"Zacatlán-Ahuacatlán-Tepetzintla Nahuatl": "nhi",
	"Zaghawa":                     "zag",
	"Zaiwa":                       "atb",
	"Zakhring":                    "zkr",
	"Zambian Sign Language":       "zsl",
	"Zan Gula":                    "zna",
	"Zanaki":                      "zak",
	"Zande (individual language)": "zne",
	"Zangskari":                   "zau",
	"Zangwal":                     "zah",
	"Zaniza Zapotec":              "zpw",
	"Záparo":                      "zro",
	"Zapotec":                     "zap",
	"Zaramo":                      "zaj",
	"Zari":                        "zaz",
	"Zarma":                       "dje",
	"Zarphatic":                   "zrp",
	"Zauzou":                      "zal",
	"Zay":                         "zwa",
	"Zayein Karen":                "kxk",
	"Zayse-Zergulla":              "zay",
	"Zaza":                        "zza",
	"Zazao":                       "jaj",
	"Zeem":                        "zua",
	"Zeeuws":                      "zea",
	"Zemba":                       "dhm",
	"Zeme Naga":                   "nzm",
	"Zemgalian":                   "xzm",
	"Zenag":                       "zeg",
	"Zenaga":                      "zen",
	"Zenzontepec Chatino":         "czn",
	"Zerenkel":                    "zrn",
	"Zhaba":                       "zhb",
	"Zhang-Zhung":                 "xzh",
	"Zhire":                       "zhi",
	"Zhoa":                        "zhw",
	"Zhuang":                      "zha",
	"Zia":                         "zia",
	"Zialo":                       "zil",
	"Zigula":                      "ziw",
	"Zimakani":                    "zik",
	"Zimba":                       "zmb",
	"Zimbabwe Sign Language":      "zib",
	"Zinza":                       "zin",
	"Zire":                        "sih",
	"Ziriya":                      "zir",
	"Zizilivakan":                 "ziz",
	"Zo'é":                        "pto",
	"Zokhuo":                      "yzk",
	"Zoogocho Zapotec":            "zpq",
	"Zoroastrian Dari":            "gbz",
	"Zotung Chin":                 "czt",
	"Zou":                         "zom",
	"Zulgo-Gemzek":                "gnd",
	"Zulu":                        "zul",
	"Zumaya":                      "zuy",
	"Zumbun":                      "jmb",
	"Zuni":                        "zun",
	"Zuojiang Zhuang":             "zzj",
	"Zyphe Chin":                  "zyp",
	"ǂUngkue":                     "gku",
}

// ISO639NameToThreeLower converts lowercase ISO language name to ISO639-3.
var ISO639NameToThreeLower = map[string]string{
	"ghotuo":                              "aaa",
	"alumu-tesu":                          "aab",
	"ari":                                 "aac",
	"amal":                                "aad",
	"arbëreshë albanian":                  "aae",
	"aranadan":                            "aaf",
	"ambrak":                              "aag",
	"abu' arapesh":                        "aah",
	"arifama-miniafia":                    "aai",
	"ankave":                              "aak",
	"afade":                               "aal",
	"anambé":                              "aan",
	"algerian saharan arabic":             "aao",
	"pará arára":                          "aap",
	"eastern abnaki":                      "aaq",
	"afar":                                "aar",
	"aasáx":                               "aas",
	"arvanitika albanian":                 "aat",
	"abau":                                "aau",
	"solong":                              "aaw",
	"mandobo atas":                        "aax",
	"amarasi":                             "aaz",
	"abé":                                 "aba",
	"bankon":                              "abb",
	"ambala ayta":                         "abc",
	"manide":                              "abd",
	"western abnaki":                      "abe",
	"abai sungai":                         "abf",
	"abaga":                               "abg",
	"tajiki arabic":                       "abh",
	"abidji":                              "abi",
	"aka-bea":                             "abj",
	"abkhazian":                           "abk",
	"lampung nyo":                         "abl",
	"abanyom":                             "abm",
	"abua":                                "abn",
	"abon":                                "abo",
	"abellen ayta":                        "abp",
	"abaza":                               "abq",
	"abron":                               "abr",
	"ambonese malay":                      "abs",
	"ambulas":                             "abt",
	"abure":                               "abu",
	"baharna arabic":                      "abv",
	"pal":                                 "abw",
	"inabaknon":                           "abx",
	"aneme wake":                          "aby",
	"abui":                                "abz",
	"achagua":                             "aca",
	"áncá":                                "acb",
	"gikyode":                             "acd",
	"achinese":                            "ace",
	"saint lucian creole french":          "acf",
	"acoli":                               "ach",
	"aka-cari":                            "aci",
	"aka-kora":                            "ack",
	"akar-bale":                           "acl",
	"mesopotamian arabic":                 "acm",
	"achang":                              "acn",
	"eastern acipa":                       "acp",
	"ta'izzi-adeni arabic":                "acq",
	"achi":                                "acr",
	"acroá":                               "acs",
	"achterhoeks":                         "act",
	"achuar-shiwiar":                      "acu",
	"achumawi":                            "acv",
	"hijazi arabic":                       "acw",
	"omani arabic":                        "acx",
	"cypriot arabic":                      "acy",
	"acheron":                             "acz",
	"adangme":                             "ada",
	"adabe":                               "adb",
	"dzodinka":                            "add",
	"adele":                               "ade",
	"dhofari arabic":                      "adf",
	"andegerebinha":                       "adg",
	"adhola":                              "adh",
	"adi":                                 "adi",
	"adioukrou":                           "adj",
	"galo":                                "adl",
	"adang":                               "adn",
	"abu":                                 "ado",
	"adangbe":                             "adq",
	"adonara":                             "adr",
	"adamorobe sign language":             "ads",
	"adnyamathanha":                       "adt",
	"aduge":                               "adu",
	"amundava":                            "adw",
	"amdo tibetan":                        "adx",
	"adyghe":                              "ady",
	"adzera":                              "adz",
	"areba":                               "aea",
	"tunisian arabic":                     "aeb",
	"saidi arabic":                        "aec",
	"argentine sign language":             "aed",
	"northeast pashai":                    "aee",
	"haeke":                               "aek",
	"ambele":                              "ael",
	"arem":                                "aem",
	"armenian sign language":              "aen",
	"aer":                                 "aeq",
	"eastern arrernte":                    "aer",
	"alsea":                               "aes",
	"akeu":                                "aeu",
	"ambakich":                            "aew",
	"amele":                               "aey",
	"aeka":                                "aez",
	"gulf arabic":                         "afb",
	"andai":                               "afd",
	"putukwam":                            "afe",
	"afghan sign language":                "afg",
	"afrihili":                            "afh",
	"akrukay":                             "afi",
	"nanubae":                             "afk",
	"defaka":                              "afn",
	"eloyi":                               "afo",
	"tapei":                               "afp",
	"afrikaans":                           "afr",
	"afro-seminole creole":                "afs",
	"afitti":                              "aft",
	"awutu":                               "afu",
	"obokuitai":                           "afz",
	"aguano":                              "aga",
	"legbo":                               "agb",
	"agatu":                               "agc",
	"agarabi":                             "agd",
	"angal":                               "age",
	"arguni":                              "agf",
	"angor":                               "agg",
	"ngelima":                             "agh",
	"agariya":                             "agi",
	"argobba":                             "agj",
	"isarog agta":                         "agk",
	"fembe":                               "agl",
	"angaataha":                           "agm",
	"agutaynen":                           "agn",
	"tainae":                              "ago",
	"aghem":                               "agq",
	"aguaruna":                            "agr",
	"esimbi":                              "ags",
	"central cagayan agta":                "agt",
	"aguacateco":                          "agu",
	"remontado dumagat":                   "agv",
	"kahua":                               "agw",
	"aghul":                               "agx",
	"southern alta":                       "agy",
	"mt. iriga agta":                      "agz",
	"ahanta":                              "aha",
	"axamb":                               "ahb",
	"qimant":                              "ahg",
	"aghu":                                "ahh",
	"tiagbamrin aizi":                     "ahi",
	"akha":                                "ahk",
	"igo":                                 "ahl",
	"mobumrin aizi":                       "ahm",
	"àhàn":                                "ahn",
	"ahom":                                "aho",
	"aproumu aizi":                        "ahp",
	"ahirani":                             "ahr",
	"ashe":                                "ahs",
	"ahtena":                              "aht",
	"arosi":                               "aia",
	"ainu (china)":                        "aib",
	"ainbai":                              "aic",
	"alngith":                             "aid",
	"amara":                               "aie",
	"agi":                                 "aif",
	"antigua and barbuda creole english":  "aig",
	"ai-cham":                             "aih",
	"assyrian neo-aramaic":                "aii",
	"lishanid noshan":                     "aij",
	"ake":                                 "aik",
	"aimele":                              "ail",
	"aimol":                               "aim",
	"ainu (japan)":                        "ain",
	"aiton":                               "aio",
	"burumakok":                           "aip",
	"aimaq":                               "aiq",
	"airoran":                             "air",
	"nataoran amis":                       "ais",
	"arikem":                              "ait",
	"aari":                                "aiw",
	"aighon":                              "aix",
	"ali":                                 "aiy",
	"aja (sudan)":                         "aja",
	"aja (benin)":                         "ajg",
	"ajië":                                "aji",
	"andajin":                             "ajn",
	"south levantine arabic":              "ajp",
	"judeo-tunisian arabic":               "ajt",
	"judeo-moroccan arabic":               "aju",
	"ajawa":                               "ajw",
	"amri karbi":                          "ajz",
	"akan":                                "aka",
	"batak angkola":                       "akb",
	"mpur":                                "akc",
	"ukpet-ehom":                          "akd",
	"akawaio":                             "ake",
	"akpa":                                "akf",
	"anakalangu":                          "akg",
	"angal heneng":                        "akh",
	"aiome":                               "aki",
	"aka-jeru":                            "akj",
	"akkadian":                            "akk",
	"aklanon":                             "akl",
	"aka-bo":                              "akm",
	"akurio":                              "ako",
	"siwu":                                "akp",
	"ak":                                  "akq",
	"araki":                               "akr",
	"akaselem":                            "aks",
	"akolet":                              "akt",
	"akum":                                "aku",
	"akhvakh":                             "akv",
	"akwa":                                "akw",
	"aka-kede":                            "akx",
	"aka-kol":                             "aky",
	"alabama":                             "akz",
	"alago":                               "ala",
	"qawasqar":                            "alc",
	"alladian":                            "ald",
	"aleut":                               "ale",
	"alege":                               "alf",
	"alawa":                               "alh",
	"amaimon":                             "ali",
	"alangan":                             "alj",
	"alak":                                "alk",
	"allar":                               "all",
	"amblong":                             "alm",
	"gheg albanian":                       "aln",
	"larike-wakasihu":                     "alo",
	"alune":                               "alp",
	"algonquin":                           "alq",
	"alutor":                              "alr",
	"tosk albanian":                       "als",
	"southern altai":                      "alt",
	"'are'are":                            "alu",
	"alaba-k’abeena":                      "alw",
	"amol":                                "alx",
	"alyawarr":                            "aly",
	"alur":                                "alz",
	"amanayé":                             "ama",
	"ambo":                                "amb",
	"amahuaca":                            "amc",
	"yanesha'":                            "ame",
	"hamer-banna":                         "amf",
	"amurdak":                             "amg",
	"amharic":                             "amh",
	"amis":                                "ami",
	"amdang":                              "amj",
	"ambai":                               "amk",
	"war-jaintia":                         "aml",
	"ama (papua new guinea)":              "amm",
	"amanab":                              "amn",
	"amo":                                 "amo",
	"alamblak":                            "amp",
	"amahai":                              "amq",
	"amarakaeri":                          "amr",
	"southern amami-oshima":               "ams",
	"amto":                                "amt",
	"guerrero amuzgo":                     "amu",
	"ambelau":                             "amv",
	"western neo-aramaic":                 "amw",
	"anmatyerre":                          "amx",
	"ami":                                 "amy",
	"atampaya":                            "amz",
	"andaqui":                             "ana",
	"andoa":                               "anb",
	"ngas":                                "anc",
	"ansus":                               "and",
	"xârâcùù":                             "ane",
	"animere":                             "anf",
	"old english (ca. 450-1100)":          "ang",
	"nend":                                "anh",
	"andi":                                "ani",
	"anor":                                "anj",
	"goemai":                              "ank",
	"anu-hkongso chin":                    "anl",
	"anal":                                "anm",
	"obolo":                               "ann",
	"andoque":                             "ano",
	"angika":                              "anp",
	"jarawa (india)":                      "anq",
	"andh":                                "anr",
	"anserma":                             "ans",
	"antakarinya":                         "ant",
	"anuak":                               "anu",
	"denya":                               "anv",
	"anaang":                              "anw",
	"andra-hus":                           "anx",
	"anyin":                               "any",
	"anem":                                "anz",
	"angolar":                             "aoa",
	"abom":                                "aob",
	"pemon":                               "aoc",
	"andarum":                             "aod",
	"angal enen":                          "aoe",
	"bragat":                              "aof",
	"angoram":                             "aog",
	"arma":                                "aoh",
	"anindilyakwa":                        "aoi",
	"mufian":                              "aoj",
	"arhö":                                "aok",
	"alor":                                "aol",
	"ömie":                                "aom",
	"bumbita arapesh":                     "aon",
	"aore":                                "aor",
	"taikat":                              "aos",
	"atong (india)":                       "aot",
	"a'ou":                                "aou",
	"atorada":                             "aox",
	"uab meto":                            "aoz",
	"sa'a":                                "apb",
	"north levantine arabic":              "apc",
	"sudanese arabic":                     "apd",
	"bukiyip":                             "ape",
	"pahanan agta":                        "apf",
	"ampanang":                            "apg",
	"athpariya":                           "aph",
	"apiaká":                              "api",
	"jicarilla apache":                    "apj",
	"kiowa apache":                        "apk",
	"lipan apache":                        "apl",
	"mescalero-chiricahua apache":         "apm",
	"apinayé":                             "apn",
	"ambul":                               "apo",
	"apma":                                "app",
	"a-pucikwar":                          "apq",
	"arop-lokep":                          "apr",
	"arop-sissano":                        "aps",
	"apatani":                             "apt",
	"apurinã":                             "apu",
	"alapmunte":                           "apv",
	"western apache":                      "apw",
	"aputai":                              "apx",
	"apalaí":                              "apy",
	"safeyoka":                            "apz",
	"archi":                               "aqc",
	"ampari dogon":                        "aqd",
	"arigidi":                             "aqg",
	"atohwaim":                            "aqm",
	"northern alta":                       "aqn",
	"atakapa":                             "aqp",
	"arhâ":                                "aqr",
	"angaité":                             "aqt",
	"akuntsu":                             "aqz",
	"arabic":                              "ara",
	"standard arabic":                     "arb",
	"official aramaic (700-300 bce)":      "arc",
	"arabana":                             "ard",
	"western arrarnta":                    "are",
	"aragonese":                           "arg",
	"arhuaco":                             "arh",
	"arikara":                             "ari",
	"arapaso":                             "arj",
	"arikapú":                             "ark",
	"arabela":                             "arl",
	"mapudungun":                          "arn",
	"araona":                              "aro",
	"arapaho":                             "arp",
	"algerian arabic":                     "arq",
	"karo (brazil)":                       "arr",
	"najdi arabic":                        "ars",
	"aruá (amazonas state)":               "aru",
	"arbore":                              "arv",
	"arawak":                              "arw",
	"aruá (rodonia state)":                "arx",
	"moroccan arabic":                     "ary",
	"egyptian arabic":                     "arz",
	"asu (tanzania)":                      "asa",
	"assiniboine":                         "asb",
	"casuarina coast asmat":               "asc",
	"asas":                                "asd",
	"american sign language":              "ase",
	"australian sign language":            "asf",
	"cishingini":                          "asg",
	"abishira":                            "ash",
	"buruwai":                             "asi",
	"sari":                                "asj",
	"ashkun":                              "ask",
	"asilulu":                             "asl",
	"assamese":                            "asm",
	"xingú asuriní":                       "asn",
	"dano":                                "aso",
	"algerian sign language":              "asp",
	"austrian sign language":              "asq",
	"asuri":                               "asr",
	"ipulo":                               "ass",
	"asturian":                            "ast",
	"tocantins asurini":                   "asu",
	"asoa":                                "asv",
	"australian aborigines sign language": "asw",
	"muratayak":                           "asx",
	"yaosakor asmat":                      "asy",
	"as":                                  "asz",
	"pele-ata":                            "ata",
	"zaiwa":                               "atb",
	"atsahuaca":                           "atc",
	"ata manobo":                          "atd",
	"atemble":                             "ate",
	"ivbie north-okpela-arhe":             "atg",
	"attié":                               "ati",
	"atikamekw":                           "atj",
	"ati":                                 "atk",
	"mt. iraya agta":                      "atl",
	"ata":                                 "atm",
	"ashtiani":                            "atn",
	"atong (cameroon)":                    "ato",
	"pudtol atta":                         "atp",
	"aralle-tabulahan":                    "atq",
	"waimiri-atroari":                     "atr",
	"gros ventre":                         "ats",
	"pamplona atta":                       "att",
	"reel":                                "atu",
	"northern altai":                      "atv",
	"atsugewi":                            "atw",
	"arutani":                             "atx",
	"aneityum":                            "aty",
	"arta":                                "atz",
	"asumboa":                             "aua",
	"alugu":                               "aub",
	"waorani":                             "auc",
	"anuta":                               "aud",
	"aguna":                               "aug",
	"aushi":                               "auh",
	"anuki":                               "aui",
	"awjilah":                             "auj",
	"heyo":                                "auk",
	"aulua":                               "aul",
	"asu (nigeria)":                       "aum",
	"molmo one":                           "aun",
	"auyokawa":                            "auo",
	"makayam":                             "aup",
	"anus":                                "auq",
	"aruek":                               "aur",
	"austral":                             "aut",
	"auye":                                "auu",
	"awyi":                                "auw",
	"aurá":                                "aux",
	"awiyaana":                            "auy",
	"uzbeki arabic":                       "auz",
	"avaric":                              "ava",
	"avau":                                "avb",
	"alviri-vidari":                       "avd",
	"avestan":                             "ave",
	"avikam":                              "avi",
	"kotava":                              "avk",
	"eastern egyptian bedawi arabic":      "avl",
	"angkamuthi":                          "avm",
	"avatime":                             "avn",
	"agavotaguerra":                       "avo",
	"aushiri":                             "avs",
	"au":                                  "avt",
	"avokaya":                             "avu",
	"avá-canoeiro":                        "avv",
	"awadhi":                              "awa",
	"awa (papua new guinea)":              "awb",
	"cicipu":                              "awc",
	"awetí":                               "awe",
	"anguthimri":                          "awg",
	"awbono":                              "awh",
	"aekyom":                              "awi",
	"awabakal":                            "awk",
	"arawum":                              "awm",
	"awngi":                               "awn",
	"awak":                                "awo",
	"awera":                               "awr",
	"south awyu":                          "aws",
	"araweté":                             "awt",
	"central awyu":                        "awu",
	"jair awyu":                           "awv",
	"awun":                                "aww",
	"awara":                               "awx",
	"edera awyu":                          "awy",
	"abipon":                              "axb",
	"ayerrerenge":                         "axe",
	"mato grosso arára":                   "axg",
	"yaka (central african republic)":     "axk",
	"lower southern aranda":               "axl",
	"middle armenian":                     "axm",
	"xârâgurè":                            "axx",
	"awar":                                "aya",
	"ayizo gbe":                           "ayb",
	"southern aymara":                     "ayc",
	"ayabadhu":                            "ayd",
	"ayere":                               "aye",
	"ginyanga":                            "ayg",
	"hadrami arabic":                      "ayh",
	"leyigha":                             "ayi",
	"akuku":                               "ayk",
	"libyan arabic":                       "ayl",
	"aymara":                              "aym",
	"sanaani arabic":                      "ayn",
	"ayoreo":                              "ayo",
	"north mesopotamian arabic":           "ayp",
	"ayi (papua new guinea)":              "ayq",
	"central aymara":                      "ayr",
	"sorsogon ayta":                       "ays",
	"magbukun ayta":                       "ayt",
	"ayu":                                 "ayu",
	"tayabas ayta":                        "ayy",
	"mai brat":                            "ayz",
	"azha":                                "aza",
	"south azerbaijani":                   "azb",
	"eastern durango nahuatl":             "azd",
	"azerbaijani":                         "aze",
	"san pedro amuzgos amuzgo":            "azg",
	"north azerbaijani":                   "azj",
	"ipalapa amuzgo":                      "azm",
	"western durango nahuatl":             "azn",
	"awing":                               "azo",
	"faire atta":                          "azt",
	"highland puebla nahuatl":             "azz",
	"babatana":                            "baa",
	"bainouk-gunyuño":                     "bab",
	"badui":                               "bac",
	"baré":                                "bae",
	"nubaca":                              "baf",
	"tuki":                                "bag",
	"bahamas creole english":              "bah",
	"barakai":                             "baj",
	"bashkir":                             "bak",
	"baluchi":                             "bal",
	"bambara":                             "bam",
	"balinese":                            "ban",
	"waimaha":                             "bao",
	"bantawa":                             "bap",
	"bavarian":                            "bar",
	"basa (cameroon)":                     "bas",
	"bada (nigeria)":                      "bau",
	"vengo":                               "bav",
	"bambili-bambui":                      "baw",
	"bamun":                               "bax",
	"batuley":                             "bay",
	"baatonum":                            "bba",
	"barai":                               "bbb",
	"batak toba":                          "bbc",
	"bau":                                 "bbd",
	"bangba":                              "bbe",
	"baibai":                              "bbf",
	"barama":                              "bbg",
	"bugan":                               "bbh",
	"barombi":                             "bbi",
	"ghomálá'":                            "bbj",
	"babanki":                             "bbk",
	"bats":                                "bbl",
	"babango":                             "bbm",
	"uneapa":                              "bbn",
	"northern bobo madaré":                "bbo",
	"west central banda":                  "bbp",
	"bamali":                              "bbq",
	"girawa":                              "bbr",
	"bakpinka":                            "bbs",
	"mburku":                              "bbt",
	"kulung (nigeria)":                    "bbu",
	"karnai":                              "bbv",
	"baba":                                "bbw",
	"bubia":                               "bbx",
	"befang":                              "bby",
	"babalia creole arabic":               "bbz",
	"central bai":                         "bca",
	"bainouk-samik":                       "bcb",
	"southern balochi":                    "bcc",
	"north babar":                         "bcd",
	"bamenyam":                            "bce",
	"bamu":                                "bcf",
	"baga pokur":                          "bcg",
	"bariai":                              "bch",
	"baoulé":                              "bci",
	"bardi":                               "bcj",
	"bunaba":                              "bck",
	"central bikol":                       "bcl",
	"bannoni":                             "bcm",
	"bali (nigeria)":                      "bcn",
	"kaluli":                              "bco",
	"bali (democratic republic of congo)": "bcp",
	"bench":                               "bcq",
	"babine":                              "bcr",
	"kohumono":                            "bcs",
	"bendi":                               "bct",
	"awad bing":                           "bcu",
	"shoo-minda-nye":                      "bcv",
	"bana":                                "bcw",
	"bacama":                              "bcy",
	"bainouk-gunyaamolo":                  "bcz",
	"bayot":                               "bda",
	"basap":                               "bdb",
	"emberá-baudó":                        "bdc",
	"bunama":                              "bdd",
	"bade":                                "bde",
	"biage":                               "bdf",
	"bonggi":                              "bdg",
	"baka (sudan)":                        "bdh",
	"burun":                               "bdi",
	"bai":                                 "bdj",
	"budukh":                              "bdk",
	"indonesian bajau":                    "bdl",
	"buduma":                              "bdm",
	"baldemu":                             "bdn",
	"morom":                               "bdo",
	"bende":                               "bdp",
	"bahnar":                              "bdq",
	"west coast bajau":                    "bdr",
	"burunge":                             "bds",
	"bokoto":                              "bdt",
	"oroko":                               "bdu",
	"bodo parja":                          "bdv",
	"baham":                               "bdw",
	"budong-budong":                       "bdx",
	"bandjalang":                          "bdy",
	"badeshi":                             "bdz",
	"beaver":                              "bea",
	"bebele":                              "beb",
	"iceve-maci":                          "bec",
	"bedoanas":                            "bed",
	"byangsi":                             "bee",
	"benabena":                            "bef",
	"belait":                              "beg",
	"biali":                               "beh",
	"bekati'":                             "bei",
	"beja":                                "bej",
	"bebeli":                              "bek",
	"belarusian":                          "bel",
	"bemba (zambia)":                      "bem",
	"bengali":                             "ben",
	"beami":                               "beo",
	"besoa":                               "bep",
	"beembe":                              "beq",
	"besme":                               "bes",
	"guiberoua béte":                      "bet",
	"blagar":                              "beu",
	"daloa bété":                          "bev",
	"betawi":                              "bew",
	"jur modo":                            "bex",
	"beli (papua new guinea)":             "bey",
	"bena (tanzania)":                     "bez",
	"bari":                                "bfa",
	"pauri bareli":                        "bfb",
	"panyi bai":                           "bfc",
	"bafut":                               "bfd",
	"betaf":                               "bfe",
	"bofi":                                "bff",
	"busang kayan":                        "bfg",
	"blafe":                               "bfh",
	"british sign language":               "bfi",
	"bafanji":                             "bfj",
	"ban khor sign language":              "bfk",
	"banda-ndélé":                         "bfl",
	"mmen":                                "bfm",
	"bunak":                               "bfn",
	"malba birifor":                       "bfo",
	"beba":                                "bfp",
	"badaga":                              "bfq",
	"bazigar":                             "bfr",
	"southern bai":                        "bfs",
	"balti":                               "bft",
	"gahri":                               "bfu",
	"bondo":                               "bfw",
	"bantayanon":                          "bfx",
	"bagheli":                             "bfy",
	"mahasu pahari":                       "bfz",
	"gwamhi-wuri":                         "bga",
	"bobongko":                            "bgb",
	"haryanvi":                            "bgc",
	"rathwi bareli":                       "bgd",
	"bauria":                              "bge",
	"bangandu":                            "bgf",
	"bugun":                               "bgg",
	"giangan":                             "bgi",
	"bangolan":                            "bgj",
	"bit":                                 "bgk",
	"bo (laos)":                           "bgl",
	"western balochi":                     "bgn",
	"baga koga":                           "bgo",
	"eastern balochi":                     "bgp",
	"bagri":                               "bgq",
	"bawm chin":                           "bgr",
	"tagabawa":                            "bgs",
	"bughotu":                             "bgt",
	"mbongno":                             "bgu",
	"warkay-bipim":                        "bgv",
	"bhatri":                              "bgw",
	"balkan gagauz turkish":               "bgx",
	"benggoi":                             "bgy",
	"banggai":                             "bgz",
	"bharia":                              "bha",
	"bhili":                               "bhb",
	"biga":                                "bhc",
	"bhadrawahi":                          "bhd",
	"bhaya":                               "bhe",
	"odiai":                               "bhf",
	"binandere":                           "bhg",
	"bukharic":                            "bhh",
	"bhilali":                             "bhi",
	"bahing":                              "bhj",
	"bimin":                               "bhl",
	"bathari":                             "bhm",
	"bohtan neo-aramaic":                  "bhn",
	"bhojpuri":                            "bho",
	"bima":                                "bhp",
	"tukang besi south":                   "bhq",
	"bara malagasy":                       "bhr",
	"buwal":                               "bhs",
	"bhattiyali":                          "bht",
	"bhunjia":                             "bhu",
	"bahau":                               "bhv",
	"biak":                                "bhw",
	"bhalay":                              "bhx",
	"bhele":                               "bhy",
	"bada (indonesia)":                    "bhz",
	"badimaya":                            "bia",
	"bissa":                               "bib",
	"bikaru":                              "bic",
	"bidiyo":                              "bid",
	"bepour":                              "bie",
	"biafada":                             "bif",
	"biangai":                             "big",
	"vaghat-ya-bijim-legeri":              "bij",
	"bikol":                               "bik",
	"bile":                                "bil",
	"bimoba":                              "bim",
	"bini":                                "bin",
	"nai":                                 "bio",
	"bila":                                "bip",
	"bipi":                                "biq",
	"bisorio":                             "bir",
	"bislama":                             "bis",
	"berinomo":                            "bit",
	"biete":                               "biu",
	"southern birifor":                    "biv",
	"kol (cameroon)":                      "biw",
	"bijori":                              "bix",
	"birhor":                              "biy",
	"baloi":                               "biz",
	"budza":                               "bja",
	"banggarla":                           "bjb",
	"bariji":                              "bjc",
	"biao-jiao mien":                      "bje",
	"barzani jewish neo-aramaic":          "bjf",
	"bidyogo":                             "bjg",
	"bahinemo":                            "bjh",
	"burji":                               "bji",
	"kanauji":                             "bjj",
	"barok":                               "bjk",
	"bulu (papua new guinea)":             "bjl",
	"bajelani":                            "bjm",
	"banjar":                              "bjn",
	"mid-southern banda":                  "bjo",
	"fanamaket":                           "bjp",
	"binumarien":                          "bjr",
	"bajan":                               "bjs",
	"balanta-ganja":                       "bjt",
	"busuu":                               "bju",
	"bedjond":                             "bjv",
	"bakwé":                               "bjw",
	"banao itneg":                         "bjx",
	"bayali":                              "bjy",
	"baruga":                              "bjz",
	"kyak":                                "bka",
	"baka (cameroon)":                     "bkc",
	"binukid":                             "bkd",
	"beeke":                               "bkf",
	"buraka":                              "bkg",
	"bakoko":                              "bkh",
	"baki":                                "bki",
	"pande":                               "bkj",
	"brokskat":                            "bkk",
	"berik":                               "bkl",
	"kom (cameroon)":                      "bkm",
	"bukitan":                             "bkn",
	"kwa'":                                "bko",
	"boko (democratic republic of congo)": "bkp",
	"bakairí":                             "bkq",
	"bakumpai":                            "bkr",
	"northern sorsoganon":                 "bks",
	"boloki":                              "bkt",
	"buhid":                               "bku",
	"bekwarra":                            "bkv",
	"bekwel":                              "bkw",
	"baikeno":                             "bkx",
	"bokyi":                               "bky",
	"bungku":                              "bkz",
	"siksika":                             "bla",
	"bilua":                               "blb",
	"bella coola":                         "blc",
	"bolango":                             "bld",
	"balanta-kentohe":                     "ble",
	"buol":                                "blf",
	"balau":                               "blg",
	"kuwaa":                               "blh",
	"bolia":                               "bli",
	"bolongan":                            "blj",
	"pa'o karen":                          "blk",
	"biloxi":                              "bll",
	"beli (sudan)":                        "blm",
	"southern catanduanes bikol":          "bln",
	"anii":                                "blo",
	"blablanga":                           "blp",
	"baluan-pam":                          "blq",
	"blang":                               "blr",
	"balaesang":                           "bls",
	"tai dam":                             "blt",
	"kibala":                              "blv",
	"balangao":                            "blw",
	"mag-indi ayta":                       "blx",
	"notre":                               "bly",
	"balantak":                            "blz",
	"lame":                                "bma",
	"bembe":                               "bmb",
	"biem":                                "bmc",
	"baga manduri":                        "bmd",
	"limassa":                             "bme",
	"bom-kim":                             "bmf",
	"bamwe":                               "bmg",
	"kein":                                "bmh",
	"bagirmi":                             "bmi",
	"bote-majhi":                          "bmj",
	"ghayavi":                             "bmk",
	"bomboli":                             "bml",
	"northern betsimisaraka malagasy":     "bmm",
	"bina (papua new guinea)":             "bmn",
	"bambalang":                           "bmo",
	"bulgebi":                             "bmp",
	"bomu":                                "bmq",
	"muinane":                             "bmr",
	"bilma kanuri":                        "bms",
	"biao mon":                            "bmt",
	"somba-siawari":                       "bmu",
	"bum":                                 "bmv",
	"bomwali":                             "bmw",
	"baimak":                              "bmx",
	"baramu":                              "bmz",
	"bonerate":                            "bna",
	"bookan":                              "bnb",
	"bontok":                              "bnc",
	"banda (indonesia)":                   "bnd",
	"bintauna":                            "bne",
	"masiwang":                            "bnf",
	"benga":                               "bng",
	"bangi":                               "bni",
	"eastern tawbuid":                     "bnj",
	"bierebo":                             "bnk",
	"boon":                                "bnl",
	"batanga":                             "bnm",
	"bunun":                               "bnn",
	"bantoanon":                           "bno",
	"bola":                                "bnp",
	"bantik":                              "bnq",
	"butmas-tur":                          "bnr",
	"bundeli":                             "bns",
	"bentong":                             "bnu",
	"bonerif":                             "bnv",
	"bisis":                               "bnw",
	"bangubangu":                          "bnx",
	"bintulu":                             "bny",
	"beezen":                              "bnz",
	"bora":                                "boa",
	"aweer":                               "bob",
	"tibetan":                             "bod",
	"mundabli":                            "boe",
	"bolon":                               "bof",
	"bamako sign language":                "bog",
	"boma":                                "boh",
	"barbareño":                           "boi",
	"anjam":                               "boj",
	"bonjo":                               "bok",
	"bole":                                "bol",
	"berom":                               "bom",
	"bine":                                "bon",
	"tiemacèwè bozo":                      "boo",
	"bonkiman":                            "bop",
	"bogaya":                              "boq",
	"borôro":                              "bor",
	"bosnian":                             "bos",
	"bongo":                               "bot",
	"bondei":                              "bou",
	"tuwuli":                              "bov",
	"rema":                                "bow",
	"buamu":                               "box",
	"bodo (central african republic)":     "boy",
	"tiéyaxo bozo":                        "boz",
	"daakaka":                             "bpa",
	"barbacoas":                           "bpb",
	"banda-banda":                         "bpd",
	"bonggo":                              "bpg",
	"botlikh":                             "bph",
	"bagupi":                              "bpi",
	"binji":                               "bpj",
	"orowe":                               "bpk",
	"broome pearling lugger pidgin":       "bpl",
	"biyom":                               "bpm",
	"dzao min":                            "bpn",
	"anasi":                               "bpo",
	"kaure":                               "bpp",
	"banda malay":                         "bpq",
	"koronadal blaan":                     "bpr",
	"sarangani blaan":                     "bps",
	"barrow point":                        "bpt",
	"bongu":                               "bpu",
	"bian marind":                         "bpv",
	"bo (papua new guinea)":               "bpw",
	"palya bareli":                        "bpx",
	"bishnupriya":                         "bpy",
	"bilba":                               "bpz",
	"tchumbuli":                           "bqa",
	"bagusa":                              "bqb",
	"boko (benin)":                        "bqc",
	"bung":                                "bqd",
	"baga kaloum":                         "bqf",
	"bago-kusuntu":                        "bqg",
	"baima":                               "bqh",
	"bakhtiari":                           "bqi",
	"bandial":                             "bqj",
	"banda-mbrès":                         "bqk",
	"bilakura":                            "bql",
	"wumboko":                             "bqm",
	"bulgarian sign language":             "bqn",
	"balo":                                "bqo",
	"busa":                                "bqp",
	"biritai":                             "bqq",
	"burusu":                              "bqr",
	"bosngun":                             "bqs",
	"bamukumbit":                          "bqt",
	"boguru":                              "bqu",
	"koro wachi":                          "bqv",
	"buru (nigeria)":                      "bqw",
	"baangi":                              "bqx",
	"bengkala sign language":              "bqy",
	"bakaka":                              "bqz",
	"braj":                                "bra",
	"lave":                                "brb",
	"berbice creole dutch":                "brc",
	"baraamu":                             "brd",
	"breton":                              "bre",
	"bera":                                "brf",
	"baure":                               "brg",
	"brahui":                              "brh",
	"mokpwe":                              "bri",
	"bieria":                              "brj",
	"birked":                              "brk",
	"birwa":                               "brl",
	"barambu":                             "brm",
	"boruca":                              "brn",
	"brokkat":                             "bro",
	"barapasi":                            "brp",
	"breri":                               "brq",
	"birao":                               "brr",
	"baras":                               "brs",
	"bitare":                              "brt",
	"eastern bru":                         "bru",
	"western bru":                         "brv",
	"bellari":                             "brw",
	"bodo (india)":                        "brx",
	"burui":                               "bry",
	"bilbil":                              "brz",
	"abinomn":                             "bsa",
	"brunei bisaya":                       "bsb",
	"bassari":                             "bsc",
	"wushi":                               "bse",
	"bauchi":                              "bsf",
	"bashkardi":                           "bsg",
	"kati":                                "bsh",
	"bassossi":                            "bsi",
	"bangwinji":                           "bsj",
	"burushaski":                          "bsk",
	"basa-gumna":                          "bsl",
	"busami":                              "bsm",
	"barasana-eduria":                     "bsn",
	"buso":                                "bso",
	"baga sitemu":                         "bsp",
	"bassa":                               "bsq",
	"bassa-kontagora":                     "bsr",
	"akoose":                              "bss",
	"basketo":                             "bst",
	"bahonsuai":                           "bsu",
	"baga sobané":                         "bsv",
	"baiso":                               "bsw",
	"yangkam":                             "bsx",
	"sabah bisaya":                        "bsy",
	"bata":                                "bta",
	"bati (cameroon)":                     "btc",
	"batak dairi":                         "btd",
	"gamo-ningi":                          "bte",
	"birgit":                              "btf",
	"gagnoa bété":                         "btg",
	"biatah bidayuh":                      "bth",
	"burate":                              "bti",
	"bacanese malay":                      "btj",
	"batak mandailing":                    "btm",
	"ratagnon":                            "btn",
	"rinconada bikol":                     "bto",
	"budibud":                             "btp",
	"batek":                               "btq",
	"baetora":                             "btr",
	"batak simalungun":                    "bts",
	"bete-bendi":                          "btt",
	"batu":                                "btu",
	"bateri":                              "btv",
	"butuanon":                            "btw",
	"batak karo":                          "btx",
	"bobot":                               "bty",
	"batak alas-kluet":                    "btz",
	"buriat":                              "bua",
	"bua":                                 "bub",
	"bushi":                               "buc",
	"ntcham":                              "bud",
	"beothuk":                             "bue",
	"bushoong":                            "buf",
	"buginese":                            "bug",
	"younuo bunu":                         "buh",
	"bongili":                             "bui",
	"basa-gurmana":                        "buj",
	"bugawac":                             "buk",
	"bulgarian":                           "bul",
	"bulu (cameroon)":                     "bum",
	"sherbro":                             "bun",
	"terei":                               "buo",
	"busoa":                               "bup",
	"brem":                                "buq",
	"bokobaru":                            "bus",
	"bungain":                             "but",
	"budu":                                "buu",
	"bun":                                 "buv",
	"bubi":                                "buw",
	"boghom":                              "bux",
	"bullom so":                           "buy",
	"bukwen":                              "buz",
	"barein":                              "bva",
	"bube":                                "bvb",
	"baelelea":                            "bvc",
	"baeggu":                              "bvd",
	"berau malay":                         "bve",
	"boor":                                "bvf",
	"bonkeng":                             "bvg",
	"bure":                                "bvh",
	"belanda viri":                        "bvi",
	"baan":                                "bvj",
	"bukat":                               "bvk",
	"bolivian sign language":              "bvl",
	"bamunka":                             "bvm",
	"buna":                                "bvn",
	"bolgo":                               "bvo",
	"bumang":                              "bvp",
	"birri":                               "bvq",
	"burarra":                             "bvr",
	"bati (indonesia)":                    "bvt",
	"bukit malay":                         "bvu",
	"baniva":                              "bvv",
	"boga":                                "bvw",
	"dibole":                              "bvx",
	"baybayanon":                          "bvy",
	"bauzi":                               "bvz",
	"bwatoo":                              "bwa",
	"namosi-naitasiri-serua":              "bwb",
	"bwile":                               "bwc",
	"bwaidoka":                            "bwd",
	"bwe karen":                           "bwe",
	"boselewa":                            "bwf",
	"barwe":                               "bwg",
	"bishuo":                              "bwh",
	"baniwa":                              "bwi",
	"láá láá bwamu":                       "bwj",
	"bauwaki":                             "bwk",
	"bwela":                               "bwl",
	"biwat":                               "bwm",
	"wunai bunu":                          "bwn",
	"boro (ethiopia)":                     "bwo",
	"mandobo bawah":                       "bwp",
	"southern bobo madaré":                "bwq",
	"bura-pabir":                          "bwr",
	"bomboma":                             "bws",
	"bafaw-balong":                        "bwt",
	"buli (ghana)":                        "bwu",
	"bwa":                                 "bww",
	"bu-nao bunu":                         "bwx",
	"cwi bwamu":                           "bwy",
	"bwisi":                               "bwz",
	"tairaha":                             "bxa",
	"belanda bor":                         "bxb",
	"molengue":                            "bxc",
	"pela":                                "bxd",
	"birale":                              "bxe",
	"bilur":                               "bxf",
	"bangala":                             "bxg",
	"buhutu":                              "bxh",
	"pirlatapa":                           "bxi",
	"bayungu":                             "bxj",
	"bukusu":                              "bxk",
	"jalkunan":                            "bxl",
	"mongolia buriat":                     "bxm",
	"burduna":                             "bxn",
	"barikanchi":                          "bxo",
	"bebil":                               "bxp",
	"beele":                               "bxq",
	"russia buriat":                       "bxr",
	"busam":                               "bxs",
	"china buriat":                        "bxu",
	"berakou":                             "bxv",
	"bankagooma":                          "bxw",
	"binahari":                            "bxz",
	"batak":                               "bya",
	"bikya":                               "byb",
	"ubaghara":                            "byc",
	"benyadu'":                            "byd",
	"pouye":                               "bye",
	"bete":                                "byf",
	"baygo":                               "byg",
	"bhujel":                              "byh",
	"buyu":                                "byi",
	"bina (nigeria)":                      "byj",
	"biao":                                "byk",
	"bayono":                              "byl",
	"bidyara":                             "bym",
	"bilin":                               "byn",
	"biyo":                                "byo",
	"bumaji":                              "byp",
	"basay":                               "byq",
	"baruya":                              "byr",
	"burak":                               "bys",
	"berti":                               "byt",
	"medumba":                             "byv",
	"belhariya":                           "byw",
	"qaqet":                               "byx",
	"banaro":                              "byz",
	"bandi":                               "bza",
	"andio":                               "bzb",
	"southern betsimisaraka malagasy":     "bzc",
	"bribri":                              "bzd",
	"jenaama bozo":                        "bze",
	"boikin":                              "bzf",
	"babuza":                              "bzg",
	"mapos buang":                         "bzh",
	"bisu":                                "bzi",
	"belize kriol english":                "bzj",
	"nicaragua creole english":            "bzk",
	"boano (sulawesi)":                    "bzl",
	"bolondo":                             "bzm",
	"boano (maluku)":                      "bzn",
	"bozaba":                              "bzo",
	"kemberano":                           "bzp",
	"buli (indonesia)":                    "bzq",
	"biri":                                "bzr",
	"brazilian sign language":             "bzs",
	"brithenig":                           "bzt",
	"burmeso":                             "bzu",
	"naami":                               "bzv",
	"basa (nigeria)":                      "bzw",
	"kɛlɛngaxo bozo":                      "bzx",
	"obanliku":                            "bzy",
	"evant":                               "bzz",
	"chortí":                              "caa",
	"garifuna":                            "cab",
	"chuj":                                "cac",
	"caddo":                               "cad",
	"lehar":                               "cae",
	"southern carrier":                    "caf",
	"nivaclé":                             "cag",
	"cahuarano":                           "cah",
	"chané":                               "caj",
	"kaqchikel":                           "cak",
	"carolinian":                          "cal",
	"cemuhî":                              "cam",
	"chambri":                             "can",
	"chácobo":                             "cao",
	"chipaya":                             "cap",
	"car nicobarese":                      "caq",
	"galibi carib":                        "car",
	"tsimané":                             "cas",
	"catalan":                             "cat",
	"cavineña":                            "cav",
	"callawalla":                          "caw",
	"chiquitano":                          "cax",
	"cayuga":                              "cay",
	"canichana":                           "caz",
	"cabiyarí":                            "cbb",
	"carapana":                            "cbc",
	"carijona":                            "cbd",
	"chimila":                             "cbg",
	"chachi":                              "cbi",
	"ede cabe":                            "cbj",
	"chavacano":                           "cbk",
	"bualkhaw chin":                       "cbl",
	"nyahkur":                             "cbn",
	"izora":                               "cbo",
	"tsucuba":                             "cbq",
	"cashibo-cacataibo":                   "cbr",
	"cashinahua":                          "cbs",
	"chayahuita":                          "cbt",
	"candoshi-shapra":                     "cbu",
	"cacua":                               "cbv",
	"kinabalian":                          "cbw",
	"carabayo":                            "cby",
	"cauca":                               "cca",
	"chamicuro":                           "ccc",
	"cafundo creole":                      "ccd",
	"chopi":                               "cce",
	"samba daka":                          "ccg",
	"atsam":                               "cch",
	"kasanga":                             "ccj",
	"cutchi-swahili":                      "ccl",
	"malaccan creole malay":               "ccm",
	"comaltepec chinantec":                "cco",
	"chakma":                              "ccp",
	"cacaopera":                           "ccr",
	"choni":                               "cda",
	"chenchu":                             "cde",
	"chiru":                               "cdf",
	"chamari":                             "cdg",
	"chambeali":                           "cdh",
	"chodri":                              "cdi",
	"churahi":                             "cdj",
	"chepang":                             "cdm",
	"chaudangsi":                          "cdn",
	"min dong chinese":                    "cdo",
	"cinda-regi-tiyal":                    "cdr",
	"chadian sign language":               "cds",
	"chadong":                             "cdy",
	"koda":                                "cdz",
	"lower chehalis":                      "cea",
	"cebuano":                             "ceb",
	"chamacoco":                           "ceg",
	"eastern khumi chin":                  "cek",
	"cen":                                 "cen",
	"czech":                               "ces",
	"centúúm":                             "cet",
	"dijim-bwilim":                        "cfa",
	"cara":                                "cfd",
	"como karim":                          "cfg",
	"falam chin":                          "cfm",
	"changriwa":                           "cga",
	"kagayanen":                           "cgc",
	"chiga":                               "cgg",
	"chocangacakha":                       "cgk",
	"chamorro":                            "cha",
	"chibcha":                             "chb",
	"catawba":                             "chc",
	"highland oaxaca chontal":             "chd",
	"chechen":                             "che",
	"tabasco chontal":                     "chf",
	"chagatai":                            "chg",
	"chinook":                             "chh",
	"ojitlán chinantec":                   "chj",
	"chuukese":                            "chk",
	"cahuilla":                            "chl",
	"mari (russia)":                       "chm",
	"chinook jargon":                      "chn",
	"choctaw":                             "cho",
	"chipewyan":                           "chp",
	"quiotepec chinantec":                 "chq",
	"cherokee":                            "chr",
	"cholón":                              "cht",
	"church slavic":                       "chu",
	"chuvash":                             "chv",
	"chuwabu":                             "chw",
	"chantyal":                            "chx",
	"cheyenne":                            "chy",
	"ozumacín chinantec":                  "chz",
	"cia-cia":                             "cia",
	"ci gbe":                              "cib",
	"chickasaw":                           "cic",
	"chimariko":                           "cid",
	"cineni":                              "cie",
	"chinali":                             "cih",
	"chitkuli kinnauri":                   "cik",
	"cimbrian":                            "cim",
	"cinta larga":                         "cin",
	"chiapanec":                           "cip",
	"tiri":                                "cir",
	"chippewa":                            "ciw",
	"chaima":                              "ciy",
	"western cham":                        "cja",
	"chru":                                "cje",
	"upper chehalis":                      "cjh",
	"chamalal":                            "cji",
	"chokwe":                              "cjk",
	"eastern cham":                        "cjm",
	"chenapian":                           "cjn",
	"ashéninka pajonal":                   "cjo",
	"cabécar":                             "cjp",
	"shor":                                "cjs",
	"chuave":                              "cjv",
	"jinyu chinese":                       "cjy",
	"central kurdish":                     "ckb",
	"chak":                                "ckh",
	"cibak":                               "ckl",
	"kaang chin":                          "ckn",
	"anufo":                               "cko",
	"kajakse":                             "ckq",
	"kairak":                              "ckr",
	"tayo":                                "cks",
	"chukot":                              "ckt",
	"koasati":                             "cku",
	"kavalan":                             "ckv",
	"caka":                                "ckx",
	"cakfem-mushere":                      "cky",
	"cakchiquel-quiché mixed language":    "ckz",
	"ron":                                 "cla",
	"chilcotin":                           "clc",
	"chaldean neo-aramaic":                "cld",
	"lealao chinantec":                    "cle",
	"chilisso":                            "clh",
	"chakali":                             "cli",
	"laitu chin":                          "clj",
	"idu-mishmi":                          "clk",
	"chala":                               "cll",
	"clallam":                             "clm",
	"lowland oaxaca chontal":              "clo",
	"lautu chin":                          "clt",
	"caluyanun":                           "clu",
	"chulym":                              "clw",
	"eastern highland chatino":            "cly",
	"maa":                                 "cma",
	"cerma":                               "cme",
	"classical mongolian":                 "cmg",
	"emberá-chamí":                        "cmi",
	"campalagian":                         "cml",
	"michigamea":                          "cmm",
	"mandarin chinese":                    "cmn",
	"central mnong":                       "cmo",
	"mro-khimi chin":                      "cmr",
	"messapic":                            "cms",
	"camtho":                              "cmt",
	"changthang":                          "cna",
	"chinbon chin":                        "cnb",
	"côông":                               "cnc",
	"northern qiang":                      "cng",
	"hakha chin":                          "cnh",
	"asháninka":                           "cni",
	"khumi chin":                          "cnk",
	"lalana chinantec":                    "cnl",
	"con":                                 "cno",
	"central asmat":                       "cns",
	"tepetotutla chinantec":               "cnt",
	"chenoua":                             "cnu",
	"ngawn chin":                          "cnw",
	"middle cornish":                      "cnx",
	"cocos islands malay":                 "coa",
	"chicomuceltec":                       "cob",
	"cocopa":                              "coc",
	"cocama-cocamilla":                    "cod",
	"koreguaje":                           "coe",
	"colorado":                            "cof",
	"chong":                               "cog",
	"chonyi-dzihana-kauma":                "coh",
	"cochimi":                             "coj",
	"santa teresa cora":                   "cok",
	"columbia-wenatchi":                   "col",
	"comanche":                            "com",
	"cofán":                               "con",
	"comox":                               "coo",
	"coptic":                              "cop",
	"coquille":                            "coq",
	"cornish":                             "cor",
	"corsican":                            "cos",
	"caquinte":                            "cot",
	"wamey":                               "cou",
	"cao miao":                            "cov",
	"cowlitz":                             "cow",
	"nanti":                               "cox",
	"chochotec":                           "coz",
	"palantla chinantec":                  "cpa",
	"ucayali-yurúa ashéninka":             "cpb",
	"ajyíninka apurucayali":               "cpc",
	"cappadocian greek":                   "cpg",
	"chinese pidgin english":              "cpi",
	"cherepon":                            "cpn",
	"kpeego":                              "cpo",
	"capiznon":                            "cps",
	"pichis ashéninka":                    "cpu",
	"pu-xian chinese":                     "cpx",
	"south ucayali ashéninka":             "cpy",
	"chuanqiandian cluster miao":          "cqd",
	"chara":                               "cra",
	"island carib":                        "crb",
	"lonwolwol":                           "crc",
	"coeur d'alene":                       "crd",
	"cree":                                "cre",
	"caramanta":                           "crf",
	"michif":                              "crg",
	"crimean tatar":                       "crh",
	"sãotomense":                          "cri",
	"southern east cree":                  "crj",
	"plains cree":                         "crk",
	"northern east cree":                  "crl",
	"moose cree":                          "crm",
	"el nayar cora":                       "crn",
	"crow":                                "cro",
	"iyo'wujwa chorote":                   "crq",
	"carolina algonquian":                 "crr",
	"seselwa creole french":               "crs",
	"iyojwa'ja chorote":                   "crt",
	"chaura":                              "crv",
	"chrau":                               "crw",
	"carrier":                             "crx",
	"cori":                                "cry",
	"cruzeño":                             "crz",
	"chiltepec chinantec":                 "csa",
	"kashubian":                           "csb",
	"catalan sign language":               "csc",
	"chiangmai sign language":             "csd",
	"czech sign language":                 "cse",
	"cuba sign language":                  "csf",
	"chilean sign language":               "csg",
	"asho chin":                           "csh",
	"coast miwok":                         "csi",
	"songlai chin":                        "csj",
	"jola-kasa":                           "csk",
	"chinese sign language":               "csl",
	"central sierra miwok":                "csm",
	"colombian sign language":             "csn",
	"sochiapam chinantec":                 "cso",
	"croatia sign language":               "csq",
	"costa rican sign language":           "csr",
	"southern ohlone":                     "css",
	"northern ohlone":                     "cst",
	"sumtu chin":                          "csv",
	"swampy cree":                         "csw",
	"siyin chin":                          "csy",
	"coos":                                "csz",
	"tataltepec chatino":                  "cta",
	"chetco":                              "ctc",
	"tedim chin":                          "ctd",
	"tepinapa chinantec":                  "cte",
	"chittagonian":                        "ctg",
	"thaiphum chin":                       "cth",
	"tlacoatzintepec chinantec":           "ctl",
	"chitimacha":                          "ctm",
	"chhintange":                          "ctn",
	"emberá-catío":                        "cto",
	"western highland chatino":            "ctp",
	"northern catanduanes bikol":          "cts",
	"wayanad chetti":                      "ctt",
	"chol":                                "ctu",
	"zacatepec chatino":                   "ctz",
	"cua":                                 "cua",
	"cubeo":                               "cub",
	"usila chinantec":                     "cuc",
	"chungmboko":                          "cug",
	"chuka":                               "cuh",
	"cuiba":                               "cui",
	"mashco piro":                         "cuj",
	"san blas kuna":                       "cuk",
	"culina":                              "cul",
	"cumanagoto":                          "cuo",
	"cupeño":                              "cup",
	"cun":                                 "cuq",
	"chhulung":                            "cur",
	"teutila cuicatec":                    "cut",
	"tai ya":                              "cuu",
	"cuvok":                               "cuv",
	"chukwa":                              "cuw",
	"tepeuxila cuicatec":                  "cux",
	"chug":                                "cvg",
	"valle nacional chinantec":            "cvn",
	"kabwa":                               "cwa",
	"maindo":                              "cwb",
	"woods cree":                          "cwd",
	"kwere":                               "cwe",
	"chewong":                             "cwg",
	"kuwaataay":                           "cwt",
	"nopala chatino":                      "cya",
	"cayubaba":                            "cyb",
	"welsh":                               "cym",
	"cuyonon":                             "cyo",
	"huizhou chinese":                     "czh",
	"knaanic":                             "czk",
	"zenzontepec chatino":                 "czn",
	"min zhong chinese":                   "czo",
	"zotung chin":                         "czt",
	"dangaléat":                           "daa",
	"dambi":                               "dac",
	"marik":                               "dad",
	"duupa":                               "dae",
	"dagbani":                             "dag",
	"gwahatike":                           "dah",
	"day":                                 "dai",
	"dar fur daju":                        "daj",
	"dakota":                              "dak",
	"dahalo":                              "dal",
	"damakawa":                            "dam",
	"danish":                              "dan",
	"daai chin":                           "dao",
	"dandami maria":                       "daq",
	"dargwa":                              "dar",
	"daho-doo":                            "das",
	"dar sila daju":                       "dau",
	"taita":                               "dav",
	"davawenyo":                           "daw",
	"dayi":                                "dax",
	"dao":                                 "daz",
	"bangime":                             "dba",
	"deno":                                "dbb",
	"dadiya":                              "dbd",
	"dabe":                                "dbe",
	"edopi":                               "dbf",
	"dogul dom dogon":                     "dbg",
	"doka":                                "dbi",
	"ida'an":                              "dbj",
	"dyirbal":                             "dbl",
	"duguri":                              "dbm",
	"duriankere":                          "dbn",
	"dulbu":                               "dbo",
	"duwai":                               "dbp",
	"daba":                                "dbq",
	"dabarre":                             "dbr",
	"ben tey dogon":                       "dbt",
	"bondum dom dogon":                    "dbu",
	"dungu":                               "dbv",
	"bankan tey dogon":                    "dbw",
	"dibiyaso":                            "dby",
	"deccan":                              "dcc",
	"negerhollands":                       "dcr",
	"dadi dadi":                           "dda",
	"dongotono":                           "ddd",
	"doondo":                              "dde",
	"fataluku":                            "ddg",
	"west goodenough":                     "ddi",
	"jaru":                                "ddj",
	"dendi (benin)":                       "ddn",
	"dido":                                "ddo",
	"dhudhuroa":                           "ddr",
	"donno so dogon":                      "dds",
	"dawera-daweloor":                     "ddw",
	"dagik":                               "dec",
	"dedua":                               "ded",
	"dewoin":                              "dee",
	"dezfuli":                             "def",
	"degema":                              "deg",
	"dehwari":                             "deh",
	"demisa":                              "dei",
	"dek":                                 "dek",
	"delaware":                            "del",
	"dem":                                 "dem",
	"slave (athapascan)":                  "den",
	"pidgin delaware":                     "dep",
	"dendi (central african republic)":    "deq",
	"deori":                               "der",
	"desano":                              "des",
	"german":                              "deu",
	"domung":                              "dev",
	"dengese":                             "dez",
	"southern dagaare":                    "dga",
	"bunoge dogon":                        "dgb",
	"casiguran dumagat agta":              "dgc",
	"dagaari dioula":                      "dgd",
	"degenan":                             "dge",
	"doga":                                "dgg",
	"dghwede":                             "dgh",
	"northern dagara":                     "dgi",
	"dagba":                               "dgk",
	"andaandi":                            "dgl",
	"dagoman":                             "dgn",
	"dogri (individual language)":         "dgo",
	"dogrib":                              "dgr",
	"dogoso":                              "dgs",
	"ndra'ngith":                          "dgt",
	"degaru":                              "dgu",
	"daungwurrung":                        "dgw",
	"doghoro":                             "dgx",
	"daga":                                "dgz",
	"dhundari":                            "dhd",
	"dhangu-djangu":                       "dhg",
	"dhimal":                              "dhi",
	"dhalandji":                           "dhl",
	"zemba":                               "dhm",
	"dhanki":                              "dhn",
	"dhodia":                              "dho",
	"dhargari":                            "dhr",
	"dhaiso":                              "dhs",
	"dhurga":                              "dhu",
	"dehu":                                "dhv",
	"dhanwar (nepal)":                     "dhw",
	"dhungaloo":                           "dhx",
	"dia":                                 "dia",
	"south central dinka":                 "dib",
	"lakota dida":                         "dic",
	"didinga":                             "did",
	"dieri":                               "dif",
	"digo":                                "dig",
	"kumiai":                              "dih",
	"dimbong":                             "dii",
	"dai":                                 "dij",
	"southwestern dinka":                  "dik",
	"dilling":                             "dil",
	"dime":                                "dim",
	"dinka":                               "din",
	"dibo":                                "dio",
	"northeastern dinka":                  "dip",
	"dimli (individual language)":         "diq",
	"dirim":                               "dir",
	"dimasa":                              "dis",
	"dirari":                              "dit",
	"diriku":                              "diu",
	"dhivehi":                             "div",
	"northwestern dinka":                  "diw",
	"dixon reef":                          "dix",
	"diuwe":                               "diy",
	"ding":                                "diz",
	"djadjawurrung":                       "dja",
	"djinba":                              "djb",
	"dar daju daju":                       "djc",
	"djamindjung":                         "djd",
	"zarma":                               "dje",
	"djangun":                             "djf",
	"djinang":                             "dji",
	"djeebbana":                           "djj",
	"eastern maroon creole":               "djk",
	"jamsay dogon":                        "djm",
	"djauan":                              "djn",
	"jangkang":                            "djo",
	"djambarrpuyngu":                      "djr",
	"kapriman":                            "dju",
	"djawi":                               "djw",
	"dakpakha":                            "dka",
	"dakka":                               "dkk",
	"kuijau":                              "dkr",
	"southeastern dinka":                  "dks",
	"mazagway":                            "dkx",
	"dolgan":                              "dlg",
	"dahalik":                             "dlk",
	"dalmatian":                           "dlm",
	"darlong":                             "dln",
	"duma":                                "dma",
	"mombo dogon":                         "dmb",
	"gavak":                               "dmc",
	"madhi madhi":                         "dmd",
	"dugwor":                              "dme",
	"upper kinabatangan":                  "dmg",
	"domaaki":                             "dmk",
	"dameli":                              "dml",
	"dama":                                "dmm",
	"kemedzung":                           "dmo",
	"east damar":                          "dmr",
	"dampelas":                            "dms",
	"dubu":                                "dmu",
	"dumpas":                              "dmv",
	"mudburra":                            "dmw",
	"dema":                                "dmx",
	"demta":                               "dmy",
	"upper grand valley dani":             "dna",
	"daonda":                              "dnd",
	"ndendeule":                           "dne",
	"dungan":                              "dng",
	"lower grand valley dani":             "dni",
	"dan":                                 "dnj",
	"dengka":                              "dnk",
	"dzùùngoo":                            "dnn",
	"danaru":                              "dnr",
	"mid grand valley dani":               "dnt",
	"danau":                               "dnu",
	"danu":                                "dnv",
	"western dani":                        "dnw",
	"dení":                                "dny",
	"dom":                                 "doa",
	"dobu":                                "dob",
	"northern dong":                       "doc",
	"doe":                                 "doe",
	"domu":                                "dof",
	"dong":                                "doh",
	"dogri (macrolanguage)":               "doi",
	"dondo":                               "dok",
	"doso":                                "dol",
	"toura (papua new guinea)":            "don",
	"dongo":                               "doo",
	"lukpa":                               "dop",
	"dominican sign language":             "doq",
	"dori'o":                              "dor",
	"dogosé":                              "dos",
	"dass":                                "dot",
	"dombe":                               "dov",
	"doyayo":                              "dow",
	"bussa":                               "dox",
	"dompo":                               "doy",
	"dorze":                               "doz",
	"papar":                               "dpp",
	"dair":                                "drb",
	"minderico":                           "drc",
	"darmiya":                             "drd",
	"dolpo":                               "dre",
	"rungus":                              "drg",
	"c'lela":                              "dri",
	"paakantyi":                           "drl",
	"west damar":                          "drn",
	"daro-matu melanau":                   "dro",
	"dura":                                "drq",
	"dororo":                              "drr",
	"gedeo":                               "drs",
	"drents":                              "drt",
	"rukai":                               "dru",
	"darai":                               "dry",
	"lower sorbian":                       "dsb",
	"dutch sign language":                 "dse",
	"daasanach":                           "dsh",
	"disa":                                "dsi",
	"danish sign language":                "dsl",
	"dusner":                              "dsn",
	"desiya":                              "dso",
	"tadaksahak":                          "dsq",
	"daur":                                "dta",
	"labuk-kinabatangan kadazan":          "dtb",
	"ditidaht":                            "dtd",
	"adithinngithigh":                     "dth",
	"ana tinga dogon":                     "dti",
	"tene kan dogon":                      "dtk",
	"tomo kan dogon":                      "dtm",
	"daatsʼíin":                          "dtn",
	"tommo so dogon":                      "dto",
	"kadazan dusun":                       "dtp",
	"lotud":                               "dtr",
	"toro so dogon":                       "dts",
	"toro tegu dogon":                     "dtt",
	"tebul ure dogon":                     "dtu",
	"dotyali":                             "dty",
	"duala":                               "dua",
	"dubli":                               "dub",
	"duna":                                "duc",
	"hun-saare":                           "dud",
	"umiray dumaget agta":                 "due",
	"dumbea":                              "duf",
	"duruma":                              "dug",
	"dungra bhil":                         "duh",
	"dumun":                               "dui",
	"uyajitaya":                           "duk",
	"alabat island agta":                  "dul",
	"middle dutch (ca. 1050-1350)":        "dum",
	"dusun deyah":                         "dun",
	"dupaninan agta":                      "duo",
	"duano":                               "dup",
	"dusun malang":                        "duq",
	"dii":                                 "dur",
	"dumi":                                "dus",
	"drung":                               "duu",
	"duvle":                               "duv",
	"dusun witu":                          "duw",
	"duungooma":                           "dux",
	"dicamay agta":                        "duy",
	"duli-gey":                            "duz",
	"duau":                                "dva",
	"diri":                                "dwa",
	"dawro":                               "dwr",
	"dutton world speedwords":             "dws",
	"dhuwal":                              "dwu",
	"dawawa":                              "dww",
	"dhuwaya":                             "dwy",
	"dyan":                                "dya",
	"dyaberdyaber":                        "dyb",
	"dyugun":                              "dyd",
	"villa viciosa agta":                  "dyg",
	"djimini senoufo":                     "dyi",
	"yanda dom dogon":                     "dym",
	"dyangadi":                            "dyn",
	"jola-fonyi":                          "dyo",
	"dyula":                               "dyu",
	"dyaabugay":                           "dyy",
	"tunzu":                               "dza",
	"djiwarli":                            "dze",
	"dazaga":                              "dzg",
	"dzalakha":                            "dzl",
	"dzando":                              "dzn",
	"dzongkha":                            "dzo",
	"karenggapa":                          "eaa",
	"ebughu":                              "ebg",
	"eastern bontok":                      "ebk",
	"teke-ebo":                            "ebo",
	"ebrié":                               "ebr",
	"embu":                                "ebu",
	"eteocretan":                          "ecr",
	"ecuadorian sign language":            "ecs",
	"eteocypriot":                         "ecy",
	"e":                                   "eee",
	"efai":                                "efa",
	"efe":                                 "efe",
	"efik":                                "efi",
	"ega":                                 "ega",
	"emilian":                             "egl",
	"eggon":                               "ego",
	"egyptian (ancient)":                  "egy",
	"ehueun":                              "ehu",
	"eipomek":                             "eip",
	"eitiep":                              "eit",
	"askopan":                             "eiv",
	"ejamat":                              "eja",
	"ekajuk":                              "eka",
	"eastern karnic":                      "ekc",
	"ekit":                                "eke",
	"ekari":                               "ekg",
	"eki":                                 "eki",
	"standard estonian":                   "ekk",
	"kol (bangladesh)":                    "ekl",
	"elip":                                "ekm",
	"koti":                                "eko",
	"ekpeye":                              "ekp",
	"yace":                                "ekr",
	"eastern kayah":                       "eky",
	"elepi":                               "ele",
	"el hugeirat":                         "elh",
	"nding":                               "eli",
	"elkei":                               "elk",
	"modern greek (1453-)":                "ell",
	"eleme":                               "elm",
	"el molo":                             "elo",
	"elu":                                 "elu",
	"elamite":                             "elx",
	"emai-iuleha-ora":                     "ema",
	"embaloh":                             "emb",
	"emerillon":                           "eme",
	"eastern meohang":                     "emg",
	"mussau-emira":                        "emi",
	"eastern maninkakan":                  "emk",
	"mamulique":                           "emm",
	"eman":                                "emn",
	"northern emberá":                     "emp",
	"pacific gulf yupik":                  "ems",
	"eastern muria":                       "emu",
	"emplawas":                            "emw",
	"erromintxela":                        "emx",
	"epigraphic mayan":                    "emy",
	"apali":                               "ena",
	"markweeta":                           "enb",
	"en":                                  "enc",
	"ende":                                "end",
	"forest enets":                        "enf",
	"english":                             "eng",
	"tundra enets":                        "enh",
	"enlhet":                              "enl",
	"middle english (1100-1500)":          "enm",
	"engenni":                             "enn",
	"enggano":                             "eno",
	"enga":                                "enq",
	"emumu":                               "enr",
	"enu":                                 "enu",
	"enwan (edu state)":                   "env",
	"enwan (akwa ibom state)":             "enw",
	"enxet":                               "enx",
	"beti (côte d'ivoire)":                "eot",
	"epie":                                "epi",
	"esperanto":                           "epo",
	"eravallan":                           "era",
	"sie":                                 "erg",
	"eruwa":                               "erh",
	"ogea":                                "eri",
	"south efate":                         "erk",
	"horpa":                               "ero",
	"erre":                                "err",
	"ersu":                                "ers",
	"eritai":                              "ert",
	"erokwanas":                           "erw",
	"ese ejja":                            "ese",
	"aheri gondi":                         "esg",
	"eshtehardi":                          "esh",
	"north alaskan inupiatun":             "esi",
	"northwest alaska inupiatun":          "esk",
	"egypt sign language":                 "esl",
	"esuma":                               "esm",
	"salvadoran sign language":            "esn",
	"estonian sign language":              "eso",
	"esselen":                             "esq",
	"central siberian yupik":              "ess",
	"estonian":                            "est",
	"central yupik":                       "esu",
	"eskayan":                             "esy",
	"etebi":                               "etb",
	"etchemin":                            "etc",
	"ethiopian sign language":             "eth",
	"eton (vanuatu)":                      "etn",
	"eton (cameroon)":                     "eto",
	"edolo":                               "etr",
	"yekhee":                              "ets",
	"etruscan":                            "ett",
	"ejagham":                             "etu",
	"eten":                                "etx",
	"semimi":                              "etz",
	"basque":                              "eus",
	"even":                                "eve",
	"uvbie":                               "evh",
	"evenki":                              "evn",
	"ewe":                                 "ewe",
	"ewondo":                              "ewo",
	"extremaduran":                        "ext",
	"eyak":                                "eya",
	"keiyo":                               "eyo",
	"ezaa":                                "eza",
	"uzekwe":                              "eze",
	"fasu":                                "faa",
	"fa d'ambu":                           "fab",
	"wagi":                                "fad",
	"fagani":                              "faf",
	"finongan":                            "fag",
	"baissa fali":                         "fah",
	"faiwol":                              "fai",
	"faita":                               "faj",
	"fang (cameroon)":                     "fak",
	"south fali":                          "fal",
	"fam":                                 "fam",
	"fang (equatorial guinea)":            "fan",
	"faroese":                             "fao",
	"palor":                               "fap",
	"fataleka":                            "far",
	"persian":                             "fas",
	"fanti":                               "fat",
	"fayu":                                "fau",
	"fala":                                "fax",
	"southwestern fars":                   "fay",
	"northwestern fars":                   "faz",
	"west albay bikol":                    "fbl",
	"quebec sign language":                "fcs",
	"feroge":                              "fer",
	"foia foia":                           "ffi",
	"maasina fulfulde":                    "ffm",
	"fongoro":                             "fgr",
	"nobiin":                              "fia",
	"fyer":                                "fie",
	"fijian":                              "fij",
	"filipino":                            "fil",
	"finnish":                             "fin",
	"fipa":                                "fip",
	"firan":                               "fir",
	"tornedalen finnish":                  "fit",
	"fiwaga":                              "fiw",
	"kirya-konzəl":                        "fkk",
	"kven finnish":                        "fkv",
	"kalispel-pend d'oreille":             "fla",
	"foau":                                "flh",
	"fali":                                "fli",
	"north fali":                          "fll",
	"flinders island":                     "fln",
	"fuliiru":                             "flr",
	"flaaitaal":                           "fly",
	"fe'fe'":                              "fmp",
	"far western muria":                   "fmu",
	"fanbak":                              "fnb",
	"fanagalo":                            "fng",
	"fania":                               "fni",
	"foodo":                               "fod",
	"foi":                                 "foi",
	"foma":                                "fom",
	"fon":                                 "fon",
	"fore":                                "for",
	"siraya":                              "fos",
	"fernando po creole english":          "fpe",
	"fas":                                 "fqs",
	"french":                              "fra",
	"cajun french":                        "frc",
	"fordata":                             "frd",
	"frankish":                            "frk",
	"middle french (ca. 1400-1600)":       "frm",
	"old french (842-ca. 1400)":           "fro",
	"arpitan":                             "frp",
	"forak":                               "frq",
	"northern frisian":                    "frr",
	"eastern frisian":                     "frs",
	"fortsenal":                           "frt",
	"western frisian":                     "fry",
	"finnish sign language":               "fse",
	"french sign language":                "fsl",
	"finland-swedish sign language":       "fss",
	"adamawa fulfulde":                    "fub",
	"pulaar":                              "fuc",
	"east futuna":                         "fud",
	"borgu fulfulde":                      "fue",
	"pular":                               "fuf",
	"western niger fulfulde":              "fuh",
	"bagirmi fulfulde":                    "fui",
	"ko":                                  "fuj",
	"fulah":                               "ful",
	"fum":                                 "fum",
	"fulniô":                              "fun",
	"central-eastern niger fulfulde":      "fuq",
	"friulian":                            "fur",
	"futuna-aniwa":                        "fut",
	"furu":                                "fuu",
	"nigerian fulfulde":                   "fuv",
	"fuyug":                               "fuy",
	"fur":                                 "fvr",
	"fwâi":                                "fwa",
	"fwe":                                 "fwe",
	"ga":                                  "gaa",
	"gabri":                               "gab",
	"mixed great andamanese":              "gac",
	"gaddang":                             "gad",
	"guarequena":                          "gae",
	"gende":                               "gaf",
	"gagauz":                              "gag",
	"alekano":                             "gah",
	"borei":                               "gai",
	"gadsup":                              "gaj",
	"gamkonora":                           "gak",
	"galolen":                             "gal",
	"kandawo":                             "gam",
	"gan chinese":                         "gan",
	"gants":                               "gao",
	"gal":                                 "gap",
	"gata'":                               "gaq",
	"galeya":                              "gar",
	"adiwasi garasia":                     "gas",
	"kenati":                              "gat",
	"mudhili gadaba":                      "gau",
	"nobonob":                             "gaw",
	"borana-arsi-guji oromo":              "gax",
	"gayo":                                "gay",
	"west central oromo":                  "gaz",
	"gbaya (central african republic)":    "gba",
	"kaytetye":                            "gbb",
	"karadjeri":                           "gbd",
	"niksek":                              "gbe",
	"gaikundi":                            "gbf",
	"gbanziri":                            "gbg",
	"defi gbe":                            "gbh",
	"galela":                              "gbi",
	"bodo gadaba":                         "gbj",
	"gaddi":                               "gbk",
	"gamit":                               "gbl",
	"garhwali":                            "gbm",
	"mo'da":                               "gbn",
	"northern grebo":                      "gbo",
	"gbaya-bossangoa":                     "gbp",
	"gbaya-bozoum":                        "gbq",
	"gbagyi":                              "gbr",
	"gbesi gbe":                           "gbs",
	"gagadu":                              "gbu",
	"gbanu":                               "gbv",
	"gabi-gabi":                           "gbw",
	"eastern xwla gbe":                    "gbx",
	"gbari":                               "gby",
	"zoroastrian dari":                    "gbz",
	"mali":                                "gcc",
	"ganggalida":                          "gcd",
	"galice":                              "gce",
	"guadeloupean creole french":          "gcf",
	"grenadian creole english":            "gcl",
	"gaina":                               "gcn",
	"guianese creole french":              "gcr",
	"colonia tovar german":                "gct",
	"gade lohar":                          "gda",
	"pottangi ollar gadaba":               "gdb",
	"gugu badhun":                         "gdc",
	"gedaged":                             "gdd",
	"gude":                                "gde",
	"guduf-gava":                          "gdf",
	"ga'dang":                             "gdg",
	"gadjerawang":                         "gdh",
	"gundi":                               "gdi",
	"gurdjar":                             "gdj",
	"gadang":                              "gdk",
	"dirasha":                             "gdl",
	"laal":                                "gdm",
	"umanakaina":                          "gdn",
	"ghodoberi":                           "gdo",
	"mehri":                               "gdq",
	"wipi":                                "gdr",
	"ghandruk sign language":              "gds",
	"kungardutyi":                         "gdt",
	"gudu":                                "gdu",
	"godwari":                             "gdx",
	"geruma":                              "gea",
	"kire":                                "geb",
	"gboloo grebo":                        "gec",
	"gade":                                "ged",
	"gengle":                              "geg",
	"hutterite german":                    "geh",
	"gebe":                                "gei",
	"gen":                                 "gej",
	"ywom":                                "gek",
	"ut-ma'in":                            "gel",
	"geme":                                "geq",
	"geser-gorom":                         "ges",
	"eviya":                               "gev",
	"gera":                                "gew",
	"garre":                               "gex",
	"enya":                                "gey",
	"geez":                                "gez",
	"patpatar":                            "gfk",
	"gafat":                               "gft",
	"gao":                                 "gga",
	"gbii":                                "ggb",
	"gugadj":                              "ggd",
	"guragone":                            "gge",
	"gurgula":                             "ggg",
	"kungarakany":                         "ggk",
	"ganglau":                             "ggl",
	"gitua":                               "ggt",
	"gagu":                                "ggu",
	"gogodala":                            "ggw",
	"ghadamès":                            "gha",
	"hiberno-scottish gaelic":             "ghc",
	"southern ghale":                      "ghe",
	"northern ghale":                      "ghh",
	"geko karen":                          "ghk",
	"ghulfan":                             "ghl",
	"ghanongga":                           "ghn",
	"ghomara":                             "gho",
	"ghera":                               "ghr",
	"guhu-samane":                         "ghs",
	"kuke":                                "ght",
	"kitja":                               "gia",
	"gibanawa":                            "gib",
	"gail":                                "gic",
	"gidar":                               "gid",
	"gaɓogbo":                             "gie",
	"goaria":                              "gig",
	"githabul":                            "gih",
	"gilbertese":                          "gil",
	"gimi (eastern highlands)":            "gim",
	"hinukh":                              "gin",
	"gimi (west new britain)":             "gip",
	"green gelao":                         "giq",
	"red gelao":                           "gir",
	"north giziga":                        "gis",
	"gitxsan":                             "git",
	"mulao":                               "giu",
	"white gelao":                         "giw",
	"gilima":                              "gix",
	"giyug":                               "giy",
	"south giziga":                        "giz",
	"geji":                                "gji",
	"kachi koli":                          "gjk",
	"gunditjmara":                         "gjm",
	"gonja":                               "gjn",
	"gurindji kriol":                      "gjr",
	"gujari":                              "gju",
	"guya":                                "gka",
	"ndai":                                "gke",
	"gokana":                              "gkn",
	"kok-nar":                             "gko",
	"guinea kpelle":                       "gkp",
	"ǂungkue":                             "gku",
	"scottish gaelic":                     "gla",
	"bon gula":                            "glc",
	"nanai":                               "gld",
	"irish":                               "gle",
	"galician":                            "glg",
	"northwest pashai":                    "glh",
	"guliguli":                            "gli",
	"gula iro":                            "glj",
	"gilaki":                              "glk",
	"garlali":                             "gll",
	"galambu":                             "glo",
	"glaro-twabo":                         "glr",
	"gula (chad)":                         "glu",
	"manx":                                "glv",
	"glavda":                              "glw",
	"gule":                                "gly",
	"gambera":                             "gma",
	"gula'alaa":                           "gmb",
	"mághdì":                              "gmd",
	"magɨyi":                              "gmg",
	"middle high german (ca. 1050-1500)":  "gmh",
	"middle low german":                   "gml",
	"gbaya-mbodomo":                       "gmm",
	"gimnime":                             "gmn",
	"gumalu":                              "gmu",
	"gamo":                                "gmv",
	"magoma":                              "gmx",
	"mycenaean greek":                     "gmy",
	"mgbolizhia":                          "gmz",
	"kaansa":                              "gna",
	"gangte":                              "gnb",
	"guanche":                             "gnc",
	"zulgo-gemzek":                        "gnd",
	"ganang":                              "gne",
	"ngangam":                             "gng",
	"lere":                                "gnh",
	"gooniyandi":                          "gni",
	"//gana":                              "gnk",
	"gangulu":                             "gnl",
	"ginuman":                             "gnm",
	"gumatj":                              "gnn",
	"northern gondi":                      "gno",
	"gana":                                "gnq",
	"gureng gureng":                       "gnr",
	"guntai":                              "gnt",
	"gnau":                                "gnu",
	"western bolivian guaraní":            "gnw",
	"ganzi":                               "gnz",
	"guro":                                "goa",
	"playero":                             "gob",
	"gorakor":                             "goc",
	"godié":                               "god",
	"gongduk":                             "goe",
	"gofa":                                "gof",
	"gogo":                                "gog",
	"old high german (ca. 750-1050)":      "goh",
	"gobasi":                              "goi",
	"gowlan":                              "goj",
	"gowli":                               "gok",
	"gola":                                "gol",
	"goan konkani":                        "gom",
	"gondi":                               "gon",
	"gone dau":                            "goo",
	"yeretuar":                            "gop",
	"gorap":                               "goq",
	"gorontalo":                           "gor",
	"gronings":                            "gos",
	"gothic":                              "got",
	"gavar":                               "gou",
	"gorowa":                              "gow",
	"gobu":                                "gox",
	"goundo":                              "goy",
	"gozarkhani":                          "goz",
	"gupa-abawa":                          "gpa",
	"ghanaian pidgin english":             "gpe",
	"taiap":                               "gpn",
	"ga'anda":                             "gqa",
	"guiqiong":                            "gqi",
	"guana (brazil)":                      "gqn",
	"gor":                                 "gqr",
	"qau":                                 "gqu",
	"rajput garasia":                      "gra",
	"grebo":                               "grb",
	"ancient greek (to 1453)":             "grc",
	"guruntum-mbaaru":                     "grd",
	"madi":                                "grg",
	"gbiri-niragu":                        "grh",
	"ghari":                               "gri",
	"southern grebo":                      "grj",
	"kota marudu talantang":               "grm",
	"guarani":                             "grn",
	"groma":                               "gro",
	"gorovu":                              "grq",
	"taznatit":                            "grr",
	"gresi":                               "grs",
	"garo":                                "grt",
	"kistane":                             "gru",
	"central grebo":                       "grv",
	"gweda":                               "grw",
	"guriaso":                             "grx",
	"barclayville grebo":                  "gry",
	"guramalum":                           "grz",
	"ghanaian sign language":              "gse",
	"german sign language":                "gsg",
	"gusilay":                             "gsl",
	"guatemalan sign language":            "gsm",
	"nema":                                "gsn",
	"southwest gbaya":                     "gso",
	"wasembo":                             "gsp",
	"greek sign language":                 "gss",
	"swiss german":                        "gsw",
	"guató":                               "gta",
	"aghu-tharnggala":                     "gtu",
	"shiki":                               "gua",
	"guajajára":                           "gub",
	"wayuu":                               "guc",
	"yocoboué dida":                       "gud",
	"gurinji":                             "gue",
	"gupapuyngu":                          "guf",
	"paraguayan guaraní":                  "gug",
	"guahibo":                             "guh",
	"eastern bolivian guaraní":            "gui",
	"gujarati":                            "guj",
	"gumuz":                               "guk",
	"sea island creole english":           "gul",
	"guambiano":                           "gum",
	"mbyá guaraní":                        "gun",
	"guayabero":                           "guo",
	"gunwinggu":                           "gup",
	"aché":                                "guq",
	"farefare":                            "gur",
	"guinean sign language":               "gus",
	"maléku jaíka":                        "gut",
	"yanomamö":                            "guu",
	"gun":                                 "guw",
	"gourmanchéma":                        "gux",
	"gusii":                               "guz",
	"guana (paraguay)":                    "gva",
	"guanano":                             "gvc",
	"duwet":                               "gve",
	"golin":                               "gvf",
	"guajá":                               "gvj",
	"gulay":                               "gvl",
	"gurmana":                             "gvm",
	"kuku-yalanji":                        "gvn",
	"gavião do jiparaná":                  "gvo",
	"pará gavião":                         "gvp",
	"gurung":                              "gvr",
	"gumawana":                            "gvs",
	"guyani":                              "gvy",
	"mbato":                               "gwa",
	"gwa":                                 "gwb",
	"kalami":                              "gwc",
	"gawwada":                             "gwd",
	"gweno":                               "gwe",
	"gowro":                               "gwf",
	"moo":                                 "gwg",
	"gwichʼin":                            "gwi",
	"/gwi":                                "gwj",
	"awngthim":                            "gwm",
	"gwandara":                            "gwn",
	"gwere":                               "gwr",
	"gawar-bati":                          "gwt",
	"guwamu":                              "gwu",
	"kwini":                               "gww",
	"gua":                                 "gwx",
	"wè southern":                         "gxx",
	"northwest gbaya":                     "gya",
	"garus":                               "gyb",
	"kayardild":                           "gyd",
	"gyem":                                "gye",
	"gungabula":                           "gyf",
	"gbayi":                               "gyg",
	"gyele":                               "gyi",
	"gayil":                               "gyl",
	"ngäbere":                             "gym",
	"guyanese creole english":             "gyn",
	"guarayu":                             "gyr",
	"gunya":                               "gyy",
	"ganza":                               "gza",
	"gazi":                                "gzi",
	"gane":                                "gzn",
	"han":                                 "haa",
	"hanoi sign language":                 "hab",
	"gurani":                              "hac",
	"hatam":                               "had",
	"eastern oromo":                       "hae",
	"haiphong sign language":              "haf",
	"hanga":                               "hag",
	"hahon":                               "hah",
	"haida":                               "hai",
	"hajong":                              "haj",
	"hakka chinese":                       "hak",
	"halang":                              "hal",
	"hewa":                                "ham",
	"hangaza":                             "han",
	"hakö":                                "hao",
	"hupla":                               "hap",
	"ha":                                  "haq",
	"harari":                              "har",
	"haisla":                              "has",
	"haitian":                             "hat",
	"hausa":                               "hau",
	"havu":                                "hav",
	"hawaiian":                            "haw",
	"southern haida":                      "hax",
	"haya":                                "hay",
	"hazaragi":                            "haz",
	"hamba":                               "hba",
	"huba":                                "hbb",
	"heiban":                              "hbn",
	"ancient hebrew":                      "hbo",
	"serbo-croatian":                      "hbs",
	"habu":                                "hbu",
	"andaman creole hindi":                "hca",
	"huichol":                             "hch",
	"northern haida":                      "hdn",
	"honduras sign language":              "hds",
	"hadiyya":                             "hdy",
	"northern qiandong miao":              "hea",
	"hebrew":                              "heb",
	"herdé":                               "hed",
	"helong":                              "heg",
	"hehe":                                "heh",
	"heiltsuk":                            "hei",
	"hemba":                               "hem",
	"herero":                              "her",
	"hai//om":                             "hgm",
	"haigwai":                             "hgw",
	"hoia hoia":                           "hhi",
	"kerak":                               "hhr",
	"hoyahoya":                            "hhy",
	"lamang":                              "hia",
	"hibito":                              "hib",
	"hidatsa":                             "hid",
	"fiji hindi":                          "hif",
	"kamwe":                               "hig",
	"pamosu":                              "hih",
	"hinduri":                             "hii",
	"hijuk":                               "hij",
	"seit-kaitetu":                        "hik",
	"hiligaynon":                          "hil",
	"hindi":                               "hin",
	"tsoa":                                "hio",
	"himarimã":                            "hir",
	"hittite":                             "hit",
	"hiw":                                 "hiw",
	"hixkaryána":                          "hix",
	"haji":                                "hji",
	"kahe":                                "hka",
	"hunde":                               "hke",
	"hunjara-kaina ke":                    "hkk",
	"hong kong sign language":             "hks",
	"halia":                               "hla",
	"halbi":                               "hlb",
	"halang doan":                         "hld",
	"hlersu":                              "hle",
	"matu chin":                           "hlt",
	"hieroglyphic luwian":                 "hlu",
	"southern mashan hmong":               "hma",
	"humburi senni songhay":               "hmb",
	"central huishui hmong":               "hmc",
	"large flowery miao":                  "hmd",
	"eastern huishui hmong":               "hme",
	"hmong don":                           "hmf",
	"southwestern guiyang hmong":          "hmg",
	"southwestern huishui hmong":          "hmh",
	"northern huishui hmong":              "hmi",
	"ge":                                  "hmj",
	"maek":                                "hmk",
	"luopohe hmong":                       "hml",
	"central mashan hmong":                "hmm",
	"hmong":                               "hmn",
	"hiri motu":                           "hmo",
	"northern mashan hmong":               "hmp",
	"eastern qiandong miao":               "hmq",
	"hmar":                                "hmr",
	"southern qiandong miao":              "hms",
	"hamtai":                              "hmt",
	"hamap":                               "hmu",
	"hmong dô":                            "hmv",
	"western mashan hmong":                "hmw",
	"southern guiyang hmong":              "hmy",
	"hmong shua":                          "hmz",
	"mina (cameroon)":                     "hna",
	"southern hindko":                     "hnd",
	"chhattisgarhi":                       "hne",
	"//ani":                               "hnh",
	"hani":                                "hni",
	"hmong njua":                          "hnj",
	"hanunoo":                             "hnn",
	"northern hindko":                     "hno",
	"caribbean hindustani":                "hns",
	"hung":                                "hnu",
	"hoava":                               "hoa",
	"mari (madang province)":              "hob",
	"ho":                                  "hoc",
	"holma":                               "hod",
	"horom":                               "hoe",
	"hobyót":                              "hoh",
	"holikachuk":                          "hoi",
	"hadothi":                             "hoj",
	"holu":                                "hol",
	"homa":                                "hom",
	"holoholo":                            "hoo",
	"hopi":                                "hop",
	"horo":                                "hor",
	"ho chi minh city sign language":      "hos",
	"hote":                                "hot",
	"hovongan":                            "hov",
	"honi":                                "how",
	"holiya":                              "hoy",
	"hozo":                                "hoz",
	"hpon":                                "hpo",
	"hawai'i sign language (hsl)":         "hps",
	"hrangkhol":                           "hra",
	"niwer mil":                           "hrc",
	"hre":                                 "hre",
	"haruku":                              "hrk",
	"horned miao":                         "hrm",
	"haroi":                               "hro",
	"nhirrpi":                             "hrp",
	"hértevin":                            "hrt",
	"hruso":                               "hru",
	"croatian":                            "hrv",
	"warwar feni":                         "hrw",
	"hunsrik":                             "hrx",
	"harzani":                             "hrz",
	"upper sorbian":                       "hsb",
	"hungarian sign language":             "hsh",
	"hausa sign language":                 "hsl",
	"xiang chinese":                       "hsn",
	"harsusi":                             "hss",
	"hoti":                                "hti",
	"minica huitoto":                      "hto",
	"hadza":                               "hts",
	"hitu":                                "htu",
	"middle hittite":                      "htx",
	"huambisa":                            "hub",
	"=/hua":                               "huc",
	"huaulu":                              "hud",
	"san francisco del mar huave":         "hue",
	"humene":                              "huf",
	"huachipaeri":                         "hug",
	"huilliche":                           "huh",
	"huli":                                "hui",
	"northern guiyang hmong":              "huj",
	"hulung":                              "huk",
	"hula":                                "hul",
	"hungana":                             "hum",
	"hungarian":                           "hun",
	"hu":                                  "huo",
	"hupa":                                "hup",
	"tsat":                                "huq",
	"halkomelem":                          "hur",
	"huastec":                             "hus",
	"humla":                               "hut",
	"murui huitoto":                       "huu",
	"san mateo del mar huave":             "huv",
	"hukumina":                            "huw",
	"nüpode huitoto":                      "hux",
	"hulaulá":                             "huy",
	"hunzib":                              "huz",
	"haitian vodoun culture language":     "hvc",
	"san dionisio del mar huave":          "hve",
	"haveke":                              "hvk",
	"sabu":                                "hvn",
	"santa maría del mar huave":           "hvv",
	"wané":                                "hwa",
	"hawai'i creole english":              "hwc",
	"hwana":                               "hwo",
	"hya":                                 "hya",
	"armenian":                            "hye",
	"iaai":                                "iai",
	"iatmul":                              "ian",
	"purari":                              "iar",
	"iban":                                "iba",
	"ibibio":                              "ibb",
	"iwaidja":                             "ibd",
	"akpes":                               "ibe",
	"ibanag":                              "ibg",
	"bih":                                 "ibh",
	"ibaloi":                              "ibl",
	"agoi":                                "ibm",
	"ibino":                               "ibn",
	"igbo":                                "ibo",
	"ibuoro":                              "ibr",
	"ibu":                                 "ibu",
	"ibani":                               "iby",
	"ede ica":                             "ica",
	"etkywan":                             "ich",
	"icelandic sign language":             "icl",
	"islander creole english":             "icr",
	"idakho-isukha-tiriki":                "ida",
	"indo-portuguese":                     "idb",
	"idon":                                "idc",
	"ede idaca":                           "idd",
	"idere":                               "ide",
	"idi":                                 "idi",
	"ido":                                 "ido",
	"indri":                               "idr",
	"idesa":                               "ids",
	"idaté":                               "idt",
	"idoma":                               "idu",
	"amganad ifugao":                      "ifa",
	"batad ifugao":                        "ifb",
	"ifè":                                 "ife",
	"ifo":                                 "iff",
	"tuwali ifugao":                       "ifk",
	"teke-fuumu":                          "ifm",
	"mayoyao ifugao":                      "ifu",
	"keley-i kallahan":                    "ify",
	"ebira":                               "igb",
	"igede":                               "ige",
	"igana":                               "igg",
	"igala":                               "igl",
	"kanggape":                            "igm",
	"ignaciano":                           "ign",
	"isebe":                               "igo",
	"interglossa":                         "igs",
	"igwe":                                "igw",
	"iha based pidgin":                    "ihb",
	"ihievbe":                             "ihi",
	"iha":                                 "ihp",
	"bidhawal":                            "ihw",
	"sichuan yi":                          "iii",
	"thiin":                               "iin",
	"izon":                                "ijc",
	"biseni":                              "ije",
	"ede ije":                             "ijj",
	"kalabari":                            "ijn",
	"southeast ijo":                       "ijs",
	"eastern canadian inuktitut":          "ike",
	"iko":                                 "iki",
	"ika":                                 "ikk",
	"ikulu":                               "ikl",
	"olulumo-ikom":                        "iko",
	"ikpeshi":                             "ikp",
	"ikaranggal":                          "ikr",
	"inuit sign language":                 "iks",
	"inuinnaqtun":                         "ikt",
	"inuktitut":                           "iku",
	"iku-gora-ankwa":                      "ikv",
	"ikwere":                              "ikw",
	"ik":                                  "ikx",
	"ikizu":                               "ikz",
	"ile ape":                             "ila",
	"ila":                                 "ilb",
	"interlingue":                         "ile",
	"garig-ilgar":                         "ilg",
	"ili turki":                           "ili",
	"ilongot":                             "ilk",
	"iranun (malaysia)":                   "ilm",
	"iloko":                               "ilo",
	"iranun (philippines)":                "ilp",
	"international sign":                  "ils",
	"ili'uun":                             "ilu",
	"ilue":                                "ilv",
	"mala malasar":                        "ima",
	"anamgura":                            "imi",
	"miluk":                               "iml",
	"imonda":                              "imn",
	"imbongu":                             "imo",
	"imroing":                             "imr",
	"marsian":                             "ims",
	"milyan":                              "imy",
	"interlingua (international auxiliary language association)": "ina",
	"inga":                                  "inb",
	"indonesian":                            "ind",
	"degexit'an":                            "ing",
	"ingush":                                "inh",
	"jungle inga":                           "inj",
	"indonesian sign language":              "inl",
	"minaean":                               "inm",
	"isinai":                                "inn",
	"inoke-yate":                            "ino",
	"iñapari":                               "inp",
	"indian sign language":                  "ins",
	"intha":                                 "int",
	"ineseño":                               "inz",
	"inor":                                  "ior",
	"tuma-irumu":                            "iou",
	"iowa-oto":                              "iow",
	"ipili":                                 "ipi",
	"inupiaq":                               "ipk",
	"ipiko":                                 "ipo",
	"iquito":                                "iqu",
	"ikwo":                                  "iqw",
	"iresim":                                "ire",
	"irarutu":                               "irh",
	"irigwe":                                "iri",
	"iraqw":                                 "irk",
	"irántxe":                               "irn",
	"ir":                                    "irr",
	"irula":                                 "iru",
	"kamberau":                              "irx",
	"iraya":                                 "iry",
	"isabi":                                 "isa",
	"isconahua":                             "isc",
	"isnag":                                 "isd",
	"italian sign language":                 "ise",
	"irish sign language":                   "isg",
	"esan":                                  "ish",
	"nkem-nkum":                             "isi",
	"ishkashimi":                            "isk",
	"icelandic":                             "isl",
	"masimasi":                              "ism",
	"isanzu":                                "isn",
	"isoko":                                 "iso",
	"israeli sign language":                 "isr",
	"istriot":                               "ist",
	"isu (menchum division)":                "isu",
	"italian":                               "ita",
	"binongan itneg":                        "itb",
	"southern tidung":                       "itd",
	"itene":                                 "ite",
	"inlaod itneg":                          "iti",
	"judeo-italian":                         "itk",
	"itelmen":                               "itl",
	"itu mbon uzo":                          "itm",
	"itonama":                               "ito",
	"iteri":                                 "itr",
	"isekiri":                               "its",
	"maeng itneg":                           "itt",
	"itawit":                                "itv",
	"ito":                                   "itw",
	"itik":                                  "itx",
	"moyadan itneg":                         "ity",
	"itzá":                                  "itz",
	"iu mien":                               "ium",
	"ibatan":                                "ivb",
	"ivatan":                                "ivv",
	"i-wak":                                 "iwk",
	"iwam":                                  "iwm",
	"iwur":                                  "iwo",
	"sepik iwam":                            "iws",
	"ixcatec":                               "ixc",
	"ixil":                                  "ixl",
	"iyayu":                                 "iya",
	"mesaka":                                "iyo",
	"yaka (congo)":                          "iyx",
	"ingrian":                               "izh",
	"izere":                                 "izr",
	"izii":                                  "izz",
	"jamamadí":                              "jaa",
	"hyam":                                  "jab",
	"popti'":                                "jac",
	"jahanka":                               "jad",
	"yabem":                                 "jae",
	"jara":                                  "jaf",
	"jah hut":                               "jah",
	"zazao":                                 "jaj",
	"jakun":                                 "jak",
	"yalahatan":                             "jal",
	"jamaican creole english":               "jam",
	"jandai":                                "jan",
	"yanyuwa":                               "jao",
	"yaqay":                                 "jaq",
	"new caledonian javanese":               "jas",
	"jakati":                                "jat",
	"yaur":                                  "jau",
	"javanese":                              "jav",
	"jambi malay":                           "jax",
	"yan-nhangu":                            "jay",
	"jawe":                                  "jaz",
	"judeo-berber":                          "jbe",
	"badjiri":                               "jbi",
	"arandai":                               "jbj",
	"barikewa":                              "jbk",
	"nafusi":                                "jbn",
	"lojban":                                "jbo",
	"jofotek-bromnya":                       "jbr",
	"jabutí":                                "jbt",
	"jukun takum":                           "jbu",
	"yawijibaya":                            "jbw",
	"jamaican country sign language":        "jcs",
	"krymchak":                              "jct",
	"jad":                                   "jda",
	"jadgali":                               "jdg",
	"judeo-tat":                             "jdt",
	"jebero":                                "jeb",
	"jerung":                                "jee",
	"jeh":                                   "jeh",
	"yei":                                   "jei",
	"jeri kuo":                              "jek",
	"yelmek":                                "jel",
	"dza":                                   "jen",
	"jere":                                  "jer",
	"manem":                                 "jet",
	"jonkor bourmataguil":                   "jeu",
	"ngbee":                                 "jgb",
	"judeo-georgian":                        "jge",
	"gwak":                                  "jgk",
	"ngomba":                                "jgo",
	"jehai":                                 "jhi",
	"jhankot sign language":                 "jhs",
	"jina":                                  "jia",
	"jibu":                                  "jib",
	"tol":                                   "jic",
	"bu":                                    "jid",
	"jilbe":                                 "jie",
	"djingili":                              "jig",
	"stodsde":                               "jih",
	"jiiddu":                                "jii",
	"jilim":                                 "jil",
	"jimi (cameroon)":                       "jim",
	"jiamao":                                "jio",
	"guanyinqiao":                           "jiq",
	"jita":                                  "jit",
	"youle jinuo":                           "jiu",
	"shuar":                                 "jiv",
	"buyuan jinuo":                          "jiy",
	"jejueo":                                "jje",
	"bankal":                                "jjr",
	"kaera":                                 "jka",
	"mobwa karen":                           "jkm",
	"kubo":                                  "jko",
	"paku karen":                            "jkp",
	"koro (india)":                          "jkr",
	"labir":                                 "jku",
	"ngile":                                 "jle",
	"jamaican sign language":                "jls",
	"dima":                                  "jma",
	"zumbun":                                "jmb",
	"machame":                               "jmc",
	"yamdena":                               "jmd",
	"jimi (nigeria)":                        "jmi",
	"jumli":                                 "jml",
	"makuri naga":                           "jmn",
	"kamara":                                "jmr",
	"mashi (nigeria)":                       "jms",
	"mouwase":                               "jmw",
	"western juxtlahuaca mixtec":            "jmx",
	"jangshung":                             "jna",
	"jandavra":                              "jnd",
	"yangman":                               "jng",
	"janji":                                 "jni",
	"yemsa":                                 "jnj",
	"rawat":                                 "jnl",
	"jaunsari":                              "jns",
	"joba":                                  "job",
	"wojenaka":                              "jod",
	"jogi":                                  "jog",
	"jorá":                                  "jor",
	"jordanian sign language":               "jos",
	"jowulu":                                "jow",
	"jewish palestinian aramaic":            "jpa",
	"japanese":                              "jpn",
	"judeo-persian":                         "jpr",
	"jaqaru":                                "jqr",
	"jarai":                                 "jra",
	"judeo-arabic":                          "jrb",
	"jiru":                                  "jrr",
	"jorto":                                 "jrt",
	"japrería":                              "jru",
	"japanese sign language":                "jsl",
	"júma":                                  "jua",
	"wannu":                                 "jub",
	"jurchen":                               "juc",
	"worodougou":                            "jud",
	"hõne":                                  "juh",
	"ngadjuri":                              "jui",
	"wapan":                                 "juk",
	"jirel":                                 "jul",
	"jumjum":                                "jum",
	"juang":                                 "jun",
	"jiba":                                  "juo",
	"hupdë":                                 "jup",
	"jurúna":                                "jur",
	"jumla sign language":                   "jus",
	"jutish":                                "jut",
	"ju":                                    "juu",
	"wãpha":                                 "juw",
	"juray":                                 "juy",
	"javindo":                               "jvd",
	"caribbean javanese":                    "jvn",
	"jwira-pepesa":                          "jwi",
	"jiarong":                               "jya",
	"judeo-yemeni arabic":                   "jye",
	"jaya":                                  "jyy",
	"kara-kalpak":                           "kaa",
	"kabyle":                                "kab",
	"kachin":                                "kac",
	"adara":                                 "kad",
	"ketangalan":                            "kae",
	"katso":                                 "kaf",
	"kajaman":                               "kag",
	"kara (central african republic)":       "kah",
	"karekare":                              "kai",
	"jju":                                   "kaj",
	"kalanguya":                             "kak",
	"kalaallisut":                           "kal",
	"kamba (kenya)":                         "kam",
	"kannada":                               "kan",
	"xaasongaxango":                         "kao",
	"bezhta":                                "kap",
	"capanahua":                             "kaq",
	"kashmiri":                              "kas",
	"georgian":                              "kat",
	"kanuri":                                "kau",
	"katukína":                              "kav",
	"kawi":                                  "kaw",
	"kao":                                   "kax",
	"kamayurá":                              "kay",
	"kazakh":                                "kaz",
	"kalarko":                               "kba",
	"kaxuiâna":                              "kbb",
	"kadiwéu":                               "kbc",
	"kabardian":                             "kbd",
	"kanju":                                 "kbe",
	"khamba":                                "kbg",
	"camsá":                                 "kbh",
	"kaptiau":                               "kbi",
	"kari":                                  "kbj",
	"grass koiari":                          "kbk",
	"kanembu":                               "kbl",
	"iwal":                                  "kbm",
	"kare (central african republic)":       "kbn",
	"keliko":                                "kbo",
	"kabiyè":                                "kbp",
	"kamano":                                "kbq",
	"kafa":                                  "kbr",
	"kande":                                 "kbs",
	"abadi":                                 "kbt",
	"kabutra":                               "kbu",
	"dera (indonesia)":                      "kbv",
	"kaiep":                                 "kbw",
	"ap ma":                                 "kbx",
	"manga kanuri":                          "kby",
	"duhwa":                                 "kbz",
	"khanty":                                "kca",
	"kawacha":                               "kcb",
	"lubila":                                "kcc",
	"ngkâlmpw kanum":                        "kcd",
	"kaivi":                                 "kce",
	"ukaan":                                 "kcf",
	"tyap":                                  "kcg",
	"vono":                                  "kch",
	"kamantan":                              "kci",
	"kobiana":                               "kcj",
	"kalanga":                               "kck",
	"kela (papua new guinea)":               "kcl",
	"gula (central african republic)":       "kcm",
	"nubi":                                  "kcn",
	"kinalakna":                             "kco",
	"kanga":                                 "kcp",
	"kamo":                                  "kcq",
	"katla":                                 "kcr",
	"koenoem":                               "kcs",
	"kaian":                                 "kct",
	"kami (tanzania)":                       "kcu",
	"kete":                                  "kcv",
	"kabwari":                               "kcw",
	"kachama-ganjule":                       "kcx",
	"korandje":                              "kcy",
	"konongo":                               "kcz",
	"worimi":                                "kda",
	"kutu":                                  "kdc",
	"yankunytjatjara":                       "kdd",
	"makonde":                               "kde",
	"mamusi":                                "kdf",
	"seba":                                  "kdg",
	"tem":                                   "kdh",
	"kumam":                                 "kdi",
	"karamojong":                            "kdj",
	"numèè":                                 "kdk",
	"tsikimba":                              "kdl",
	"kagoma":                                "kdm",
	"kunda":                                 "kdn",
	"kaningdon-nindem":                      "kdp",
	"koch":                                  "kdq",
	"karaim":                                "kdr",
	"kuy":                                   "kdt",
	"kadaru":                                "kdu",
	"koneraw":                               "kdw",
	"kam":                                   "kdx",
	"keder":                                 "kdy",
	"kwaja":                                 "kdz",
	"kabuverdianu":                          "kea",
	"kélé":                                  "keb",
	"keiga":                                 "kec",
	"kerewe":                                "ked",
	"eastern keres":                         "kee",
	"kpessi":                                "kef",
	"tese":                                  "keg",
	"keak":                                  "keh",
	"kei":                                   "kei",
	"kadar":                                 "kej",
	"kekchí":                                "kek",
	"kela (democratic republic of congo)":   "kel",
	"kemak":                                 "kem",
	"kenyang":                               "ken",
	"kakwa":                                 "keo",
	"kaikadi":                               "kep",
	"kamar":                                 "keq",
	"kera":                                  "ker",
	"kugbo":                                 "kes",
	"ket":                                   "ket",
	"akebu":                                 "keu",
	"kanikkaran":                            "kev",
	"west kewa":                             "kew",
	"kukna":                                 "kex",
	"kupia":                                 "key",
	"kukele":                                "kez",
	"kodava":                                "kfa",
	"northwestern kolami":                   "kfb",
	"konda-dora":                            "kfc",
	"korra koraga":                          "kfd",
	"kota (india)":                          "kfe",
	"koya":                                  "kff",
	"kudiya":                                "kfg",
	"kurichiya":                             "kfh",
	"kannada kurumba":                       "kfi",
	"kemiehua":                              "kfj",
	"kinnauri":                              "kfk",
	"kung":                                  "kfl",
	"khunsari":                              "kfm",
	"kuk":                                   "kfn",
	"koro (côte d'ivoire)":                  "kfo",
	"korwa":                                 "kfp",
	"korku":                                 "kfq",
	"kachhi":                                "kfr",
	"bilaspuri":                             "kfs",
	"kanjari":                               "kft",
	"katkari":                               "kfu",
	"kurmukar":                              "kfv",
	"kharam naga":                           "kfw",
	"kullu pahari":                          "kfx",
	"kumaoni":                               "kfy",
	"koromfé":                               "kfz",
	"koyaga":                                "kga",
	"kawe":                                  "kgb",
	"komering":                              "kge",
	"kube":                                  "kgf",
	"kusunda":                               "kgg",
	"selangor sign language":                "kgi",
	"gamale kham":                           "kgj",
	"kaiwá":                                 "kgk",
	"kunggari":                              "kgl",
	"karipúna":                              "kgm",
	"karingani":                             "kgn",
	"krongo":                                "kgo",
	"kaingang":                              "kgp",
	"kamoro":                                "kgq",
	"abun":                                  "kgr",
	"kumbainggar":                           "kgs",
	"somyev":                                "kgt",
	"kobol":                                 "kgu",
	"karas":                                 "kgv",
	"karon dori":                            "kgw",
	"kamaru":                                "kgx",
	"kyerung":                               "kgy",
	"khasi":                                 "kha",
	"lü":                                    "khb",
	"tukang besi north":                     "khc",
	"bädi kanum":                            "khd",
	"korowai":                               "khe",
	"khuen":                                 "khf",
	"khams tibetan":                         "khg",
	"kehu":                                  "khh",
	"kuturmi":                               "khj",
	"halh mongolian":                        "khk",
	"lusi":                                  "khl",
	"central khmer":                         "khm",
	"khandesi":                              "khn",
	"khotanese":                             "kho",
	"kapori":                                "khp",
	"koyra chiini songhay":                  "khq",
	"kharia":                                "khr",
	"kasua":                                 "khs",
	"khamti":                                "kht",
	"nkhumbi":                               "khu",
	"khvarshi":                              "khv",
	"khowar":                                "khw",
	"kanu":                                  "khx",
	"kele (democratic republic of congo)":   "khy",
	"keapara":                               "khz",
	"kim":                                   "kia",
	"koalib":                                "kib",
	"kickapoo":                              "kic",
	"koshin":                                "kid",
	"kibet":                                 "kie",
	"eastern parbate kham":                  "kif",
	"kimaama":                               "kig",
	"kilmeri":                               "kih",
	"kitsai":                                "kii",
	"kilivila":                              "kij",
	"kikuyu":                                "kik",
	"kariya":                                "kil",
	"karagas":                               "kim",
	"kinyarwanda":                           "kin",
	"kiowa":                                 "kio",
	"sheshi kham":                           "kip",
	"kosadle":                               "kiq",
	"kirghiz":                               "kir",
	"kis":                                   "kis",
	"agob":                                  "kit",
	"kirmanjki (individual language)":       "kiu",
	"kimbu":                                 "kiv",
	"northeast kiwai":                       "kiw",
	"khiamniungan naga":                     "kix",
	"kirikiri":                              "kiy",
	"kisi":                                  "kiz",
	"mlap":                                  "kja",
	"q'anjob'al":                            "kjb",
	"coastal konjo":                         "kjc",
	"southern kiwai":                        "kjd",
	"kisar":                                 "kje",
	"khalaj":                                "kjf",
	"khmu":                                  "kjg",
	"khakas":                                "kjh",
	"zabana":                                "kji",
	"khinalugh":                             "kjj",
	"highland konjo":                        "kjk",
	"western parbate kham":                  "kjl",
	"kháng":                                 "kjm",
	"kunjen":                                "kjn",
	"harijan kinnauri":                      "kjo",
	"pwo eastern karen":                     "kjp",
	"western keres":                         "kjq",
	"kurudu":                                "kjr",
	"east kewa":                             "kjs",
	"phrae pwo karen":                       "kjt",
	"kashaya":                               "kju",
	"kaikavian literary language":           "kjv",
	"ramopa":                                "kjx",
	"erave":                                 "kjy",
	"bumthangkha":                           "kjz",
	"kakanda":                               "kka",
	"kwerisa":                               "kkb",
	"odoodee":                               "kkc",
	"kinuku":                                "kkd",
	"kakabe":                                "kke",
	"kalaktang monpa":                       "kkf",
	"mabaka valley kalinga":                 "kkg",
	"khün":                                  "kkh",
	"kagulu":                                "kki",
	"kako":                                  "kkj",
	"kokota":                                "kkk",
	"kosarek yale":                          "kkl",
	"kiong":                                 "kkm",
	"kon keu":                               "kkn",
	"karko":                                 "kko",
	"gugubera":                              "kkp",
	"kaiku":                                 "kkq",
	"kir-balar":                             "kkr",
	"giiwo":                                 "kks",
	"koi":                                   "kkt",
	"tumi":                                  "kku",
	"kangean":                               "kkv",
	"teke-kukuya":                           "kkw",
	"kohin":                                 "kkx",
	"guguyimidjir":                          "kky",
	"kaska":                                 "kkz",
	"klamath-modoc":                         "kla",
	"kiliwa":                                "klb",
	"kolbila":                               "klc",
	"gamilaraay":                            "kld",
	"kulung (nepal)":                        "kle",
	"kendeje":                               "klf",
	"tagakaulo":                             "klg",
	"weliki":                                "klh",
	"kalumpang":                             "kli",
	"turkic khalaj":                         "klj",
	"kono (nigeria)":                        "klk",
	"kagan kalagan":                         "kll",
	"migum":                                 "klm",
	"kalenjin":                              "kln",
	"kapya":                                 "klo",
	"kamasa":                                "klp",
	"rumu":                                  "klq",
	"khaling":                               "klr",
	"kalasha":                               "kls",
	"nukna":                                 "klt",
	"klao":                                  "klu",
	"maskelynes":                            "klv",
	"tado":                                  "klw",
	"koluwawa":                              "klx",
	"kalao":                                 "kly",
	"kabola":                                "klz",
	"konni":                                 "kma",
	"kimbundu":                              "kmb",
	"southern dong":                         "kmc",
	"majukayang kalinga":                    "kmd",
	"bakole":                                "kme",
	"kare (papua new guinea)":               "kmf",
	"kâte":                                  "kmg",
	"kalam":                                 "kmh",
	"kami (nigeria)":                        "kmi",
	"kumarbhag paharia":                     "kmj",
	"limos kalinga":                         "kmk",
	"tanudan kalinga":                       "kml",
	"kom (india)":                           "kmm",
	"awtuw":                                 "kmn",
	"kwoma":                                 "kmo",
	"gimme":                                 "kmp",
	"kwama":                                 "kmq",
	"northern kurdish":                      "kmr",
	"kamasau":                               "kms",
	"kemtuik":                               "kmt",
	"kanite":                                "kmu",
	"karipúna creole french":                "kmv",
	"komo (democratic republic of congo)":   "kmw",
	"waboda":                                "kmx",
	"koma":                                  "kmy",
	"khorasani turkish":                     "kmz",
	"dera (nigeria)":                        "kna",
	"lubuagan kalinga":                      "knb",
	"central kanuri":                        "knc",
	"konda":                                 "knd",
	"kankanaey":                             "kne",
	"mankanya":                              "knf",
	"koongo":                                "kng",
	"kanufi":                                "kni",
	"western kanjobal":                      "knj",
	"kuranko":                               "knk",
	"keninjal":                              "knl",
	"kanamarí":                              "knm",
	"konkani (individual language)":         "knn",
	"kono (sierra leone)":                   "kno",
	"kwanja":                                "knp",
	"kintaq":                                "knq",
	"kaningra":                              "knr",
	"kensiu":                                "kns",
	"panoan katukína":                       "knt",
	"kono (guinea)":                         "knu",
	"tabo":                                  "knv",
	"kung-ekoka":                            "knw",
	"kendayan":                              "knx",
	"kanyok":                                "kny",
	"kalamsé":                               "knz",
	"konomala":                              "koa",
	"kpati":                                 "koc",
	"kodi":                                  "kod",
	"kacipo-balesi":                         "koe",
	"kubi":                                  "kof",
	"cogui":                                 "kog",
	"koyo":                                  "koh",
	"komi-permyak":                          "koi",
	"konkani (macrolanguage)":               "kok",
	"kol (papua new guinea)":                "kol",
	"komi":                                  "kom",
	"kongo":                                 "kon",
	"konzo":                                 "koo",
	"waube":                                 "kop",
	"kota (gabon)":                          "koq",
	"korean":                                "kor",
	"kosraean":                              "kos",
	"lagwan":                                "kot",
	"koke":                                  "kou",
	"kudu-camo":                             "kov",
	"kugama":                                "kow",
	"koyukon":                               "koy",
	"korak":                                 "koz",
	"kutto":                                 "kpa",
	"mullu kurumba":                         "kpb",
	"curripaco":                             "kpc",
	"koba":                                  "kpd",
	"kpelle":                                "kpe",
	"komba":                                 "kpf",
	"kapingamarangi":                        "kpg",
	"kplang":                                "kph",
	"kofei":                                 "kpi",
	"karajá":                                "kpj",
	"kpan":                                  "kpk",
	"kpala":                                 "kpl",
	"koho":                                  "kpm",
	"kepkiriwát":                            "kpn",
	"ikposo":                                "kpo",
	"korupun-sela":                          "kpq",
	"korafe-yegha":                          "kpr",
	"tehit":                                 "kps",
	"karata":                                "kpt",
	"kafoa":                                 "kpu",
	"komi-zyrian":                           "kpv",
	"kobon":                                 "kpw",
	"mountain koiali":                       "kpx",
	"koryak":                                "kpy",
	"kupsabiny":                             "kpz",
	"mum":                                   "kqa",
	"kovai":                                 "kqb",
	"doromu-koki":                           "kqc",
	"koy sanjaq surat":                      "kqd",
	"kalagan":                               "kqe",
	"kakabai":                               "kqf",
	"khe":                                   "kqg",
	"kisankasa":                             "kqh",
	"koitabu":                               "kqi",
	"koromira":                              "kqj",
	"kotafon gbe":                           "kqk",
	"kyenele":                               "kql",
	"khisa":                                 "kqm",
	"kaonde":                                "kqn",
	"eastern krahn":                         "kqo",
	"kimré":                                 "kqp",
	"krenak":                                "kqq",
	"kimaragang":                            "kqr",
	"northern kissi":                        "kqs",
	"klias river kadazan":                   "kqt",
	"seroa":                                 "kqu",
	"okolod":                                "kqv",
	"kandas":                                "kqw",
	"mser":                                  "kqx",
	"koorete":                               "kqy",
	"korana":                                "kqz",
	"kumhali":                               "kra",
	"karkin":                                "krb",
	"karachay-balkar":                       "krc",
	"kairui-midiki":                         "krd",
	"panará":                                "kre",
	"koro (vanuatu)":                        "krf",
	"kurama":                                "krh",
	"krio":                                  "kri",
	"kinaray-a":                             "krj",
	"kerek":                                 "krk",
	"karelian":                              "krl",
	"sapo":                                  "krn",
	"korop":                                 "krp",
	"krung":                                 "krr",
	"gbaya (sudan)":                         "krs",
	"tumari kanuri":                         "krt",
	"kurukh":                                "kru",
	"kavet":                                 "krv",
	"western krahn":                         "krw",
	"karon":                                 "krx",
	"kryts":                                 "kry",
	"sota kanum":                            "krz",
	"shuwa-zamani":                          "ksa",
	"shambala":                              "ksb",
	"southern kalinga":                      "ksc",
	"kuanua":                                "ksd",
	"kuni":                                  "kse",
	"bafia":                                 "ksf",
	"kusaghe":                               "ksg",
	"kölsch":                                "ksh",
	"krisa":                                 "ksi",
	"uare":                                  "ksj",
	"kansa":                                 "ksk",
	"kumalu":                                "ksl",
	"kumba":                                 "ksm",
	"kasiguranin":                           "ksn",
	"kofa":                                  "kso",
	"kaba":                                  "ksp",
	"kwaami":                                "ksq",
	"borong":                                "ksr",
	"southern kisi":                         "kss",
	"winyé":                                 "kst",
	"khamyang":                              "ksu",
	"kusu":                                  "ksv",
	"s'gaw karen":                           "ksw",
	"kedang":                                "ksx",
	"kharia thar":                           "ksy",
	"kodaku":                                "ksz",
	"katua":                                 "kta",
	"kambaata":                              "ktb",
	"kholok":                                "ktc",
	"kokata":                                "ktd",
	"nubri":                                 "kte",
	"kwami":                                 "ktf",
	"kalkutung":                             "ktg",
	"karanga":                               "kth",
	"north muyu":                            "kti",
	"plapo krumen":                          "ktj",
	"kaniet":                                "ktk",
	"koroshi":                               "ktl",
	"kurti":                                 "ktm",
	"karitiâna":                             "ktn",
	"kuot":                                  "kto",
	"kaduo":                                 "ktp",
	"katabaga":                              "ktq",
	"south muyu":                            "kts",
	"ketum":                                 "ktt",
	"kituba (democratic republic of congo)": "ktu",
	"eastern katu":                          "ktv",
	"kato":                                  "ktw",
	"kaxararí":                              "ktx",
	"kango (bas-uélé district)":             "kty",
	"ju/'hoan":                              "ktz",
	"kuanyama":                              "kua",
	"kutep":                                 "kub",
	"kwinsu":                                "kuc",
	"'auhelawa":                             "kud",
	"kuman (papua new guinea)":              "kue",
	"western katu":                          "kuf",
	"kupa":                                  "kug",
	"kushi":                                 "kuh",
	"kuikúro-kalapálo":                      "kui",
	"kuria":                                 "kuj",
	"kepo'":                                 "kuk",
	"kulere":                                "kul",
	"kumyk":                                 "kum",
	"kunama":                                "kun",
	"kumukio":                               "kuo",
	"kunimaipa":                             "kup",
	"karipuna":                              "kuq",
	"kurdish":                               "kur",
	"kusaal":                                "kus",
	"kutenai":                               "kut",
	"upper kuskokwim":                       "kuu",
	"kur":                                   "kuv",
	"kpagua":                                "kuw",
	"kukatja":                               "kux",
	"kuuku-ya'u":                            "kuy",
	"kunza":                                 "kuz",
	"bagvalal":                              "kva",
	"kubu":                                  "kvb",
	"kove":                                  "kvc",
	"kui (indonesia)":                       "kvd",
	"kalabakan":                             "kve",
	"kabalai":                               "kvf",
	"kuni-boazi":                            "kvg",
	"komodo":                                "kvh",
	"kwang":                                 "kvi",
	"psikye":                                "kvj",
	"korean sign language":                  "kvk",
	"kayaw":                                 "kvl",
	"kendem":                                "kvm",
	"border kuna":                           "kvn",
	"dobel":                                 "kvo",
	"kompane":                               "kvp",
	"geba karen":                            "kvq",
	"kerinci":                               "kvr",
	"lahta karen":                           "kvt",
	"yinbaw karen":                          "kvu",
	"kola":                                  "kvv",
	"wersing":                               "kvw",
	"parkari koli":                          "kvx",
	"yintale karen":                         "kvy",
	"tsakwambo":                             "kvz",
	"dâw":                                   "kwa",
	"kwa":                                   "kwb",
	"likwala":                               "kwc",
	"kwaio":                                 "kwd",
	"kwerba":                                "kwe",
	"kwara'ae":                              "kwf",
	"sara kaba deme":                        "kwg",
	"kowiai":                                "kwh",
	"awa-cuaiquer":                          "kwi",
	"kwanga":                                "kwj",
	"kwakiutl":                              "kwk",
	"kofyar":                                "kwl",
	"kwambi":                                "kwm",
	"kwangali":                              "kwn",
	"kwomtari":                              "kwo",
	"kodia":                                 "kwp",
	"kwer":                                  "kwr",
	"kwese":                                 "kws",
	"kwesten":                               "kwt",
	"kwakum":                                "kwu",
	"sara kaba náà":                         "kwv",
	"kwinti":                                "kww",
	"khirwar":                               "kwx",
	"san salvador kongo":                    "kwy",
	"kwadi":                                 "kwz",
	"kairiru":                               "kxa",
	"krobu":                                 "kxb",
	"konso":                                 "kxc",
	"brunei":                                "kxd",
	"manumanaw karen":                       "kxf",
	"karo (ethiopia)":                       "kxh",
	"keningau murut":                        "kxi",
	"kulfa":                                 "kxj",
	"zayein karen":                          "kxk",
	"nepali kurux":                          "kxl",
	"northern khmer":                        "kxm",
	"kanowit-tanjong melanau":               "kxn",
	"kanoé":                                 "kxo",
	"wadiyara koli":                         "kxp",
	"smärky kanum":                          "kxq",
	"koro (papua new guinea)":               "kxr",
	"kangjia":                               "kxs",
	"koiwat":                                "kxt",
	"kui (india)":                           "kxu",
	"kuvi":                                  "kxv",
	"konai":                                 "kxw",
	"likuba":                                "kxx",
	"kayong":                                "kxy",
	"kerewo":                                "kxz",
	"kwaya":                                 "kya",
	"butbut kalinga":                        "kyb",
	"kyaka":                                 "kyc",
	"karey":                                 "kyd",
	"krache":                                "kye",
	"kouya":                                 "kyf",
	"keyagana":                              "kyg",
	"karok":                                 "kyh",
	"kiput":                                 "kyi",
	"karao":                                 "kyj",
	"kamayo":                                "kyk",
	"kalapuya":                              "kyl",
	"kpatili":                               "kym",
	"northern binukidnon":                   "kyn",
	"kelon":                                 "kyo",
	"kang":                                  "kyp",
	"kenga":                                 "kyq",
	"kuruáya":                               "kyr",
	"baram kayan":                           "kys",
	"kayagar":                               "kyt",
	"western kayah":                         "kyu",
	"kayort":                                "kyv",
	"kudmali":                               "kyw",
	"rapoisi":                               "kyx",
	"kambaira":                              "kyy",
	"kayabí":                                "kyz",
	"western karaboro":                      "kza",
	"kaibobo":                               "kzb",
	"bondoukou kulango":                     "kzc",
	"kadai":                                 "kzd",
	"kosena":                                "kze",
	"da'a kaili":                            "kzf",
	"kikai":                                 "kzg",
	"kelabit":                               "kzi",
	"kazukuru":                              "kzk",
	"kayeli":                                "kzl",
	"kais":                                  "kzm",
	"kokola":                                "kzn",
	"kaningi":                               "kzo",
	"kaidipang":                             "kzp",
	"kaike":                                 "kzq",
	"karang":                                "kzr",
	"sugut dusun":                           "kzs",
	"kayupulau":                             "kzu",
	"komyandaret":                           "kzv",
	"karirí-xocó":                           "kzw",
	"kamarian":                              "kzx",
	"kango (tshopo district)":               "kzy",
	"kalabra":                               "kzz",
	"southern subanen":                      "laa",
	"linear a":                              "lab",
	"lacandon":                              "lac",
	"ladino":                                "lad",
	"pattani":                               "lae",
	"lafofa":                                "laf",
	"langi":                                 "lag",
	"lahnda":                                "lah",
	"lambya":                                "lai",
	"lango (uganda)":                        "laj",
	"laka (nigeria)":                        "lak",
	"lalia":                                 "lal",
	"lamba":                                 "lam",
	"laru":                                  "lan",
	"lao":                                   "lao",
	"laka (chad)":                           "lap",
	"qabiao":                                "laq",
	"larteh":                                "lar",
	"lama (togo)":                           "las",
	"latin":                                 "lat",
	"laba":                                  "lau",
	"latvian":                               "lav",
	"lauje":                                 "law",
	"tiwa":                                  "lax",
	"lama bai":                              "lay",
	"aribwatsa":                             "laz",
	"lui":                                   "lba",
	"label":                                 "lbb",
	"lakkia":                                "lbc",
	"lak":                                   "lbe",
	"tinani":                                "lbf",
	"laopang":                               "lbg",
	"la'bi":                                 "lbi",
	"ladakhi":                               "lbj",
	"central bontok":                        "lbk",
	"libon bikol":                           "lbl",
	"lodhi":                                 "lbm",
	"lamet":                                 "lbn",
	"laven":                                 "lbo",
	"wampar":                                "lbq",
	"lohorung":                              "lbr",
	"libyan sign language":                  "lbs",
	"lachi":                                 "lbt",
	"labu":                                  "lbu",
	"lavatbura-lamusong":                    "lbv",
	"tolaki":                                "lbw",
	"lawangan":                              "lbx",
	"lamu-lamu":                             "lby",
	"lardil":                                "lbz",
	"legenyem":                              "lcc",
	"lola":                                  "lcd",
	"loncong":                               "lce",
	"lubu":                                  "lcf",
	"luchazi":                               "lch",
	"lisela":                                "lcl",
	"tungag":                                "lcm",
	"western lawa":                          "lcp",
	"luhu":                                  "lcq",
	"lisabata-nuniali":                      "lcs",
	"kla-dan":                               "lda",
	"dũya":                                 "ldb",
	"luri":                                  "ldd",
	"lenyima":                               "ldg",
	"lamja-dengsa-tola":                     "ldh",
	"laari":                                 "ldi",
	"lemoro":                                "ldj",
	"leelau":                                "ldk",
	"kaan":                                  "ldl",
	"landoma":                               "ldm",
	"láadan":                                "ldn",
	"loo":                                   "ldo",
	"tso":                                   "ldp",
	"lufu":                                  "ldq",
	"lega-shabunda":                         "lea",
	"lala-bisa":                             "leb",
	"leco":                                  "lec",
	"lendu":                                 "led",
	"lyélé":                                 "lee",
	"lelemi":                                "lef",
	"lenje":                                 "leh",
	"lemio":                                 "lei",
	"lengola":                               "lej",
	"leipon":                                "lek",
	"lele (democratic republic of congo)":   "lel",
	"nomaande":                              "lem",
	"lenca":                                 "len",
	"leti (cameroon)":                       "leo",
	"lepcha":                                "lep",
	"lembena":                               "leq",
	"lenkau":                                "ler",
	"lese":                                  "les",
	"lesing-gelimi":                         "let",
	"kara (papua new guinea)":               "leu",
	"lamma":                                 "lev",
	"ledo kaili":                            "lew",
	"luang":                                 "lex",
	"lemolang":                              "ley",
	"lezghian":                              "lez",
	"lefa":                                  "lfa",
	"lingua franca nova":                    "lfn",
	"lungga":                                "lga",
	"laghu":                                 "lgb",
	"lugbara":                               "lgg",
	"laghuu":                                "lgh",
	"lengilu":                               "lgi",
	"lingarak":                              "lgk",
	"wala":                                  "lgl",
	"lega-mwenga":                           "lgm",
	"t'apo":                                 "lgn",
	"logba":                                 "lgq",
	"lengo":                                 "lgr",
	"pahi":                                  "lgt",
	"longgu":                                "lgu",
	"ligenza":                               "lgz",
	"laha (viet nam)":                       "lha",
	"laha (indonesia)":                      "lhh",
	"lahu shi":                              "lhi",
	"lahul lohar":                           "lhl",
	"lhomi":                                 "lhm",
	"lahanan":                               "lhn",
	"lhokpu":                                "lhp",
	"mlahsö":                                "lhs",
	"lo-toga":                               "lht",
	"lahu":                                  "lhu",
	"west-central limba":                    "lia",
	"likum":                                 "lib",
	"hlai":                                  "lic",
	"nyindrou":                              "lid",
	"likila":                                "lie",
	"limbu":                                 "lif",
	"ligbi":                                 "lig",
	"lihir":                                 "lih",
	"ligurian":                              "lij",
	"lika":                                  "lik",
	"lillooet":                              "lil",
	"limburgan":                             "lim",
	"lingala":                               "lin",
	"liki":                                  "lio",
	"sekpele":                               "lip",
	"libido":                                "liq",
	"liberian english":                      "lir",
	"lisu":                                  "lis",
	"lithuanian":                            "lit",
	"logorik":                               "liu",
	"liv":                                   "liv",
	"col":                                   "liw",
	"liabuku":                               "lix",
	"banda-bambari":                         "liy",
	"libinza":                               "liz",
	"golpa":                                 "lja",
	"rampi":                                 "lje",
	"laiyolo":                               "lji",
	"li'o":                                  "ljl",
	"lampung api":                           "ljp",
	"yirandali":                             "ljw",
	"yuru":                                  "ljx",
	"lakalei":                               "lka",
	"kabras":                                "lkb",
	"kucong":                                "lkc",
	"lakondê":                               "lkd",
	"kenyi":                                 "lke",
	"lakha":                                 "lkh",
	"laki":                                  "lki",
	"remun":                                 "lkj",
	"laeko-libuat":                          "lkl",
	"kalaamaya":                             "lkm",
	"lakon":                                 "lkn",
	"khayo":                                 "lko",
	"päri":                                  "lkr",
	"kisa":                                  "lks",
	"lakota":                                "lkt",
	"kungkari":                              "lku",
	"lokoya":                                "lky",
	"lala-roba":                             "lla",
	"lolo":                                  "llb",
	"lele (guinea)":                         "llc",
	"ladin":                                 "lld",
	"lele (papua new guinea)":               "lle",
	"hermit":                                "llf",
	"lole":                                  "llg",
	"lamu":                                  "llh",
	"teke-laali":                            "lli",
	"ladji ladji":                           "llj",
	"lelak":                                 "llk",
	"lilau":                                 "lll",
	"lasalimu":                              "llm",
	"lele (chad)":                           "lln",
	"khlor":                                 "llo",
	"north efate":                           "llp",
	"lolak":                                 "llq",
	"lithuanian sign language":              "lls",
	"lau":                                   "llu",
	"lauan":                                 "llx",
	"east limba":                            "lma",
	"merei":                                 "lmb",
	"limilngan":                             "lmc",
	"lumun":                                 "lmd",
	"pévé":                                  "lme",
	"south lembata":                         "lmf",
	"lamogai":                               "lmg",
	"lambichhong":                           "lmh",
	"lombi":                                 "lmi",
	"west lembata":                          "lmj",
	"lamkang":                               "lmk",
	"hano":                                  "lml",
	"lambadi":                               "lmn",
	"lombard":                               "lmo",
	"limbum":                                "lmp",
	"lamatuka":                              "lmq",
	"lamalera":                              "lmr",
	"lamenu":                                "lmu",
	"lomaiviti":                             "lmv",
	"lake miwok":                            "lmw",
	"laimbue":                               "lmx",
	"lamboya":                               "lmy",
	"lumbee":                                "lmz",
	"langbashe":                             "lna",
	"mbalanhu":                              "lnb",
	"lundayeh":                              "lnd",
	"langobardic":                           "lng",
	"lanoh":                                 "lnh",
	"daantanai'":                            "lni",
	"leningitij":                            "lnj",
	"south central banda":                   "lnl",
	"langam":                                "lnm",
	"lorediakarkar":                         "lnn",
	"lango (sudan)":                         "lno",
	"lamnso'":                               "lns",
	"longuda":                               "lnu",
	"lanima":                                "lnw",
	"lonzo":                                 "lnz",
	"loloda":                                "loa",
	"lobi":                                  "lob",
	"inonhan":                               "loc",
	"saluan":                                "loe",
	"logol":                                 "lof",
	"logo":                                  "log",
	"narim":                                 "loh",
	"loma (côte d'ivoire)":                  "loi",
	"lou":                                   "loj",
	"loko":                                  "lok",
	"mongo":                                 "lol",
	"loma (liberia)":                        "lom",
	"malawi lomwe":                          "lon",
	"lombo":                                 "loo",
	"lopa":                                  "lop",
	"lobala":                                "loq",
	"téén":                                  "lor",
	"loniu":                                 "los",
	"otuho":                                 "lot",
	"louisiana creole":                      "lou",
	"lopi":                                  "lov",
	"tampias lobu":                          "low",
	"loun":                                  "lox",
	"loke":                                  "loy",
	"lozi":                                  "loz",
	"lelepa":                                "lpa",
	"lepki":                                 "lpe",
	"long phuri naga":                       "lpn",
	"lipo":                                  "lpo",
	"lopit":                                 "lpx",
	"rara bakati'":                          "lra",
	"northern luri":                         "lrc",
	"laurentian":                            "lre",
	"laragia":                               "lrg",
	"marachi":                               "lri",
	"loarki":                                "lrk",
	"lari":                                  "lrl",
	"marama":                                "lrm",
	"lorang":                                "lrn",
	"laro":                                  "lro",
	"southern yamphu":                       "lrr",
	"larantuka malay":                       "lrt",
	"larevat":                               "lrv",
	"lemerig":                               "lrz",
	"lasgerdi":                              "lsa",
	"lishana deni":                          "lsd",
	"lusengo":                               "lse",
	"lyons sign language":                   "lsg",
	"lish":                                  "lsh",
	"lashi":                                 "lsi",
	"latvian sign language":                 "lsl",
	"saamia":                                "lsm",
	"laos sign language":                    "lso",
	"panamanian sign language":              "lsp",
	"aruop":                                 "lsr",
	"lasi":                                  "lss",
	"trinidad and tobago sign language":     "lst",
	"mauritian sign language":               "lsy",
	"late middle chinese":                   "ltc",
	"latgalian":                             "ltg",
	"thur":                                  "lth",
	"leti (indonesia)":                      "lti",
	"latundê":                               "ltn",
	"tsotso":                                "lto",
	"tachoni":                               "lts",
	"latu":                                  "ltu",
	"luxembourgish":                         "ltz",
	"luba-lulua":                            "lua",
	"luba-katanga":                          "lub",
	"aringa":                                "luc",
	"ludian":                                "lud",
	"luvale":                                "lue",
	"laua":                                  "luf",
	"ganda":                                 "lug",
	"luiseno":                               "lui",
	"luna":                                  "luj",
	"lunanakha":                             "luk",
	"olu'bo":                                "lul",
	"luimbi":                                "lum",
	"lunda":                                 "lun",
	"luo (kenya and tanzania)":              "luo",
	"lumbu":                                 "lup",
	"lucumi":                                "luq",
	"laura":                                 "lur",
	"lushai":                                "lus",
	"lushootseed":                           "lut",
	"lumba-yakkha":                          "luu",
	"luwati":                                "luv",
	"luo (cameroon)":                        "luw",
	"luyia":                                 "luy",
	"southern luri":                         "luz",
	"maku'a":                                "lva",
	"lavukaleve":                            "lvk",
	"standard latvian":                      "lvs",
	"levuka":                                "lvu",
	"lwalu":                                 "lwa",
	"lewo eleng":                            "lwe",
	"wanga":                                 "lwg",
	"white lachi":                           "lwh",
	"eastern lawa":                          "lwl",
	"laomian":                               "lwm",
	"luwo":                                  "lwo",
	"lewotobi":                              "lwt",
	"lawu":                                  "lwu",
	"lewo":                                  "lww",
	"layakha":                               "lya",
	"lyngngam":                              "lyg",
	"luyana":                                "lyn",
	"literary chinese":                      "lzh",
	"litzlitz":                              "lzl",
	"leinong naga":                          "lzn",
	"laz":                                   "lzz",
	"san jerónimo tecóatl mazatec":          "maa",
	"yutanduchi mixtec":                     "mab",
	"madurese":                              "mad",
	"bo-rukul":                              "mae",
	"mafa":                                  "maf",
	"magahi":                                "mag",
	"marshallese":                           "mah",
	"maithili":                              "mai",
	"jalapa de díaz mazatec":                "maj",
	"makasar":                               "mak",
	"malayalam":                             "mal",
	"mam":                                   "mam",
	"mandingo":                              "man",
	"chiquihuitlán mazatec":                 "maq",
	"marathi":                               "mar",
	"masai":                                 "mas",
	"san francisco matlatzinca":             "mat",
	"huautla mazatec":                       "mau",
	"sateré-mawé":                           "mav",
	"mampruli":                              "maw",
	"north moluccan malay":                  "max",
	"central mazahua":                       "maz",
	"higaonon":                              "mba",
	"western bukidnon manobo":               "mbb",
	"macushi":                               "mbc",
	"dibabawon manobo":                      "mbd",
	"molale":                                "mbe",
	"baba malay":                            "mbf",
	"mangseng":                              "mbh",
	"ilianen manobo":                        "mbi",
	"nadëb":                                 "mbj",
	"malol":                                 "mbk",
	"maxakalí":                              "mbl",
	"ombamba":                               "mbm",
	"macaguán":                              "mbn",
	"mbo (cameroon)":                        "mbo",
	"malayo":                                "mbp",
	"maisin":                                "mbq",
	"nukak makú":                            "mbr",
	"sarangani manobo":                      "mbs",
	"matigsalug manobo":                     "mbt",
	"mbula-bwazza":                          "mbu",
	"mbulungish":                            "mbv",
	"maring":                                "mbw",
	"mari (east sepik province)":            "mbx",
	"memoni":                                "mby",
	"amoltepec mixtec":                      "mbz",
	"maca":                                  "mca",
	"machiguenga":                           "mcb",
	"bitur":                                 "mcc",
	"sharanahua":                            "mcd",
	"itundujia mixtec":                      "mce",
	"matsés":                                "mcf",
	"mapoyo":                                "mcg",
	"maquiritari":                           "mch",
	"mese":                                  "mci",
	"mvanip":                                "mcj",
	"mbunda":                                "mck",
	"macaguaje":                             "mcl",
	"malaccan creole portuguese":            "mcm",
	"masana":                                "mcn",
	"coatlán mixe":                          "mco",
	"makaa":                                 "mcp",
	"ese":                                   "mcq",
	"menya":                                 "mcr",
	"mambai":                                "mcs",
	"mengisa":                               "mct",
	"cameroon mambila":                      "mcu",
	"minanibai":                             "mcv",
	"mawa (chad)":                           "mcw",
	"mpiemo":                                "mcx",
	"south watut":                           "mcy",
	"mawan":                                 "mcz",
	"mada (nigeria)":                        "mda",
	"morigi":                                "mdb",
	"male (papua new guinea)":               "mdc",
	"mbum":                                  "mdd",
	"maba (chad)":                           "mde",
	"moksha":                                "mdf",
	"massalat":                              "mdg",
	"maguindanaon":                          "mdh",
	"mamvu":                                 "mdi",
	"mangbetu":                              "mdj",
	"mangbutu":                              "mdk",
	"maltese sign language":                 "mdl",
	"mayogo":                                "mdm",
	"mbati":                                 "mdn",
	"mbala":                                 "mdp",
	"mbole":                                 "mdq",
	"mandar":                                "mdr",
	"maria (papua new guinea)":              "mds",
	"mbere":                                 "mdt",
	"mboko":                                 "mdu",
	"santa lucía monteverde mixtec":         "mdv",
	"mbosi":                                 "mdw",
	"dizin":                                 "mdx",
	"male (ethiopia)":                       "mdy",
	"suruí do pará":                         "mdz",
	"menka":                                 "mea",
	"ikobi":                                 "meb",
	"mara":                                  "mec",
	"melpa":                                 "med",
	"mengen":                                "mee",
	"megam":                                 "mef",
	"southwestern tlaxiaco mixtec":          "meh",
	"midob":                                 "mei",
	"meyah":                                 "mej",
	"mekeo":                                 "mek",
	"central melanau":                       "mel",
	"mangala":                               "mem",
	"mende (sierra leone)":                  "men",
	"kedah malay":                           "meo",
	"miriwung":                              "mep",
	"merey":                                 "meq",
	"meru":                                  "mer",
	"masmaje":                               "mes",
	"mato":                                  "met",
	"motu":                                  "meu",
	"mano":                                  "mev",
	"maaka":                                 "mew",
	"hassaniyya":                            "mey",
	"menominee":                             "mez",
	"pattani malay":                         "mfa",
	"bangka":                                "mfb",
	"mba":                                   "mfc",
	"mendankwe-nkwen":                       "mfd",
	"morisyen":                              "mfe",
	"naki":                                  "mff",
	"mogofin":                               "mfg",
	"matal":                                 "mfh",
	"wandala":                               "mfi",
	"mefele":                                "mfj",
	"north mofu":                            "mfk",
	"putai":                                 "mfl",
	"marghi south":                          "mfm",
	"cross river mbembe":                    "mfn",
	"mbe":                                   "mfo",
	"makassar malay":                        "mfp",
	"moba":                                  "mfq",
	"marithiel":                             "mfr",
	"mexican sign language":                 "mfs",
	"mokerang":                              "mft",
	"mbwela":                                "mfu",
	"mandjak":                               "mfv",
	"mulaha":                                "mfw",
	"melo":                                  "mfx",
	"mayo":                                  "mfy",
	"mabaan":                                "mfz",
	"middle irish (900-1200)":               "mga",
	"mararit":                               "mgb",
	"morokodo":                              "mgc",
	"moru":                                  "mgd",
	"mango":                                 "mge",
	"maklew":                                "mgf",
	"mpumpong":                              "mgg",
	"makhuwa-meetto":                        "mgh",
	"lijili":                                "mgi",
	"abureni":                               "mgj",
	"mawes":                                 "mgk",
	"maleu-kilenge":                         "mgl",
	"mambae":                                "mgm",
	"mbangi":                                "mgn",
	"meta'":                                 "mgo",
	"eastern magar":                         "mgp",
	"malila":                                "mgq",
	"mambwe-lungu":                          "mgr",
	"manda (tanzania)":                      "mgs",
	"mongol":                                "mgt",
	"mailu":                                 "mgu",
	"matengo":                               "mgv",
	"matumbi":                               "mgw",
	"mbunga":                                "mgy",
	"mbugwe":                                "mgz",
	"manda (india)":                         "mha",
	"mahongwe":                              "mhb",
	"mocho":                                 "mhc",
	"mbugu":                                 "mhd",
	"besisi":                                "mhe",
	"mamaa":                                 "mhf",
	"margu":                                 "mhg",
	"ma'di":                                 "mhi",
	"mogholi":                               "mhj",
	"mungaka":                               "mhk",
	"mauwake":                               "mhl",
	"makhuwa-moniga":                        "mhm",
	"mócheno":                               "mhn",
	"mashi (zambia)":                        "mho",
	"balinese malay":                        "mhp",
	"mandan":                                "mhq",
	"eastern mari":                          "mhr",
	"buru (indonesia)":                      "mhs",
	"mandahuaca":                            "mht",
	"digaro-mishmi":                         "mhu",
	"mbukushu":                              "mhw",
	"maru":                                  "mhx",
	"ma'anyan":                              "mhy",
	"mor (mor islands)":                     "mhz",
	"miami":                                 "mia",
	"atatláhuca mixtec":                     "mib",
	"mi'kmaq":                               "mic",
	"mandaic":                               "mid",
	"ocotepec mixtec":                       "mie",
	"mofu-gudur":                            "mif",
	"san miguel el grande mixtec":           "mig",
	"chayuco mixtec":                        "mih",
	"chigmecatitlán mixtec":                 "mii",
	"abar":                                  "mij",
	"mikasuki":                              "mik",
	"peñoles mixtec":                        "mil",
	"alacatlatzala mixtec":                  "mim",
	"minangkabau":                           "min",
	"pinotepa nacional mixtec":              "mio",
	"apasco-apoala mixtec":                  "mip",
	"mískito":                               "miq",
	"isthmus mixe":                          "mir",
	"uncoded languages":                     "mis",
	"southern puebla mixtec":                "mit",
	"cacaloxtepec mixtec":                   "miu",
	"akoye":                                 "miw",
	"mixtepec mixtec":                       "mix",
	"ayutla mixtec":                         "miy",
	"coatzospan mixtec":                     "miz",
	"makalero":                              "mjb",
	"san juan colorado mixtec":              "mjc",
	"northwest maidu":                       "mjd",
	"muskum":                                "mje",
	"tu":                                    "mjg",
	"mwera (nyasa)":                         "mjh",
	"kim mun":                               "mji",
	"mawak":                                 "mjj",
	"matukar":                               "mjk",
	"mandeali":                              "mjl",
	"medebur":                               "mjm",
	"ma (papua new guinea)":                 "mjn",
	"malankuravan":                          "mjo",
	"malapandaram":                          "mjp",
	"malaryan":                              "mjq",
	"malavedan":                             "mjr",
	"miship":                                "mjs",
	"sauria paharia":                        "mjt",
	"manna-dora":                            "mju",
	"mannan":                                "mjv",
	"karbi":                                 "mjw",
	"mahali":                                "mjx",
	"mahican":                               "mjy",
	"majhi":                                 "mjz",
	"mbre":                                  "mka",
	"mal paharia":                           "mkb",
	"siliput":                               "mkc",
	"macedonian":                            "mkd",
	"mawchi":                                "mke",
	"miya":                                  "mkf",
	"mak (china)":                           "mkg",
	"dhatki":                                "mki",
	"mokilese":                              "mkj",
	"byep":                                  "mkk",
	"mokole":                                "mkl",
	"moklen":                                "mkm",
	"kupang malay":                          "mkn",
	"mingang doso":                          "mko",
	"moikodi":                               "mkp",
	"bay miwok":                             "mkq",
	"malas":                                 "mkr",
	"silacayoapan mixtec":                   "mks",
	"vamale":                                "mkt",
	"konyanka maninka":                      "mku",
	"mafea":                                 "mkv",
	"kituba (congo)":                        "mkw",
	"kinamiging manobo":                     "mkx",
	"east makian":                           "mky",
	"makasae":                               "mkz",
	"malo":                                  "mla",
	"mbule":                                 "mlb",
	"cao lan":                               "mlc",
	"manambu":                               "mle",
	"mal":                                   "mlf",
	"malagasy":                              "mlg",
	"mape":                                  "mlh",
	"malimpung":                             "mli",
	"miltu":                                 "mlj",
	"ilwana":                                "mlk",
	"malua bay":                             "mll",
	"mulam":                                 "mlm",
	"malango":                               "mln",
	"mlomp":                                 "mlo",
	"bargam":                                "mlp",
	"western maninkakan":                    "mlq",
	"vame":                                  "mlr",
	"masalit":                               "mls",
	"maltese":                               "mlt",
	"to'abaita":                             "mlu",
	"motlav":                                "mlv",
	"moloko":                                "mlw",
	"malfaxal":                              "mlx",
	"malaynon":                              "mlz",
	"mama":                                  "mma",
	"momina":                                "mmb",
	"michoacán mazahua":                     "mmc",
	"maonan":                                "mmd",
	"mae":                                   "mme",
	"mundat":                                "mmf",
	"north ambrym":                          "mmg",
	"mehináku":                              "mmh",
	"musar":                                 "mmi",
	"majhwar":                               "mmj",
	"mukha-dora":                            "mmk",
	"man met":                               "mml",
	"maii":                                  "mmm",
	"mamanwa":                               "mmn",
	"mangga buang":                          "mmo",
	"siawi":                                 "mmp",
	"musak":                                 "mmq",
	"western xiangxi miao":                  "mmr",
	"malalamai":                             "mmt",
	"mmaala":                                "mmu",
	"miriti":                                "mmv",
	"emae":                                  "mmw",
	"madak":                                 "mmx",
	"migaama":                               "mmy",
	"mabaale":                               "mmz",
	"mbula":                                 "mna",
	"muna":                                  "mnb",
	"manchu":                                "mnc",
	"mondé":                                 "mnd",
	"naba":                                  "mne",
	"mundani":                               "mnf",
	"eastern mnong":                         "mng",
	"mono (democratic republic of congo)":   "mnh",
	"manipuri":                              "mni",
	"munji":                                 "mnj",
	"mandinka":                              "mnk",
	"tiale":                                 "mnl",
	"mapena":                                "mnm",
	"southern mnong":                        "mnn",
	"min bei chinese":                       "mnp",
	"minriq":                                "mnq",
	"mono (usa)":                            "mnr",
	"mansi":                                 "mns",
	"mer":                                   "mnu",
	"rennell-bellona":                       "mnv",
	"mon":                                   "mnw",
	"manikion":                              "mnx",
	"manyawa":                               "mny",
	"moni":                                  "mnz",
	"mwan":                                  "moa",
	"mocoví":                                "moc",
	"mobilian":                              "mod",
	"montagnais":                            "moe",
	"mongondow":                             "mog",
	"mohawk":                                "moh",
	"mboi":                                  "moi",
	"monzombo":                              "moj",
	"morori":                                "mok",
	"mangue":                                "mom",
	"mongolian":                             "mon",
	"monom":                                 "moo",
	"mopán maya":                            "mop",
	"mor (bomberai peninsula)":              "moq",
	"moro":                                  "mor",
	"mossi":                                 "mos",
	"barí":                                  "mot",
	"mogum":                                 "mou",
	"mohave":                                "mov",
	"moi (congo)":                           "mow",
	"molima":                                "mox",
	"shekkacho":                             "moy",
	"mukulu":                                "moz",
	"mpoto":                                 "mpa",
	"mullukmulluk":                          "mpb",
	"mangarayi":                             "mpc",
	"machinere":                             "mpd",
	"majang":                                "mpe",
	"marba":                                 "mpg",
	"maung":                                 "mph",
	"mpade":                                 "mpi",
	"martu wangka":                          "mpj",
	"mbara (chad)":                          "mpk",
	"middle watut":                          "mpl",
	"yosondúa mixtec":                       "mpm",
	"mindiri":                               "mpn",
	"miu":                                   "mpo",
	"migabac":                               "mpp",
	"matís":                                 "mpq",
	"vangunu":                               "mpr",
	"dadibi":                                "mps",
	"mian":                                  "mpt",
	"makuráp":                               "mpu",
	"mungkip":                               "mpv",
	"mapidian":                              "mpw",
	"misima-panaeati":                       "mpx",
	"mapia":                                 "mpy",
	"mpi":                                   "mpz",
	"maba (indonesia)":                      "mqa",
	"mbuko":                                 "mqb",
	"mangole":                               "mqc",
	"matepi":                                "mqe",
	"momuna":                                "mqf",
	"kota bangun kutai malay":               "mqg",
	"tlazoyaltepec mixtec":                  "mqh",
	"mariri":                                "mqi",
	"mamasa":                                "mqj",
	"rajah kabunsuwan manobo":               "mqk",
	"mbelime":                               "mql",
	"south marquesan":                       "mqm",
	"moronene":                              "mqn",
	"modole":                                "mqo",
	"manipa":                                "mqp",
	"minokok":                               "mqq",
	"mander":                                "mqr",
	"west makian":                           "mqs",
	"mok":                                   "mqt",
	"mandari":                               "mqu",
	"mosimo":                                "mqv",
	"murupi":                                "mqw",
	"mamuju":                                "mqx",
	"manggarai":                             "mqy",
	"pano":                                  "mqz",
	"mlabri":                                "mra",
	"marino":                                "mrb",
	"maricopa":                              "mrc",
	"western magar":                         "mrd",
	"martha's vineyard sign language":       "mre",
	"elseng":                                "mrf",
	"mising":                                "mrg",
	"mara chin":                             "mrh",
	"maori":                                 "mri",
	"western mari":                          "mrj",
	"hmwaveke":                              "mrk",
	"mortlockese":                           "mrl",
	"merlav":                                "mrm",
	"cheke holo":                            "mrn",
	"mru":                                   "mro",
	"morouas":                               "mrp",
	"north marquesan":                       "mrq",
	"maria (india)":                         "mrr",
	"maragus":                               "mrs",
	"marghi central":                        "mrt",
	"mono (cameroon)":                       "mru",
	"mangareva":                             "mrv",
	"maranao":                               "mrw",
	"maremgi":                               "mrx",
	"mandaya":                               "mry",
	"marind":                                "mrz",
	"malay (macrolanguage)":                 "msa",
	"masbatenyo":                            "msb",
	"sankaran maninka":                      "msc",
	"yucatec maya sign language":            "msd",
	"musey":                                 "mse",
	"mekwei":                                "msf",
	"moraid":                                "msg",
	"masikoro malagasy":                     "msh",
	"sabah malay":                           "msi",
	"ma (democratic republic of congo)":     "msj",
	"mansaka":                               "msk",
	"molof":                                 "msl",
	"agusan manobo":                         "msm",
	"vurës":                                 "msn",
	"mombum":                                "mso",
	"maritsauá":                             "msp",
	"caac":                                  "msq",
	"mongolian sign language":               "msr",
	"west masela":                           "mss",
	"musom":                                 "msu",
	"maslam":                                "msv",
	"mansoanka":                             "msw",
	"moresada":                              "msx",
	"aruamu":                                "msy",
	"momare":                                "msz",
	"cotabato manobo":                       "mta",
	"anyin morofo":                          "mtb",
	"munit":                                 "mtc",
	"mualang":                               "mtd",
	"mono (solomon islands)":                "mte",
	"murik (papua new guinea)":              "mtf",
	"una":                                   "mtg",
	"munggui":                               "mth",
	"maiwa (papua new guinea)":              "mti",
	"moskona":                               "mtj",
	"mbe'":                                  "mtk",
	"montol":                                "mtl",
	"mator":                                 "mtm",
	"matagalpa":                             "mtn",
	"totontepec mixe":                       "mto",
	"wichí lhamtés nocten":                  "mtp",
	"muong":                                 "mtq",
	"mewari":                                "mtr",
	"yora":                                  "mts",
	"mota":                                  "mtt",
	"tututepec mixtec":                      "mtu",
	"asaro'o":                               "mtv",
	"southern binukidnon":                   "mtw",
	"tidaá mixtec":                          "mtx",
	"nabi":                                  "mty",
	"mundang":                               "mua",
	"mubi":                                  "mub",
	"ajumbu":                                "muc",
	"mednyj aleut":                          "mud",
	"media lengua":                          "mue",
	"musgu":                                 "mug",
	"mündü":                                 "muh",
	"musi":                                  "mui",
	"mabire":                                "muj",
	"mugom":                                 "muk",
	"multiple languages":                    "mul",
	"maiwala":                               "mum",
	"nyong":                                 "muo",
	"malvi":                                 "mup",
	"eastern xiangxi miao":                  "muq",
	"murle":                                 "mur",
	"creek":                                 "mus",
	"western muria":                         "mut",
	"yaaku":                                 "muu",
	"muthuvan":                              "muv",
	"bo-ung":                                "mux",
	"muyang":                                "muy",
	"mursi":                                 "muz",
	"manam":                                 "mva",
	"mattole":                               "mvb",
	"mamboru":                               "mvd",
	"marwari (pakistan)":                    "mve",
	"peripheral mongolian":                  "mvf",
	"yucuañe mixtec":                        "mvg",
	"mulgi":                                 "mvh",
	"miyako":                                "mvi",
	"mekmek":                                "mvk",
	"mbara (australia)":                     "mvl",
	"muya":                                  "mvm",
	"minaveha":                              "mvn",
	"marovo":                                "mvo",
	"duri":                                  "mvp",
	"moere":                                 "mvq",
	"marau":                                 "mvr",
	"massep":                                "mvs",
	"mpotovoro":                             "mvt",
	"marfa":                                 "mvu",
	"tagal murut":                           "mvv",
	"machinga":                              "mvw",
	"meoswar":                               "mvx",
	"indus kohistani":                       "mvy",
	"mesqan":                                "mvz",
	"mwatebu":                               "mwa",
	"juwal":                                 "mwb",
	"are":                                   "mwc",
	"mwera (chimwera)":                      "mwe",
	"murrinh-patha":                         "mwf",
	"aiklep":                                "mwg",
	"mouk-aria":                             "mwh",
	"labo":                                  "mwi",
	"kita maninkakan":                       "mwk",
	"mirandese":                             "mwl",
	"sar":                                   "mwm",
	"nyamwanga":                             "mwn",
	"central maewo":                         "mwo",
	"kala lagaw ya":                         "mwp",
	"mün chin":                              "mwq",
	"marwari":                               "mwr",
	"mwimbi-muthambi":                       "mws",
	"moken":                                 "mwt",
	"mittu":                                 "mwu",
	"mentawai":                              "mwv",
	"hmong daw":                             "mww",
	"mediak":                                "mwx",
	"mosiro":                                "mwy",
	"moingi":                                "mwz",
	"northwest oaxaca mixtec":               "mxa",
	"tezoatlán mixtec":                      "mxb",
	"manyika":                               "mxc",
	"modang":                                "mxd",
	"mele-fila":                             "mxe",
	"malgbe":                                "mxf",
	"mbangala":                              "mxg",
	"mvuba":                                 "mxh",
	"mozarabic":                             "mxi",
	"miju-mishmi":                           "mxj",
	"monumbo":                               "mxk",
	"maxi gbe":                              "mxl",
	"meramera":                              "mxm",
	"moi (indonesia)":                       "mxn",
	"mbowe":                                 "mxo",
	"tlahuitoltepec mixe":                   "mxp",
	"juquila mixe":                          "mxq",
	"murik (malaysia)":                      "mxr",
	"huitepec mixtec":                       "mxs",
	"jamiltepec mixtec":                     "mxt",
	"mada (cameroon)":                       "mxu",
	"metlatónoc mixtec":                     "mxv",
	"namo":                                  "mxw",
	"mahou":                                 "mxx",
	"southeastern nochixtlán mixtec":        "mxy",
	"central masela":                        "mxz",
	"burmese":                               "mya",
	"mbay":                                  "myb",
	"mayeka":                                "myc",
	"maramba":                               "myd",
	"myene":                                 "mye",
	"bambassi":                              "myf",
	"manta":                                 "myg",
	"makah":                                 "myh",
	"mina (india)":                          "myi",
	"mangayat":                              "myj",
	"mamara senoufo":                        "myk",
	"moma":                                  "myl",
	"me'en":                                 "mym",
	"anfillo":                               "myo",
	"pirahã":                                "myp",
	"muniche":                               "myr",
	"mesmes":                                "mys",
	"mundurukú":                             "myu",
	"erzya":                                 "myv",
	"muyuw":                                 "myw",
	"masaaba":                               "myx",
	"macuna":                                "myy",
	"classical mandaic":                     "myz",
	"santa maría zacatepec mixtec":          "mza",
	"tumzabt":                               "mzb",
	"madagascar sign language":              "mzc",
	"malimba":                               "mzd",
	"morawa":                                "mze",
	"monastic sign language":                "mzg",
	"wichí lhamtés güisnay":                 "mzh",
	"ixcatlán mazatec":                      "mzi",
	"manya":                                 "mzj",
	"nigeria mambila":                       "mzk",
	"mazatlán mixe":                         "mzl",
	"mumuye":                                "mzm",
	"mazanderani":                           "mzn",
	"matipuhy":                              "mzo",
	"movima":                                "mzp",
	"mori atas":                             "mzq",
	"marúbo":                                "mzr",
	"macanese":                              "mzs",
	"mintil":                                "mzt",
	"inapang":                               "mzu",
	"manza":                                 "mzv",
	"deg":                                   "mzw",
	"mawayana":                              "mzx",
	"mozambican sign language":              "mzy",
	"maiadomu":                              "mzz",
	"namla":                                 "naa",
	"southern nambikuára":                   "nab",
	"narak":                                 "nac",
	"naka'ela":                              "nae",
	"nabak":                                 "naf",
	"naga pidgin":                           "nag",
	"nalu":                                  "naj",
	"nakanai":                               "nak",
	"nalik":                                 "nal",
	"ngan'gityemerri":                       "nam",
	"min nan chinese":                       "nan",
	"naaba":                                 "nao",
	"neapolitan":                            "nap",
	"khoekhoe":                              "naq",
	"iguta":                                 "nar",
	"naasioi":                               "nas",
	"ca̱hungwa̱rya̱":                        "nat",
	"nauru":                                 "nau",
	"navajo":                                "nav",
	"nawuri":                                "naw",
	"nakwi":                                 "nax",
	"narrinyeri":                            "nay",
	"coatepec nahuatl":                      "naz",
	"nyemba":                                "nba",
	"ndoe":                                  "nbb",
	"chang naga":                            "nbc",
	"ngbinda":                               "nbd",
	"konyak naga":                           "nbe",
	"nagarchal":                             "nbg",
	"ngamo":                                 "nbh",
	"mao naga":                              "nbi",
	"ngarinman":                             "nbj",
	"nake":                                  "nbk",
	"south ndebele":                         "nbl",
	"ngbaka ma'bo":                          "nbm",
	"kuri":                                  "nbn",
	"nkukoli":                               "nbo",
	"nnam":                                  "nbp",
	"nggem":                                 "nbq",
	"numana-nunku-gbantu-numbu":             "nbr",
	"namibian sign language":                "nbs",
	"na":                                    "nbt",
	"rongmei naga":                          "nbu",
	"ngamambo":                              "nbv",
	"southern ngbandi":                      "nbw",
	"ningera":                               "nby",
	"iyo":                                   "nca",
	"central nicobarese":                    "ncb",
	"ponam":                                 "ncc",
	"nachering":                             "ncd",
	"yale":                                  "nce",
	"notsi":                                 "ncf",
	"nisga'a":                               "ncg",
	"central huasteca nahuatl":              "nch",
	"classical nahuatl":                     "nci",
	"northern puebla nahuatl":               "ncj",
	"nakara":                                "nck",
	"michoacán nahuatl":                     "ncl",
	"nambo":                                 "ncm",
	"nauna":                                 "ncn",
	"sibe":                                  "nco",
	"ndaktup":                               "ncp",
	"northern katang":                       "ncq",
	"ncane":                                 "ncr",
	"nicaraguan sign language":              "ncs",
	"chothe naga":                           "nct",
	"chumburung":                            "ncu",
	"central puebla nahuatl":                "ncx",
	"natchez":                               "ncz",
	"ndasa":                                 "nda",
	"kenswei nsei":                          "ndb",
	"ndau":                                  "ndc",
	"nde-nsele-nta":                         "ndd",
	"north ndebele":                         "nde",
	"nadruvian":                             "ndf",
	"ndengereko":                            "ndg",
	"ndali":                                 "ndh",
	"samba leko":                            "ndi",
	"ndamba":                                "ndj",
	"ndaka":                                 "ndk",
	"ndolo":                                 "ndl",
	"ndam":                                  "ndm",
	"ngundi":                                "ndn",
	"ndonga":                                "ndo",
	"ndo":                                   "ndp",
	"ndombe":                                "ndq",
	"ndoola":                                "ndr",
	"low german":                            "nds",
	"ndunga":                                "ndt",
	"dugun":                                 "ndu",
	"ndut":                                  "ndv",
	"ndobo":                                 "ndw",
	"nduga":                                 "ndx",
	"lutos":                                 "ndy",
	"ndogo":                                 "ndz",
	"eastern ngad'a":                        "nea",
	"toura (côte d'ivoire)":                 "neb",
	"nedebang":                              "nec",
	"nde-gbite":                             "ned",
	"nêlêmwa-nixumwak":                      "nee",
	"nefamese":                              "nef",
	"negidal":                               "neg",
	"nyenkha":                               "neh",
	"neo-hittite":                           "nei",
	"neko":                                  "nej",
	"neku":                                  "nek",
	"nemi":                                  "nem",
	"nengone":                               "nen",
	"ná-meo":                                "neo",
	"nepali (macrolanguage)":                "nep",
	"north central mixe":                    "neq",
	"yahadian":                              "ner",
	"bhoti kinnauri":                        "nes",
	"nete":                                  "net",
	"neo":                                   "neu",
	"nyaheun":                               "nev",
	"newari":                                "new",
	"neme":                                  "nex",
	"neyo":                                  "ney",
	"nez perce":                             "nez",
	"dhao":                                  "nfa",
	"ahwai":                                 "nfd",
	"ayiwo":                                 "nfl",
	"nafaanra":                              "nfr",
	"mfumte":                                "nfu",
	"ngbaka":                                "nga",
	"northern ngbandi":                      "ngb",
	"ngombe (democratic republic of congo)": "ngc",
	"ngando (central african republic)":     "ngd",
	"ngemba":                                "nge",
	"ngbaka manza":                          "ngg",
	"n/u":                                   "ngh",
	"ngizim":                                "ngi",
	"ngie":                                  "ngj",
	"dalabon":                               "ngk",
	"lomwe":                                 "ngl",
	"ngatik men's creole":                   "ngm",
	"ngwo":                                  "ngn",
	"ngoni":                                 "ngo",
	"ngulu":                                 "ngp",
	"ngurimi":                               "ngq",
	"engdewu":                               "ngr",
	"gvoko":                                 "ngs",
	"kriang":                                "ngt",
	"guerrero nahuatl":                      "ngu",
	"nagumi":                                "ngv",
	"ngwaba":                                "ngw",
	"nggwahyi":                              "ngx",
	"tibea":                                 "ngy",
	"ngungwel":                              "ngz",
	"nhanda":                                "nha",
	"beng":                                  "nhb",
	"tabasco nahuatl":                       "nhc",
	"chiripá":                               "nhd",
	"eastern huasteca nahuatl":              "nhe",
	"nhuwala":                               "nhf",
	"tetelcingo nahuatl":                    "nhg",
	"nahari":                                "nhh",
	"zacatlán-ahuacatlán-tepetzintla nahuatl": "nhi",
	"isthmus-cosoleacaque nahuatl":            "nhk",
	"morelos nahuatl":                         "nhm",
	"central nahuatl":                         "nhn",
	"takuu":                                   "nho",
	"isthmus-pajapan nahuatl":                 "nhp",
	"huaxcaleca nahuatl":                      "nhq",
	"naro":                                    "nhr",
	"ometepec nahuatl":                        "nht",
	"noone":                                   "nhu",
	"temascaltepec nahuatl":                   "nhv",
	"western huasteca nahuatl":                "nhw",
	"isthmus-mecayapan nahuatl":               "nhx",
	"northern oaxaca nahuatl":                 "nhy",
	"santa maría la alta nahuatl":             "nhz",
	"nias":                                    "nia",
	"nakame":                                  "nib",
	"ngandi":                                  "nid",
	"niellim":                                 "nie",
	"nek":                                     "nif",
	"ngalakan":                                "nig",
	"nyiha (tanzania)":                        "nih",
	"nii":                                     "nii",
	"ngaju":                                   "nij",
	"southern nicobarese":                     "nik",
	"nila":                                    "nil",
	"nilamba":                                 "nim",
	"ninzo":                                   "nin",
	"nganasan":                                "nio",
	"nandi":                                   "niq",
	"nimboran":                                "nir",
	"nimi":                                    "nis",
	"southeastern kolami":                     "nit",
	"niuean":                                  "niu",
	"gilyak":                                  "niv",
	"nimo":                                    "niw",
	"hema":                                    "nix",
	"ngiti":                                   "niy",
	"ningil":                                  "niz",
	"nzanyi":                                  "nja",
	"nocte naga":                              "njb",
	"ndonde hamba":                            "njd",
	"lotha naga":                              "njh",
	"gudanji":                                 "nji",
	"njen":                                    "njj",
	"njalgulgule":                             "njl",
	"angami naga":                             "njm",
	"liangmai naga":                           "njn",
	"ao naga":                                 "njo",
	"njerep":                                  "njr",
	"nisa":                                    "njs",
	"ndyuka-trio pidgin":                      "njt",
	"ngadjunmaya":                             "nju",
	"kunyi":                                   "njx",
	"njyem":                                   "njy",
	"nyishi":                                  "njz",
	"nkoya":                                   "nka",
	"khoibu naga":                             "nkb",
	"nkongho":                                 "nkc",
	"koireng":                                 "nkd",
	"duke":                                    "nke",
	"inpui naga":                              "nkf",
	"nekgini":                                 "nkg",
	"khezha naga":                             "nkh",
	"thangal naga":                            "nki",
	"nakai":                                   "nkj",
	"nokuku":                                  "nkk",
	"namat":                                   "nkm",
	"nkangala":                                "nkn",
	"nkonya":                                  "nko",
	"niuatoputapu":                            "nkp",
	"nkami":                                   "nkq",
	"nukuoro":                                 "nkr",
	"north asmat":                             "nks",
	"nyika (tanzania)":                        "nkt",
	"bouna kulango":                           "nku",
	"nyika (malawi and zambia)":               "nkv",
	"nkutu":                                   "nkw",
	"nkoroo":                                  "nkx",
	"nkari":                                   "nkz",
	"ngombale":                                "nla",
	"nalca":                                   "nlc",
	"dutch":                                   "nld",
	"east nyala":                              "nle",
	"gela":                                    "nlg",
	"grangali":                                "nli",
	"nyali":                                   "nlj",
	"ninia yali":                              "nlk",
	"nihali":                                  "nll",
	"ngul":                                    "nlo",
	"lao naga":                                "nlq",
	"nchumbulu":                               "nlu",
	"orizaba nahuatl":                         "nlv",
	"walangama":                               "nlw",
	"nahali":                                  "nlx",
	"nyamal":                                  "nly",
	"nalögo":                                  "nlz",
	"maram naga":                              "nma",
	"big nambas":                              "nmb",
	"ngam":                                    "nmc",
	"ndumu":                                   "nmd",
	"mzieme naga":                             "nme",
	"tangkhul naga (india)":                   "nmf",
	"kwasio":                                  "nmg",
	"monsang naga":                            "nmh",
	"nyam":                                    "nmi",
	"ngombe (central african republic)":       "nmj",
	"namakura":                                "nmk",
	"ndemli":                                  "nml",
	"manangba":                                "nmm",
	"!xóõ":                                    "nmn",
	"moyon naga":                              "nmo",
	"nimanbur":                                "nmp",
	"nambya":                                  "nmq",
	"nimbari":                                 "nmr",
	"letemboi":                                "nms",
	"namonuito":                               "nmt",
	"northeast maidu":                         "nmu",
	"ngamini":                                 "nmv",
	"nimoa":                                   "nmw",
	"nama (papua new guinea)":                 "nmx",
	"namuyi":                                  "nmy",
	"nawdm":                                   "nmz",
	"nyangumarta":                             "nna",
	"nande":                                   "nnb",
	"nancere":                                 "nnc",
	"west ambae":                              "nnd",
	"ngandyera":                               "nne",
	"ngaing":                                  "nnf",
	"maring naga":                             "nng",
	"ngiemboon":                               "nnh",
	"north nuaulu":                            "nni",
	"nyangatom":                               "nnj",
	"nankina":                                 "nnk",
	"northern rengma naga":                    "nnl",
	"namia":                                   "nnm",
	"ngete":                                   "nnn",
	"norwegian nynorsk":                       "nno",
	"wancho naga":                             "nnp",
	"ngindo":                                  "nnq",
	"narungga":                                "nnr",
	"ningye":                                  "nns",
	"nanticoke":                               "nnt",
	"dwang":                                   "nnu",
	"nugunu (australia)":                      "nnv",
	"southern nuni":                           "nnw",
	"nyangga":                                 "nny",
	"nda'nda'":                                "nnz",
	"woun meu":                                "noa",
	"norwegian bokmål":                        "nob",
	"nuk":                                     "noc",
	"northern thai":                           "nod",
	"nimadi":                                  "noe",
	"nomane":                                  "nof",
	"nogai":                                   "nog",
	"nomu":                                    "noh",
	"noiri":                                   "noi",
	"nonuya":                                  "noj",
	"nooksack":                                "nok",
	"nomlaki":                                 "nol",
	"nocamán":                                 "nom",
	"old norse":                               "non",
	"numanggang":                              "nop",
	"ngongo":                                  "noq",
	"norwegian":                               "nor",
	"eastern nisu":                            "nos",
	"nomatsiguenga":                           "not",
	"ewage-notu":                              "nou",
	"novial":                                  "nov",
	"nyambo":                                  "now",
	"noy":                                     "noy",
	"nayi":                                    "noz",
	"nar phu":                                 "npa",
	"nupbikha":                                "npb",
	"ponyo-gongwang naga":                     "npg",
	"phom naga":                               "nph",
	"nepali (individual language)":            "npi",
	"southeastern puebla nahuatl":             "npl",
	"mondropolon":                             "npn",
	"pochuri naga":                            "npo",
	"nipsan":                                  "nps",
	"puimei naga":                             "npu",
	"noipx":                                   "npx",
	"napu":                                    "npy",
	"southern nago":                           "nqg",
	"kura ede nago":                           "nqk",
	"ngendelengo":                             "nql",
	"ndom":                                    "nqm",
	"nen":                                     "nqn",
	"n'ko":                                    "nqo",
	"kyan-karyaw naga":                        "nqq",
	"akyaung ari naga":                        "nqy",
	"ngom":                                    "nra",
	"nara":                                    "nrb",
	"noric":                                   "nrc",
	"southern rengma naga":                    "nre",
	"jèrriais":                                "nrf",
	"narango":                                 "nrg",
	"chokri naga":                             "nri",
	"ngarla":                                  "nrk",
	"ngarluma":                                "nrl",
	"narom":                                   "nrm",
	"norn":                                    "nrn",
	"north picene":                            "nrp",
	"norra":                                   "nrr",
	"northern kalapuya":                       "nrt",
	"narua":                                   "nru",
	"ngurmbur":                                "nrx",
	"lala":                                    "nrz",
	"sangtam naga":                            "nsa",
	"nshi":                                    "nsc",
	"southern nisu":                           "nsd",
	"nsenga":                                  "nse",
	"northwestern nisu":                       "nsf",
	"ngasa":                                   "nsg",
	"ngoshie":                                 "nsh",
	"nigerian sign language":                  "nsi",
	"naskapi":                                 "nsk",
	"norwegian sign language":                 "nsl",
	"sumi naga":                               "nsm",
	"nehan":                                   "nsn",
	"pedi":                                    "nso",
	"nepalese sign language":                  "nsp",
	"northern sierra miwok":                   "nsq",
	"maritime sign language":                  "nsr",
	"nali":                                    "nss",
	"tase naga":                               "nst",
	"sierra negra nahuatl":                    "nsu",
	"southwestern nisu":                       "nsv",
	"navut":                                   "nsw",
	"nsongo":                                  "nsx",
	"nasal":                                   "nsy",
	"nisenan":                                 "nsz",
	"northern tidung":                         "ntd",
	"nathembo":                                "nte",
	"ngantangarra":                            "ntg",
	"natioro":                                 "nti",
	"ngaanyatjarra":                           "ntj",
	"ikoma-nata-isenye":                       "ntk",
	"nateni":                                  "ntm",
	"ntomba":                                  "nto",
	"northern tepehuan":                       "ntp",
	"delo":                                    "ntr",
	"natügu":                                  "ntu",
	"nottoway":                                "ntw",
	"tangkhul naga (myanmar)":                 "ntx",
	"mantsi":                                  "nty",
	"natanzi":                                 "ntz",
	"yuanga":                                  "nua",
	"nukuini":                                 "nuc",
	"ngala":                                   "nud",
	"ngundu":                                  "nue",
	"nusu":                                    "nuf",
	"nungali":                                 "nug",
	"ndunda":                                  "nuh",
	"ngumbi":                                  "nui",
	"nyole":                                   "nuj",
	"nuu-chah-nulth":                          "nuk",
	"nusa laut":                               "nul",
	"niuafo'ou":                               "num",
	"anong":                                   "nun",
	"nguôn":                                   "nuo",
	"nupe-nupe-tako":                          "nup",
	"nukumanu":                                "nuq",
	"nukuria":                                 "nur",
	"nuer":                                    "nus",
	"nung (viet nam)":                         "nut",
	"ngbundu":                                 "nuu",
	"northern nuni":                           "nuv",
	"nguluwan":                                "nuw",
	"mehek":                                   "nux",
	"nunggubuyu":                              "nuy",
	"tlamacazapa nahuatl":                     "nuz",
	"nasarian":                                "nvh",
	"namiae":                                  "nvm",
	"nyokon":                                  "nvo",
	"nawathinehena":                           "nwa",
	"nyabwa":                                  "nwb",
	"classical newari":                        "nwc",
	"ngwe":                                    "nwe",
	"ngayawung":                               "nwg",
	"southwest tanna":                         "nwi",
	"nyamusa-molo":                            "nwm",
	"nauo":                                    "nwo",
	"nawaru":                                  "nwr",
	"middle newar":                            "nwx",
	"nottoway-meherrin":                       "nwy",
	"nauete":                                  "nxa",
	"ngando (democratic republic of congo)":   "nxd",
	"nage":                                    "nxe",
	"ngad'a":                                  "nxg",
	"nindi":                                   "nxi",
	"koki naga":                               "nxk",
	"south nuaulu":                            "nxl",
	"numidian":                                "nxm",
	"ngawun":                                  "nxn",
	"ndambomo":                                "nxo",
	"naxi":                                    "nxq",
	"ninggerum":                               "nxr",
	"narau":                                   "nxu",
	"nafri":                                   "nxx",
	"nyanja":                                  "nya",
	"nyangbo":                                 "nyb",
	"nyanga-li":                               "nyc",
	"nyore":                                   "nyd",
	"nyengo":                                  "nye",
	"giryama":                                 "nyf",
	"nyindu":                                  "nyg",
	"nyigina":                                 "nyh",
	"ama (sudan)":                             "nyi",
	"nyanga":                                  "nyj",
	"nyaneka":                                 "nyk",
	"nyeu":                                    "nyl",
	"nyamwezi":                                "nym",
	"nyankole":                                "nyn",
	"nyoro":                                   "nyo",
	"nyang'i":                                 "nyp",
	"nayini":                                  "nyq",
	"nyiha (malawi)":                          "nyr",
	"nyunga":                                  "nys",
	"nyawaygi":                                "nyt",
	"nyungwe":                                 "nyu",
	"nyulnyul":                                "nyv",
	"nyaw":                                    "nyw",
	"nganyaywana":                             "nyx",
	"nyakyusa-ngonde":                         "nyy",
	"tigon mbembe":                            "nza",
	"njebi":                                   "nzb",
	"nzima":                                   "nzi",
	"nzakara":                                 "nzk",
	"zeme naga":                               "nzm",
	"new zealand sign language":               "nzs",
	"teke-nzikou":                             "nzu",
	"nzakambay":                               "nzy",
	"nanga dama dogon":                        "nzz",
	"orok":                                    "oaa",
	"oroch":                                   "oac",
	"old aramaic (up to 700 bce)":             "oar",
	"old avar":                                "oav",
	"obispeño":                                "obi",
	"southern bontok":                         "obk",
	"oblo":                                    "obl",
	"moabite":                                 "obm",
	"obo manobo":                              "obo",
	"old burmese":                             "obr",
	"old breton":                              "obt",
	"obulom":                                  "obu",
	"ocaina":                                  "oca",
	"old chinese":                             "och",
	"occitan (post 1500)":                     "oci",
	"old cornish":                             "oco",
	"atzingo matlatzinca":                     "ocu",
	"odut":                                    "oda",
	"od":                                      "odk",
	"old dutch":                               "odt",
	"odual":                                   "odu",
	"ofo":                                     "ofo",
	"old frisian":                             "ofs",
	"efutop":                                  "ofu",
	"ogbia":                                   "ogb",
	"ogbah":                                   "ogc",
	"old georgian":                            "oge",
	"ogbogolo":                                "ogg",
	"khana":                                   "ogo",
	"ogbronuagum":                             "ogu",
	"old hittite":                             "oht",
	"old hungarian":                           "ohu",
	"oirata":                                  "oia",
	"inebu one":                               "oin",
	"northwestern ojibwa":                     "ojb",
	"central ojibwa":                          "ojc",
	"eastern ojibwa":                          "ojg",
	"ojibwa":                                  "oji",
	"old japanese":                            "ojp",
	"severn ojibwa":                           "ojs",
	"ontong java":                             "ojv",
	"western ojibwa":                          "ojw",
	"okanagan":                                "oka",
	"okobo":                                   "okb",
	"okodia":                                  "okd",
	"okpe (southwestern edo)":                 "oke",
	"koko babangk":                            "okg",
	"koresh-e rostam":                         "okh",
	"okiek":                                   "oki",
	"oko-juwoi":                               "okj",
	"kwamtim one":                             "okk",
	"old kentish sign language":               "okl",
	"middle korean (10th-16th cent.)":         "okm",
	"oki-no-erabu":                            "okn",
	"old korean (3rd-9th cent.)":              "oko",
	"kirike":                                  "okr",
	"oko-eni-osayen":                          "oks",
	"oku":                                     "oku",
	"orokaiva":                                "okv",
	"okpe (northwestern edo)":                 "okx",
	"walungge":                                "ola",
	"mochi":                                   "old",
	"olekha":                                  "ole",
	"olkol":                                   "olk",
	"oloma":                                   "olm",
	"livvi":                                   "olo",
	"olrat":                                   "olr",
	"old lithuanian":                          "olt",
	"kuvale":                                  "olu",
	"omaha-ponca":                             "oma",
	"east ambae":                              "omb",
	"mochica":                                 "omc",
	"omagua":                                  "omg",
	"omi":                                     "omi",
	"omok":                                    "omk",
	"ombo":                                    "oml",
	"minoan":                                  "omn",
	"utarmbung":                               "omo",
	"old manipuri":                            "omp",
	"old marathi":                             "omr",
	"omotik":                                  "omt",
	"omurano":                                 "omu",
	"south tairora":                           "omw",
	"old mon":                                 "omx",
	"ona":                                     "ona",
	"lingao":                                  "onb",
	"oneida":                                  "one",
	"olo":                                     "ong",
	"onin":                                    "oni",
	"onjob":                                   "onj",
	"kabore one":                              "onk",
	"onobasulu":                               "onn",
	"onondaga":                                "ono",
	"sartang":                                 "onp",
	"northern one":                            "onr",
	"ono":                                     "ons",
	"ontenu":                                  "ont",
	"unua":                                    "onu",
	"old nubian":                              "onw",
	"onin based pidgin":                       "onx",
	"tohono o'odham":                          "ood",
	"ong":                                     "oog",
	"önge":                                    "oon",
	"oorlams":                                 "oor",
	"old ossetic":                             "oos",
	"okpamheri":                               "opa",
	"kopkaka":                                 "opk",
	"oksapmin":                                "opm",
	"opao":                                    "opo",
	"opata":                                   "opt",
	"ofayé":                                   "opy",
	"oroha":                                   "ora",
	"orma":                                    "orc",
	"orejón":                                  "ore",
	"oring":                                   "org",
	"oroqen":                                  "orh",
	"oriya (macrolanguage)":                   "ori",
	"oromo":                                   "orm",
	"orang kanaq":                             "orn",
	"orokolo":                                 "oro",
	"oruma":                                   "orr",
	"orang seletar":                           "ors",
	"adivasi oriya":                           "ort",
	"ormuri":                                  "oru",
	"old russian":                             "orv",
	"oro win":                                 "orw",
	"oro":                                     "orx",
	"odia":                                    "ory",
	"ormu":                                    "orz",
	"osage":                                   "osa",
	"oscan":                                   "osc",
	"osing":                                   "osi",
	"ososo":                                   "oso",
	"old spanish":                             "osp",
	"ossetian":                                "oss",
	"osatu":                                   "ost",
	"southern one":                            "osu",
	"old saxon":                               "osx",
	"ottoman turkish (1500-1928)":             "ota",
	"old tibetan":                             "otb",
	"ot danum":                                "otd",
	"mezquital otomi":                         "ote",
	"oti":                                     "oti",
	"old turkish":                             "otk",
	"tilapa otomi":                            "otl",
	"eastern highland otomi":                  "otm",
	"tenango otomi":                           "otn",
	"querétaro otomi":                         "otq",
	"otoro":                                   "otr",
	"estado de méxico otomi":                  "ots",
	"temoaya otomi":                           "ott",
	"otuke":                                   "otu",
	"ottawa":                                  "otw",
	"texcatepec otomi":                        "otx",
	"old tamil":                               "oty",
	"ixtenco otomi":                           "otz",
	"tagargrent":                              "oua",
	"glio-oubi":                               "oub",
	"oune":                                    "oue",
	"old uighur":                              "oui",
	"ouma":                                    "oum",
	"elfdalian":                               "ovd",
	"owiniga":                                 "owi",
	"old welsh":                               "owl",
	"oy":                                      "oyb",
	"oyda":                                    "oyd",
	"wayampi":                                 "oym",
	"oya'oya":                                 "oyy",
	"koonzime":                                "ozm",
	"parecís":                                 "pab",
	"pacoh":                                   "pac",
	"paumarí":                                 "pad",
	"pagibete":                                "pae",
	"paranawát":                               "paf",
	"pangasinan":                              "pag",
	"tenharim":                                "pah",
	"pe":                                      "pai",
	"parakanã":                                "pak",
	"pahlavi":                                 "pal",
	"pampanga":                                "pam",
	"panjabi":                                 "pan",
	"northern paiute":                         "pao",
	"papiamento":                              "pap",
	"parya":                                   "paq",
	"panamint":                                "par",
	"papasena":                                "pas",
	"papitalai":                               "pat",
	"palauan":                                 "pau",
	"pakaásnovos":                             "pav",
	"pawnee":                                  "paw",
	"pankararé":                               "pax",
	"pech":                                    "pay",
	"pankararú":                               "paz",
	"páez":                                    "pbb",
	"patamona":                                "pbc",
	"mezontla popoloca":                       "pbe",
	"coyotepec popoloca":                      "pbf",
	"paraujano":                               "pbg",
	"e'ñapa woromaipu":                        "pbh",
	"parkwa":                                  "pbi",
	"mak (nigeria)":                           "pbl",
	"kpasam":                                  "pbn",
	"papel":                                   "pbo",
	"badyara":                                 "pbp",
	"pangwa":                                  "pbr",
	"central pame":                            "pbs",
	"southern pashto":                         "pbt",
	"northern pashto":                         "pbu",
	"pnar":                                    "pbv",
	"pyu (papua new guinea)":                  "pby",
	"santa inés ahuatempan popoloca":          "pca",
	"pear":                                    "pcb",
	"bouyei":                                  "pcc",
	"picard":                                  "pcd",
	"ruching palaung":                         "pce",
	"paliyan":                                 "pcf",
	"paniya":                                  "pcg",
	"pardhan":                                 "pch",
	"duruwa":                                  "pci",
	"parenga":                                 "pcj",
	"paite chin":                              "pck",
	"pardhi":                                  "pcl",
	"nigerian pidgin":                         "pcm",
	"piti":                                    "pcn",
	"pacahuara":                               "pcp",
	"pyapun":                                  "pcw",
	"anam":                                    "pda",
	"pennsylvania german":                     "pdc",
	"pa di":                                   "pdi",
	"podena":                                  "pdn",
	"padoe":                                   "pdo",
	"plautdietsch":                            "pdt",
	"kayan":                                   "pdu",
	"peranakan indonesian":                    "pea",
	"eastern pomo":                            "peb",
	"mala (papua new guinea)":                 "ped",
	"taje":                                    "pee",
	"northeastern pomo":                       "pef",
	"pengo":                                   "peg",
	"bonan":                                   "peh",
	"chichimeca-jonaz":                        "pei",
	"northern pomo":                           "pej",
	"penchal":                                 "pek",
	"pekal":                                   "pel",
	"phende":                                  "pem",
	"old persian (ca. 600-400 b.c.)":          "peo",
	"kunja":                                   "pep",
	"southern pomo":                           "peq",
	"iranian persian":                         "pes",
	"pémono":                                  "pev",
	"petats":                                  "pex",
	"petjo":                                   "pey",
	"eastern penan":                           "pez",
	"pááfang":                                 "pfa",
	"peere":                                   "pfe",
	"pfaelzisch":                              "pfl",
	"sudanese creole arabic":                  "pga",
	"gāndhārī":                                "pgd",
	"pangwali":                                "pgg",
	"pagi":                                    "pgi",
	"rerep":                                   "pgk",
	"primitive irish":                         "pgl",
	"paelignian":                              "pgn",
	"pangseng":                                "pgs",
	"pagu":                                    "pgu",
	"papua new guinean sign language":         "pgz",
	"pa-hng":                                  "pha",
	"phudagi":                                 "phd",
	"phuong":                                  "phg",
	"phukha":                                  "phh",
	"phake":                                   "phk",
	"phalura":                                 "phl",
	"phimbi":                                  "phm",
	"phoenician":                              "phn",
	"phunoi":                                  "pho",
	"phana'":                                  "phq",
	"pahari-potwari":                          "phr",
	"phu thai":                                "pht",
	"phuan":                                   "phu",
	"pahlavani":                               "phv",
	"phangduwali":                             "phw",
	"pima bajo":                               "pia",
	"yine":                                    "pib",
	"pinji":                                   "pic",
	"piaroa":                                  "pid",
	"piro":                                    "pie",
	"pingelapese":                             "pif",
	"pisabo":                                  "pig",
	"pitcairn-norfolk":                        "pih",
	"pini":                                    "pii",
	"pijao":                                   "pij",
	"yom":                                     "pil",
	"powhatan":                                "pim",
	"piame":                                   "pin",
	"piapoco":                                 "pio",
	"pero":                                    "pip",
	"piratapuyo":                              "pir",
	"pijin":                                   "pis",
	"pitta pitta":                             "pit",
	"pintupi-luritja":                         "piu",
	"pileni":                                  "piv",
	"pimbwe":                                  "piw",
	"piu":                                     "pix",
	"piya-kwonci":                             "piy",
	"pije":                                    "piz",
	"pitjantjatjara":                          "pjt",
	"ardhamāgadhī prākrit":                    "pka",
	"pokomo":                                  "pkb",
	"paekche":                                 "pkc",
	"pak-tong":                                "pkg",
	"pankhu":                                  "pkh",
	"pakanha":                                 "pkn",
	"pökoot":                                  "pko",
	"pukapuka":                                "pkp",
	"attapady kurumba":                        "pkr",
	"pakistan sign language":                  "pks",
	"maleng":                                  "pkt",
	"paku":                                    "pku",
	"miani":                                   "pla",
	"polonombauk":                             "plb",
	"central palawano":                        "plc",
	"polari":                                  "pld",
	"palu'e":                                  "ple",
	"pilagá":                                  "plg",
	"paulohi":                                 "plh",
	"pali":                                    "pli",
	"polci":                                   "plj",
	"kohistani shina":                         "plk",
	"shwe palaung":                            "pll",
	"palenquero":                              "pln",
	"oluta popoluca":                          "plo",
	"palpa":                                   "plp",
	"palaic":                                  "plq",
	"palaka senoufo":                          "plr",
	"san marcos tlacoyalco popoloca":          "pls",
	"plateau malagasy":                        "plt",
	"palikúr":                                 "plu",
	"southwest palawano":                      "plv",
	"brooke's point palawano":                 "plw",
	"bolyu":                                   "ply",
	"paluan":                                  "plz",
	"paama":                                   "pma",
	"pambia":                                  "pmb",
	"pallanganmiddang":                        "pmd",
	"pwaamei":                                 "pme",
	"pamona":                                  "pmf",
	"māhārāṣṭri prākrit":                      "pmh",
	"northern pumi":                           "pmi",
	"southern pumi":                           "pmj",
	"pamlico":                                 "pmk",
	"lingua franca":                           "pml",
	"pomo":                                    "pmm",
	"pam":                                     "pmn",
	"pom":                                     "pmo",
	"northern pame":                           "pmq",
	"paynamar":                                "pmr",
	"piemontese":                              "pms",
	"tuamotuan":                               "pmt",
	"plains miwok":                            "pmw",
	"poumei naga":                             "pmx",
	"papuan malay":                            "pmy",
	"southern pame":                           "pmz",
	"punan bah-biau":                          "pna",
	"western panjabi":                         "pnb",
	"pannei":                                  "pnc",
	"western penan":                           "pne",
	"pongu":                                   "png",
	"penrhyn":                                 "pnh",
	"aoheng":                                  "pni",
	"pinjarup":                                "pnj",
	"paunaka":                                 "pnk",
	"paleni":                                  "pnl",
	"punan batu 1":                            "pnm",
	"pinai-hagahai":                           "pnn",
	"panobo":                                  "pno",
	"pancana":                                 "pnp",
	"pana (burkina faso)":                     "pnq",
	"panim":                                   "pnr",
	"ponosakan":                               "pns",
	"pontic":                                  "pnt",
	"jiongnai bunu":                           "pnu",
	"pinigura":                                "pnv",
	"panytyima":                               "pnw",
	"phong-kniang":                            "pnx",
	"pinyin":                                  "pny",
	"pana (central african republic)":         "pnz",
	"poqomam":                                 "poc",
	"san juan atzingo popoloca":               "poe",
	"poke":                                    "pof",
	"potiguára":                               "pog",
	"poqomchi'":                               "poh",
	"highland popoluca":                       "poi",
	"pokangá":                                 "pok",
	"polish":                                  "pol",
	"southeastern pomo":                       "pom",
	"pohnpeian":                               "pon",
	"central pomo":                            "poo",
	"pwapwâ":                                  "pop",
	"texistepec popoluca":                     "poq",
	"portuguese":                              "por",
	"sayula popoluca":                         "pos",
	"potawatomi":                              "pot",
	"upper guinea crioulo":                    "pov",
	"san felipe otlaltepec popoloca":          "pow",
	"polabian":                                "pox",
	"pogolo":                                  "poy",
	"papi":                                    "ppe",
	"paipai":                                  "ppi",
	"uma":                                     "ppk",
	"pipil":                                   "ppl",
	"papuma":                                  "ppm",
	"papapana":                                "ppn",
	"folopa":                                  "ppo",
	"pelende":                                 "ppp",
	"pei":                                     "ppq",
	"san luís temalacayuca popoloca":          "pps",
	"pare":                                    "ppt",
	"papora":                                  "ppu",
	"pa'a":                                    "pqa",
	"malecite-passamaquoddy":                  "pqm",
	"parachi":                                 "prc",
	"parsi-dari":                              "prd",
	"principense":                             "pre",
	"paranan":                                 "prf",
	"prussian":                                "prg",
	"porohanon":                               "prh",
	"paicî":                                   "pri",
	"parauk":                                  "prk",
	"peruvian sign language":                  "prl",
	"kibiri":                                  "prm",
	"prasuni":                                 "prn",
	"old provençal (to 1500)":                 "pro",
	"parsi":                                   "prp",
	"ashéninka perené":                        "prq",
	"puri":                                    "prr",
	"dari":                                    "prs",
	"phai":                                    "prt",
	"puragi":                                  "pru",
	"parawen":                                 "prw",
	"purik":                                   "prx",
	"providencia sign language":               "prz",
	"asue awyu":                               "psa",
	"persian sign language":                   "psc",
	"plains indian sign language":             "psd",
	"central malay":                           "pse",
	"penang sign language":                    "psg",
	"southwest pashai":                        "psh",
	"southeast pashai":                        "psi",
	"puerto rican sign language":              "psl",
	"pauserna":                                "psm",
	"panasuan":                                "psn",
	"polish sign language":                    "pso",
	"philippine sign language":                "psp",
	"pasi":                                    "psq",
	"portuguese sign language":                "psr",
	"kaulong":                                 "pss",
	"central pashto":                          "pst",
	"sauraseni prākrit":                       "psu",
	"port sandwich":                           "psw",
	"piscataway":                              "psy",
	"pai tavytera":                            "pta",
	"pataxó hã-ha-hãe":                        "pth",
	"pintiini":                                "pti",
	"patani":                                  "ptn",
	"zo'é":                                    "pto",
	"patep":                                   "ptp",
	"pattapu":                                 "ptq",
	"piamatsina":                              "ptr",
	"enrekang":                                "ptt",
	"bambam":                                  "ptu",
	"port vato":                               "ptv",
	"pentlatch":                               "ptw",
	"pathiya":                                 "pty",
	"western highland purepecha":              "pua",
	"purum":                                   "pub",
	"punan merap":                             "puc",
	"punan aput":                              "pud",
	"puelche":                                 "pue",
	"punan merah":                             "puf",
	"phuie":                                   "pug",
	"puinave":                                 "pui",
	"punan tubu":                              "puj",
	"puma":                                    "pum",
	"puoc":                                    "puo",
	"pulabu":                                  "pup",
	"puquina":                                 "puq",
	"puruborá":                                "pur",
	"pushto":                                  "pus",
	"putoh":                                   "put",
	"punu":                                    "puu",
	"puluwatese":                              "puw",
	"puare":                                   "pux",
	"purisimeño":                              "puy",
	"pawaia":                                  "pwa",
	"panawa":                                  "pwb",
	"gapapaiwa":                               "pwg",
	"patwin":                                  "pwi",
	"molbog":                                  "pwm",
	"paiwan":                                  "pwn",
	"pwo western karen":                       "pwo",
	"powari":                                  "pwr",
	"pwo northern karen":                      "pww",
	"quetzaltepec mixe":                       "pxm",
	"pye krumen":                              "pye",
	"fyam":                                    "pym",
	"poyanáwa":                                "pyn",
	"paraguayan sign language":                "pys",
	"puyuma":                                  "pyu",
	"pyu (myanmar)":                           "pyx",
	"pyen":                                    "pyy",
	"para naga":                               "pzn",
	"quapaw":                                  "qua",
	"huallaga huánuco quechua":                "qub",
	"k'iche'":                                 "quc",
	"calderón highland quichua":               "qud",
	"quechua":                                 "que",
	"lambayeque quechua":                      "quf",
	"chimborazo highland quichua":             "qug",
	"south bolivian quechua":                  "quh",
	"quileute":                                "qui",
	"chachapoyas quechua":                     "quk",
	"north bolivian quechua":                  "qul",
	"sipacapense":                             "qum",
	"quinault":                                "qun",
	"southern pastaza quechua":                "qup",
	"quinqui":                                 "quq",
	"yanahuanca pasco quechua":                "qur",
	"santiago del estero quichua":             "qus",
	"sacapulteco":                             "quv",
	"tena lowland quichua":                    "quw",
	"yauyos quechua":                          "qux",
	"ayacucho quechua":                        "quy",
	"cusco quechua":                           "quz",
	"ambo-pasco quechua":                      "qva",
	"cajamarca quechua":                       "qvc",
	"eastern apurímac quechua":                "qve",
	"huamalíes-dos de mayo huánuco quechua": "qvh",
	"imbabura highland quichua":             "qvi",
	"loja highland quichua":                 "qvj",
	"cajatambo north lima quechua":          "qvl",
	"margos-yarowilca-lauricocha quechua":   "qvm",
	"north junín quechua":                   "qvn",
	"napo lowland quechua":                  "qvo",
	"pacaraos quechua":                      "qvp",
	"san martín quechua":                    "qvs",
	"huaylla wanca quechua":                 "qvw",
	"queyu":                                 "qvy",
	"northern pastaza quichua":              "qvz",
	"corongo ancash quechua":                "qwa",
	"classical quechua":                     "qwc",
	"huaylas ancash quechua":                "qwh",
	"kuman (russia)":                        "qwm",
	"sihuas ancash quechua":                 "qws",
	"kwalhioqua-tlatskanai":                 "qwt",
	"chiquián ancash quechua":               "qxa",
	"chincha quechua":                       "qxc",
	"panao huánuco quechua":                 "qxh",
	"salasaca highland quichua":             "qxl",
	"northern conchucos ancash quechua":     "qxn",
	"southern conchucos ancash quechua":     "qxo",
	"puno quechua":                          "qxp",
	"qashqa'i":                              "qxq",
	"cañar highland quichua":                "qxr",
	"southern qiang":                        "qxs",
	"santa ana de tusi pasco quechua":       "qxt",
	"arequipa-la unión quechua":             "qxu",
	"jauja wanca quechua":                   "qxw",
	"quenya":                                "qya",
	"quiripi":                               "qyp",
	"dungmali":                              "raa",
	"camling":                               "rab",
	"rasawa":                                "rac",
	"rade":                                  "rad",
	"western meohang":                       "raf",
	"logooli":                               "rag",
	"rabha":                                 "rah",
	"ramoaaina":                             "rai",
	"rajasthani":                            "raj",
	"tulu-bohuai":                           "rak",
	"ralte":                                 "ral",
	"canela":                                "ram",
	"riantana":                              "ran",
	"rao":                                   "rao",
	"rapanui":                               "rap",
	"saam":                                  "raq",
	"rarotongan":                            "rar",
	"tegali":                                "ras",
	"razajerdi":                             "rat",
	"raute":                                 "rau",
	"sampang":                               "rav",
	"rawang":                                "raw",
	"rang":                                  "rax",
	"rapa":                                  "ray",
	"rahambuu":                              "raz",
	"rumai palaung":                         "rbb",
	"northern bontok":                       "rbk",
	"miraya bikol":                          "rbl",
	"barababaraba":                          "rbp",
	"réunion creole french":                 "rcf",
	"rudbari":                               "rdb",
	"rerau":                                 "rea",
	"rembong":                               "reb",
	"rejang kayan":                          "ree",
	"kara (tanzania)":                       "reg",
	"reli":                                  "rei",
	"rejang":                                "rej",
	"rendille":                              "rel",
	"remo":                                  "rem",
	"rengao":                                "ren",
	"rer bare":                              "rer",
	"reshe":                                 "res",
	"retta":                                 "ret",
	"reyesano":                              "rey",
	"roria":                                 "rga",
	"romano-greek":                          "rge",
	"rangkas":                               "rgk",
	"romagnol":                              "rgn",
	"resígaro":                              "rgr",
	"southern roglai":                       "rgs",
	"ringgou":                               "rgu",
	"rohingya":                              "rhg",
	"yahang":                                "rhp",
	"riang (india)":                         "ria",
	"tarifit":                               "rif",
	"riang (myanmar)":                       "ril",
	"nyaturu":                               "rim",
	"nungu":                                 "rin",
	"ribun":                                 "rir",
	"ritarungo":                             "rit",
	"riung":                                 "riu",
	"rajong":                                "rjg",
	"raji":                                  "rji",
	"rajbanshi":                             "rjs",
	"kraol":                                 "rka",
	"rikbaktsa":                             "rkb",
	"rakahanga-manihiki":                    "rkh",
	"rakhine":                               "rki",
	"marka":                                 "rkm",
	"rangpuri":                              "rkt",
	"arakwal":                               "rkw",
	"rama":                                  "rma",
	"rembarunga":                            "rmb",
	"carpathian romani":                     "rmc",
	"traveller danish":                      "rmd",
	"angloromani":                           "rme",
	"kalo finnish romani":                   "rmf",
	"traveller norwegian":                   "rmg",
	"murkim":                                "rmh",
	"lomavren":                              "rmi",
	"romkun":                                "rmk",
	"baltic romani":                         "rml",
	"roma":                                  "rmm",
	"balkan romani":                         "rmn",
	"sinte romani":                          "rmo",
	"rempi":                                 "rmp",
	"caló":                                  "rmq",
	"romanian sign language":                "rms",
	"domari":                                "rmt",
	"tavringer romani":                      "rmu",
	"romanova":                              "rmv",
	"welsh romani":                          "rmw",
	"romam":                                 "rmx",
	"vlax romani":                           "rmy",
	"marma":                                 "rmz",
	"ruund":                                 "rnd",
	"ronga":                                 "rng",
	"ranglong":                              "rnl",
	"roon":                                  "rnn",
	"rongpo":                                "rnp",
	"nari nari":                             "rnr",
	"rungwa":                                "rnw",
	"tae'":                                  "rob",
	"cacgia roglai":                         "roc",
	"rogo":                                  "rod",
	"ronji":                                 "roe",
	"rombo":                                 "rof",
	"northern roglai":                       "rog",
	"romansh":                               "roh",
	"romblomanon":                           "rol",
	"romany":                                "rom",
	"romanian":                              "ron",
	"rotokas":                               "roo",
	"kriol":                                 "rop",
	"rongga":                                "ror",
	"runga":                                 "rou",
	"dela-oenale":                           "row",
	"repanbitip":                            "rpn",
	"rapting":                               "rpt",
	"ririo":                                 "rri",
	"waima":                                 "rro",
	"arritinngithigh":                       "rrt",
	"romano-serbian":                        "rsb",
	"russian sign language":                 "rsl",
	"miriwoong sign language":               "rsm",
	"rungtu chin":                           "rtc",
	"ratahan":                               "rth",
	"rotuman":                               "rtm",
	"yurats":                                "rts",
	"rathawi":                               "rtw",
	"gungu":                                 "rub",
	"ruuli":                                 "ruc",
	"rusyn":                                 "rue",
	"luguru":                                "ruf",
	"roviana":                               "rug",
	"ruga":                                  "ruh",
	"rufiji":                                "rui",
	"che":                                   "ruk",
	"rundi":                                 "run",
	"istro romanian":                        "ruo",
	"macedo-romanian":                       "rup",
	"megleno romanian":                      "ruq",
	"russian":                               "rus",
	"rutul":                                 "rut",
	"lanas lobu":                            "ruu",
	"mala (nigeria)":                        "ruy",
	"ruma":                                  "ruz",
	"rawo":                                  "rwa",
	"rwa":                                   "rwk",
	"amba (uganda)":                         "rwm",
	"rawa":                                  "rwo",
	"marwari (india)":                       "rwr",
	"ngardi":                                "rxd",
	"karuwali":                              "rxw",
	"northern amami-oshima":                 "ryn",
	"yaeyama":                               "rys",
	"central okinawan":                      "ryu",
	"rāziḥī":                                "rzh",
	"saba":                                  "saa",
	"buglere":                               "sab",
	"meskwaki":                              "sac",
	"sandawe":                               "sad",
	"sabanê":                                "sae",
	"safaliba":                              "saf",
	"sango":                                 "sag",
	"yakut":                                 "sah",
	"sahu":                                  "saj",
	"sake":                                  "sak",
	"samaritan aramaic":                     "sam",
	"sanskrit":                              "san",
	"sause":                                 "sao",
	"samburu":                               "saq",
	"saraveca":                              "sar",
	"sasak":                                 "sas",
	"santali":                               "sat",
	"saleman":                               "sau",
	"saafi-saafi":                           "sav",
	"sawi":                                  "saw",
	"sa":                                    "sax",
	"saya":                                  "say",
	"saurashtra":                            "saz",
	"ngambay":                               "sba",
	"simbo":                                 "sbb",
	"kele (papua new guinea)":               "sbc",
	"southern samo":                         "sbd",
	"saliba":                                "sbe",
	"chabu":                                 "sbf",
	"seget":                                 "sbg",
	"sori-harengan":                         "sbh",
	"seti":                                  "sbi",
	"surbakhal":                             "sbj",
	"safwa":                                 "sbk",
	"botolan sambal":                        "sbl",
	"sagala":                                "sbm",
	"sindhi bhil":                           "sbn",
	"sabüm":                                 "sbo",
	"sangu (tanzania)":                      "sbp",
	"sileibi":                               "sbq",
	"sembakung murut":                       "sbr",
	"subiya":                                "sbs",
	"kimki":                                 "sbt",
	"stod bhoti":                            "sbu",
	"sabine":                                "sbv",
	"simba":                                 "sbw",
	"seberuang":                             "sbx",
	"soli":                                  "sby",
	"sara kaba":                             "sbz",
	"chut":                                  "scb",
	"dongxiang":                             "sce",
	"san miguel creole french":              "scf",
	"sanggau":                               "scg",
	"sakachep":                              "sch",
	"sri lankan creole malay":               "sci",
	"sadri":                                 "sck",
	"shina":                                 "scl",
	"sicilian":                              "scn",
	"scots":                                 "sco",
	"helambu sherpa":                        "scp",
	"sa'och":                                "scq",
	"north slavey":                          "scs",
	"southern katang":                       "sct",
	"shumcho":                               "scu",
	"sheni":                                 "scv",
	"sha":                                   "scw",
	"sicel":                                 "scx",
	"toraja-sa'dan":                         "sda",
	"shabak":                                "sdb",
	"sassarese sardinian":                   "sdc",
	"surubu":                                "sde",
	"sarli":                                 "sdf",
	"savi":                                  "sdg",
	"southern kurdish":                      "sdh",
	"suundi":                                "sdj",
	"sos kundi":                             "sdk",
	"saudi arabian sign language":           "sdl",
	"semandang":                             "sdm",
	"gallurese sardinian":                   "sdn",
	"bukar-sadung bidayuh":                  "sdo",
	"sherdukpen":                            "sdp",
	"oraon sadri":                           "sdr",
	"sened":                                 "sds",
	"shuadit":                               "sdt",
	"sarudu":                                "sdu",
	"sibu melanau":                          "sdx",
	"sallands":                              "sdz",
	"semai":                                 "sea",
	"shempire senoufo":                      "seb",
	"sechelt":                               "sec",
	"sedang":                                "sed",
	"seneca":                                "see",
	"cebaara senoufo":                       "sef",
	"segeju":                                "seg",
	"sena":                                  "seh",
	"seri":                                  "sei",
	"sene":                                  "sej",
	"sekani":                                "sek",
	"selkup":                                "sel",
	"nanerigé sénoufo":                      "sen",
	"suarmin":                               "seo",
	"sìcìté sénoufo":                        "sep",
	"senara sénoufo":                        "seq",
	"serrano":                               "ser",
	"koyraboro senni songhai":               "ses",
	"sentani":                               "set",
	"serui-laut":                            "seu",
	"nyarafolo senoufo":                     "sev",
	"sewa bay":                              "sew",
	"secoya":                                "sey",
	"senthang chin":                         "sez",
	"langue des signes de belgique francophone": "sfb",
	"eastern subanen":                      "sfe",
	"small flowery miao":                   "sfm",
	"south african sign language":          "sfs",
	"sehwi":                                "sfw",
	"old irish (to 900)":                   "sga",
	"mag-antsi ayta":                       "sgb",
	"kipsigis":                             "sgc",
	"surigaonon":                           "sgd",
	"segai":                                "sge",
	"swiss-german sign language":           "sgg",
	"shughni":                              "sgh",
	"suga":                                 "sgi",
	"surgujia":                             "sgj",
	"sangkong":                             "sgk",
	"singa":                                "sgm",
	"singpho":                              "sgp",
	"sangisari":                            "sgr",
	"samogitian":                           "sgs",
	"brokpake":                             "sgt",
	"salas":                                "sgu",
	"sebat bet gurage":                     "sgw",
	"sierra leone sign language":           "sgx",
	"sanglechi":                            "sgy",
	"sursurunga":                           "sgz",
	"shall-zwall":                          "sha",
	"ninam":                                "shb",
	"sonde":                                "shc",
	"kundal shahi":                         "shd",
	"sheko":                                "she",
	"shua":                                 "shg",
	"shoshoni":                             "shh",
	"tachelhit":                            "shi",
	"shatt":                                "shj",
	"shilluk":                              "shk",
	"shendu":                               "shl",
	"shahrudi":                             "shm",
	"shan":                                 "shn",
	"shanga":                               "sho",
	"shipibo-conibo":                       "shp",
	"sala":                                 "shq",
	"shi":                                  "shr",
	"shuswap":                              "shs",
	"shasta":                               "sht",
	"chadian arabic":                       "shu",
	"shehri":                               "shv",
	"shwai":                                "shw",
	"she":                                  "shx",
	"tachawit":                             "shy",
	"syenara senoufo":                      "shz",
	"akkala sami":                          "sia",
	"sebop":                                "sib",
	"sidamo":                               "sid",
	"simaa":                                "sie",
	"siamou":                               "sif",
	"paasaal":                              "sig",
	"zire":                                 "sih",
	"shom peng":                            "sii",
	"numbami":                              "sij",
	"sikiana":                              "sik",
	"tumulung sisaala":                     "sil",
	"mende (papua new guinea)":             "sim",
	"sinhala":                              "sin",
	"sikkimese":                            "sip",
	"sonia":                                "siq",
	"siri":                                 "sir",
	"siuslaw":                              "sis",
	"sinagen":                              "siu",
	"sumariup":                             "siv",
	"siwai":                                "siw",
	"sumau":                                "six",
	"sivandi":                              "siy",
	"siwi":                                 "siz",
	"epena":                                "sja",
	"sajau basap":                          "sjb",
	"kildin sami":                          "sjd",
	"pite sami":                            "sje",
	"assangori":                            "sjg",
	"kemi sami":                            "sjk",
	"sajalong":                             "sjl",
	"mapun":                                "sjm",
	"sindarin":                             "sjn",
	"xibe":                                 "sjo",
	"surjapuri":                            "sjp",
	"siar-lak":                             "sjr",
	"senhaja de srair":                     "sjs",
	"ter sami":                             "sjt",
	"ume sami":                             "sju",
	"shawnee":                              "sjw",
	"skagit":                               "ska",
	"saek":                                 "skb",
	"ma manda":                             "skc",
	"southern sierra miwok":                "skd",
	"seke (vanuatu)":                       "ske",
	"sakirabiá":                            "skf",
	"sakalava malagasy":                    "skg",
	"sikule":                               "skh",
	"sika":                                 "ski",
	"seke (nepal)":                         "skj",
	"kutong":                               "skm",
	"kolibugan subanon":                    "skn",
	"seko tengah":                          "sko",
	"sekapan":                              "skp",
	"sininkere":                            "skq",
	"saraiki":                              "skr",
	"maia":                                 "sks",
	"sakata":                               "skt",
	"sakao":                                "sku",
	"skou":                                 "skv",
	"skepi creole dutch":                   "skw",
	"seko padang":                          "skx",
	"sikaiana":                             "sky",
	"sekar":                                "skz",
	"sáliba":                               "slc",
	"sissala":                              "sld",
	"sholaga":                              "sle",
	"swiss-italian sign language":          "slf",
	"selungai murut":                       "slg",
	"southern puget sound salish":          "slh",
	"lower silesian":                       "sli",
	"salumá":                               "slj",
	"slovak":                               "slk",
	"salt-yui":                             "sll",
	"pangutaran sama":                      "slm",
	"salinan":                              "sln",
	"lamaholot":                            "slp",
	"salchuq":                              "slq",
	"salar":                                "slr",
	"singapore sign language":              "sls",
	"sila":                                 "slt",
	"selaru":                               "slu",
	"slovenian":                            "slv",
	"sialum":                               "slw",
	"salampasu":                            "slx",
	"selayar":                              "sly",
	"ma'ya":                                "slz",
	"southern sami":                        "sma",
	"simbari":                              "smb",
	"som":                                  "smc",
	"sama":                                 "smd",
	"northern sami":                        "sme",
	"auwe":                                 "smf",
	"simbali":                              "smg",
	"samei":                                "smh",
	"lule sami":                            "smj",
	"bolinao":                              "smk",
	"central sama":                         "sml",
	"musasa":                               "smm",
	"inari sami":                           "smn",
	"samoan":                               "smo",
	"samaritan":                            "smp",
	"samo":                                 "smq",
	"simeulue":                             "smr",
	"skolt sami":                           "sms",
	"simte":                                "smt",
	"somray":                               "smu",
	"samvedi":                              "smv",
	"sumbawa":                              "smw",
	"samba":                                "smx",
	"semnani":                              "smy",
	"simeku":                               "smz",
	"shona":                                "sna",
	"sebuyau":                              "snb",
	"sinaugoro":                            "snc",
	"sindhi":                               "snd",
	"bau bidayuh":                          "sne",
	"noon":                                 "snf",
	"sanga (democratic republic of congo)": "sng",
	"sensi":                                "sni",
	"riverain sango":                       "snj",
	"soninke":                              "snk",
	"sangil":                               "snl",
	"southern ma'di":                       "snm",
	"siona":                                "snn",
	"snohomish":                            "sno",
	"siane":                                "snp",
	"sangu (gabon)":                        "snq",
	"sihan":                                "snr",
	"south west bay":                       "sns",
	"senggi":                               "snu",
	"sa'ban":                               "snv",
	"selee":                                "snw",
	"sam":                                  "snx",
	"saniyo-hiyewe":                        "sny",
	"sinsauru":                             "snz",
	"thai song":                            "soa",
	"sobei":                                "sob",
	"so (democratic republic of congo)":    "soc",
	"songoora":                             "sod",
	"songomeno":                            "soe",
	"sogdian":                              "sog",
	"aka":                                  "soh",
	"sonha":                                "soi",
	"soi":                                  "soj",
	"sokoro":                               "sok",
	"solos":                                "sol",
	"somali":                               "som",
	"songo":                                "soo",
	"songe":                                "sop",
	"kanasi":                               "soq",
	"somrai":                               "sor",
	"seeku":                                "sos",
	"southern sotho":                       "sot",
	"southern thai":                        "sou",
	"sonsorol":                             "sov",
	"sowanda":                              "sow",
	"swo":                                  "sox",
	"miyobe":                               "soy",
	"temi":                                 "soz",
	"spanish":                              "spa",
	"sepa (indonesia)":                     "spb",
	"sapé":                                 "spc",
	"saep":                                 "spd",
	"sepa (papua new guinea)":              "spe",
	"sian":                                 "spg",
	"saponi":                               "spi",
	"sengo":                                "spk",
	"selepet":                              "spl",
	"akukem":                               "spm",
	"sanapaná":                             "spn",
	"spokane":                              "spo",
	"supyire senoufo":                      "spp",
	"loreto-ucayali spanish":               "spq",
	"saparua":                              "spr",
	"saposa":                               "sps",
	"spiti bhoti":                          "spt",
	"sapuan":                               "spu",
	"sambalpuri":                           "spv",
	"south picene":                         "spx",
	"sabaot":                               "spy",
	"shama-sambuga":                        "sqa",
	"shau":                                 "sqh",
	"albanian":                             "sqi",
	"albanian sign language":               "sqk",
	"suma":                                 "sqm",
	"susquehannock":                        "sqn",
	"sorkhei":                              "sqo",
	"sou":                                  "sqq",
	"siculo arabic":                        "sqr",
	"sri lankan sign language":             "sqs",
	"soqotri":                              "sqt",
	"squamish":                             "squ",
	"saruga":                               "sra",
	"sora":                                 "srb",
	"logudorese sardinian":                 "src",
	"sardinian":                            "srd",
	"sara":                                 "sre",
	"nafi":                                 "srf",
	"sulod":                                "srg",
	"sarikoli":                             "srh",
	"siriano":                              "sri",
	"serudung murut":                       "srk",
	"isirawa":                              "srl",
	"saramaccan":                           "srm",
	"sranan tongo":                         "srn",
	"campidanese sardinian":                "sro",
	"serbian":                              "srp",
	"sirionó":                              "srq",
	"serer":                                "srr",
	"sarsi":                                "srs",
	"sauri":                                "srt",
	"suruí":                                "sru",
	"southern sorsoganon":                  "srv",
	"serua":                                "srw",
	"sirmauri":                             "srx",
	"sera":                                 "sry",
	"shahmirzadi":                          "srz",
	"southern sama":                        "ssb",
	"suba-simbiti":                         "ssc",
	"siroi":                                "ssd",
	"balangingi":                           "sse",
	"thao":                                 "ssf",
	"seimat":                               "ssg",
	"shihhi arabic":                        "ssh",
	"sansi":                                "ssi",
	"sausi":                                "ssj",
	"sunam":                                "ssk",
	"western sisaala":                      "ssl",
	"semnam":                               "ssm",
	"waata":                                "ssn",
	"sissano":                              "sso",
	"spanish sign language":                "ssp",
	"so'a":                                 "ssq",
	"swiss-french sign language":           "ssr",
	"sô":                                   "sss",
	"sinasina":                             "sst",
	"susuami":                              "ssu",
	"shark bay":                            "ssv",
	"swati":                                "ssw",
	"samberigi":                            "ssx",
	"saho":                                 "ssy",
	"sengseng":                             "ssz",
	"settla":                               "sta",
	"northern subanen":                     "stb",
	"sentinel":                             "std",
	"liana-seti":                           "ste",
	"seta":                                 "stf",
	"trieng":                               "stg",
	"shelta":                               "sth",
	"bulo stieng":                          "sti",
	"matya samo":                           "stj",
	"arammba":                              "stk",
	"stellingwerfs":                        "stl",
	"setaman":                              "stm",
	"owa":                                  "stn",
	"stoney":                               "sto",
	"southeastern tepehuan":                "stp",
	"saterfriesisch":                       "stq",
	"straits salish":                       "str",
	"shumashti":                            "sts",
	"budeh stieng":                         "stt",
	"samtao":                               "stu",
	"silt'e":                               "stv",
	"satawalese":                           "stw",
	"siberian tatar":                       "sty",
	"sulka":                                "sua",
	"suku":                                 "sub",
	"western subanon":                      "suc",
	"suena":                                "sue",
	"suganga":                              "sug",
	"suki":                                 "sui",
	"shubi":                                "suj",
	"sukuma":                               "suk",
	"sundanese":                            "sun",
	"suri":                                 "suq",
	"mwaghavul":                            "sur",
	"susu":                                 "sus",
	"subtiaba":                             "sut",
	"puroik":                               "suv",
	"sumbwa":                               "suw",
	"sumerian":                             "sux",
	"suyá":                                 "suy",
	"sunwar":                               "suz",
	"svan":                                 "sva",
	"ulau-suain":                           "svb",
	"vincentian creole english":            "svc",
	"serili":                               "sve",
	"slovakian sign language":              "svk",
	"slavomolisano":                        "svm",
	"savosavo":                             "svs",
	"skalvian":                             "svx",
	"swahili (macrolanguage)":              "swa",
	"maore comorian":                       "swb",
	"congo swahili":                        "swc",
	"swedish":                              "swe",
	"sere":                                 "swf",
	"swabian":                              "swg",
	"swahili (individual language)":        "swh",
	"sui":                                  "swi",
	"sira":                                 "swj",
	"malawi sena":                          "swk",
	"swedish sign language":                "swl",
	"samosa":                               "swm",
	"sawknah":                              "swn",
	"shanenawa":                            "swo",
	"suau":                                 "swp",
	"sharwa":                               "swq",
	"saweru":                               "swr",
	"seluwasan":                            "sws",
	"sawila":                               "swt",
	"suwawa":                               "swu",
	"shekhawati":                           "swv",
	"sowa":                                 "sww",
	"suruahá":                              "swx",
	"sarua":                                "swy",
	"suba":                                 "sxb",
	"sicanian":                             "sxc",
	"sighu":                                "sxe",
	"shixing":                              "sxg",
	"southern kalapuya":                    "sxk",
	"selian":                               "sxl",
	"samre":                                "sxm",
	"sangir":                               "sxn",
	"sorothaptic":                          "sxo",
	"saaroa":                               "sxr",
	"sasaru":                               "sxs",
	"upper saxon":                          "sxu",
	"saxwe gbe":                            "sxw",
	"siang":                                "sya",
	"central subanen":                      "syb",
	"classical syriac":                     "syc",
	"seki":                                 "syi",
	"sukur":                                "syk",
	"sylheti":                              "syl",
	"maya samo":                            "sym",
	"senaya":                               "syn",
	"suoy":                                 "syo",
	"syriac":                               "syr",
	"sinyar":                               "sys",
	"kagate":                               "syw",
	"samay":                                "syx",
	"al-sayyid bedouin sign language":      "syy",
	"semelai":                              "sza",
	"ngalum":                               "szb",
	"semaq beri":                           "szc",
	"seru":                                 "szd",
	"seze":                                 "sze",
	"sengele":                              "szg",
	"silesian":                             "szl",
	"sula":                                 "szn",
	"suabo":                                "szp",
	"solomon islands sign language":        "szs",
	"isu (fako division)":                  "szv",
	"sawai":                                "szw",
	"lower tanana":                         "taa",
	"tabassaran":                           "tab",
	"lowland tarahumara":                   "tac",
	"tause":                                "tad",
	"tariana":                              "tae",
	"tapirapé":                             "taf",
	"tagoi":                                "tag",
	"tahitian":                             "tah",
	"eastern tamang":                       "taj",
	"tala":                                 "tak",
	"tal":                                  "tal",
	"tamil":                                "tam",
	"tangale":                              "tan",
	"yami":                                 "tao",
	"taabwa":                               "tap",
	"tamasheq":                             "taq",
	"central tarahumara":                   "tar",
	"tay boi":                              "tas",
	"tatar":                                "tat",
	"upper tanana":                         "tau",
	"tatuyo":                               "tav",
	"tai":                                  "taw",
	"tamki":                                "tax",
	"atayal":                               "tay",
	"tocho":                                "taz",
	"aikanã":                               "tba",
	"tapeba":                               "tbb",
	"takia":                                "tbc",
	"kaki ae":                              "tbd",
	"tanimbili":                            "tbe",
	"mandara":                              "tbf",
	"north tairora":                        "tbg",
	"thurawal":                             "tbh",
	"gaam":                                 "tbi",
	"tiang":                                "tbj",
	"calamian tagbanwa":                    "tbk",
	"tboli":                                "tbl",
	"tagbu":                                "tbm",
	"barro negro tunebo":                   "tbn",
	"tawala":                               "tbo",
	"taworta":                              "tbp",
	"tumtum":                               "tbr",
	"tanguat":                              "tbs",
	"tembo (kitembo)":                      "tbt",
	"tubar":                                "tbu",
	"tobo":                                 "tbv",
	"tagbanwa":                             "tbw",
	"kapin":                                "tbx",
	"tabaru":                               "tby",
	"ditammari":                            "tbz",
	"ticuna":                               "tca",
	"tanacross":                            "tcb",
	"datooga":                              "tcc",
	"tafi":                                 "tcd",
	"southern tutchone":                    "tce",
	"malinaltepec me'phaa":                 "tcf",
	"tamagario":                            "tcg",
	"turks and caicos creole english":      "tch",
	"wára":                                 "tci",
	"tchitchege":                           "tck",
	"taman (myanmar)":                      "tcl",
	"tanahmerah":                           "tcm",
	"tichurong":                            "tcn",
	"taungyo":                              "tco",
	"tawr chin":                            "tcp",
	"kaiy":                                 "tcq",
	"torres strait creole":                 "tcs",
	"t'en":                                 "tct",
	"southeastern tarahumara":              "tcu",
	"tecpatlán totonac":                    "tcw",
	"toda":                                 "tcx",
	"tulu":                                 "tcy",
	"thado chin":                           "tcz",
	"tagdal":                               "tda",
	"panchpargania":                        "tdb",
	"emberá-tadó":                          "tdc",
	"tai nüa":                              "tdd",
	"tiranige diga dogon":                  "tde",
	"talieng":                              "tdf",
	"western tamang":                       "tdg",
	"thulung":                              "tdh",
	"tomadino":                             "tdi",
	"tajio":                                "tdj",
	"tambas":                               "tdk",
	"sur":                                  "tdl",
	"taruma":                               "tdm",
	"tondano":                              "tdn",
	"teme":                                 "tdo",
	"tita":                                 "tdq",
	"todrah":                               "tdr",
	"doutai":                               "tds",
	"tetun dili":                           "tdt",
	"toro":                                 "tdv",
	"tandroy-mahafaly malagasy":            "tdx",
	"tadyawan":                             "tdy",
	"temiar":                               "tea",
	"tetete":                               "teb",
	"terik":                                "tec",
	"tepo krumen":                          "ted",
	"huehuetla tepehua":                    "tee",
	"teressa":                              "tef",
	"teke-tege":                            "teg",
	"tehuelche":                            "teh",
	"torricelli":                           "tei",
	"ibali teke":                           "tek",
	"telugu":                               "tel",
	"timne":                                "tem",
	"tama (colombia)":                      "ten",
	"teso":                                 "teo",
	"tepecano":                             "tep",
	"temein":                               "teq",
	"tereno":                               "ter",
	"tengger":                              "tes",
	"tetum":                                "tet",
	"soo":                                  "teu",
	"teor":                                 "tev",
	"tewa (usa)":                           "tew",
	"tennet":                               "tex",
	"tulishi":                              "tey",
	"tofin gbe":                            "tfi",
	"tanaina":                              "tfn",
	"tefaro":                               "tfo",
	"teribe":                               "tfr",
	"ternate":                              "tft",
	"sagalla":                              "tga",
	"tobilung":                             "tgb",
	"tigak":                                "tgc",
	"ciwogai":                              "tgd",
	"eastern gorkha tamang":                "tge",
	"chalikha":                             "tgf",
	"tobagonian creole english":            "tgh",
	"lawunuia":                             "tgi",
	"tagin":                                "tgj",
	"tajik":                                "tgk",
	"tagalog":                              "tgl",
	"tandaganon":                           "tgn",
	"sudest":                               "tgo",
	"tangoa":                               "tgp",
	"tring":                                "tgq",
	"tareng":                               "tgr",
	"nume":                                 "tgs",
	"central tagbanwa":                     "tgt",
	"tanggu":                               "tgu",
	"tingui-boto":                          "tgv",
	"tagwana senoufo":                      "tgw",
	"tagish":                               "tgx",
	"togoyo":                               "tgy",
	"tagalaka":                             "tgz",
	"thai":                                 "tha",
	"thayore":                              "thd",
	"chitwania tharu":                      "the",
	"thangmi":                              "thf",
	"northern tarahumara":                  "thh",
	"tai long":                             "thi",
	"tharaka":                              "thk",
	"dangaura tharu":                       "thl",
	"aheu":                                 "thm",
	"thachanadan":                          "thn",
	"thompson":                             "thp",
	"kochila tharu":                        "thq",
	"rana tharu":                           "thr",
	"thakali":                              "ths",
	"tahltan":                              "tht",
	"thuri":                                "thu",
	"tahaggart tamahaq":                    "thv",
	"thudam":                               "thw",
	"tha":                                  "thy",
	"tayart tamajeq":                       "thz",
	"tidikelt tamazight":                   "tia",
	"tira":                                 "tic",
	"tifal":                                "tif",
	"tigre":                                "tig",
	"timugon murut":                        "tih",
	"tiene":                                "tii",
	"tilung":                               "tij",
	"tikar":                                "tik",
	"tillamook":                            "til",
	"timbe":                                "tim",
	"tindi":                                "tin",
	"teop":                                 "tio",
	"trimuris":                             "tip",
	"tiéfo":                                "tiq",
	"tigrinya":                             "tir",
	"masadiit itneg":                       "tis",
	"tinigua":                              "tit",
	"adasen":                               "tiu",
	"tiv":                                  "tiv",
	"tiwi":                                 "tiw",
	"southern tiwa":                        "tix",
	"tiruray":                              "tiy",
	"tai hongjin":                          "tiz",
	"tajuasohn":                            "tja",
	"tunjung":                              "tjg",
	"northern tujia":                       "tji",
	"tai laing":                            "tjl",
	"timucua":                              "tjm",
	"tonjon":                               "tjn",
	"temacine tamazight":                   "tjo",
	"southern tujia":                       "tjs",
	"tjurruru":                             "tju",
	"djabwurrung":                          "tjw",
	"truká":                                "tka",
	"buksa":                                "tkb",
	"tukudede":                             "tkd",
	"takwane":                              "tke",
	"tukumanféd":                           "tkf",
	"tesaka malagasy":                      "tkg",
	"tokelau":                              "tkl",
	"takelma":                              "tkm",
	"toku-no-shima":                        "tkn",
	"tikopia":                              "tkp",
	"tee":                                  "tkq",
	"tsakhur":                              "tkr",
	"takestani":                            "tks",
	"kathoriya tharu":                      "tkt",
	"upper necaxa totonac":                 "tku",
	"mur pano":                             "tkv",
	"teanu":                                "tkw",
	"tangko":                               "tkx",
	"takua":                                "tkz",
	"southwestern tepehuan":                "tla",
	"tobelo":                               "tlb",
	"yecuatla totonac":                     "tlc",
	"talaud":                               "tld",
	"telefol":                              "tlf",
	"tofanma":                              "tlg",
	"klingon":                              "tlh",
	"tlingit":                              "tli",
	"talinga-bwisi":                        "tlj",
	"taloki":                               "tlk",
	"tetela":                               "tll",
	"tolomako":                             "tlm",
	"talondo'":                             "tln",
	"talodi":                               "tlo",
	"filomena mata-coahuitlán totonac":     "tlp",
	"tai loi":                              "tlq",
	"talise":                               "tlr",
	"tambotalo":                            "tls",
	"sou nama":                             "tlt",
	"tulehu":                               "tlu",
	"taliabu":                              "tlv",
	"khehek":                               "tlx",
	"talysh":                               "tly",
	"tama (chad)":                          "tma",
	"katbol":                               "tmb",
	"tumak":                                "tmc",
	"haruai":                               "tmd",
	"tremembé":                             "tme",
	"toba-maskoy":                          "tmf",
	"ternateño":                            "tmg",
	"tamashek":                             "tmh",
	"tutuba":                               "tmi",
	"samarokena":                           "tmj",
	"northwestern tamang":                  "tmk",
	"tamnim citak":                         "tml",
	"tai thanh":                            "tmm",
	"taman (indonesia)":                    "tmn",
	"temoq":                                "tmo",
	"tumleo":                               "tmq",
	"jewish babylonian aramaic (ca. 200-1200 ce)": "tmr",
	"tima":                                "tms",
	"tasmate":                             "tmt",
	"iau":                                 "tmu",
	"tembo (motembo)":                     "tmv",
	"temuan":                              "tmw",
	"tami":                                "tmy",
	"tamanaku":                            "tmz",
	"tacana":                              "tna",
	"western tunebo":                      "tnb",
	"tanimuca-retuarã":                    "tnc",
	"angosturas tunebo":                   "tnd",
	"tobanga":                             "tng",
	"maiani":                              "tnh",
	"tandia":                              "tni",
	"kwamera":                             "tnk",
	"lenakel":                             "tnl",
	"tabla":                               "tnm",
	"north tanna":                         "tnn",
	"toromono":                            "tno",
	"whitesands":                          "tnp",
	"taino":                               "tnq",
	"ménik":                               "tnr",
	"tenis":                               "tns",
	"tontemboan":                          "tnt",
	"tay khang":                           "tnu",
	"tangchangya":                         "tnv",
	"tonsawang":                           "tnw",
	"tanema":                              "tnx",
	"tongwe":                              "tny",
	"ten'edn":                             "tnz",
	"toba":                                "tob",
	"coyutla totonac":                     "toc",
	"toma":                                "tod",
	"gizrra":                              "tof",
	"tonga (nyasa)":                       "tog",
	"gitonga":                             "toh",
	"tonga (zambia)":                      "toi",
	"tojolabal":                           "toj",
	"tolowa":                              "tol",
	"tombulu":                             "tom",
	"tonga (tonga islands)":               "ton",
	"xicotepec de juárez totonac":         "too",
	"papantla totonac":                    "top",
	"toposa":                              "toq",
	"togbo-vara banda":                    "tor",
	"highland totonac":                    "tos",
	"tho":                                 "tou",
	"upper taromi":                        "tov",
	"jemez":                               "tow",
	"tobian":                              "tox",
	"topoiyo":                             "toy",
	"to":                                  "toz",
	"taupota":                             "tpa",
	"azoyú me'phaa":                       "tpc",
	"tippera":                             "tpe",
	"tarpia":                              "tpf",
	"kula":                                "tpg",
	"tok pisin":                           "tpi",
	"tapieté":                             "tpj",
	"tupinikin":                           "tpk",
	"tlacoapa me'phaa":                    "tpl",
	"tampulma":                            "tpm",
	"tupinambá":                           "tpn",
	"tai pao":                             "tpo",
	"pisaflores tepehua":                  "tpp",
	"tukpa":                               "tpq",
	"tuparí":                              "tpr",
	"tlachichilco tepehua":                "tpt",
	"tampuan":                             "tpu",
	"tanapag":                             "tpv",
	"tupí":                                "tpw",
	"acatepec me'phaa":                    "tpx",
	"trumai":                              "tpy",
	"tinputz":                             "tpz",
	"tembé":                               "tqb",
	"lehali":                              "tql",
	"turumsa":                             "tqm",
	"tenino":                              "tqn",
	"toaripi":                             "tqo",
	"tomoip":                              "tqp",
	"tunni":                               "tqq",
	"torona":                              "tqr",
	"western totonac":                     "tqt",
	"touo":                                "tqu",
	"tonkawa":                             "tqw",
	"tirahi":                              "tra",
	"terebu":                              "trb",
	"copala triqui":                       "trc",
	"turi":                                "trd",
	"east tarangan":                       "tre",
	"trinidadian creole english":          "trf",
	"lishán didán":                        "trg",
	"turaka":                              "trh",
	"trió":                                "tri",
	"toram":                               "trj",
	"traveller scottish":                  "trl",
	"tregami":                             "trm",
	"trinitario":                          "trn",
	"tarao naga":                          "tro",
	"kok borok":                           "trp",
	"san martín itunyoso triqui":          "trq",
	"taushiro":                            "trr",
	"chicahuaxtla triqui":                 "trs",
	"tunggare":                            "trt",
	"turoyo":                              "tru",
	"taroko":                              "trv",
	"torwali":                             "trw",
	"tringgus-sembaan bidayuh":            "trx",
	"turung":                              "try",
	"torá":                                "trz",
	"tsaangi":                             "tsa",
	"tsamai":                              "tsb",
	"tswa":                                "tsc",
	"tsakonian":                           "tsd",
	"tunisian sign language":              "tse",
	"tausug":                              "tsg",
	"tsuvan":                              "tsh",
	"tsimshian":                           "tsi",
	"tshangla":                            "tsj",
	"tseku":                               "tsk",
	"ts'ün-lao":                           "tsl",
	"turkish sign language":               "tsm",
	"tswana":                              "tsn",
	"tsonga":                              "tso",
	"northern toussian":                   "tsp",
	"thai sign language":                  "tsq",
	"akei":                                "tsr",
	"taiwan sign language":                "tss",
	"tondi songway kiini":                 "tst",
	"tsou":                                "tsu",
	"tsogo":                               "tsv",
	"tsishingini":                         "tsw",
	"mubami":                              "tsx",
	"tebul sign language":                 "tsy",
	"purepecha":                           "tsz",
	"tutelo":                              "tta",
	"gaa":                                 "ttb",
	"tektiteko":                           "ttc",
	"tauade":                              "ttd",
	"bwanabwana":                          "tte",
	"tuotomb":                             "ttf",
	"tutong":                              "ttg",
	"upper ta'oih":                        "tth",
	"tobati":                              "tti",
	"tooro":                               "ttj",
	"totoro":                              "ttk",
	"totela":                              "ttl",
	"northern tutchone":                   "ttm",
	"towei":                               "ttn",
	"lower ta'oih":                        "tto",
	"tombelala":                           "ttp",
	"tawallammat tamajaq":                 "ttq",
	"tera":                                "ttr",
	"northeastern thai":                   "tts",
	"muslim tat":                          "ttt",
	"torau":                               "ttu",
	"titan":                               "ttv",
	"long wat":                            "ttw",
	"sikaritai":                           "tty",
	"tsum":                                "ttz",
	"wiarumus":                            "tua",
	"tübatulabal":                         "tub",
	"mutu":                                "tuc",
	"tuxá":                                "tud",
	"tuyuca":                              "tue",
	"central tunebo":                      "tuf",
	"tunia":                               "tug",
	"taulil":                              "tuh",
	"tupuri":                              "tui",
	"tugutil":                             "tuj",
	"turkmen":                             "tuk",
	"tula":                                "tul",
	"tumbuka":                             "tum",
	"tunica":                              "tun",
	"tucano":                              "tuo",
	"tedaga":                              "tuq",
	"turkish":                             "tur",
	"tuscarora":                           "tus",
	"tututni":                             "tuu",
	"turkana":                             "tuv",
	"tuxináwa":                            "tux",
	"tugen":                               "tuy",
	"turka":                               "tuz",
	"vaghua":                              "tva",
	"tsuvadi":                             "tvd",
	"te'un":                               "tve",
	"southeast ambrym":                    "tvk",
	"tuvalu":                              "tvl",
	"tela-masbuar":                        "tvm",
	"tavoyan":                             "tvn",
	"tidore":                              "tvo",
	"taveta":                              "tvs",
	"tutsa naga":                          "tvt",
	"tunen":                               "tvu",
	"sedoa":                               "tvw",
	"timor pidgin":                        "tvy",
	"twana":                               "twa",
	"western tawbuid":                     "twb",
	"teshenawa":                           "twc",
	"twents":                              "twd",
	"tewa (indonesia)":                    "twe",
	"northern tiwa":                       "twf",
	"tereweng":                            "twg",
	"tai dón":                             "twh",
	"twi":                                 "twi",
	"tawara":                              "twl",
	"tawang monpa":                        "twm",
	"twendi":                              "twn",
	"tswapong":                            "two",
	"ere":                                 "twp",
	"tasawaq":                             "twq",
	"southwestern tarahumara":             "twr",
	"turiwára":                            "twt",
	"termanu":                             "twu",
	"tuwari":                              "tww",
	"tewe":                                "twx",
	"tawoyan":                             "twy",
	"tombonuo":                            "txa",
	"tokharian b":                         "txb",
	"tsetsaut":                            "txc",
	"totoli":                              "txe",
	"tangut":                              "txg",
	"thracian":                            "txh",
	"ikpeng":                              "txi",
	"tarjumo":                             "txj",
	"tomini":                              "txm",
	"west tarangan":                       "txn",
	"toto":                                "txo",
	"tii":                                 "txq",
	"tartessian":                          "txr",
	"tonsea":                              "txs",
	"citak":                               "txt",
	"kayapó":                              "txu",
	"tatana":                              "txx",
	"tanosy malagasy":                     "txy",
	"tauya":                               "tya",
	"kyanga":                              "tye",
	"o'du":                                "tyh",
	"teke-tsaayi":                         "tyi",
	"tai do":                              "tyj",
	"thu lao":                             "tyl",
	"kombai":                              "tyn",
	"thaypan":                             "typ",
	"tai daeng":                           "tyr",
	"tày sa pa":                           "tys",
	"tày tac":                             "tyt",
	"kua":                                 "tyu",
	"tuvinian":                            "tyv",
	"teke-tyee":                           "tyx",
	"tày":                                 "tyz",
	"tanzanian sign language":             "tza",
	"tzeltal":                             "tzh",
	"tz'utujil":                           "tzj",
	"talossan":                            "tzl",
	"central atlas tamazight":             "tzm",
	"tugun":                               "tzn",
	"tzotzil":                             "tzo",
	"tabriak":                             "tzx",
	"uamué":                               "uam",
	"kuan":                                "uan",
	"tairuma":                             "uar",
	"ubang":                               "uba",
	"ubi":                                 "ubi",
	"buhi'non bikol":                      "ubl",
	"ubir":                                "ubr",
	"umbu-ungu":                           "ubu",
	"ubykh":                               "uby",
	"uda":                                 "uda",
	"udihe":                               "ude",
	"muduga":                              "udg",
	"udi":                                 "udi",
	"ujir":                                "udj",
	"wuzlam":                              "udl",
	"udmurt":                              "udm",
	"uduk":                                "udu",
	"kioko":                               "ues",
	"ufim":                                "ufi",
	"ugaritic":                            "uga",
	"kuku-ugbanh":                         "ugb",
	"ughele":                              "uge",
	"ugandan sign language":               "ugn",
	"ugong":                               "ugo",
	"uruguayan sign language":             "ugy",
	"uhami":                               "uha",
	"damal":                               "uhn",
	"uighur":                              "uig",
	"uisai":                               "uis",
	"iyive":                               "uiv",
	"tanjijili":                           "uji",
	"kaburi":                              "uka",
	"ukuriguma":                           "ukg",
	"ukhwejo":                             "ukh",
	"muak sa-aak":                         "ukk",
	"ukrainian sign language":             "ukl",
	"ukpe-bayobiri":                       "ukp",
	"ukwa":                                "ukq",
	"ukrainian":                           "ukr",
	"urubú-kaapor sign language":          "uks",
	"ukue":                                "uku",
	"ukwuani-aboh-ndoni":                  "ukw",
	"kuuk-yak":                            "uky",
	"fungwa":                              "ula",
	"ulukwumi":                            "ulb",
	"ulch":                                "ulc",
	"lule":                                "ule",
	"usku":                                "ulf",
	"ulithian":                            "uli",
	"meriam":                              "ulk",
	"ullatan":                             "ull",
	"ulumanda'":                           "ulm",
	"unserdeutsch":                        "uln",
	"uma' lung":                           "ulu",
	"ulwa":                                "ulw",
	"umatilla":                            "uma",
	"umbundu":                             "umb",
	"marrucinian":                         "umc",
	"umbindhamu":                          "umd",
	"umbuygamu":                           "umg",
	"ukit":                                "umi",
	"umon":                                "umm",
	"makyan naga":                         "umn",
	"umotína":                             "umo",
	"umpila":                              "ump",
	"umbugarla":                           "umr",
	"pendau":                              "ums",
	"munsee":                              "umu",
	"north watut":                         "una",
	"undetermined":                        "und",
	"uneme":                               "une",
	"ngarinyin":                           "ung",
	"enawené-nawé":                        "unk",
	"unami":                               "unm",
	"kurnai":                              "unn",
	"mundari":                             "unr",
	"unubahe":                             "unu",
	"munda":                               "unx",
	"unde kaili":                          "unz",
	"umeda":                               "upi",
	"uripiv-wala-rano-atchin":             "upv",
	"urarina":                             "ura",
	"urubú-kaapor":                        "urb",
	"urningangg":                          "urc",
	"urdu":                                "urd",
	"uru":                                 "ure",
	"uradhi":                              "urf",
	"urigina":                             "urg",
	"urhobo":                              "urh",
	"urim":                                "uri",
	"urak lawoi'":                         "urk",
	"urali":                               "url",
	"urapmin":                             "urm",
	"uruangnirin":                         "urn",
	"ura (papua new guinea)":              "uro",
	"uru-pa-in":                           "urp",
	"lehalurup":                           "urr",
	"urat":                                "urt",
	"urumi":                               "uru",
	"uruava":                              "urv",
	"sop":                                 "urw",
	"urimo":                               "urx",
	"orya":                                "ury",
	"uru-eu-wau-wau":                      "urz",
	"usarufa":                             "usa",
	"ushojo":                              "ush",
	"usui":                                "usi",
	"usaghade":                            "usk",
	"uspanteco":                           "usp",
	"uya":                                 "usu",
	"otank":                               "uta",
	"ute-southern paiute":                 "ute",
	"amba (solomon islands)":              "utp",
	"etulo":                               "utr",
	"utu":                                 "utu",
	"urum":                                "uum",
	"kulon-pazeh":                         "uun",
	"ura (vanuatu)":                       "uur",
	"u":                                   "uuu",
	"west uvean":                          "uve",
	"uri":                                 "uvh",
	"lote":                                "uvl",
	"kuku-uwanh":                          "uwa",
	"doko-uyanga":                         "uya",
	"uzbek":                               "uzb",
	"northern uzbek":                      "uzn",
	"southern uzbek":                      "uzs",
	"vaagri booli":                        "vaa",
	"vale":                                "vae",
	"vafsi":                               "vaf",
	"vagla":                               "vag",
	"varhadi-nagpuri":                     "vah",
	"vai":                                 "vai",
	"sekele":                              "vaj",
	"vehes":                               "val",
	"vanimo":                              "vam",
	"valman":                              "van",
	"vao":                                 "vao",
	"vaiphei":                             "vap",
	"huarijio":                            "var",
	"vasavi":                              "vas",
	"vanuma":                              "vau",
	"varli":                               "vav",
	"wayu":                                "vay",
	"southeast babar":                     "vbb",
	"southwestern bontok":                 "vbk",
	"venetian":                            "vec",
	"veddah":                              "ved",
	"veluws":                              "vel",
	"vemgo-mabas":                         "vem",
	"venda":                               "ven",
	"ventureño":                           "veo",
	"veps":                                "vep",
	"mom jango":                           "ver",
	"vaghri":                              "vgr",
	"vlaamse gebarentaal":                 "vgt",
	"virgin islands creole english":       "vic",
	"vidunda":                             "vid",
	"vietnamese":                          "vie",
	"vili":                                "vif",
	"viemo":                               "vig",
	"vilela":                              "vil",
	"vinza":                               "vin",
	"vishavan":                            "vis",
	"viti":                                "vit",
	"iduna":                               "viv",
	"kariyarra":                           "vka",
	"ija-zuba":                            "vki",
	"kujarge":                             "vkj",
	"kaur":                                "vkk",
	"kulisusu":                            "vkl",
	"kamakan":                             "vkm",
	"kodeoha":                             "vko",
	"korlai creole portuguese":            "vkp",
	"tenggarong kutai malay":              "vkt",
	"kurrama":                             "vku",
	"valpei":                              "vlp",
	"vlaams":                              "vls",
	"martuyhunira":                        "vma",
	"barbaram":                            "vmb",
	"juxtlahuaca mixtec":                  "vmc",
	"mudu koraga":                         "vmd",
	"east masela":                         "vme",
	"mainfränkisch":                       "vmf",
	"lungalunga":                          "vmg",
	"maraghei":                            "vmh",
	"miwa":                                "vmi",
	"ixtayutla mixtec":                    "vmj",
	"makhuwa-shirima":                     "vmk",
	"malgana":                             "vml",
	"mitlatongo mixtec":                   "vmm",
	"soyaltepec mazatec":                  "vmp",
	"soyaltepec mixtec":                   "vmq",
	"marenje":                             "vmr",
	"moksela":                             "vms",
	"muluridyi":                           "vmu",
	"valley maidu":                        "vmv",
	"makhuwa":                             "vmw",
	"tamazola mixtec":                     "vmx",
	"ayautla mazatec":                     "vmy",
	"mazatlán mazatec":                    "vmz",
	"vano":                                "vnk",
	"vinmavis":                            "vnm",
	"vunapu":                              "vnp",
	"volapük":                             "vol",
	"voro":                                "vor",
	"votic":                               "vot",
	"vera'a":                              "vra",
	"võro":                                "vro",
	"varisi":                              "vrs",
	"burmbar":                             "vrt",
	"moldova sign language":               "vsi",
	"venezuelan sign language":            "vsl",
	"valencian sign language":             "vsv",
	"vitou":                               "vto",
	"vumbu":                               "vum",
	"vunjo":                               "vun",
	"vute":                                "vut",
	"awa (china)":                         "vwa",
	"walla walla":                         "waa",
	"wab":                                 "wab",
	"wasco-wishram":                       "wac",
	"wandamen":                            "wad",
	"walser":                              "wae",
	"wakoná":                              "waf",
	"wa'ema":                              "wag",
	"watubela":                            "wah",
	"wares":                               "wai",
	"waffa":                               "waj",
	"wolaytta":                            "wal",
	"wampanoag":                           "wam",
	"wan":                                 "wan",
	"wappo":                               "wao",
	"wapishana":                           "wap",
	"wageman":                             "waq",
	"waray (philippines)":                 "war",
	"washo":                               "was",
	"kaninuwa":                            "wat",
	"waurá":                               "wau",
	"waka":                                "wav",
	"waiwai":                              "waw",
	"watam":                               "wax",
	"wayana":                              "way",
	"wampur":                              "waz",
	"warao":                               "wba",
	"wabo":                                "wbb",
	"waritai":                             "wbe",
	"wara":                                "wbf",
	"wanda":                               "wbh",
	"vwanji":                              "wbi",
	"alagwa":                              "wbj",
	"waigali":                             "wbk",
	"wakhi":                               "wbl",
	"wa":                                  "wbm",
	"warlpiri":                            "wbp",
	"waddar":                              "wbq",
	"wagdi":                               "wbr",
	"west bengal sign language":           "wbs",
	"wanman":                              "wbt",
	"wajarri":                             "wbv",
	"woi":                                 "wbw",
	"yanomámi":                            "wca",
	"waci gbe":                            "wci",
	"wandji":                              "wdd",
	"wadaginam":                           "wdg",
	"wadjiginy":                           "wdj",
	"wadikali":                            "wdk",
	"wadjigu":                             "wdu",
	"wadjabangayi":                        "wdy",
	"wewaw":                               "wea",
	"wè western":                          "wec",
	"wedau":                               "wed",
	"wergaia":                             "weg",
	"weh":                                 "weh",
	"kiunum":                              "wei",
	"weme gbe":                            "wem",
	"wemale":                              "weo",
	"westphalien":                         "wep",
	"weri":                                "wer",
	"cameroon pidgin":                     "wes",
	"perai":                               "wet",
	"rawngtu chin":                        "weu",
	"wejewa":                              "wew",
	"yafi":                                "wfg",
	"wagaya":                              "wga",
	"wagawaga":                            "wgb",
	"wangganguru":                         "wgg",
	"wahgi":                               "wgi",
	"waigeo":                              "wgo",
	"wirangu":                             "wgu",
	"warrgamay":                           "wgy",
	"sou upaa":                            "wha",
	"north wahgi":                         "whg",
	"wahau kenyah":                        "whk",
	"wahau kayan":                         "whu",
	"southern toussian":                   "wib",
	"wichita":                             "wic",
	"wik-epa":                             "wie",
	"wik-keyangan":                        "wif",
	"wik-ngathana":                        "wig",
	"wik-me'anha":                         "wih",
	"minidien":                            "wii",
	"wik-iiyanh":                          "wij",
	"wikalkan":                            "wik",
	"wilawila":                            "wil",
	"wik-mungkan":                         "wim",
	"ho-chunk":                            "win",
	"wiraféd":                             "wir",
	"wiru":                                "wiu",
	"vitu":                                "wiv",
	"wiyot":                               "wiy",
	"waja":                                "wja",
	"warji":                               "wji",
	"kw'adza":                             "wka",
	"kumbaran":                            "wkb",
	"wakde":                               "wkd",
	"kalanadi":                            "wkl",
	"kunduvadi":                           "wku",
	"wakawaka":                            "wkw",
	"wangkayutyuru":                       "wky",
	"walio":                               "wla",
	"mwali comorian":                      "wlc",
	"wolane":                              "wle",
	"kunbarlang":                          "wlg",
	"waioli":                              "wli",
	"wailaki":                             "wlk",
	"wali (sudan)":                        "wll",
	"middle welsh":                        "wlm",
	"walloon":                             "wln",
	"wolio":                               "wlo",
	"wailapa":                             "wlr",
	"wallisian":                           "wls",
	"wuliwuli":                            "wlu",
	"wichí lhamtés vejoz":                 "wlv",
	"walak":                               "wlw",
	"wali (ghana)":                        "wlx",
	"waling":                              "wly",
	"mawa (nigeria)":                      "wma",
	"wambaya":                             "wmb",
	"wamas":                               "wmc",
	"mamaindé":                            "wmd",
	"wambule":                             "wme",
	"waima'a":                             "wmh",
	"wamin":                               "wmi",
	"maiwa (indonesia)":                   "wmm",
	"waamwang":                            "wmn",
	"wom (papua new guinea)":              "wmo",
	"wambon":                              "wms",
	"walmajarri":                          "wmt",
	"mwani":                               "wmw",
	"womo":                                "wmx",
	"wanambre":                            "wnb",
	"wantoat":                             "wnc",
	"wandarang":                           "wnd",
	"waneci":                              "wne",
	"wanggom":                             "wng",
	"ndzwani comorian":                    "wni",
	"wanukaka":                            "wnk",
	"wanggamala":                          "wnm",
	"wunumara":                            "wnn",
	"wano":                                "wno",
	"wanap":                               "wnp",
	"usan":                                "wnu",
	"wintu":                               "wnw",
	"wanyi":                               "wny",
	"tyaraity":                            "woa",
	"wè northern":                         "wob",
	"wogeo":                               "woc",
	"wolani":                              "wod",
	"woleaian":                            "woe",
	"gambian wolof":                       "wof",
	"wogamusin":                           "wog",
	"kamang":                              "woi",
	"longto":                              "wok",
	"wolof":                               "wol",
	"wom (nigeria)":                       "wom",
	"wongo":                               "won",
	"manombai":                            "woo",
	"woria":                               "wor",
	"hanga hundi":                         "wos",
	"wawonii":                             "wow",
	"weyto":                               "woy",
	"maco":                                "wpc",
	"warapu":                              "wra",
	"warluwara":                           "wrb",
	"warduji":                             "wrd",
	"warungu":                             "wrg",
	"wiradhuri":                           "wrh",
	"wariyangga":                          "wri",
	"garrwa":                              "wrk",
	"warlmanpa":                           "wrl",
	"warumungu":                           "wrm",
	"warnang":                             "wrn",
	"worrorra":                            "wro",
	"waropen":                             "wrp",
	"wardaman":                            "wrr",
	"waris":                               "wrs",
	"waru":                                "wru",
	"waruna":                              "wrv",
	"gugu warra":                          "wrw",
	"wae rana":                            "wrx",
	"merwari":                             "wry",
	"waray (australia)":                   "wrz",
	"warembori":                           "wsa",
	"adilabad gondi":                      "wsg",
	"wusi":                                "wsi",
	"waskia":                              "wsk",
	"owenia":                              "wsr",
	"wasa":                                "wss",
	"wasu":                                "wsu",
	"wotapuri-katarqalai":                 "wsv",
	"watiwa":                              "wtf",
	"wathawurrung":                        "wth",
	"berta":                               "wti",
	"watakataui":                          "wtk",
	"mewati":                              "wtm",
	"wotu":                                "wtw",
	"wikngenchera":                        "wua",
	"wunambal":                            "wub",
	"wudu":                                "wud",
	"wutunhua":                            "wuh",
	"silimo":                              "wul",
	"wumbvu":                              "wum",
	"bungu":                               "wun",
	"wurrugu":                             "wur",
	"wutung":                              "wut",
	"wu chinese":                          "wuu",
	"wuvulu-aua":                          "wuv",
	"wulna":                               "wux",
	"wauyai":                              "wuy",
	"waama":                               "wwa",
	"wakabunga":                           "wwb",
	"wetamut":                             "wwo",
	"warrwa":                              "wwr",
	"wawa":                                "www",
	"waxianghua":                          "wxa",
	"wardandi":                            "wxw",
	"wyandot":                             "wya",
	"wangaaybuwan-ngiyambaa":              "wyb",
	"woiwurrung":                          "wyi",
	"wymysorys":                           "wym",
	"wayoró":                              "wyr",
	"western fijian":                      "wyy",
	"andalusian arabic":                   "xaa",
	"sambe":                               "xab",
	"kachari":                             "xac",
	"adai":                                "xad",
	"aequian":                             "xae",
	"aghwan":                              "xag",
	"kaimbé":                              "xai",
	"ararandewára":                        "xaj",
	"máku":                                "xak",
	"kalmyk":                              "xal",
	"/xam":                                "xam",
	"xamtanga":                            "xan",
	"khao":                                "xao",
	"apalachee":                           "xap",
	"aquitanian":                          "xaq",
	"karami":                              "xar",
	"kamas":                               "xas",
	"katawixi":                            "xat",
	"kauwera":                             "xau",
	"xavánte":                             "xav",
	"kawaiisu":                            "xaw",
	"kayan mahakam":                       "xay",
	"lower burdekin":                      "xbb",
	"bactrian":                            "xbc",
	"bindal":                              "xbd",
	"bigambal":                            "xbe",
	"bunganditj":                          "xbg",
	"kombio":                              "xbi",
	"birrpayi":                            "xbj",
	"middle breton":                       "xbm",
	"kenaboi":                             "xbn",
	"bolgarian":                           "xbo",
	"bibbulman":                           "xbp",
	"kambera":                             "xbr",
	"kambiwá":                             "xbw",
	"batyala":                             "xby",
	"cumbric":                             "xcb",
	"camunic":                             "xcc",
	"celtiberian":                         "xce",
	"cisalpine gaulish":                   "xcg",
	"chemakum":                            "xch",
	"classical armenian":                  "xcl",
	"comecrudo":                           "xcm",
	"cotoname":                            "xcn",
	"chorasmian":                          "xco",
	"carian":                              "xcr",
	"classical tibetan":                   "xct",
	"curonian":                            "xcu",
	"chuvantsy":                           "xcv",
	"coahuilteco":                         "xcw",
	"cayuse":                              "xcy",
	"darkinyung":                          "xda",
	"dacian":                              "xdc",
	"dharuk":                              "xdk",
	"edomite":                             "xdm",
	"kwandu":                              "xdo",
	"malayic dayak":                       "xdy",
	"eblan":                               "xeb",
	"hdi":                                 "xed",
	"//xegwi":                             "xeg",
	"kelo":                                "xel",
	"kembayan":                            "xem",
	"epi-olmec":                           "xep",
	"xerénte":                             "xer",
	"kesawai":                             "xes",
	"xetá":                                "xet",
	"keoru-ahia":                          "xeu",
	"faliscan":                            "xfa",
	"galatian":                            "xga",
	"gbin":                                "xgb",
	"gudang":                              "xgd",
	"gabrielino-fernandeño":               "xgf",
	"goreng":                              "xgg",
	"garingbal":                           "xgi",
	"galindan":                            "xgl",
	"dharumbal":                           "xgm",
	"garza":                               "xgr",
	"unggumi":                             "xgu",
	"guwa":                                "xgw",
	"harami":                              "xha",
	"hunnic":                              "xhc",
	"hadrami":                             "xhd",
	"khetrani":                            "xhe",
	"xhosa":                               "xho",
	"hernican":                            "xhr",
	"hattic":                              "xht",
	"hurrian":                             "xhu",
	"khua":                                "xhv",
	"iberian":                             "xib",
	"xiri":                                "xii",
	"illyrian":                            "xil",
	"xinca":                               "xin",
	"xiriâna":                             "xir",
	"kisan":                               "xis",
	"indus valley language":               "xiv",
	"xipaya":                              "xiy",
	"minjungbal":                          "xjb",
	"jaitmatang":                          "xjt",
	"kalkoti":                             "xka",
	"northern nago":                       "xkb",
	"kho'ini":                             "xkc",
	"mendalam kayan":                      "xkd",
	"kereho":                              "xke",
	"khengkha":                            "xkf",
	"kagoro":                              "xkg",
	"kenyan sign language":                "xki",
	"kajali":                              "xkj",
	"kaco'":                               "xkk",
	"mainstream kenyah":                   "xkl",
	"kayan river kayan":                   "xkn",
	"kiorr":                               "xko",
	"kabatei":                             "xkp",
	"koroni":                              "xkq",
	"xakriabá":                            "xkr",
	"kumbewaha":                           "xks",
	"kantosi":                             "xkt",
	"kaamba":                              "xku",
	"kgalagadi":                           "xkv",
	"kembra":                              "xkw",
	"karore":                              "xkx",
	"uma' lasan":                          "xky",
	"kurtokha":                            "xkz",
	"kamula":                              "xla",
	"loup b":                              "xlb",
	"lycian":                              "xlc",
	"lydian":                              "xld",
	"lemnian":                             "xle",
	"ligurian (ancient)":                  "xlg",
	"liburnian":                           "xli",
	"alanic":                              "xln",
	"loup a":                              "xlo",
	"lepontic":                            "xlp",
	"lusitanian":                          "xls",
	"cuneiform luwian":                    "xlu",
	"elymian":                             "xly",
	"mushungulu":                          "xma",
	"mbonga":                              "xmb",
	"makhuwa-marrevone":                   "xmc",
	"mbudum":                              "xmd",
	"median":                              "xme",
	"mingrelian":                          "xmf",
	"mengaka":                             "xmg",
	"kuku-muminh":                         "xmh",
	"majera":                              "xmj",
	"ancient macedonian":                  "xmk",
	"malaysian sign language":             "xml",
	"manado malay":                        "xmm",
	"manichaean middle persian":           "xmn",
	"morerebi":                            "xmo",
	"kuku-mu'inh":                         "xmp",
	"kuku-mangk":                          "xmq",
	"meroitic":                            "xmr",
	"moroccan sign language":              "xms",
	"matbat":                              "xmt",
	"kamu":                                "xmu",
	"antankarana malagasy":                "xmv",
	"tsimihety malagasy":                  "xmw",
	"maden":                               "xmx",
	"mayaguduna":                          "xmy",
	"mori bawah":                          "xmz",
	"ancient north arabian":               "xna",
	"kanakanabu":                          "xnb",
	"middle mongolian":                    "xng",
	"kuanhua":                             "xnh",
	"ngarigu":                             "xni",
	"nganakarti":                          "xnk",
	"northern kankanay":                   "xnn",
	"anglo-norman":                        "xno",
	"kangri":                              "xnr",
	"kanashi":                             "xns",
	"narragansett":                        "xnt",
	"nukunul":                             "xnu",
	"nyiyaparli":                          "xny",
	"kenzi":                               "xnz",
	"o'chi'chi'":                          "xoc",
	"kokoda":                              "xod",
	"soga":                                "xog",
	"kominimung":                          "xoi",
	"xokleng":                             "xok",
	"komo (sudan)":                        "xom",
	"konkomba":                            "xon",
	"xukurú":                              "xoo",
	"kopar":                               "xop",
	"korubo":                              "xor",
	"kowaki":                              "xow",
	"pirriya":                             "xpa",
	"pecheneg":                            "xpc",
	"liberia kpelle":                      "xpe",
	"phrygian":                            "xpg",
	"pictish":                             "xpi",
	"mpalitjanh":                          "xpj",
	"kulina pano":                         "xpk",
	"pumpokol":                            "xpm",
	"kapinawá":                            "xpn",
	"pochutec":                            "xpo",
	"puyo-paekche":                        "xpp",
	"mohegan-pequot":                      "xpq",
	"parthian":                            "xpr",
	"pisidian":                            "xps",
	"punthamara":                          "xpt",
	"punic":                               "xpu",
	"puyo":                                "xpy",
	"karakhanid":                          "xqa",
	"qatabanian":                          "xqt",
	"krahô":                               "xra",
	"eastern karaboro":                    "xrb",
	"gundungurra":                         "xrd",
	"kreye":                               "xre",
	"minang":                              "xrg",
	"krikati-timbira":                     "xri",
	"armazic":                             "xrm",
	"arin":                                "xrn",
	"karranga":                            "xrq",
	"raetic":                              "xrr",
	"aranama-tamique":                     "xrt",
	"marriammu":                           "xru",
	"karawa":                              "xrw",
	"sabaean":                             "xsa",
	"sambal":                              "xsb",
	"scythian":                            "xsc",
	"sidetic":                             "xsd",
	"sempan":                              "xse",
	"shamang":                             "xsh",
	"sio":                                 "xsi",
	"south slavey":                        "xsl",
	"kasem":                               "xsm",
	"sanga (nigeria)":                     "xsn",
	"solano":                              "xso",
	"silopi":                              "xsp",
	"makhuwa-saka":                        "xsq",
	"sherpa":                              "xsr",
	"assan":                               "xss",
	"sanumá":                              "xsu",
	"sudovian":                            "xsv",
	"saisiyat":                            "xsy",
	"alcozauca mixtec":                    "xta",
	"chazumba mixtec":                     "xtb",
	"katcha-kadugli-miri":                 "xtc",
	"diuxi-tilantongo mixtec":             "xtd",
	"ketengban":                           "xte",
	"transalpine gaulish":                 "xtg",
	"yitha yitha":                         "xth",
	"sinicahua mixtec":                    "xti",
	"san juan teita mixtec":               "xtj",
	"tijaltepec mixtec":                   "xtl",
	"magdalena peñasco mixtec":            "xtm",
	"northern tlaxiaco mixtec":            "xtn",
	"tokharian a":                         "xto",
	"san miguel piedras mixtec":           "xtp",
	"tumshuqese":                          "xtq",
	"early tripuri":                       "xtr",
	"sindihui mixtec":                     "xts",
	"tacahua mixtec":                      "xtt",
	"cuyamecalco mixtec":                  "xtu",
	"thawa":                               "xtv",
	"tawandê":                             "xtw",
	"yoloxochitl mixtec":                  "xty",
	"tasmanian":                           "xtz",
	"alu kurumba":                         "xua",
	"betta kurumba":                       "xub",
	"umiida":                              "xud",
	"kunigami":                            "xug",
	"jennu kurumba":                       "xuj",
	"ngunawal":                            "xul",
	"umbrian":                             "xum",
	"unggaranggu":                         "xun",
	"kuo":                                 "xuo",
	"upper umpqua":                        "xup",
	"urartian":                            "xur",
	"kuthant":                             "xut",
	"kxoe":                                "xuu",
	"venetic":                             "xve",
	"kamviri":                             "xvi",
	"vandalic":                            "xvn",
	"volscian":                            "xvo",
	"vestinian":                           "xvs",
	"kwaza":                               "xwa",
	"woccon":                              "xwc",
	"wadi wadi":                           "xwd",
	"xwela gbe":                           "xwe",
	"kwegu":                               "xwg",
	"wajuk":                               "xwj",
	"wangkumara":                          "xwk",
	"western xwla gbe":                    "xwl",
	"written oirat":                       "xwo",
	"kwerba mamberamo":                    "xwr",
	"wotjobaluk":                          "xwt",
	"wemba wemba":                         "xww",
	"boro (ghana)":                        "xxb",
	"ke'o":                                "xxk",
	"minkin":                              "xxm",
	"koropó":                              "xxr",
	"tambora":                             "xxt",
	"yaygir":                              "xya",
	"yandjibara":                          "xyb",
	"mayi-yapi":                           "xyj",
	"mayi-kulan":                          "xyk",
	"yalakalore":                          "xyl",
	"mayi-thakurti":                       "xyt",
	"yorta yorta":                         "xyy",
	"zhang-zhung":                         "xzh",
	"zemgalian":                           "xzm",
	"ancient zapotec":                     "xzp",
	"yaminahua":                           "yaa",
	"yuhup":                               "yab",
	"pass valley yali":                    "yac",
	"yagua":                               "yad",
	"pumé":                                "yae",
	"yaka (democratic republic of congo)": "yaf",
	"yámana":                              "yag",
	"yazgulyam":                           "yah",
	"yagnobi":                             "yai",
	"banda-yangere":                       "yaj",
	"yakama":                              "yak",
	"yalunka":                             "yal",
	"yamba":                               "yam",
	"mayangna":                            "yan",
	"yao":                                 "yao",
	"yapese":                              "yap",
	"yaqui":                               "yaq",
	"yabarana":                            "yar",
	"nugunu (cameroon)":                   "yas",
	"yambeta":                             "yat",
	"yuwana":                              "yau",
	"yangben":                             "yav",
	"yawalapití":                          "yaw",
	"yauma":                               "yax",
	"agwagwune":                           "yay",
	"lokaa":                               "yaz",
	"yala":                                "yba",
	"yemba":                               "ybb",
	"west yugur":                          "ybe",
	"yakha":                               "ybh",
	"yamphu":                              "ybi",
	"hasha":                               "ybj",
	"bokha":                               "ybk",
	"yukuben":                             "ybl",
	"yaben":                               "ybm",
	"yabaâna":                             "ybn",
	"yabong":                              "ybo",
	"yawiyo":                              "ybx",
	"yaweyuha":                            "yby",
	"chesu":                               "ych",
	"lolopo":                              "ycl",
	"yucuna":                              "ycn",
	"chepya":                              "ycp",
	"yanda":                               "yda",
	"eastern yiddish":                     "ydd",
	"yangum dey":                          "yde",
	"yidgha":                              "ydg",
	"yoidik":                              "ydk",
	"ravula":                              "yea",
	"yeniche":                             "yec",
	"yimas":                               "yee",
	"yeni":                                "yei",
	"yevanic":                             "yej",
	"yela":                                "yel",
	"tarok":                               "yer",
	"nyankpa":                             "yes",
	"yetfa":                               "yet",
	"yerukula":                            "yeu",
	"yapunda":                             "yev",
	"yeyi":                                "yey",
	"malyangapa":                          "yga",
	"yiningayi":                           "ygi",
	"yangum gel":                          "ygl",
	"yagomi":                              "ygm",
	"gepo":                                "ygp",
	"yagaria":                             "ygr",
	"yolŋu sign language":                 "ygs",
	"yugul":                               "ygu",
	"yagwoia":                             "ygw",
	"baha buyang":                         "yha",
	"judeo-iraqi arabic":                  "yhd",
	"hlepho phowa":                        "yhl",
	"yan-nhaŋu sign language":             "yhs",
	"yinggarda":                           "yia",
	"yiddish":                             "yid",
	"ache":                                "yif",
	"wusa nasu":                           "yig",
	"western yiddish":                     "yih",
	"yidiny":                              "yii",
	"yindjibarndi":                        "yij",
	"dongshanba lalo":                     "yik",
	"yindjilandji":                        "yil",
	"yimchungru naga":                     "yim",
	"yinchia":                             "yin",
	"pholo":                               "yip",
	"miqie":                               "yiq",
	"north awyu":                          "yir",
	"yis":                                 "yis",
	"eastern lalu":                        "yit",
	"awu":                                 "yiu",
	"northern nisu":                       "yiv",
	"axi yi":                              "yix",
	"azhe":                                "yiz",
	"yakan":                               "yka",
	"northern yukaghir":                   "ykg",
	"yoke":                                "yki",
	"yakaikeke":                           "ykk",
	"khlula":                              "ykl",
	"kap":                                 "ykm",
	"kua-nsi":                             "ykn",
	"yasa":                                "yko",
	"yekora":                              "ykr",
	"kathu":                               "ykt",
	"kuamasi":                             "yku",
	"yakoma":                              "yky",
	"yaul":                                "yla",
	"yaleba":                              "ylb",
	"yele":                                "yle",
	"yelogu":                              "ylg",
	"angguruk yali":                       "yli",
	"yil":                                 "yll",
	"limi":                                "ylm",
	"langnian buyang":                     "yln",
	"naluo yi":                            "ylo",
	"yalarnnga":                           "ylr",
	"aribwaung":                           "ylu",
	"nyâlayu":                             "yly",
	"yambes":                              "ymb",
	"southern muji":                       "ymc",
	"muda":                                "ymd",
	"yameo":                               "yme",
	"yamongeri":                           "ymg",
	"mili":                                "ymh",
	"moji":                                "ymi",
	"makwe":                               "ymk",
	"iamalele":                            "yml",
	"maay":                                "ymm",
	"yamna":                               "ymn",
	"yangum mon":                          "ymo",
	"yamap":                               "ymp",
	"qila muji":                           "ymq",
	"malasar":                             "ymr",
	"mysian":                              "yms",
	"northern muji":                       "ymx",
	"muzi":                                "ymz",
	"aluo":                                "yna",
	"yandruwandha":                        "ynd",
	"lang'e":                              "yne",
	"yango":                               "yng",
	"naukan yupik":                        "ynk",
	"yangulam":                            "ynl",
	"yana":                                "ynn",
	"yong":                                "yno",
	"yendang":                             "ynq",
	"yansi":                               "yns",
	"yahuna":                              "ynu",
	"yoba":                                "yob",
	"yogad":                               "yog",
	"yonaguni":                            "yoi",
	"yokuts":                              "yok",
	"yola":                                "yol",
	"yombe":                               "yom",
	"yongkom":                             "yon",
	"yoruba":                              "yor",
	"yotti":                               "yot",
	"yoron":                               "yox",
	"yoy":                                 "yoy",
	"phala":                               "ypa",
	"labo phowa":                          "ypb",
	"phola":                               "ypg",
	"phupha":                              "yph",
	"phuma":                               "ypm",
	"ani phowa":                           "ypn",
	"alo phola":                           "ypo",
	"phupa":                               "ypp",
	"phuza":                               "ypz",
	"yerakai":                             "yra",
	"yareba":                              "yrb",
	"yaouré":                              "yre",
	"nenets":                              "yrk",
	"nhengatu":                            "yrl",
	"yirrk-mel":                           "yrm",
	"yerong":                              "yrn",
	"yaroamë":                             "yro",
	"yarsun":                              "yrs",
	"yarawata":                            "yrw",
	"yarluyandi":                          "yry",
	"yassic":                              "ysc",
	"samatao":                             "ysd",
	"sonaga":                              "ysg",
	"yugoslavian sign language":           "ysl",
	"sani":                                "ysn",
	"nisi (china)":                        "yso",
	"southern lolopo":                     "ysp",
	"sirenik yupik":                       "ysr",
	"yessan-mayo":                         "yss",
	"sanie":                               "ysy",
	"talu":                                "yta",
	"tanglang":                            "ytl",
	"thopho":                              "ytp",
	"yout wam":                            "ytw",
	"yatay":                               "yty",
	"yucateco":                            "yua",
	"yugambal":                            "yub",
	"yuchi":                               "yuc",
	"judeo-tripolitanian arabic":          "yud",
	"yue chinese":                         "yue",
	"havasupai-walapai-yavapai":           "yuf",
	"yug":                                 "yug",
	"yurutí":                              "yui",
	"karkar-yuri":                         "yuj",
	"yuki":                                "yuk",
	"yulu":                                "yul",
	"quechan":                             "yum",
	"bena (nigeria)":                      "yun",
	"yukpa":                               "yup",
	"yuqui":                               "yuq",
	"yurok":                               "yur",
	"yopno":                               "yut",
	"yau (morobe province)":               "yuw",
	"southern yukaghir":                   "yux",
	"east yugur":                          "yuy",
	"yuracare":                            "yuz",
	"yawa":                                "yva",
	"yavitero":                            "yvt",
	"kalou":                               "ywa",
	"yinhawangka":                         "ywg",
	"western lalu":                        "ywl",
	"yawanawa":                            "ywn",
	"wuding-luquan yi":                    "ywq",
	"yawuru":                              "ywr",
	"xishanba lalo":                       "ywt",
	"wumeng nasu":                         "ywu",
	"yawarawarga":                         "yww",
	"mayawali":                            "yxa",
	"yagara":                              "yxg",
	"yardliyawarra":                       "yxl",
	"yinwum":                              "yxm",
	"yuyu":                                "yxu",
	"yabula yabula":                       "yxy",
	"yir yoront":                          "yyr",
	"yau (sandaun province)":              "yyu",
	"ayizi":                               "yyz",
	"e'ma buyang":                         "yzg",
	"zokhuo":                              "yzk",
	"sierra de juárez zapotec":            "zaa",
	"western tlacolula valley zapotec":    "zab",
	"ocotlán zapotec":                     "zac",
	"cajonos zapotec":                     "zad",
	"yareni zapotec":                      "zae",
	"ayoquesco zapotec":                   "zaf",
	"zaghawa":                             "zag",
	"zangwal":                             "zah",
	"isthmus zapotec":                     "zai",
	"zaramo":                              "zaj",
	"zanaki":                              "zak",
	"zauzou":                              "zal",
	"miahuatlán zapotec":                  "zam",
	"ozolotepec zapotec":                  "zao",
	"zapotec":                             "zap",
	"aloápam zapotec":                     "zaq",
	"rincón zapotec":                      "zar",
	"santo domingo albarradas zapotec":    "zas",
	"tabaa zapotec":                       "zat",
	"zangskari":                           "zau",
	"yatzachi zapotec":                    "zav",
	"mitla zapotec":                       "zaw",
	"xadani zapotec":                      "zax",
	"zayse-zergulla":                      "zay",
	"zari":                                "zaz",
	"central berawan":                     "zbc",
	"east berawan":                        "zbe",
	"blissymbols":                         "zbl",
	"batui":                               "zbt",
	"west berawan":                        "zbw",
	"coatecas altas zapotec":              "zca",
	"central hongshuihe zhuang":           "zch",
	"ngazidja comorian":                   "zdj",
	"zeeuws":                              "zea",
	"zenag":                               "zeg",
	"eastern hongshuihe zhuang":           "zeh",
	"zenaga":                              "zen",
	"kinga":                               "zga",
	"guibei zhuang":                       "zgb",
	"standard moroccan tamazight":         "zgh",
	"minz zhuang":                         "zgm",
	"guibian zhuang":                      "zgn",
	"magori":                              "zgr",
	"zhuang":                              "zha",
	"zhaba":                               "zhb",
	"dai zhuang":                          "zhd",
	"zhire":                               "zhi",
	"nong zhuang":                         "zhn",
	"chinese":                             "zho",
	"zhoa":                                "zhw",
	"zia":                                 "zia",
	"zimbabwe sign language":              "zib",
	"zimakani":                            "zik",
	"zialo":                               "zil",
	"mesme":                               "zim",
	"zinza":                               "zin",
	"ziriya":                              "zir",
	"zigula":                              "ziw",
	"zizilivakan":                         "ziz",
	"kaimbulawa":                          "zka",
	"koibal":                              "zkb",
	"kadu":                                "zkd",
	"koguryo":                             "zkg",
	"khorezmian":                          "zkh",
	"karankawa":                           "zkk",
	"kanan":                               "zkn",
	"kott":                                "zko",
	"são paulo kaingáng":                  "zkp",
	"zakhring":                            "zkr",
	"kitan":                               "zkt",
	"kaurna":                              "zku",
	"krevinian":                           "zkv",
	"khazar":                              "zkz",
	"liujiang zhuang":                     "zlj",
	"malay (individual language)":         "zlm",
	"lianshan zhuang":                     "zln",
	"liuqian zhuang":                      "zlq",
	"manda (australia)":                   "zma",
	"zimba":                               "zmb",
	"margany":                             "zmc",
	"maridan":                             "zmd",
	"mangerr":                             "zme",
	"mfinu":                               "zmf",
	"marti ke":                            "zmg",
	"makolkol":                            "zmh",
	"negeri sembilan malay":               "zmi",
	"maridjabin":                          "zmj",
	"mandandanyi":                         "zmk",
	"madngele":                            "zml",
	"marimanindji":                        "zmm",
	"mbangwe":                             "zmn",
	"molo":                                "zmo",
	"mpuono":                              "zmp",
	"mituku":                              "zmq",
	"maranunggu":                          "zmr",
	"mbesa":                               "zms",
	"maringarr":                           "zmt",
	"muruwari":                            "zmu",
	"mbariman-gudhinma":                   "zmv",
	"mbo (democratic republic of congo)":  "zmw",
	"bomitaba":                            "zmx",
	"mariyedi":                            "zmy",
	"mbandja":                             "zmz",
	"zan gula":                            "zna",
	"zande (individual language)":         "zne",
	"mang":                                "zng",
	"manangkari":                          "znk",
	"mangas":                              "zns",
	"copainalá zoque":                     "zoc",
	"chimalapa zoque":                     "zoh",
	"zou":                                 "zom",
	"asunción mixtepec zapotec":           "zoo",
	"tabasco zoque":                       "zoq",
	"rayón zoque":                         "zor",
	"francisco león zoque":                "zos",
	"lachiguiri zapotec":                  "zpa",
	"yautepec zapotec":                    "zpb",
	"choapan zapotec":                     "zpc",
	"southeastern ixtlán zapotec":         "zpd",
	"petapa zapotec":                      "zpe",
	"san pedro quiatoni zapotec":          "zpf",
	"guevea de humboldt zapotec":          "zpg",
	"totomachapan zapotec":                "zph",
	"santa maría quiegolani zapotec":      "zpi",
	"quiavicuzas zapotec":                 "zpj",
	"tlacolulita zapotec":                 "zpk",
	"lachixío zapotec":                    "zpl",
	"mixtepec zapotec":                    "zpm",
	"santa inés yatzechi zapotec":         "zpn",
	"amatlán zapotec":                     "zpo",
	"el alto zapotec":                     "zpp",
	"zoogocho zapotec":                    "zpq",
	"santiago xanica zapotec":             "zpr",
	"coatlán zapotec":                     "zps",
	"san vicente coatlán zapotec":         "zpt",
	"yalálag zapotec":                     "zpu",
	"chichicapan zapotec":                 "zpv",
	"zaniza zapotec":                      "zpw",
	"san baltazar loxicha zapotec":        "zpx",
	"mazaltepec zapotec":                  "zpy",
	"texmelucan zapotec":                  "zpz",
	"qiubei zhuang":                       "zqe",
	"kara (korea)":                        "zra",
	"mirgan":                              "zrg",
	"zerenkel":                            "zrn",
	"záparo":                              "zro",
	"zarphatic":                           "zrp",
	"mairasi":                             "zrs",
	"sarasira":                            "zsa",
	"kaskean":                             "zsk",
	"zambian sign language":               "zsl",
	"standard malay":                      "zsm",
	"southern rincon zapotec":             "zsr",
	"sukurum":                             "zsu",
	"elotepec zapotec":                    "zte",
	"xanaguía zapotec":                    "ztg",
	"lapaguía-guivini zapotec":            "ztl",
	"san agustín mixtepec zapotec":        "ztm",
	"santa catarina albarradas zapotec":   "ztn",
	"loxicha zapotec":                     "ztp",
	"quioquitani-quierí zapotec":          "ztq",
	"tilquiapan zapotec":                  "zts",
	"tejalapan zapotec":                   "ztt",
	"güilá zapotec":                       "ztu",
	"zaachila zapotec":                    "ztx",
	"yatee zapotec":                       "zty",
	"zeem":                                "zua",
	"tokano":                              "zuh",
	"zulu":                                "zul",
	"kumzari":                             "zum",
	"zuni":                                "zun",
	"zumaya":                              "zuy",
	"zay":                                 "zwa",
	"no linguistic content":               "zxx",
	"yongbei zhuang":                      "zyb",
	"yang zhuang":                         "zyg",
	"youjiang zhuang":                     "zyj",
	"yongnan zhuang":                      "zyn",
	"zyphe chin":                          "zyp",
	"zaza":                                "zza",
	"zuojiang zhuang":                     "zzj",
}
